# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import air_tasking_order_tuple_params, air_tasking_order_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.air_tasking_order_full import AirTaskingOrderFull
from ..types.air_tasking_order_tuple_response import AirTaskingOrderTupleResponse

__all__ = ["AirTaskingOrdersResource", "AsyncAirTaskingOrdersResource"]


class AirTaskingOrdersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AirTaskingOrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AirTaskingOrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AirTaskingOrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AirTaskingOrdersResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        begin_ts: Union[str, datetime],
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        op_exer_name: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        ack_req_ind: str | NotGiven = NOT_GIVEN,
        ack_unit_instructions: str | NotGiven = NOT_GIVEN,
        ac_msn_tasking: Iterable[air_tasking_order_create_params.AcMsnTasking] | NotGiven = NOT_GIVEN,
        end_ts: Union[str, datetime] | NotGiven = NOT_GIVEN,
        gen_text: Iterable[air_tasking_order_create_params.GenText] | NotGiven = NOT_GIVEN,
        msg_month: str | NotGiven = NOT_GIVEN,
        msg_originator: str | NotGiven = NOT_GIVEN,
        msg_qualifier: str | NotGiven = NOT_GIVEN,
        msg_sn: str | NotGiven = NOT_GIVEN,
        naval_flt_ops: Iterable[air_tasking_order_create_params.NavalFltOp] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single airtaskingorder record as a POST body and
        ingest into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          begin_ts: The effective begin time for this ATO in ISO 8601 UTC format with millisecond
              precision.

          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          op_exer_name: Specifies the unique operation or exercise name, nickname, or codeword assigned
              to a joint exercise or operation plan.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          ack_req_ind: The indicator specifying an affirmative or a negatice condition for this
              message.

          ack_unit_instructions: Specifies textual data amplifying the data contained in the acknowledgement
              requirement indicator (ackRedInd) field or the unit required to acknowledge.

          ac_msn_tasking: A collection that specifies the tasked country, tasked service, unit and mission
              level tasking for this ATO.

          end_ts: The effective end time for this ATO in ISO 8601 UTC format with millisecond
              precision.

          gen_text: A collection that details special instructions, important information, guidance,
              and amplifying information regarding this ATO.

          msg_month: The month in which the message originated.

          msg_originator: The identifier of the originator of the message.

          msg_qualifier: The qualifier which caveats the message status.

          msg_sn: The unique message identifier sequentially assigned by the originator.

          naval_flt_ops: A collection that specifies the naval flight operations for this ATO.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/airtaskingorder",
            body=maybe_transform(
                {
                    "begin_ts": begin_ts,
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "op_exer_name": op_exer_name,
                    "source": source,
                    "id": id,
                    "ack_req_ind": ack_req_ind,
                    "ack_unit_instructions": ack_unit_instructions,
                    "ac_msn_tasking": ac_msn_tasking,
                    "end_ts": end_ts,
                    "gen_text": gen_text,
                    "msg_month": msg_month,
                    "msg_originator": msg_originator,
                    "msg_qualifier": msg_qualifier,
                    "msg_sn": msg_sn,
                    "naval_flt_ops": naval_flt_ops,
                    "origin": origin,
                },
                air_tasking_order_create_params.AirTaskingOrderCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AirTaskingOrderFull:
        """
        Service operation to get a single airtaskingorder record by its unique ID passed
        as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/airtaskingorder/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AirTaskingOrderFull,
        )

    def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/airtaskingorder/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def query_help(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/airtaskingorder/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AirTaskingOrderTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/airtaskingorder/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"columns": columns}, air_tasking_order_tuple_params.AirTaskingOrderTupleParams),
            ),
            cast_to=AirTaskingOrderTupleResponse,
        )


class AsyncAirTaskingOrdersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAirTaskingOrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAirTaskingOrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAirTaskingOrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncAirTaskingOrdersResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        begin_ts: Union[str, datetime],
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        op_exer_name: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        ack_req_ind: str | NotGiven = NOT_GIVEN,
        ack_unit_instructions: str | NotGiven = NOT_GIVEN,
        ac_msn_tasking: Iterable[air_tasking_order_create_params.AcMsnTasking] | NotGiven = NOT_GIVEN,
        end_ts: Union[str, datetime] | NotGiven = NOT_GIVEN,
        gen_text: Iterable[air_tasking_order_create_params.GenText] | NotGiven = NOT_GIVEN,
        msg_month: str | NotGiven = NOT_GIVEN,
        msg_originator: str | NotGiven = NOT_GIVEN,
        msg_qualifier: str | NotGiven = NOT_GIVEN,
        msg_sn: str | NotGiven = NOT_GIVEN,
        naval_flt_ops: Iterable[air_tasking_order_create_params.NavalFltOp] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single airtaskingorder record as a POST body and
        ingest into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          begin_ts: The effective begin time for this ATO in ISO 8601 UTC format with millisecond
              precision.

          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          op_exer_name: Specifies the unique operation or exercise name, nickname, or codeword assigned
              to a joint exercise or operation plan.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          ack_req_ind: The indicator specifying an affirmative or a negatice condition for this
              message.

          ack_unit_instructions: Specifies textual data amplifying the data contained in the acknowledgement
              requirement indicator (ackRedInd) field or the unit required to acknowledge.

          ac_msn_tasking: A collection that specifies the tasked country, tasked service, unit and mission
              level tasking for this ATO.

          end_ts: The effective end time for this ATO in ISO 8601 UTC format with millisecond
              precision.

          gen_text: A collection that details special instructions, important information, guidance,
              and amplifying information regarding this ATO.

          msg_month: The month in which the message originated.

          msg_originator: The identifier of the originator of the message.

          msg_qualifier: The qualifier which caveats the message status.

          msg_sn: The unique message identifier sequentially assigned by the originator.

          naval_flt_ops: A collection that specifies the naval flight operations for this ATO.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/airtaskingorder",
            body=await async_maybe_transform(
                {
                    "begin_ts": begin_ts,
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "op_exer_name": op_exer_name,
                    "source": source,
                    "id": id,
                    "ack_req_ind": ack_req_ind,
                    "ack_unit_instructions": ack_unit_instructions,
                    "ac_msn_tasking": ac_msn_tasking,
                    "end_ts": end_ts,
                    "gen_text": gen_text,
                    "msg_month": msg_month,
                    "msg_originator": msg_originator,
                    "msg_qualifier": msg_qualifier,
                    "msg_sn": msg_sn,
                    "naval_flt_ops": naval_flt_ops,
                    "origin": origin,
                },
                air_tasking_order_create_params.AirTaskingOrderCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AirTaskingOrderFull:
        """
        Service operation to get a single airtaskingorder record by its unique ID passed
        as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/airtaskingorder/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AirTaskingOrderFull,
        )

    async def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/airtaskingorder/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def query_help(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/airtaskingorder/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AirTaskingOrderTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/airtaskingorder/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"columns": columns}, air_tasking_order_tuple_params.AirTaskingOrderTupleParams
                ),
            ),
            cast_to=AirTaskingOrderTupleResponse,
        )


class AirTaskingOrdersResourceWithRawResponse:
    def __init__(self, air_tasking_orders: AirTaskingOrdersResource) -> None:
        self._air_tasking_orders = air_tasking_orders

        self.create = to_raw_response_wrapper(
            air_tasking_orders.create,
        )
        self.retrieve = to_raw_response_wrapper(
            air_tasking_orders.retrieve,
        )
        self.count = to_raw_response_wrapper(
            air_tasking_orders.count,
        )
        self.query_help = to_raw_response_wrapper(
            air_tasking_orders.query_help,
        )
        self.tuple = to_raw_response_wrapper(
            air_tasking_orders.tuple,
        )


class AsyncAirTaskingOrdersResourceWithRawResponse:
    def __init__(self, air_tasking_orders: AsyncAirTaskingOrdersResource) -> None:
        self._air_tasking_orders = air_tasking_orders

        self.create = async_to_raw_response_wrapper(
            air_tasking_orders.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            air_tasking_orders.retrieve,
        )
        self.count = async_to_raw_response_wrapper(
            air_tasking_orders.count,
        )
        self.query_help = async_to_raw_response_wrapper(
            air_tasking_orders.query_help,
        )
        self.tuple = async_to_raw_response_wrapper(
            air_tasking_orders.tuple,
        )


class AirTaskingOrdersResourceWithStreamingResponse:
    def __init__(self, air_tasking_orders: AirTaskingOrdersResource) -> None:
        self._air_tasking_orders = air_tasking_orders

        self.create = to_streamed_response_wrapper(
            air_tasking_orders.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            air_tasking_orders.retrieve,
        )
        self.count = to_streamed_response_wrapper(
            air_tasking_orders.count,
        )
        self.query_help = to_streamed_response_wrapper(
            air_tasking_orders.query_help,
        )
        self.tuple = to_streamed_response_wrapper(
            air_tasking_orders.tuple,
        )


class AsyncAirTaskingOrdersResourceWithStreamingResponse:
    def __init__(self, air_tasking_orders: AsyncAirTaskingOrdersResource) -> None:
        self._air_tasking_orders = air_tasking_orders

        self.create = async_to_streamed_response_wrapper(
            air_tasking_orders.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            air_tasking_orders.retrieve,
        )
        self.count = async_to_streamed_response_wrapper(
            air_tasking_orders.count,
        )
        self.query_help = async_to_streamed_response_wrapper(
            air_tasking_orders.query_help,
        )
        self.tuple = async_to_streamed_response_wrapper(
            air_tasking_orders.tuple,
        )
