# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import aircraft_status_remark_tuple_params, aircraft_status_remark_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.aircraftstatusremark_full import AircraftstatusremarkFull
from ..types.aircraft_status_remark_list_response import AircraftStatusRemarkListResponse
from ..types.aircraft_status_remark_tuple_response import AircraftStatusRemarkTupleResponse

__all__ = ["AircraftStatusRemarksResource", "AsyncAircraftStatusRemarksResource"]


class AircraftStatusRemarksResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AircraftStatusRemarksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AircraftStatusRemarksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AircraftStatusRemarksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AircraftStatusRemarksResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_aircraft_status: str,
        source: str,
        text: str,
        id: str | NotGiven = NOT_GIVEN,
        alt_rmk_id: str | NotGiven = NOT_GIVEN,
        last_updated_at: Union[str, datetime] | NotGiven = NOT_GIVEN,
        last_updated_by: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Aircraft Status Remark record as a POST body
        and ingest into the database. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_aircraft_status: The ID of the Aircraft Status to which this remark applies.

          source: Source of the data.

          text: The text of the remark.

          id: Unique identifier of the record, auto-generated by the system if not provided on
              create operations.

          alt_rmk_id: Unique identifier of the Aircraft Status Remark record from the originating
              system.

          last_updated_at: Time the remark was last updated in the originating system in ISO 8601 UTC
              format with millisecond precision.

          last_updated_by: The name or ID of the external user that updated this remark in the originating
              system.

          name: The name of the remark.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          timestamp: Time the remark was created in the originating system in ISO 8601 UTC format
              with millisecond precision.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/aircraftstatusremark",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_aircraft_status": id_aircraft_status,
                    "source": source,
                    "text": text,
                    "id": id,
                    "alt_rmk_id": alt_rmk_id,
                    "last_updated_at": last_updated_at,
                    "last_updated_by": last_updated_by,
                    "name": name,
                    "origin": origin,
                    "timestamp": timestamp,
                },
                aircraft_status_remark_create_params.AircraftStatusRemarkCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AircraftstatusremarkFull:
        """
        Service operation to get a single Aircraft Status Remark record by its unique ID
        passed as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/aircraftstatusremark/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AircraftstatusremarkFull,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AircraftStatusRemarkListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/aircraftstatusremark",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AircraftStatusRemarkListResponse,
        )

    def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/aircraftstatusremark/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/aircraftstatusremark/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AircraftStatusRemarkTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/aircraftstatusremark/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"columns": columns}, aircraft_status_remark_tuple_params.AircraftStatusRemarkTupleParams
                ),
            ),
            cast_to=AircraftStatusRemarkTupleResponse,
        )


class AsyncAircraftStatusRemarksResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAircraftStatusRemarksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAircraftStatusRemarksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAircraftStatusRemarksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncAircraftStatusRemarksResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_aircraft_status: str,
        source: str,
        text: str,
        id: str | NotGiven = NOT_GIVEN,
        alt_rmk_id: str | NotGiven = NOT_GIVEN,
        last_updated_at: Union[str, datetime] | NotGiven = NOT_GIVEN,
        last_updated_by: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Aircraft Status Remark record as a POST body
        and ingest into the database. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_aircraft_status: The ID of the Aircraft Status to which this remark applies.

          source: Source of the data.

          text: The text of the remark.

          id: Unique identifier of the record, auto-generated by the system if not provided on
              create operations.

          alt_rmk_id: Unique identifier of the Aircraft Status Remark record from the originating
              system.

          last_updated_at: Time the remark was last updated in the originating system in ISO 8601 UTC
              format with millisecond precision.

          last_updated_by: The name or ID of the external user that updated this remark in the originating
              system.

          name: The name of the remark.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          timestamp: Time the remark was created in the originating system in ISO 8601 UTC format
              with millisecond precision.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/aircraftstatusremark",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_aircraft_status": id_aircraft_status,
                    "source": source,
                    "text": text,
                    "id": id,
                    "alt_rmk_id": alt_rmk_id,
                    "last_updated_at": last_updated_at,
                    "last_updated_by": last_updated_by,
                    "name": name,
                    "origin": origin,
                    "timestamp": timestamp,
                },
                aircraft_status_remark_create_params.AircraftStatusRemarkCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AircraftstatusremarkFull:
        """
        Service operation to get a single Aircraft Status Remark record by its unique ID
        passed as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/aircraftstatusremark/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AircraftstatusremarkFull,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AircraftStatusRemarkListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/aircraftstatusremark",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AircraftStatusRemarkListResponse,
        )

    async def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/aircraftstatusremark/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/aircraftstatusremark/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AircraftStatusRemarkTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/aircraftstatusremark/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"columns": columns}, aircraft_status_remark_tuple_params.AircraftStatusRemarkTupleParams
                ),
            ),
            cast_to=AircraftStatusRemarkTupleResponse,
        )


class AircraftStatusRemarksResourceWithRawResponse:
    def __init__(self, aircraft_status_remarks: AircraftStatusRemarksResource) -> None:
        self._aircraft_status_remarks = aircraft_status_remarks

        self.create = to_raw_response_wrapper(
            aircraft_status_remarks.create,
        )
        self.retrieve = to_raw_response_wrapper(
            aircraft_status_remarks.retrieve,
        )
        self.list = to_raw_response_wrapper(
            aircraft_status_remarks.list,
        )
        self.count = to_raw_response_wrapper(
            aircraft_status_remarks.count,
        )
        self.queryhelp = to_raw_response_wrapper(
            aircraft_status_remarks.queryhelp,
        )
        self.tuple = to_raw_response_wrapper(
            aircraft_status_remarks.tuple,
        )


class AsyncAircraftStatusRemarksResourceWithRawResponse:
    def __init__(self, aircraft_status_remarks: AsyncAircraftStatusRemarksResource) -> None:
        self._aircraft_status_remarks = aircraft_status_remarks

        self.create = async_to_raw_response_wrapper(
            aircraft_status_remarks.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            aircraft_status_remarks.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            aircraft_status_remarks.list,
        )
        self.count = async_to_raw_response_wrapper(
            aircraft_status_remarks.count,
        )
        self.queryhelp = async_to_raw_response_wrapper(
            aircraft_status_remarks.queryhelp,
        )
        self.tuple = async_to_raw_response_wrapper(
            aircraft_status_remarks.tuple,
        )


class AircraftStatusRemarksResourceWithStreamingResponse:
    def __init__(self, aircraft_status_remarks: AircraftStatusRemarksResource) -> None:
        self._aircraft_status_remarks = aircraft_status_remarks

        self.create = to_streamed_response_wrapper(
            aircraft_status_remarks.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            aircraft_status_remarks.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            aircraft_status_remarks.list,
        )
        self.count = to_streamed_response_wrapper(
            aircraft_status_remarks.count,
        )
        self.queryhelp = to_streamed_response_wrapper(
            aircraft_status_remarks.queryhelp,
        )
        self.tuple = to_streamed_response_wrapper(
            aircraft_status_remarks.tuple,
        )


class AsyncAircraftStatusRemarksResourceWithStreamingResponse:
    def __init__(self, aircraft_status_remarks: AsyncAircraftStatusRemarksResource) -> None:
        self._aircraft_status_remarks = aircraft_status_remarks

        self.create = async_to_streamed_response_wrapper(
            aircraft_status_remarks.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            aircraft_status_remarks.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            aircraft_status_remarks.list,
        )
        self.count = async_to_streamed_response_wrapper(
            aircraft_status_remarks.count,
        )
        self.queryhelp = async_to_streamed_response_wrapper(
            aircraft_status_remarks.queryhelp,
        )
        self.tuple = async_to_streamed_response_wrapper(
            aircraft_status_remarks.tuple,
        )
