# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import airfield_slot_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.airfield_slot_list_response import AirfieldSlotListResponse

__all__ = ["AirfieldSlotsResource", "AsyncAirfieldSlotsResource"]


class AirfieldSlotsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AirfieldSlotsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AirfieldSlotsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AirfieldSlotsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AirfieldSlotsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        airfield_name: str,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        name: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        ac_slot_cat: Literal["WIDE", "NARROW", "HELO", "ALL", "OTHER"] | NotGiven = NOT_GIVEN,
        alt_airfield_id: str | NotGiven = NOT_GIVEN,
        capacity: int | NotGiven = NOT_GIVEN,
        end_time: str | NotGiven = NOT_GIVEN,
        icao: str | NotGiven = NOT_GIVEN,
        id_airfield: str | NotGiven = NOT_GIVEN,
        min_separation: int | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        start_time: str | NotGiven = NOT_GIVEN,
        type: Literal["WORKING", "PARKING", "TAKEOFF", "LANDING", "OTHER"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single airfieldslot record as a POST body and ingest
        into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          airfield_name: The name of the airfield where this slot is located.

          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          name: Name of this slot.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          ac_slot_cat: Largest category of aircraft supported in this slot (WIDE, NARROW, HELO, ALL,
              OTHER).

          alt_airfield_id: Alternate airfield identifier provided by the source.

          capacity: Number of aircraft that can fit in this slot at the same time.

          end_time: Latest zulu time this slot is available based on daily standard hours. Not
              applicable to slots with type PARKING. Abnormal hours, such as holidays, should
              be marked via the AirfieldSlotConsumption schema.

          icao: The International Civil Aviation Organization (ICAO) code of the airfield.

          id_airfield: Unique identifier of the Airfield for which this slot information applies.

          min_separation: Minimum time that must elapse between different aircraft leaving and entering
              this slot, in minutes.

          notes: Optional notes/comments for this airfield slot.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          start_time: Zulu time this slot is first available based on daily standard hours. Not
              applicable to slots with type PARKING. Abnormal hours, such as holidays, should
              be marked via the AirfieldSlotConsumption schema.

          type: Designates how this slot can be used (WORKING, PARKING, TAKEOFF, LANDING,
              OTHER).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/airfieldslot",
            body=maybe_transform(
                {
                    "airfield_name": airfield_name,
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "name": name,
                    "source": source,
                    "id": id,
                    "ac_slot_cat": ac_slot_cat,
                    "alt_airfield_id": alt_airfield_id,
                    "capacity": capacity,
                    "end_time": end_time,
                    "icao": icao,
                    "id_airfield": id_airfield,
                    "min_separation": min_separation,
                    "notes": notes,
                    "origin": origin,
                    "start_time": start_time,
                    "type": type,
                },
                airfield_slot_create_params.AirfieldSlotCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AirfieldSlotListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/airfieldslot",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AirfieldSlotListResponse,
        )


class AsyncAirfieldSlotsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAirfieldSlotsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAirfieldSlotsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAirfieldSlotsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncAirfieldSlotsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        airfield_name: str,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        name: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        ac_slot_cat: Literal["WIDE", "NARROW", "HELO", "ALL", "OTHER"] | NotGiven = NOT_GIVEN,
        alt_airfield_id: str | NotGiven = NOT_GIVEN,
        capacity: int | NotGiven = NOT_GIVEN,
        end_time: str | NotGiven = NOT_GIVEN,
        icao: str | NotGiven = NOT_GIVEN,
        id_airfield: str | NotGiven = NOT_GIVEN,
        min_separation: int | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        start_time: str | NotGiven = NOT_GIVEN,
        type: Literal["WORKING", "PARKING", "TAKEOFF", "LANDING", "OTHER"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single airfieldslot record as a POST body and ingest
        into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          airfield_name: The name of the airfield where this slot is located.

          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          name: Name of this slot.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          ac_slot_cat: Largest category of aircraft supported in this slot (WIDE, NARROW, HELO, ALL,
              OTHER).

          alt_airfield_id: Alternate airfield identifier provided by the source.

          capacity: Number of aircraft that can fit in this slot at the same time.

          end_time: Latest zulu time this slot is available based on daily standard hours. Not
              applicable to slots with type PARKING. Abnormal hours, such as holidays, should
              be marked via the AirfieldSlotConsumption schema.

          icao: The International Civil Aviation Organization (ICAO) code of the airfield.

          id_airfield: Unique identifier of the Airfield for which this slot information applies.

          min_separation: Minimum time that must elapse between different aircraft leaving and entering
              this slot, in minutes.

          notes: Optional notes/comments for this airfield slot.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          start_time: Zulu time this slot is first available based on daily standard hours. Not
              applicable to slots with type PARKING. Abnormal hours, such as holidays, should
              be marked via the AirfieldSlotConsumption schema.

          type: Designates how this slot can be used (WORKING, PARKING, TAKEOFF, LANDING,
              OTHER).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/airfieldslot",
            body=await async_maybe_transform(
                {
                    "airfield_name": airfield_name,
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "name": name,
                    "source": source,
                    "id": id,
                    "ac_slot_cat": ac_slot_cat,
                    "alt_airfield_id": alt_airfield_id,
                    "capacity": capacity,
                    "end_time": end_time,
                    "icao": icao,
                    "id_airfield": id_airfield,
                    "min_separation": min_separation,
                    "notes": notes,
                    "origin": origin,
                    "start_time": start_time,
                    "type": type,
                },
                airfield_slot_create_params.AirfieldSlotCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AirfieldSlotListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/airfieldslot",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AirfieldSlotListResponse,
        )


class AirfieldSlotsResourceWithRawResponse:
    def __init__(self, airfield_slots: AirfieldSlotsResource) -> None:
        self._airfield_slots = airfield_slots

        self.create = to_raw_response_wrapper(
            airfield_slots.create,
        )
        self.list = to_raw_response_wrapper(
            airfield_slots.list,
        )


class AsyncAirfieldSlotsResourceWithRawResponse:
    def __init__(self, airfield_slots: AsyncAirfieldSlotsResource) -> None:
        self._airfield_slots = airfield_slots

        self.create = async_to_raw_response_wrapper(
            airfield_slots.create,
        )
        self.list = async_to_raw_response_wrapper(
            airfield_slots.list,
        )


class AirfieldSlotsResourceWithStreamingResponse:
    def __init__(self, airfield_slots: AirfieldSlotsResource) -> None:
        self._airfield_slots = airfield_slots

        self.create = to_streamed_response_wrapper(
            airfield_slots.create,
        )
        self.list = to_streamed_response_wrapper(
            airfield_slots.list,
        )


class AsyncAirfieldSlotsResourceWithStreamingResponse:
    def __init__(self, airfield_slots: AsyncAirfieldSlotsResource) -> None:
        self._airfield_slots = airfield_slots

        self.create = async_to_streamed_response_wrapper(
            airfield_slots.create,
        )
        self.list = async_to_streamed_response_wrapper(
            airfield_slots.list,
        )
