# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal

import httpx

from ..types import (
    aviationriskmanagement_count_params,
    aviationriskmanagement_query_params,
    aviationriskmanagement_tuple_params,
    aviationriskmanagement_create_params,
    aviationriskmanagement_update_params,
    aviationriskmanagement_create_bulk_params,
    aviationriskmanagement_unvalidated_publish_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.aviationriskmanagement_query_response import AviationriskmanagementQueryResponse
from ..types.aviationriskmanagement_tuple_response import AviationriskmanagementTupleResponse
from ..types.aviationriskmanagement_retrieve_response import AviationriskmanagementRetrieveResponse

__all__ = ["AviationriskmanagementResource", "AsyncAviationriskmanagementResource"]


class AviationriskmanagementResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AviationriskmanagementResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AviationriskmanagementResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AviationriskmanagementResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AviationriskmanagementResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_mission: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        aviation_risk_management_worksheet_record: Iterable[
            aviationriskmanagement_create_params.AviationRiskManagementWorksheetRecord
        ]
        | NotGiven = NOT_GIVEN,
        ext_mission_id: str | NotGiven = NOT_GIVEN,
        mission_number: str | NotGiven = NOT_GIVEN,
        org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        unit_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Aviation Risk Management record as a POST
        body and ingest into the database. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system if not provided on
              create operations.

          aviation_risk_management_worksheet_record: Collection of Aviation Risk Management Worksheet Records.

          ext_mission_id: Optional mission ID from external systems. This field has no meaning within UDL
              and is provided as a convenience for systems that require tracking of an
              internal system generated ID.

          mission_number: The mission number of the mission associated with this record.

          org_id: Identifier for the organization which this risk management record is evaluated.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          unit_id: Identifier for the unit which this risk management record is evaluated.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/aviationriskmanagement",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_mission": id_mission,
                    "source": source,
                    "id": id,
                    "aviation_risk_management_worksheet_record": aviation_risk_management_worksheet_record,
                    "ext_mission_id": ext_mission_id,
                    "mission_number": mission_number,
                    "org_id": org_id,
                    "origin": origin,
                    "unit_id": unit_id,
                },
                aviationriskmanagement_create_params.AviationriskmanagementCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AviationriskmanagementRetrieveResponse:
        """
        Service operation to get a single Aviation Risk Management record by its unique
        ID passed as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/aviationriskmanagement/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AviationriskmanagementRetrieveResponse,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_mission: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        aviation_risk_management_worksheet_record: Iterable[
            aviationriskmanagement_update_params.AviationRiskManagementWorksheetRecord
        ]
        | NotGiven = NOT_GIVEN,
        ext_mission_id: str | NotGiven = NOT_GIVEN,
        mission_number: str | NotGiven = NOT_GIVEN,
        org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        unit_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Aviation Risk Management record.

        A specific
        role is required to perform this service operation. Please contact the UDL team
        for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system if not provided on
              create operations.

          aviation_risk_management_worksheet_record: Collection of Aviation Risk Management Worksheet Records.

          ext_mission_id: Optional mission ID from external systems. This field has no meaning within UDL
              and is provided as a convenience for systems that require tracking of an
              internal system generated ID.

          mission_number: The mission number of the mission associated with this record.

          org_id: Identifier for the organization which this risk management record is evaluated.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          unit_id: Identifier for the unit which this risk management record is evaluated.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/aviationriskmanagement/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_mission": id_mission,
                    "source": source,
                    "body_id": body_id,
                    "aviation_risk_management_worksheet_record": aviation_risk_management_worksheet_record,
                    "ext_mission_id": ext_mission_id,
                    "mission_number": mission_number,
                    "org_id": org_id,
                    "origin": origin,
                    "unit_id": unit_id,
                },
                aviationriskmanagement_update_params.AviationriskmanagementUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete an Aviation Risk Management record specified by the
        passed ID path parameter. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/aviationriskmanagement/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def count(
        self,
        *,
        id_mission: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.

        Args:
          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/aviationriskmanagement/count",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"id_mission": id_mission}, aviationriskmanagement_count_params.AviationriskmanagementCountParams
                ),
            ),
            cast_to=str,
        )

    def create_bulk(
        self,
        *,
        body: Iterable[aviationriskmanagement_create_bulk_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation intended for initial integration only, to take a list of
        Aviation Risk Management records as a POST body and ingest into the database.
        This operation is not intended to be used for automated feeds into UDL. Data
        providers should contact the UDL team for specific role assignments and for
        instructions on setting up a permanent feed through an alternate mechanism.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/aviationriskmanagement/createBulk",
            body=maybe_transform(body, Iterable[aviationriskmanagement_create_bulk_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def query(
        self,
        *,
        id_mission: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AviationriskmanagementQueryResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.

        Args:
          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/aviationriskmanagement",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"id_mission": id_mission}, aviationriskmanagement_query_params.AviationriskmanagementQueryParams
                ),
            ),
            cast_to=AviationriskmanagementQueryResponse,
        )

    def query_help(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/aviationriskmanagement/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        id_mission: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AviationriskmanagementTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/aviationriskmanagement/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "columns": columns,
                        "id_mission": id_mission,
                    },
                    aviationriskmanagement_tuple_params.AviationriskmanagementTupleParams,
                ),
            ),
            cast_to=AviationriskmanagementTupleResponse,
        )

    def unvalidated_publish(
        self,
        *,
        body: Iterable[aviationriskmanagement_unvalidated_publish_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take multiple Aviation Risk Management records as a POST
        body and ingest into the database. This operation is intended to be used for
        automated feeds into UDL. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/filedrop/udl-aviationriskmanagement",
            body=maybe_transform(body, Iterable[aviationriskmanagement_unvalidated_publish_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAviationriskmanagementResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAviationriskmanagementResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAviationriskmanagementResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAviationriskmanagementResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncAviationriskmanagementResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_mission: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        aviation_risk_management_worksheet_record: Iterable[
            aviationriskmanagement_create_params.AviationRiskManagementWorksheetRecord
        ]
        | NotGiven = NOT_GIVEN,
        ext_mission_id: str | NotGiven = NOT_GIVEN,
        mission_number: str | NotGiven = NOT_GIVEN,
        org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        unit_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Aviation Risk Management record as a POST
        body and ingest into the database. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system if not provided on
              create operations.

          aviation_risk_management_worksheet_record: Collection of Aviation Risk Management Worksheet Records.

          ext_mission_id: Optional mission ID from external systems. This field has no meaning within UDL
              and is provided as a convenience for systems that require tracking of an
              internal system generated ID.

          mission_number: The mission number of the mission associated with this record.

          org_id: Identifier for the organization which this risk management record is evaluated.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          unit_id: Identifier for the unit which this risk management record is evaluated.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/aviationriskmanagement",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_mission": id_mission,
                    "source": source,
                    "id": id,
                    "aviation_risk_management_worksheet_record": aviation_risk_management_worksheet_record,
                    "ext_mission_id": ext_mission_id,
                    "mission_number": mission_number,
                    "org_id": org_id,
                    "origin": origin,
                    "unit_id": unit_id,
                },
                aviationriskmanagement_create_params.AviationriskmanagementCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AviationriskmanagementRetrieveResponse:
        """
        Service operation to get a single Aviation Risk Management record by its unique
        ID passed as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/aviationriskmanagement/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AviationriskmanagementRetrieveResponse,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_mission: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        aviation_risk_management_worksheet_record: Iterable[
            aviationriskmanagement_update_params.AviationRiskManagementWorksheetRecord
        ]
        | NotGiven = NOT_GIVEN,
        ext_mission_id: str | NotGiven = NOT_GIVEN,
        mission_number: str | NotGiven = NOT_GIVEN,
        org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        unit_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Aviation Risk Management record.

        A specific
        role is required to perform this service operation. Please contact the UDL team
        for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system if not provided on
              create operations.

          aviation_risk_management_worksheet_record: Collection of Aviation Risk Management Worksheet Records.

          ext_mission_id: Optional mission ID from external systems. This field has no meaning within UDL
              and is provided as a convenience for systems that require tracking of an
              internal system generated ID.

          mission_number: The mission number of the mission associated with this record.

          org_id: Identifier for the organization which this risk management record is evaluated.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          unit_id: Identifier for the unit which this risk management record is evaluated.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/aviationriskmanagement/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_mission": id_mission,
                    "source": source,
                    "body_id": body_id,
                    "aviation_risk_management_worksheet_record": aviation_risk_management_worksheet_record,
                    "ext_mission_id": ext_mission_id,
                    "mission_number": mission_number,
                    "org_id": org_id,
                    "origin": origin,
                    "unit_id": unit_id,
                },
                aviationriskmanagement_update_params.AviationriskmanagementUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete an Aviation Risk Management record specified by the
        passed ID path parameter. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/aviationriskmanagement/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def count(
        self,
        *,
        id_mission: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.

        Args:
          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/aviationriskmanagement/count",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"id_mission": id_mission}, aviationriskmanagement_count_params.AviationriskmanagementCountParams
                ),
            ),
            cast_to=str,
        )

    async def create_bulk(
        self,
        *,
        body: Iterable[aviationriskmanagement_create_bulk_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation intended for initial integration only, to take a list of
        Aviation Risk Management records as a POST body and ingest into the database.
        This operation is not intended to be used for automated feeds into UDL. Data
        providers should contact the UDL team for specific role assignments and for
        instructions on setting up a permanent feed through an alternate mechanism.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/aviationriskmanagement/createBulk",
            body=await async_maybe_transform(body, Iterable[aviationriskmanagement_create_bulk_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def query(
        self,
        *,
        id_mission: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AviationriskmanagementQueryResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.

        Args:
          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/aviationriskmanagement",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"id_mission": id_mission}, aviationriskmanagement_query_params.AviationriskmanagementQueryParams
                ),
            ),
            cast_to=AviationriskmanagementQueryResponse,
        )

    async def query_help(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/aviationriskmanagement/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        id_mission: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AviationriskmanagementTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          id_mission: The unique identifier of the mission to which this risk management record is
              assigned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/aviationriskmanagement/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "columns": columns,
                        "id_mission": id_mission,
                    },
                    aviationriskmanagement_tuple_params.AviationriskmanagementTupleParams,
                ),
            ),
            cast_to=AviationriskmanagementTupleResponse,
        )

    async def unvalidated_publish(
        self,
        *,
        body: Iterable[aviationriskmanagement_unvalidated_publish_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take multiple Aviation Risk Management records as a POST
        body and ingest into the database. This operation is intended to be used for
        automated feeds into UDL. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/filedrop/udl-aviationriskmanagement",
            body=await async_maybe_transform(body, Iterable[aviationriskmanagement_unvalidated_publish_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AviationriskmanagementResourceWithRawResponse:
    def __init__(self, aviationriskmanagement: AviationriskmanagementResource) -> None:
        self._aviationriskmanagement = aviationriskmanagement

        self.create = to_raw_response_wrapper(
            aviationriskmanagement.create,
        )
        self.retrieve = to_raw_response_wrapper(
            aviationriskmanagement.retrieve,
        )
        self.update = to_raw_response_wrapper(
            aviationriskmanagement.update,
        )
        self.delete = to_raw_response_wrapper(
            aviationriskmanagement.delete,
        )
        self.count = to_raw_response_wrapper(
            aviationriskmanagement.count,
        )
        self.create_bulk = to_raw_response_wrapper(
            aviationriskmanagement.create_bulk,
        )
        self.query = to_raw_response_wrapper(
            aviationriskmanagement.query,
        )
        self.query_help = to_raw_response_wrapper(
            aviationriskmanagement.query_help,
        )
        self.tuple = to_raw_response_wrapper(
            aviationriskmanagement.tuple,
        )
        self.unvalidated_publish = to_raw_response_wrapper(
            aviationriskmanagement.unvalidated_publish,
        )


class AsyncAviationriskmanagementResourceWithRawResponse:
    def __init__(self, aviationriskmanagement: AsyncAviationriskmanagementResource) -> None:
        self._aviationriskmanagement = aviationriskmanagement

        self.create = async_to_raw_response_wrapper(
            aviationriskmanagement.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            aviationriskmanagement.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            aviationriskmanagement.update,
        )
        self.delete = async_to_raw_response_wrapper(
            aviationriskmanagement.delete,
        )
        self.count = async_to_raw_response_wrapper(
            aviationriskmanagement.count,
        )
        self.create_bulk = async_to_raw_response_wrapper(
            aviationriskmanagement.create_bulk,
        )
        self.query = async_to_raw_response_wrapper(
            aviationriskmanagement.query,
        )
        self.query_help = async_to_raw_response_wrapper(
            aviationriskmanagement.query_help,
        )
        self.tuple = async_to_raw_response_wrapper(
            aviationriskmanagement.tuple,
        )
        self.unvalidated_publish = async_to_raw_response_wrapper(
            aviationriskmanagement.unvalidated_publish,
        )


class AviationriskmanagementResourceWithStreamingResponse:
    def __init__(self, aviationriskmanagement: AviationriskmanagementResource) -> None:
        self._aviationriskmanagement = aviationriskmanagement

        self.create = to_streamed_response_wrapper(
            aviationriskmanagement.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            aviationriskmanagement.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            aviationriskmanagement.update,
        )
        self.delete = to_streamed_response_wrapper(
            aviationriskmanagement.delete,
        )
        self.count = to_streamed_response_wrapper(
            aviationriskmanagement.count,
        )
        self.create_bulk = to_streamed_response_wrapper(
            aviationriskmanagement.create_bulk,
        )
        self.query = to_streamed_response_wrapper(
            aviationriskmanagement.query,
        )
        self.query_help = to_streamed_response_wrapper(
            aviationriskmanagement.query_help,
        )
        self.tuple = to_streamed_response_wrapper(
            aviationriskmanagement.tuple,
        )
        self.unvalidated_publish = to_streamed_response_wrapper(
            aviationriskmanagement.unvalidated_publish,
        )


class AsyncAviationriskmanagementResourceWithStreamingResponse:
    def __init__(self, aviationriskmanagement: AsyncAviationriskmanagementResource) -> None:
        self._aviationriskmanagement = aviationriskmanagement

        self.create = async_to_streamed_response_wrapper(
            aviationriskmanagement.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            aviationriskmanagement.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            aviationriskmanagement.update,
        )
        self.delete = async_to_streamed_response_wrapper(
            aviationriskmanagement.delete,
        )
        self.count = async_to_streamed_response_wrapper(
            aviationriskmanagement.count,
        )
        self.create_bulk = async_to_streamed_response_wrapper(
            aviationriskmanagement.create_bulk,
        )
        self.query = async_to_streamed_response_wrapper(
            aviationriskmanagement.query,
        )
        self.query_help = async_to_streamed_response_wrapper(
            aviationriskmanagement.query_help,
        )
        self.tuple = async_to_streamed_response_wrapper(
            aviationriskmanagement.tuple,
        )
        self.unvalidated_publish = async_to_streamed_response_wrapper(
            aviationriskmanagement.unvalidated_publish,
        )
