# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import channel_tuple_params, channel_create_params, channel_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.channel_full import ChannelFull
from ..types.channel_list_response import ChannelListResponse
from ..types.channel_tuple_response import ChannelTupleResponse

__all__ = ["ChannelsResource", "AsyncChannelsResource"]


class ChannelsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ChannelsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return ChannelsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ChannelsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return ChannelsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_transponder: str,
        name: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        apid: str | NotGiven = NOT_GIVEN,
        beam_name: str | NotGiven = NOT_GIVEN,
        compression: str | NotGiven = NOT_GIVEN,
        encryption: str | NotGiven = NOT_GIVEN,
        id_beam: str | NotGiven = NOT_GIVEN,
        id_rf_band: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        owner: str | NotGiven = NOT_GIVEN,
        pkg: str | NotGiven = NOT_GIVEN,
        res: str | NotGiven = NOT_GIVEN,
        sid: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        vpid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Channel as a POST body and ingest into the
        database. A Comm payload may have multiple transponders and a transponder may
        have many channels. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_transponder: ID of the parent transponder object for this Channel.

          name: Channel name.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          apid: Channel aPid.

          beam_name: The antenna beam ID of the particular beam for this channel. beamName is not
              unique across payloads.

          compression: Channel compression.

          encryption: Channel encryption.

          id_beam: Identifier of the particular beam for this channel.

          id_rf_band: ID of the RF Band object for this channel.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          owner: Owner.

          pkg: Pkg.

          res: Res.

          sid: SID.

          type: Channel type.

          vpid: Channel vPid.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/channel",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_transponder": id_transponder,
                    "name": name,
                    "source": source,
                    "id": id,
                    "apid": apid,
                    "beam_name": beam_name,
                    "compression": compression,
                    "encryption": encryption,
                    "id_beam": id_beam,
                    "id_rf_band": id_rf_band,
                    "origin": origin,
                    "owner": owner,
                    "pkg": pkg,
                    "res": res,
                    "sid": sid,
                    "type": type,
                    "vpid": vpid,
                },
                channel_create_params.ChannelCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChannelFull:
        """
        Service operation to get a single Channel record by its unique ID passed as a
        path parameter. A Comm payload may have multiple transponders and a transponder
        may have many channels.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/channel/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChannelFull,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_transponder: str,
        name: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        apid: str | NotGiven = NOT_GIVEN,
        beam_name: str | NotGiven = NOT_GIVEN,
        compression: str | NotGiven = NOT_GIVEN,
        encryption: str | NotGiven = NOT_GIVEN,
        id_beam: str | NotGiven = NOT_GIVEN,
        id_rf_band: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        owner: str | NotGiven = NOT_GIVEN,
        pkg: str | NotGiven = NOT_GIVEN,
        res: str | NotGiven = NOT_GIVEN,
        sid: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        vpid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Channel.

        A Comm payload may have multiple
        transponders and a transponder may have many channels. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_transponder: ID of the parent transponder object for this Channel.

          name: Channel name.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          apid: Channel aPid.

          beam_name: The antenna beam ID of the particular beam for this channel. beamName is not
              unique across payloads.

          compression: Channel compression.

          encryption: Channel encryption.

          id_beam: Identifier of the particular beam for this channel.

          id_rf_band: ID of the RF Band object for this channel.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          owner: Owner.

          pkg: Pkg.

          res: Res.

          sid: SID.

          type: Channel type.

          vpid: Channel vPid.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/channel/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_transponder": id_transponder,
                    "name": name,
                    "source": source,
                    "body_id": body_id,
                    "apid": apid,
                    "beam_name": beam_name,
                    "compression": compression,
                    "encryption": encryption,
                    "id_beam": id_beam,
                    "id_rf_band": id_rf_band,
                    "origin": origin,
                    "owner": owner,
                    "pkg": pkg,
                    "res": res,
                    "sid": sid,
                    "type": type,
                    "vpid": vpid,
                },
                channel_update_params.ChannelUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChannelListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/channel",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChannelListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a Channel object specified by the passed ID path
        parameter. A Comm payload may have multiple transponders and a transponder may
        have many channels. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/channel/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/channel/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/channel/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChannelTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/channel/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"columns": columns}, channel_tuple_params.ChannelTupleParams),
            ),
            cast_to=ChannelTupleResponse,
        )


class AsyncChannelsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncChannelsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncChannelsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncChannelsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncChannelsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_transponder: str,
        name: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        apid: str | NotGiven = NOT_GIVEN,
        beam_name: str | NotGiven = NOT_GIVEN,
        compression: str | NotGiven = NOT_GIVEN,
        encryption: str | NotGiven = NOT_GIVEN,
        id_beam: str | NotGiven = NOT_GIVEN,
        id_rf_band: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        owner: str | NotGiven = NOT_GIVEN,
        pkg: str | NotGiven = NOT_GIVEN,
        res: str | NotGiven = NOT_GIVEN,
        sid: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        vpid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Channel as a POST body and ingest into the
        database. A Comm payload may have multiple transponders and a transponder may
        have many channels. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_transponder: ID of the parent transponder object for this Channel.

          name: Channel name.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          apid: Channel aPid.

          beam_name: The antenna beam ID of the particular beam for this channel. beamName is not
              unique across payloads.

          compression: Channel compression.

          encryption: Channel encryption.

          id_beam: Identifier of the particular beam for this channel.

          id_rf_band: ID of the RF Band object for this channel.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          owner: Owner.

          pkg: Pkg.

          res: Res.

          sid: SID.

          type: Channel type.

          vpid: Channel vPid.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/channel",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_transponder": id_transponder,
                    "name": name,
                    "source": source,
                    "id": id,
                    "apid": apid,
                    "beam_name": beam_name,
                    "compression": compression,
                    "encryption": encryption,
                    "id_beam": id_beam,
                    "id_rf_band": id_rf_band,
                    "origin": origin,
                    "owner": owner,
                    "pkg": pkg,
                    "res": res,
                    "sid": sid,
                    "type": type,
                    "vpid": vpid,
                },
                channel_create_params.ChannelCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChannelFull:
        """
        Service operation to get a single Channel record by its unique ID passed as a
        path parameter. A Comm payload may have multiple transponders and a transponder
        may have many channels.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/channel/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChannelFull,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_transponder: str,
        name: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        apid: str | NotGiven = NOT_GIVEN,
        beam_name: str | NotGiven = NOT_GIVEN,
        compression: str | NotGiven = NOT_GIVEN,
        encryption: str | NotGiven = NOT_GIVEN,
        id_beam: str | NotGiven = NOT_GIVEN,
        id_rf_band: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        owner: str | NotGiven = NOT_GIVEN,
        pkg: str | NotGiven = NOT_GIVEN,
        res: str | NotGiven = NOT_GIVEN,
        sid: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        vpid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Channel.

        A Comm payload may have multiple
        transponders and a transponder may have many channels. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_transponder: ID of the parent transponder object for this Channel.

          name: Channel name.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          apid: Channel aPid.

          beam_name: The antenna beam ID of the particular beam for this channel. beamName is not
              unique across payloads.

          compression: Channel compression.

          encryption: Channel encryption.

          id_beam: Identifier of the particular beam for this channel.

          id_rf_band: ID of the RF Band object for this channel.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          owner: Owner.

          pkg: Pkg.

          res: Res.

          sid: SID.

          type: Channel type.

          vpid: Channel vPid.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/channel/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_transponder": id_transponder,
                    "name": name,
                    "source": source,
                    "body_id": body_id,
                    "apid": apid,
                    "beam_name": beam_name,
                    "compression": compression,
                    "encryption": encryption,
                    "id_beam": id_beam,
                    "id_rf_band": id_rf_band,
                    "origin": origin,
                    "owner": owner,
                    "pkg": pkg,
                    "res": res,
                    "sid": sid,
                    "type": type,
                    "vpid": vpid,
                },
                channel_update_params.ChannelUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChannelListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/channel",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChannelListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a Channel object specified by the passed ID path
        parameter. A Comm payload may have multiple transponders and a transponder may
        have many channels. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/channel/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/channel/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/channel/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChannelTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/channel/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"columns": columns}, channel_tuple_params.ChannelTupleParams),
            ),
            cast_to=ChannelTupleResponse,
        )


class ChannelsResourceWithRawResponse:
    def __init__(self, channels: ChannelsResource) -> None:
        self._channels = channels

        self.create = to_raw_response_wrapper(
            channels.create,
        )
        self.retrieve = to_raw_response_wrapper(
            channels.retrieve,
        )
        self.update = to_raw_response_wrapper(
            channels.update,
        )
        self.list = to_raw_response_wrapper(
            channels.list,
        )
        self.delete = to_raw_response_wrapper(
            channels.delete,
        )
        self.count = to_raw_response_wrapper(
            channels.count,
        )
        self.queryhelp = to_raw_response_wrapper(
            channels.queryhelp,
        )
        self.tuple = to_raw_response_wrapper(
            channels.tuple,
        )


class AsyncChannelsResourceWithRawResponse:
    def __init__(self, channels: AsyncChannelsResource) -> None:
        self._channels = channels

        self.create = async_to_raw_response_wrapper(
            channels.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            channels.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            channels.update,
        )
        self.list = async_to_raw_response_wrapper(
            channels.list,
        )
        self.delete = async_to_raw_response_wrapper(
            channels.delete,
        )
        self.count = async_to_raw_response_wrapper(
            channels.count,
        )
        self.queryhelp = async_to_raw_response_wrapper(
            channels.queryhelp,
        )
        self.tuple = async_to_raw_response_wrapper(
            channels.tuple,
        )


class ChannelsResourceWithStreamingResponse:
    def __init__(self, channels: ChannelsResource) -> None:
        self._channels = channels

        self.create = to_streamed_response_wrapper(
            channels.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            channels.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            channels.update,
        )
        self.list = to_streamed_response_wrapper(
            channels.list,
        )
        self.delete = to_streamed_response_wrapper(
            channels.delete,
        )
        self.count = to_streamed_response_wrapper(
            channels.count,
        )
        self.queryhelp = to_streamed_response_wrapper(
            channels.queryhelp,
        )
        self.tuple = to_streamed_response_wrapper(
            channels.tuple,
        )


class AsyncChannelsResourceWithStreamingResponse:
    def __init__(self, channels: AsyncChannelsResource) -> None:
        self._channels = channels

        self.create = async_to_streamed_response_wrapper(
            channels.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            channels.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            channels.update,
        )
        self.list = async_to_streamed_response_wrapper(
            channels.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            channels.delete,
        )
        self.count = async_to_streamed_response_wrapper(
            channels.count,
        )
        self.queryhelp = async_to_streamed_response_wrapper(
            channels.queryhelp,
        )
        self.tuple = async_to_streamed_response_wrapper(
            channels.tuple,
        )
