# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import (
    groundimagery_list_params,
    groundimagery_count_params,
    groundimagery_tuple_params,
    groundimagery_create_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    to_custom_raw_response_wrapper,
    async_to_streamed_response_wrapper,
    to_custom_streamed_response_wrapper,
    async_to_custom_raw_response_wrapper,
    async_to_custom_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.groundimagery_list_response import GroundimageryListResponse
from ..types.groundimagery_tuple_response import GroundimageryTupleResponse
from ..types.udl.groundimagery.ground_imagery_full import GroundImageryFull

__all__ = ["GroundimageryResource", "AsyncGroundimageryResource"]


class GroundimageryResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GroundimageryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return GroundimageryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GroundimageryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return GroundimageryResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        filename: str,
        image_time: Union[str, datetime],
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        checksum_value: str | NotGiven = NOT_GIVEN,
        filesize: int | NotGiven = NOT_GIVEN,
        format: str | NotGiven = NOT_GIVEN,
        id_sensor: str | NotGiven = NOT_GIVEN,
        keywords: List[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        orig_sensor_id: str | NotGiven = NOT_GIVEN,
        region: str | NotGiven = NOT_GIVEN,
        region_geo_json: str | NotGiven = NOT_GIVEN,
        region_n_dims: int | NotGiven = NOT_GIVEN,
        region_s_rid: int | NotGiven = NOT_GIVEN,
        region_text: str | NotGiven = NOT_GIVEN,
        region_type: str | NotGiven = NOT_GIVEN,
        subject_id: str | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        transaction_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single GroundImagery object as a POST body and
        ingest into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          filename: Name of the image file.

          image_time: Timestamp the image was captured/produced.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          checksum_value: MD5 value of the file. The ingest/create operation will automatically generate
              the value.

          filesize: Size of the image file. Units in bytes. If filesize is provided without an
              associated file, it defaults to 0.

          format: Optional, field indicating type of image, NITF, PNG, etc.

          id_sensor: Optional ID of the sensor that produced this ground image.

          keywords: Optional array of keywords for this image.

          name: Optional name/description associated with this image.

          notes: Description and notes of the image.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          orig_sensor_id: Optional identifier provided by source to indicate the sensor identifier used to
              detect this event. This may be an internal identifier and not necessarily a
              valid sensor ID.

          region: Geographical region or polygon (lon/lat pairs) of the image as projected on the
              ground in geoJSON or geoText format. This is an optional convenience field only
              used for create operations. The system will auto-detect the format (Well Known
              Text or GeoJSON) and populate both regionText and regionGeoJSON fields
              appropriately. When omitted, regionText or regionGeoJSON is expected.

          region_geo_json: Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
              representation of the geometry/geography, of the image as projected on the
              ground. Reference: https://geojson.org/. Ignored if included with a create
              operation that also specifies a valid region or regionText.

          region_n_dims: Number of dimensions of the geometry depicted by region.

          region_s_rid: Geographical spatial_ref_sys for region.

          region_text: Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
              Text representation of the geometry/geography, of the image as projected on the
              ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
              if included with a create operation that also specifies a valid region.

          region_type: Type of region as projected on the ground.

          subject_id: Optional identifier of the subject/target of the image, useful for correlating
              multiple images of the same subject.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          transaction_id: Optional identifier to track a commercial or marketplace transaction executed to
              produce this data.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/groundimagery",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "filename": filename,
                    "image_time": image_time,
                    "source": source,
                    "id": id,
                    "checksum_value": checksum_value,
                    "filesize": filesize,
                    "format": format,
                    "id_sensor": id_sensor,
                    "keywords": keywords,
                    "name": name,
                    "notes": notes,
                    "origin": origin,
                    "orig_sensor_id": orig_sensor_id,
                    "region": region,
                    "region_geo_json": region_geo_json,
                    "region_n_dims": region_n_dims,
                    "region_s_rid": region_s_rid,
                    "region_text": region_text,
                    "region_type": region_type,
                    "subject_id": subject_id,
                    "tags": tags,
                    "transaction_id": transaction_id,
                },
                groundimagery_create_params.GroundimageryCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        image_time: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GroundimageryListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.

        Args:
          image_time: Timestamp the image was captured/produced. (YYYY-MM-DDTHH:MM:SS.ssssssZ)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/groundimagery",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"image_time": image_time}, groundimagery_list_params.GroundimageryListParams),
            ),
            cast_to=GroundimageryListResponse,
        )

    def count(
        self,
        *,
        image_time: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.

        Args:
          image_time: Timestamp the image was captured/produced. (YYYY-MM-DDTHH:MM:SS.ssssssZ)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/groundimagery/count",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"image_time": image_time}, groundimagery_count_params.GroundimageryCountParams),
            ),
            cast_to=str,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GroundImageryFull:
        """
        Service operation to get a single GroundImagery record by its unique ID passed
        as a path parameter. GroundImagery represents metadata about a ground image, as
        well as the actual binary image data.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/groundimagery/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GroundImageryFull,
        )

    def get_file(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> BinaryAPIResponse:
        """
        Service operation to get a single GroundImagery binary image by its unique ID
        passed as a path parameter. The image is returned as an attachment
        Content-Disposition.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/octet-stream", **(extra_headers or {})}
        return self._get(
            f"/udl/groundimagery/getFile/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )

    def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/groundimagery/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        image_time: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GroundimageryTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          image_time: Timestamp the image was captured/produced. (YYYY-MM-DDTHH:MM:SS.ssssssZ)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/groundimagery/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "columns": columns,
                        "image_time": image_time,
                    },
                    groundimagery_tuple_params.GroundimageryTupleParams,
                ),
            ),
            cast_to=GroundimageryTupleResponse,
        )


class AsyncGroundimageryResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGroundimageryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncGroundimageryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGroundimageryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncGroundimageryResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        filename: str,
        image_time: Union[str, datetime],
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        checksum_value: str | NotGiven = NOT_GIVEN,
        filesize: int | NotGiven = NOT_GIVEN,
        format: str | NotGiven = NOT_GIVEN,
        id_sensor: str | NotGiven = NOT_GIVEN,
        keywords: List[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        orig_sensor_id: str | NotGiven = NOT_GIVEN,
        region: str | NotGiven = NOT_GIVEN,
        region_geo_json: str | NotGiven = NOT_GIVEN,
        region_n_dims: int | NotGiven = NOT_GIVEN,
        region_s_rid: int | NotGiven = NOT_GIVEN,
        region_text: str | NotGiven = NOT_GIVEN,
        region_type: str | NotGiven = NOT_GIVEN,
        subject_id: str | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        transaction_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single GroundImagery object as a POST body and
        ingest into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          filename: Name of the image file.

          image_time: Timestamp the image was captured/produced.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          checksum_value: MD5 value of the file. The ingest/create operation will automatically generate
              the value.

          filesize: Size of the image file. Units in bytes. If filesize is provided without an
              associated file, it defaults to 0.

          format: Optional, field indicating type of image, NITF, PNG, etc.

          id_sensor: Optional ID of the sensor that produced this ground image.

          keywords: Optional array of keywords for this image.

          name: Optional name/description associated with this image.

          notes: Description and notes of the image.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          orig_sensor_id: Optional identifier provided by source to indicate the sensor identifier used to
              detect this event. This may be an internal identifier and not necessarily a
              valid sensor ID.

          region: Geographical region or polygon (lon/lat pairs) of the image as projected on the
              ground in geoJSON or geoText format. This is an optional convenience field only
              used for create operations. The system will auto-detect the format (Well Known
              Text or GeoJSON) and populate both regionText and regionGeoJSON fields
              appropriately. When omitted, regionText or regionGeoJSON is expected.

          region_geo_json: Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
              representation of the geometry/geography, of the image as projected on the
              ground. Reference: https://geojson.org/. Ignored if included with a create
              operation that also specifies a valid region or regionText.

          region_n_dims: Number of dimensions of the geometry depicted by region.

          region_s_rid: Geographical spatial_ref_sys for region.

          region_text: Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
              Text representation of the geometry/geography, of the image as projected on the
              ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
              if included with a create operation that also specifies a valid region.

          region_type: Type of region as projected on the ground.

          subject_id: Optional identifier of the subject/target of the image, useful for correlating
              multiple images of the same subject.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          transaction_id: Optional identifier to track a commercial or marketplace transaction executed to
              produce this data.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/groundimagery",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "filename": filename,
                    "image_time": image_time,
                    "source": source,
                    "id": id,
                    "checksum_value": checksum_value,
                    "filesize": filesize,
                    "format": format,
                    "id_sensor": id_sensor,
                    "keywords": keywords,
                    "name": name,
                    "notes": notes,
                    "origin": origin,
                    "orig_sensor_id": orig_sensor_id,
                    "region": region,
                    "region_geo_json": region_geo_json,
                    "region_n_dims": region_n_dims,
                    "region_s_rid": region_s_rid,
                    "region_text": region_text,
                    "region_type": region_type,
                    "subject_id": subject_id,
                    "tags": tags,
                    "transaction_id": transaction_id,
                },
                groundimagery_create_params.GroundimageryCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        image_time: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GroundimageryListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.

        Args:
          image_time: Timestamp the image was captured/produced. (YYYY-MM-DDTHH:MM:SS.ssssssZ)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/groundimagery",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"image_time": image_time}, groundimagery_list_params.GroundimageryListParams
                ),
            ),
            cast_to=GroundimageryListResponse,
        )

    async def count(
        self,
        *,
        image_time: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.

        Args:
          image_time: Timestamp the image was captured/produced. (YYYY-MM-DDTHH:MM:SS.ssssssZ)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/groundimagery/count",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"image_time": image_time}, groundimagery_count_params.GroundimageryCountParams
                ),
            ),
            cast_to=str,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GroundImageryFull:
        """
        Service operation to get a single GroundImagery record by its unique ID passed
        as a path parameter. GroundImagery represents metadata about a ground image, as
        well as the actual binary image data.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/groundimagery/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GroundImageryFull,
        )

    async def get_file(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AsyncBinaryAPIResponse:
        """
        Service operation to get a single GroundImagery binary image by its unique ID
        passed as a path parameter. The image is returned as an attachment
        Content-Disposition.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/octet-stream", **(extra_headers or {})}
        return await self._get(
            f"/udl/groundimagery/getFile/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )

    async def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/groundimagery/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        image_time: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GroundimageryTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          image_time: Timestamp the image was captured/produced. (YYYY-MM-DDTHH:MM:SS.ssssssZ)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/groundimagery/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "columns": columns,
                        "image_time": image_time,
                    },
                    groundimagery_tuple_params.GroundimageryTupleParams,
                ),
            ),
            cast_to=GroundimageryTupleResponse,
        )


class GroundimageryResourceWithRawResponse:
    def __init__(self, groundimagery: GroundimageryResource) -> None:
        self._groundimagery = groundimagery

        self.create = to_raw_response_wrapper(
            groundimagery.create,
        )
        self.list = to_raw_response_wrapper(
            groundimagery.list,
        )
        self.count = to_raw_response_wrapper(
            groundimagery.count,
        )
        self.get = to_raw_response_wrapper(
            groundimagery.get,
        )
        self.get_file = to_custom_raw_response_wrapper(
            groundimagery.get_file,
            BinaryAPIResponse,
        )
        self.queryhelp = to_raw_response_wrapper(
            groundimagery.queryhelp,
        )
        self.tuple = to_raw_response_wrapper(
            groundimagery.tuple,
        )


class AsyncGroundimageryResourceWithRawResponse:
    def __init__(self, groundimagery: AsyncGroundimageryResource) -> None:
        self._groundimagery = groundimagery

        self.create = async_to_raw_response_wrapper(
            groundimagery.create,
        )
        self.list = async_to_raw_response_wrapper(
            groundimagery.list,
        )
        self.count = async_to_raw_response_wrapper(
            groundimagery.count,
        )
        self.get = async_to_raw_response_wrapper(
            groundimagery.get,
        )
        self.get_file = async_to_custom_raw_response_wrapper(
            groundimagery.get_file,
            AsyncBinaryAPIResponse,
        )
        self.queryhelp = async_to_raw_response_wrapper(
            groundimagery.queryhelp,
        )
        self.tuple = async_to_raw_response_wrapper(
            groundimagery.tuple,
        )


class GroundimageryResourceWithStreamingResponse:
    def __init__(self, groundimagery: GroundimageryResource) -> None:
        self._groundimagery = groundimagery

        self.create = to_streamed_response_wrapper(
            groundimagery.create,
        )
        self.list = to_streamed_response_wrapper(
            groundimagery.list,
        )
        self.count = to_streamed_response_wrapper(
            groundimagery.count,
        )
        self.get = to_streamed_response_wrapper(
            groundimagery.get,
        )
        self.get_file = to_custom_streamed_response_wrapper(
            groundimagery.get_file,
            StreamedBinaryAPIResponse,
        )
        self.queryhelp = to_streamed_response_wrapper(
            groundimagery.queryhelp,
        )
        self.tuple = to_streamed_response_wrapper(
            groundimagery.tuple,
        )


class AsyncGroundimageryResourceWithStreamingResponse:
    def __init__(self, groundimagery: AsyncGroundimageryResource) -> None:
        self._groundimagery = groundimagery

        self.create = async_to_streamed_response_wrapper(
            groundimagery.create,
        )
        self.list = async_to_streamed_response_wrapper(
            groundimagery.list,
        )
        self.count = async_to_streamed_response_wrapper(
            groundimagery.count,
        )
        self.get = async_to_streamed_response_wrapper(
            groundimagery.get,
        )
        self.get_file = async_to_custom_streamed_response_wrapper(
            groundimagery.get_file,
            AsyncStreamedBinaryAPIResponse,
        )
        self.queryhelp = async_to_streamed_response_wrapper(
            groundimagery.queryhelp,
        )
        self.tuple = async_to_streamed_response_wrapper(
            groundimagery.tuple,
        )
