# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal

import httpx

from ..types import (
    launchsitedetail_create_params,
    launchsitedetail_update_params,
    launchsitedetail_find_by_source_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.location_ingest_param import LocationIngestParam
from ..types.launchsitedetail_get_response import LaunchsitedetailGetResponse
from ..types.launchsitedetail_list_response import LaunchsitedetailListResponse
from ..types.launchsitedetail_find_by_source_response import LaunchsitedetailFindBySourceResponse

__all__ = ["LaunchsitedetailsResource", "AsyncLaunchsitedetailsResource"]


class LaunchsitedetailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LaunchsitedetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return LaunchsitedetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LaunchsitedetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return LaunchsitedetailsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_launch_site: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        available_inclinations: Iterable[float] | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        id_location: str | NotGiven = NOT_GIVEN,
        launch_group: str | NotGiven = NOT_GIVEN,
        location: LocationIngestParam | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single LaunchSiteDetails as a POST body and ingest
        into the database. A LaunchSiteDetails represents details compiled/collected on
        a launch site by a particular source. A launch site may have several details
        records. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_launch_site: Identifier of the parent launch site record.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          available_inclinations: Array of supported launch inclinations known for this site. The array is always
              sized as a multiple of two and includes start/end values to support ranges. For
              example, if a site support inclinations of 10 and 12-14, the array would have
              the following values: [10,10, 12,14].

          description: Notes/description of the launch site.

          id_location: ID of the location data for the launch site, or null if mobile (e.g. sea launch
              platform in international waters).

          launch_group: Launch site group name. Multiple launch sites may be colocated within a launch
              ''group''.

          location: Model representation of a location, which is a specific fixed point on the earth
              and is used to denote the locations of fixed sensors, operating units, etc.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/launchsitedetails",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_launch_site": id_launch_site,
                    "source": source,
                    "id": id,
                    "available_inclinations": available_inclinations,
                    "description": description,
                    "id_location": id_location,
                    "launch_group": launch_group,
                    "location": location,
                    "origin": origin,
                },
                launchsitedetail_create_params.LaunchsitedetailCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_launch_site: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        available_inclinations: Iterable[float] | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        id_location: str | NotGiven = NOT_GIVEN,
        launch_group: str | NotGiven = NOT_GIVEN,
        location: LocationIngestParam | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a LaunchSiteDetails.

        A LaunchSiteDetails represents
        details compiled/collected on a launch site by a particular source. A launch
        site may have several details records. A specific role is required to perform
        this service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_launch_site: Identifier of the parent launch site record.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          available_inclinations: Array of supported launch inclinations known for this site. The array is always
              sized as a multiple of two and includes start/end values to support ranges. For
              example, if a site support inclinations of 10 and 12-14, the array would have
              the following values: [10,10, 12,14].

          description: Notes/description of the launch site.

          id_location: ID of the location data for the launch site, or null if mobile (e.g. sea launch
              platform in international waters).

          launch_group: Launch site group name. Multiple launch sites may be colocated within a launch
              ''group''.

          location: Model representation of a location, which is a specific fixed point on the earth
              and is used to denote the locations of fixed sensors, operating units, etc.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/launchsitedetails/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_launch_site": id_launch_site,
                    "source": source,
                    "body_id": body_id,
                    "available_inclinations": available_inclinations,
                    "description": description,
                    "id_location": id_location,
                    "launch_group": launch_group,
                    "location": location,
                    "origin": origin,
                },
                launchsitedetail_update_params.LaunchsitedetailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LaunchsitedetailListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/launchsitedetails",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LaunchsitedetailListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a LaunchSiteDetails specified by the passed ID path
        parameter. A LaunchSiteDetails represents details compiled/collected on a launch
        site by a particular source. A launch site may have several details records. A
        specific role is required to perform this service operation. Please contact the
        UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/launchsitedetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def find_by_source(
        self,
        *,
        source: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LaunchsitedetailFindBySourceResponse:
        """
        Service operation to get a single LaunchSiteDetails by a source passed as a
        query parameter. A LaunchSiteDetails represents details compiled/collected on a
        launch site by a particular source. A launch site may have several details
        records.

        Args:
          source: The source of the LaunchSiteDetails records to find.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/launchsitedetails/findBySource",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"source": source}, launchsitedetail_find_by_source_params.LaunchsitedetailFindBySourceParams
                ),
            ),
            cast_to=LaunchsitedetailFindBySourceResponse,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LaunchsitedetailGetResponse:
        """
        Service operation to get a single LaunchSiteDetails by its unique ID passed as a
        path parameter. A LaunchSiteDetails represents details compiled/collected on a
        launch site by a particular source. A launch site may have several details
        records.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/launchsitedetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LaunchsitedetailGetResponse,
        )


class AsyncLaunchsitedetailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLaunchsitedetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncLaunchsitedetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLaunchsitedetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncLaunchsitedetailsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_launch_site: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        available_inclinations: Iterable[float] | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        id_location: str | NotGiven = NOT_GIVEN,
        launch_group: str | NotGiven = NOT_GIVEN,
        location: LocationIngestParam | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single LaunchSiteDetails as a POST body and ingest
        into the database. A LaunchSiteDetails represents details compiled/collected on
        a launch site by a particular source. A launch site may have several details
        records. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_launch_site: Identifier of the parent launch site record.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          available_inclinations: Array of supported launch inclinations known for this site. The array is always
              sized as a multiple of two and includes start/end values to support ranges. For
              example, if a site support inclinations of 10 and 12-14, the array would have
              the following values: [10,10, 12,14].

          description: Notes/description of the launch site.

          id_location: ID of the location data for the launch site, or null if mobile (e.g. sea launch
              platform in international waters).

          launch_group: Launch site group name. Multiple launch sites may be colocated within a launch
              ''group''.

          location: Model representation of a location, which is a specific fixed point on the earth
              and is used to denote the locations of fixed sensors, operating units, etc.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/launchsitedetails",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_launch_site": id_launch_site,
                    "source": source,
                    "id": id,
                    "available_inclinations": available_inclinations,
                    "description": description,
                    "id_location": id_location,
                    "launch_group": launch_group,
                    "location": location,
                    "origin": origin,
                },
                launchsitedetail_create_params.LaunchsitedetailCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_launch_site: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        available_inclinations: Iterable[float] | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        id_location: str | NotGiven = NOT_GIVEN,
        launch_group: str | NotGiven = NOT_GIVEN,
        location: LocationIngestParam | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a LaunchSiteDetails.

        A LaunchSiteDetails represents
        details compiled/collected on a launch site by a particular source. A launch
        site may have several details records. A specific role is required to perform
        this service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_launch_site: Identifier of the parent launch site record.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          available_inclinations: Array of supported launch inclinations known for this site. The array is always
              sized as a multiple of two and includes start/end values to support ranges. For
              example, if a site support inclinations of 10 and 12-14, the array would have
              the following values: [10,10, 12,14].

          description: Notes/description of the launch site.

          id_location: ID of the location data for the launch site, or null if mobile (e.g. sea launch
              platform in international waters).

          launch_group: Launch site group name. Multiple launch sites may be colocated within a launch
              ''group''.

          location: Model representation of a location, which is a specific fixed point on the earth
              and is used to denote the locations of fixed sensors, operating units, etc.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/launchsitedetails/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_launch_site": id_launch_site,
                    "source": source,
                    "body_id": body_id,
                    "available_inclinations": available_inclinations,
                    "description": description,
                    "id_location": id_location,
                    "launch_group": launch_group,
                    "location": location,
                    "origin": origin,
                },
                launchsitedetail_update_params.LaunchsitedetailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LaunchsitedetailListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/launchsitedetails",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LaunchsitedetailListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a LaunchSiteDetails specified by the passed ID path
        parameter. A LaunchSiteDetails represents details compiled/collected on a launch
        site by a particular source. A launch site may have several details records. A
        specific role is required to perform this service operation. Please contact the
        UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/launchsitedetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def find_by_source(
        self,
        *,
        source: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LaunchsitedetailFindBySourceResponse:
        """
        Service operation to get a single LaunchSiteDetails by a source passed as a
        query parameter. A LaunchSiteDetails represents details compiled/collected on a
        launch site by a particular source. A launch site may have several details
        records.

        Args:
          source: The source of the LaunchSiteDetails records to find.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/launchsitedetails/findBySource",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"source": source}, launchsitedetail_find_by_source_params.LaunchsitedetailFindBySourceParams
                ),
            ),
            cast_to=LaunchsitedetailFindBySourceResponse,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LaunchsitedetailGetResponse:
        """
        Service operation to get a single LaunchSiteDetails by its unique ID passed as a
        path parameter. A LaunchSiteDetails represents details compiled/collected on a
        launch site by a particular source. A launch site may have several details
        records.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/launchsitedetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LaunchsitedetailGetResponse,
        )


class LaunchsitedetailsResourceWithRawResponse:
    def __init__(self, launchsitedetails: LaunchsitedetailsResource) -> None:
        self._launchsitedetails = launchsitedetails

        self.create = to_raw_response_wrapper(
            launchsitedetails.create,
        )
        self.update = to_raw_response_wrapper(
            launchsitedetails.update,
        )
        self.list = to_raw_response_wrapper(
            launchsitedetails.list,
        )
        self.delete = to_raw_response_wrapper(
            launchsitedetails.delete,
        )
        self.find_by_source = to_raw_response_wrapper(
            launchsitedetails.find_by_source,
        )
        self.get = to_raw_response_wrapper(
            launchsitedetails.get,
        )


class AsyncLaunchsitedetailsResourceWithRawResponse:
    def __init__(self, launchsitedetails: AsyncLaunchsitedetailsResource) -> None:
        self._launchsitedetails = launchsitedetails

        self.create = async_to_raw_response_wrapper(
            launchsitedetails.create,
        )
        self.update = async_to_raw_response_wrapper(
            launchsitedetails.update,
        )
        self.list = async_to_raw_response_wrapper(
            launchsitedetails.list,
        )
        self.delete = async_to_raw_response_wrapper(
            launchsitedetails.delete,
        )
        self.find_by_source = async_to_raw_response_wrapper(
            launchsitedetails.find_by_source,
        )
        self.get = async_to_raw_response_wrapper(
            launchsitedetails.get,
        )


class LaunchsitedetailsResourceWithStreamingResponse:
    def __init__(self, launchsitedetails: LaunchsitedetailsResource) -> None:
        self._launchsitedetails = launchsitedetails

        self.create = to_streamed_response_wrapper(
            launchsitedetails.create,
        )
        self.update = to_streamed_response_wrapper(
            launchsitedetails.update,
        )
        self.list = to_streamed_response_wrapper(
            launchsitedetails.list,
        )
        self.delete = to_streamed_response_wrapper(
            launchsitedetails.delete,
        )
        self.find_by_source = to_streamed_response_wrapper(
            launchsitedetails.find_by_source,
        )
        self.get = to_streamed_response_wrapper(
            launchsitedetails.get,
        )


class AsyncLaunchsitedetailsResourceWithStreamingResponse:
    def __init__(self, launchsitedetails: AsyncLaunchsitedetailsResource) -> None:
        self._launchsitedetails = launchsitedetails

        self.create = async_to_streamed_response_wrapper(
            launchsitedetails.create,
        )
        self.update = async_to_streamed_response_wrapper(
            launchsitedetails.update,
        )
        self.list = async_to_streamed_response_wrapper(
            launchsitedetails.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            launchsitedetails.delete,
        )
        self.find_by_source = async_to_streamed_response_wrapper(
            launchsitedetails.find_by_source,
        )
        self.get = async_to_streamed_response_wrapper(
            launchsitedetails.get,
        )
