# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.onorbit import antenna_detail_create_params, antenna_detail_update_params
from ...types.onorbit.antenna_details_full import AntennaDetailsFull
from ...types.onorbit.antenna_detail_list_response import AntennaDetailListResponse

__all__ = ["AntennaDetailsResource", "AsyncAntennaDetailsResource"]


class AntennaDetailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AntennaDetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AntennaDetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AntennaDetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AntennaDetailsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        beam_forming: bool | NotGiven = NOT_GIVEN,
        beamwidth: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        diameter: float | NotGiven = NOT_GIVEN,
        end_frequency: float | NotGiven = NOT_GIVEN,
        gain: float | NotGiven = NOT_GIVEN,
        gain_tolerance: float | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        mode: Literal["TX", "RX"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        polarization: float | NotGiven = NOT_GIVEN,
        position: str | NotGiven = NOT_GIVEN,
        size: Iterable[float] | NotGiven = NOT_GIVEN,
        start_frequency: float | NotGiven = NOT_GIVEN,
        steerable: bool | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single AntennaDetails as a POST body and ingest into
        the database. An antenna may have multiple details records compiled by various
        sources. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: Unique identifier of the parent Antenna.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          beam_forming: Boolean indicating if this is a beam forming antenna.

          beamwidth: Array of angles between the half-power (-3 dB) points of the main lobe of the
              antenna, in degrees.

          description: Antenna description.

          diameter: Antenna diameter in meters.

          end_frequency: Antenna end of frequency range in Mhz.

          gain: Antenna maximum gain in dBi.

          gain_tolerance: Antenna gain tolerance in dB.

          manufacturer_org_id: ID of the organization that manufactures the antenna.

          mode: Antenna mode (e.g. TX,RX).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          polarization: Antenna polarization in degrees.

          position: Antenna position (e.g. Top, Nadir, Side).

          size: Array with 1-2 values specifying the length and width (for rectangular) and just
              length for dipole antennas in meters.

          start_frequency: Antenna start of frequency range in Mhz.

          steerable: Boolean indicating if this antenna is steerable.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          type: Type of antenna (e.g. Reflector, Double Reflector, Shaped Reflector, Horn,
              Parabolic, etc.).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/antennadetails",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "source": source,
                    "id": id,
                    "beam_forming": beam_forming,
                    "beamwidth": beamwidth,
                    "description": description,
                    "diameter": diameter,
                    "end_frequency": end_frequency,
                    "gain": gain,
                    "gain_tolerance": gain_tolerance,
                    "manufacturer_org_id": manufacturer_org_id,
                    "mode": mode,
                    "origin": origin,
                    "polarization": polarization,
                    "position": position,
                    "size": size,
                    "start_frequency": start_frequency,
                    "steerable": steerable,
                    "tags": tags,
                    "type": type,
                },
                antenna_detail_create_params.AntennaDetailCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AntennaDetailsFull:
        """
        Service operation to get a single AntennaDetails record by its unique ID passed
        as a path parameter. An antenna may have multiple details records compiled by
        various sources.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/antennadetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AntennaDetailsFull,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        beam_forming: bool | NotGiven = NOT_GIVEN,
        beamwidth: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        diameter: float | NotGiven = NOT_GIVEN,
        end_frequency: float | NotGiven = NOT_GIVEN,
        gain: float | NotGiven = NOT_GIVEN,
        gain_tolerance: float | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        mode: Literal["TX", "RX"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        polarization: float | NotGiven = NOT_GIVEN,
        position: str | NotGiven = NOT_GIVEN,
        size: Iterable[float] | NotGiven = NOT_GIVEN,
        start_frequency: float | NotGiven = NOT_GIVEN,
        steerable: bool | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single AntennaDetails.

        An antenna may have
        multiple details records compiled by various sources. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: Unique identifier of the parent Antenna.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          beam_forming: Boolean indicating if this is a beam forming antenna.

          beamwidth: Array of angles between the half-power (-3 dB) points of the main lobe of the
              antenna, in degrees.

          description: Antenna description.

          diameter: Antenna diameter in meters.

          end_frequency: Antenna end of frequency range in Mhz.

          gain: Antenna maximum gain in dBi.

          gain_tolerance: Antenna gain tolerance in dB.

          manufacturer_org_id: ID of the organization that manufactures the antenna.

          mode: Antenna mode (e.g. TX,RX).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          polarization: Antenna polarization in degrees.

          position: Antenna position (e.g. Top, Nadir, Side).

          size: Array with 1-2 values specifying the length and width (for rectangular) and just
              length for dipole antennas in meters.

          start_frequency: Antenna start of frequency range in Mhz.

          steerable: Boolean indicating if this antenna is steerable.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          type: Type of antenna (e.g. Reflector, Double Reflector, Shaped Reflector, Horn,
              Parabolic, etc.).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/antennadetails/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "source": source,
                    "body_id": body_id,
                    "beam_forming": beam_forming,
                    "beamwidth": beamwidth,
                    "description": description,
                    "diameter": diameter,
                    "end_frequency": end_frequency,
                    "gain": gain,
                    "gain_tolerance": gain_tolerance,
                    "manufacturer_org_id": manufacturer_org_id,
                    "mode": mode,
                    "origin": origin,
                    "polarization": polarization,
                    "position": position,
                    "size": size,
                    "start_frequency": start_frequency,
                    "steerable": steerable,
                    "tags": tags,
                    "type": type,
                },
                antenna_detail_update_params.AntennaDetailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AntennaDetailListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/antennadetails",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AntennaDetailListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a AntennaDetails object specified by the passed ID
        path parameter. An antenna may have multiple details records compiled by various
        sources. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/antennadetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAntennaDetailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAntennaDetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAntennaDetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAntennaDetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncAntennaDetailsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        beam_forming: bool | NotGiven = NOT_GIVEN,
        beamwidth: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        diameter: float | NotGiven = NOT_GIVEN,
        end_frequency: float | NotGiven = NOT_GIVEN,
        gain: float | NotGiven = NOT_GIVEN,
        gain_tolerance: float | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        mode: Literal["TX", "RX"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        polarization: float | NotGiven = NOT_GIVEN,
        position: str | NotGiven = NOT_GIVEN,
        size: Iterable[float] | NotGiven = NOT_GIVEN,
        start_frequency: float | NotGiven = NOT_GIVEN,
        steerable: bool | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single AntennaDetails as a POST body and ingest into
        the database. An antenna may have multiple details records compiled by various
        sources. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: Unique identifier of the parent Antenna.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          beam_forming: Boolean indicating if this is a beam forming antenna.

          beamwidth: Array of angles between the half-power (-3 dB) points of the main lobe of the
              antenna, in degrees.

          description: Antenna description.

          diameter: Antenna diameter in meters.

          end_frequency: Antenna end of frequency range in Mhz.

          gain: Antenna maximum gain in dBi.

          gain_tolerance: Antenna gain tolerance in dB.

          manufacturer_org_id: ID of the organization that manufactures the antenna.

          mode: Antenna mode (e.g. TX,RX).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          polarization: Antenna polarization in degrees.

          position: Antenna position (e.g. Top, Nadir, Side).

          size: Array with 1-2 values specifying the length and width (for rectangular) and just
              length for dipole antennas in meters.

          start_frequency: Antenna start of frequency range in Mhz.

          steerable: Boolean indicating if this antenna is steerable.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          type: Type of antenna (e.g. Reflector, Double Reflector, Shaped Reflector, Horn,
              Parabolic, etc.).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/antennadetails",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "source": source,
                    "id": id,
                    "beam_forming": beam_forming,
                    "beamwidth": beamwidth,
                    "description": description,
                    "diameter": diameter,
                    "end_frequency": end_frequency,
                    "gain": gain,
                    "gain_tolerance": gain_tolerance,
                    "manufacturer_org_id": manufacturer_org_id,
                    "mode": mode,
                    "origin": origin,
                    "polarization": polarization,
                    "position": position,
                    "size": size,
                    "start_frequency": start_frequency,
                    "steerable": steerable,
                    "tags": tags,
                    "type": type,
                },
                antenna_detail_create_params.AntennaDetailCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AntennaDetailsFull:
        """
        Service operation to get a single AntennaDetails record by its unique ID passed
        as a path parameter. An antenna may have multiple details records compiled by
        various sources.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/antennadetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AntennaDetailsFull,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        beam_forming: bool | NotGiven = NOT_GIVEN,
        beamwidth: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        diameter: float | NotGiven = NOT_GIVEN,
        end_frequency: float | NotGiven = NOT_GIVEN,
        gain: float | NotGiven = NOT_GIVEN,
        gain_tolerance: float | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        mode: Literal["TX", "RX"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        polarization: float | NotGiven = NOT_GIVEN,
        position: str | NotGiven = NOT_GIVEN,
        size: Iterable[float] | NotGiven = NOT_GIVEN,
        start_frequency: float | NotGiven = NOT_GIVEN,
        steerable: bool | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single AntennaDetails.

        An antenna may have
        multiple details records compiled by various sources. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: Unique identifier of the parent Antenna.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          beam_forming: Boolean indicating if this is a beam forming antenna.

          beamwidth: Array of angles between the half-power (-3 dB) points of the main lobe of the
              antenna, in degrees.

          description: Antenna description.

          diameter: Antenna diameter in meters.

          end_frequency: Antenna end of frequency range in Mhz.

          gain: Antenna maximum gain in dBi.

          gain_tolerance: Antenna gain tolerance in dB.

          manufacturer_org_id: ID of the organization that manufactures the antenna.

          mode: Antenna mode (e.g. TX,RX).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          polarization: Antenna polarization in degrees.

          position: Antenna position (e.g. Top, Nadir, Side).

          size: Array with 1-2 values specifying the length and width (for rectangular) and just
              length for dipole antennas in meters.

          start_frequency: Antenna start of frequency range in Mhz.

          steerable: Boolean indicating if this antenna is steerable.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          type: Type of antenna (e.g. Reflector, Double Reflector, Shaped Reflector, Horn,
              Parabolic, etc.).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/antennadetails/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "source": source,
                    "body_id": body_id,
                    "beam_forming": beam_forming,
                    "beamwidth": beamwidth,
                    "description": description,
                    "diameter": diameter,
                    "end_frequency": end_frequency,
                    "gain": gain,
                    "gain_tolerance": gain_tolerance,
                    "manufacturer_org_id": manufacturer_org_id,
                    "mode": mode,
                    "origin": origin,
                    "polarization": polarization,
                    "position": position,
                    "size": size,
                    "start_frequency": start_frequency,
                    "steerable": steerable,
                    "tags": tags,
                    "type": type,
                },
                antenna_detail_update_params.AntennaDetailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AntennaDetailListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/antennadetails",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AntennaDetailListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a AntennaDetails object specified by the passed ID
        path parameter. An antenna may have multiple details records compiled by various
        sources. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/antennadetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AntennaDetailsResourceWithRawResponse:
    def __init__(self, antenna_details: AntennaDetailsResource) -> None:
        self._antenna_details = antenna_details

        self.create = to_raw_response_wrapper(
            antenna_details.create,
        )
        self.retrieve = to_raw_response_wrapper(
            antenna_details.retrieve,
        )
        self.update = to_raw_response_wrapper(
            antenna_details.update,
        )
        self.list = to_raw_response_wrapper(
            antenna_details.list,
        )
        self.delete = to_raw_response_wrapper(
            antenna_details.delete,
        )


class AsyncAntennaDetailsResourceWithRawResponse:
    def __init__(self, antenna_details: AsyncAntennaDetailsResource) -> None:
        self._antenna_details = antenna_details

        self.create = async_to_raw_response_wrapper(
            antenna_details.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            antenna_details.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            antenna_details.update,
        )
        self.list = async_to_raw_response_wrapper(
            antenna_details.list,
        )
        self.delete = async_to_raw_response_wrapper(
            antenna_details.delete,
        )


class AntennaDetailsResourceWithStreamingResponse:
    def __init__(self, antenna_details: AntennaDetailsResource) -> None:
        self._antenna_details = antenna_details

        self.create = to_streamed_response_wrapper(
            antenna_details.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            antenna_details.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            antenna_details.update,
        )
        self.list = to_streamed_response_wrapper(
            antenna_details.list,
        )
        self.delete = to_streamed_response_wrapper(
            antenna_details.delete,
        )


class AsyncAntennaDetailsResourceWithStreamingResponse:
    def __init__(self, antenna_details: AsyncAntennaDetailsResource) -> None:
        self._antenna_details = antenna_details

        self.create = async_to_streamed_response_wrapper(
            antenna_details.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            antenna_details.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            antenna_details.update,
        )
        self.list = async_to_streamed_response_wrapper(
            antenna_details.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            antenna_details.delete,
        )
