# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import onorbitantenna_create_params, onorbitantenna_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.onorbitantenna_get_response import OnorbitantennaGetResponse
from ..types.onorbitantenna_list_response import OnorbitantennaListResponse

__all__ = ["OnorbitantennaResource", "AsyncOnorbitantennaResource"]


class OnorbitantennaResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OnorbitantennaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return OnorbitantennaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OnorbitantennaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return OnorbitantennaResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        id_on_orbit: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        antenna: onorbitantenna_create_params.Antenna | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single OnorbitAntenna as a POST body and ingest into
        the database. An OnorbitAntenna is the association between on-orbit spacecraft
        antennas and a particular on-orbit spacecraft. An antenna type may be associated
        with many different on-orbit spacecraft. A specific role is required to perform
        this service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: ID of the antenna.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          antenna: Model representation of information on on-orbit/spacecraft communication
              antennas. A spacecraft may have multiple antennas and each antenna can have
              multiple 'details' records compiled by different sources.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/onorbitantenna",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "id": id,
                    "antenna": antenna,
                    "origin": origin,
                },
                onorbitantenna_create_params.OnorbitantennaCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        id_on_orbit: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        antenna: onorbitantenna_update_params.Antenna | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single OnorbitAntenna.

        An OnorbitAntenna is the
        association between on-orbit spacecraft antennas and a particular on-orbit
        spacecraft. An antenna type may be associated with many different on-orbit
        spacecraft. A specific role is required to perform this service operation.
        Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: ID of the antenna.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          antenna: Model representation of information on on-orbit/spacecraft communication
              antennas. A spacecraft may have multiple antennas and each antenna can have
              multiple 'details' records compiled by different sources.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/onorbitantenna/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "body_id": body_id,
                    "antenna": antenna,
                    "origin": origin,
                },
                onorbitantenna_update_params.OnorbitantennaUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitantennaListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/onorbitantenna",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitantennaListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a OnorbitAntenna object specified by the passed ID
        path parameter. An OnorbitAntenna is the association between on-orbit spacecraft
        antennas and a particular on-orbit spacecraft. An antenna type may be associated
        with many different on-orbit spacecraft. A specific role is required to perform
        this service operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/onorbitantenna/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitantennaGetResponse:
        """
        Service operation to get a single OnorbitAntenna record by its unique ID passed
        as a path parameter. An OnorbitAntenna is the association between on-orbit
        spacecraft antennas and a particular on-orbit spacecraft. An antenna type may be
        associated with many different on-orbit spacecraft.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/onorbitantenna/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitantennaGetResponse,
        )


class AsyncOnorbitantennaResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOnorbitantennaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncOnorbitantennaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOnorbitantennaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncOnorbitantennaResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        id_on_orbit: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        antenna: onorbitantenna_create_params.Antenna | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single OnorbitAntenna as a POST body and ingest into
        the database. An OnorbitAntenna is the association between on-orbit spacecraft
        antennas and a particular on-orbit spacecraft. An antenna type may be associated
        with many different on-orbit spacecraft. A specific role is required to perform
        this service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: ID of the antenna.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          antenna: Model representation of information on on-orbit/spacecraft communication
              antennas. A spacecraft may have multiple antennas and each antenna can have
              multiple 'details' records compiled by different sources.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/onorbitantenna",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "id": id,
                    "antenna": antenna,
                    "origin": origin,
                },
                onorbitantenna_create_params.OnorbitantennaCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_antenna: str,
        id_on_orbit: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        antenna: onorbitantenna_update_params.Antenna | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single OnorbitAntenna.

        An OnorbitAntenna is the
        association between on-orbit spacecraft antennas and a particular on-orbit
        spacecraft. An antenna type may be associated with many different on-orbit
        spacecraft. A specific role is required to perform this service operation.
        Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_antenna: ID of the antenna.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          antenna: Model representation of information on on-orbit/spacecraft communication
              antennas. A spacecraft may have multiple antennas and each antenna can have
              multiple 'details' records compiled by different sources.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/onorbitantenna/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_antenna": id_antenna,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "body_id": body_id,
                    "antenna": antenna,
                    "origin": origin,
                },
                onorbitantenna_update_params.OnorbitantennaUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitantennaListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/onorbitantenna",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitantennaListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a OnorbitAntenna object specified by the passed ID
        path parameter. An OnorbitAntenna is the association between on-orbit spacecraft
        antennas and a particular on-orbit spacecraft. An antenna type may be associated
        with many different on-orbit spacecraft. A specific role is required to perform
        this service operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/onorbitantenna/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitantennaGetResponse:
        """
        Service operation to get a single OnorbitAntenna record by its unique ID passed
        as a path parameter. An OnorbitAntenna is the association between on-orbit
        spacecraft antennas and a particular on-orbit spacecraft. An antenna type may be
        associated with many different on-orbit spacecraft.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/onorbitantenna/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitantennaGetResponse,
        )


class OnorbitantennaResourceWithRawResponse:
    def __init__(self, onorbitantenna: OnorbitantennaResource) -> None:
        self._onorbitantenna = onorbitantenna

        self.create = to_raw_response_wrapper(
            onorbitantenna.create,
        )
        self.update = to_raw_response_wrapper(
            onorbitantenna.update,
        )
        self.list = to_raw_response_wrapper(
            onorbitantenna.list,
        )
        self.delete = to_raw_response_wrapper(
            onorbitantenna.delete,
        )
        self.get = to_raw_response_wrapper(
            onorbitantenna.get,
        )


class AsyncOnorbitantennaResourceWithRawResponse:
    def __init__(self, onorbitantenna: AsyncOnorbitantennaResource) -> None:
        self._onorbitantenna = onorbitantenna

        self.create = async_to_raw_response_wrapper(
            onorbitantenna.create,
        )
        self.update = async_to_raw_response_wrapper(
            onorbitantenna.update,
        )
        self.list = async_to_raw_response_wrapper(
            onorbitantenna.list,
        )
        self.delete = async_to_raw_response_wrapper(
            onorbitantenna.delete,
        )
        self.get = async_to_raw_response_wrapper(
            onorbitantenna.get,
        )


class OnorbitantennaResourceWithStreamingResponse:
    def __init__(self, onorbitantenna: OnorbitantennaResource) -> None:
        self._onorbitantenna = onorbitantenna

        self.create = to_streamed_response_wrapper(
            onorbitantenna.create,
        )
        self.update = to_streamed_response_wrapper(
            onorbitantenna.update,
        )
        self.list = to_streamed_response_wrapper(
            onorbitantenna.list,
        )
        self.delete = to_streamed_response_wrapper(
            onorbitantenna.delete,
        )
        self.get = to_streamed_response_wrapper(
            onorbitantenna.get,
        )


class AsyncOnorbitantennaResourceWithStreamingResponse:
    def __init__(self, onorbitantenna: AsyncOnorbitantennaResource) -> None:
        self._onorbitantenna = onorbitantenna

        self.create = async_to_streamed_response_wrapper(
            onorbitantenna.create,
        )
        self.update = async_to_streamed_response_wrapper(
            onorbitantenna.update,
        )
        self.list = async_to_streamed_response_wrapper(
            onorbitantenna.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            onorbitantenna.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            onorbitantenna.get,
        )
