# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import onorbitbattery_create_params, onorbitbattery_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.onorbitbattery_get_response import OnorbitbatteryGetResponse
from ..types.onorbitbattery_list_response import OnorbitbatteryListResponse

__all__ = ["OnorbitbatteryResource", "AsyncOnorbitbatteryResource"]


class OnorbitbatteryResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OnorbitbatteryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return OnorbitbatteryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OnorbitbatteryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return OnorbitbatteryResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_battery: str,
        id_on_orbit: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        battery: onorbitbattery_create_params.Battery | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single OnorbitBattery as a POST body and ingest into
        the database. OnorbitBattery is the association between on-orbit spacecraft
        batteries and a particular on-orbit spacecraft. A Battery may be associated with
        many different on-orbit spacecraft. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_battery: ID of the battery.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          battery: Model representation of specific spacecraft battery types.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of batteries on the spacecraft of the type identified by idBattery.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/onorbitbattery",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_battery": id_battery,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "id": id,
                    "battery": battery,
                    "origin": origin,
                    "quantity": quantity,
                },
                onorbitbattery_create_params.OnorbitbatteryCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_battery: str,
        id_on_orbit: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        battery: onorbitbattery_update_params.Battery | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single OnorbitBattery.

        OnorbitBattery is the
        association between on-orbit spacecraft batteries and a particular on-orbit
        spacecraft. A Battery may be associated with many different on-orbit spacecraft.
        A specific role is required to perform this service operation. Please contact
        the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_battery: ID of the battery.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          battery: Model representation of specific spacecraft battery types.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of batteries on the spacecraft of the type identified by idBattery.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/onorbitbattery/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_battery": id_battery,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "body_id": body_id,
                    "battery": battery,
                    "origin": origin,
                    "quantity": quantity,
                },
                onorbitbattery_update_params.OnorbitbatteryUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitbatteryListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/onorbitbattery",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitbatteryListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a OnorbitBattery object specified by the passed ID
        path parameter. OnorbitBattery is the association between on-orbit spacecraft
        batteries and a particular on-orbit spacecraft. A Battery may be associated with
        many different on-orbit spacecraft. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/onorbitbattery/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitbatteryGetResponse:
        """
        Service operation to get a single OnorbitBattery record by its unique ID passed
        as a path parameter. OnorbitBattery is the association between on-orbit
        spacecraft batteries and a particular on-orbit spacecraft. A Battery may be
        associated with many different on-orbit spacecraft.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/onorbitbattery/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitbatteryGetResponse,
        )


class AsyncOnorbitbatteryResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOnorbitbatteryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncOnorbitbatteryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOnorbitbatteryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncOnorbitbatteryResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_battery: str,
        id_on_orbit: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        battery: onorbitbattery_create_params.Battery | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single OnorbitBattery as a POST body and ingest into
        the database. OnorbitBattery is the association between on-orbit spacecraft
        batteries and a particular on-orbit spacecraft. A Battery may be associated with
        many different on-orbit spacecraft. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_battery: ID of the battery.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          battery: Model representation of specific spacecraft battery types.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of batteries on the spacecraft of the type identified by idBattery.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/onorbitbattery",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_battery": id_battery,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "id": id,
                    "battery": battery,
                    "origin": origin,
                    "quantity": quantity,
                },
                onorbitbattery_create_params.OnorbitbatteryCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_battery: str,
        id_on_orbit: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        battery: onorbitbattery_update_params.Battery | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single OnorbitBattery.

        OnorbitBattery is the
        association between on-orbit spacecraft batteries and a particular on-orbit
        spacecraft. A Battery may be associated with many different on-orbit spacecraft.
        A specific role is required to perform this service operation. Please contact
        the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_battery: ID of the battery.

          id_on_orbit: ID of the on-orbit object.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          battery: Model representation of specific spacecraft battery types.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of batteries on the spacecraft of the type identified by idBattery.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/onorbitbattery/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_battery": id_battery,
                    "id_on_orbit": id_on_orbit,
                    "source": source,
                    "body_id": body_id,
                    "battery": battery,
                    "origin": origin,
                    "quantity": quantity,
                },
                onorbitbattery_update_params.OnorbitbatteryUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitbatteryListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/onorbitbattery",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitbatteryListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a OnorbitBattery object specified by the passed ID
        path parameter. OnorbitBattery is the association between on-orbit spacecraft
        batteries and a particular on-orbit spacecraft. A Battery may be associated with
        many different on-orbit spacecraft. A specific role is required to perform this
        service operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/onorbitbattery/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitbatteryGetResponse:
        """
        Service operation to get a single OnorbitBattery record by its unique ID passed
        as a path parameter. OnorbitBattery is the association between on-orbit
        spacecraft batteries and a particular on-orbit spacecraft. A Battery may be
        associated with many different on-orbit spacecraft.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/onorbitbattery/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitbatteryGetResponse,
        )


class OnorbitbatteryResourceWithRawResponse:
    def __init__(self, onorbitbattery: OnorbitbatteryResource) -> None:
        self._onorbitbattery = onorbitbattery

        self.create = to_raw_response_wrapper(
            onorbitbattery.create,
        )
        self.update = to_raw_response_wrapper(
            onorbitbattery.update,
        )
        self.list = to_raw_response_wrapper(
            onorbitbattery.list,
        )
        self.delete = to_raw_response_wrapper(
            onorbitbattery.delete,
        )
        self.get = to_raw_response_wrapper(
            onorbitbattery.get,
        )


class AsyncOnorbitbatteryResourceWithRawResponse:
    def __init__(self, onorbitbattery: AsyncOnorbitbatteryResource) -> None:
        self._onorbitbattery = onorbitbattery

        self.create = async_to_raw_response_wrapper(
            onorbitbattery.create,
        )
        self.update = async_to_raw_response_wrapper(
            onorbitbattery.update,
        )
        self.list = async_to_raw_response_wrapper(
            onorbitbattery.list,
        )
        self.delete = async_to_raw_response_wrapper(
            onorbitbattery.delete,
        )
        self.get = async_to_raw_response_wrapper(
            onorbitbattery.get,
        )


class OnorbitbatteryResourceWithStreamingResponse:
    def __init__(self, onorbitbattery: OnorbitbatteryResource) -> None:
        self._onorbitbattery = onorbitbattery

        self.create = to_streamed_response_wrapper(
            onorbitbattery.create,
        )
        self.update = to_streamed_response_wrapper(
            onorbitbattery.update,
        )
        self.list = to_streamed_response_wrapper(
            onorbitbattery.list,
        )
        self.delete = to_streamed_response_wrapper(
            onorbitbattery.delete,
        )
        self.get = to_streamed_response_wrapper(
            onorbitbattery.get,
        )


class AsyncOnorbitbatteryResourceWithStreamingResponse:
    def __init__(self, onorbitbattery: AsyncOnorbitbatteryResource) -> None:
        self._onorbitbattery = onorbitbattery

        self.create = async_to_streamed_response_wrapper(
            onorbitbattery.create,
        )
        self.update = async_to_streamed_response_wrapper(
            onorbitbattery.update,
        )
        self.list = async_to_streamed_response_wrapper(
            onorbitbattery.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            onorbitbattery.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            onorbitbattery.get,
        )
