# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import onorbitsolararray_create_params, onorbitsolararray_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.onorbitsolararray_get_response import OnorbitsolararrayGetResponse
from ..types.onorbitsolararray_list_response import OnorbitsolararrayListResponse

__all__ = ["OnorbitsolararrayResource", "AsyncOnorbitsolararrayResource"]


class OnorbitsolararrayResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OnorbitsolararrayResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return OnorbitsolararrayResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OnorbitsolararrayResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return OnorbitsolararrayResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_on_orbit: str,
        id_solar_array: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        solar_array: onorbitsolararray_create_params.SolarArray | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single OnorbitSolarArray as a POST body and ingest
        into the database. An OnorbitSolarArray is the association between on-orbit
        spacecraft SolarArrays and a particular on-orbit spacecraft. A SolarArray type
        may be associated with many different on-orbit spacecraft. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_on_orbit: ID of the on-orbit object.

          id_solar_array: ID of the SolarArray.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of solar arrays on the spacecraft of the type identified by
              idSolarArray.

          solar_array: Model representation of information on on-orbit/spacecraft solar arrays. A
              spacecraft may have multiple solar arrays and each solar array can have multiple
              'details' records compiled by different sources.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/onorbitsolararray",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_on_orbit": id_on_orbit,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "id": id,
                    "origin": origin,
                    "quantity": quantity,
                    "solar_array": solar_array,
                },
                onorbitsolararray_create_params.OnorbitsolararrayCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_on_orbit: str,
        id_solar_array: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        solar_array: onorbitsolararray_update_params.SolarArray | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single OnorbitSolarArray.

        An OnorbitSolarArray is
        the association between on-orbit spacecraft SolarArrays and a particular
        on-orbit spacecraft. A SolarArray type may be associated with many different
        on-orbit spacecraft. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_on_orbit: ID of the on-orbit object.

          id_solar_array: ID of the SolarArray.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of solar arrays on the spacecraft of the type identified by
              idSolarArray.

          solar_array: Model representation of information on on-orbit/spacecraft solar arrays. A
              spacecraft may have multiple solar arrays and each solar array can have multiple
              'details' records compiled by different sources.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/onorbitsolararray/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_on_orbit": id_on_orbit,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "body_id": body_id,
                    "origin": origin,
                    "quantity": quantity,
                    "solar_array": solar_array,
                },
                onorbitsolararray_update_params.OnorbitsolararrayUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitsolararrayListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/onorbitsolararray",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitsolararrayListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a OnorbitSolarArray object specified by the passed
        ID path parameter. An OnorbitSolarArray is the association between on-orbit
        spacecraft SolarArrays and a particular on-orbit spacecraft. A SolarArray type
        may be associated with many different on-orbit spacecraft. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/onorbitsolararray/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitsolararrayGetResponse:
        """
        Service operation to get a single OnorbitSolarArray record by its unique ID
        passed as a path parameter. An OnorbitSolarArray is the association between
        on-orbit spacecraft SolarArrays and a particular on-orbit spacecraft. A
        SolarArray type may be associated with many different on-orbit spacecraft.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/onorbitsolararray/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitsolararrayGetResponse,
        )


class AsyncOnorbitsolararrayResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOnorbitsolararrayResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncOnorbitsolararrayResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOnorbitsolararrayResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncOnorbitsolararrayResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_on_orbit: str,
        id_solar_array: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        solar_array: onorbitsolararray_create_params.SolarArray | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single OnorbitSolarArray as a POST body and ingest
        into the database. An OnorbitSolarArray is the association between on-orbit
        spacecraft SolarArrays and a particular on-orbit spacecraft. A SolarArray type
        may be associated with many different on-orbit spacecraft. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_on_orbit: ID of the on-orbit object.

          id_solar_array: ID of the SolarArray.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of solar arrays on the spacecraft of the type identified by
              idSolarArray.

          solar_array: Model representation of information on on-orbit/spacecraft solar arrays. A
              spacecraft may have multiple solar arrays and each solar array can have multiple
              'details' records compiled by different sources.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/onorbitsolararray",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_on_orbit": id_on_orbit,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "id": id,
                    "origin": origin,
                    "quantity": quantity,
                    "solar_array": solar_array,
                },
                onorbitsolararray_create_params.OnorbitsolararrayCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_on_orbit: str,
        id_solar_array: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        quantity: int | NotGiven = NOT_GIVEN,
        solar_array: onorbitsolararray_update_params.SolarArray | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single OnorbitSolarArray.

        An OnorbitSolarArray is
        the association between on-orbit spacecraft SolarArrays and a particular
        on-orbit spacecraft. A SolarArray type may be associated with many different
        on-orbit spacecraft. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_on_orbit: ID of the on-orbit object.

          id_solar_array: ID of the SolarArray.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          quantity: The number of solar arrays on the spacecraft of the type identified by
              idSolarArray.

          solar_array: Model representation of information on on-orbit/spacecraft solar arrays. A
              spacecraft may have multiple solar arrays and each solar array can have multiple
              'details' records compiled by different sources.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/onorbitsolararray/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_on_orbit": id_on_orbit,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "body_id": body_id,
                    "origin": origin,
                    "quantity": quantity,
                    "solar_array": solar_array,
                },
                onorbitsolararray_update_params.OnorbitsolararrayUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitsolararrayListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/onorbitsolararray",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitsolararrayListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a OnorbitSolarArray object specified by the passed
        ID path parameter. An OnorbitSolarArray is the association between on-orbit
        spacecraft SolarArrays and a particular on-orbit spacecraft. A SolarArray type
        may be associated with many different on-orbit spacecraft. A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/onorbitsolararray/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OnorbitsolararrayGetResponse:
        """
        Service operation to get a single OnorbitSolarArray record by its unique ID
        passed as a path parameter. An OnorbitSolarArray is the association between
        on-orbit spacecraft SolarArrays and a particular on-orbit spacecraft. A
        SolarArray type may be associated with many different on-orbit spacecraft.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/onorbitsolararray/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OnorbitsolararrayGetResponse,
        )


class OnorbitsolararrayResourceWithRawResponse:
    def __init__(self, onorbitsolararray: OnorbitsolararrayResource) -> None:
        self._onorbitsolararray = onorbitsolararray

        self.create = to_raw_response_wrapper(
            onorbitsolararray.create,
        )
        self.update = to_raw_response_wrapper(
            onorbitsolararray.update,
        )
        self.list = to_raw_response_wrapper(
            onorbitsolararray.list,
        )
        self.delete = to_raw_response_wrapper(
            onorbitsolararray.delete,
        )
        self.get = to_raw_response_wrapper(
            onorbitsolararray.get,
        )


class AsyncOnorbitsolararrayResourceWithRawResponse:
    def __init__(self, onorbitsolararray: AsyncOnorbitsolararrayResource) -> None:
        self._onorbitsolararray = onorbitsolararray

        self.create = async_to_raw_response_wrapper(
            onorbitsolararray.create,
        )
        self.update = async_to_raw_response_wrapper(
            onorbitsolararray.update,
        )
        self.list = async_to_raw_response_wrapper(
            onorbitsolararray.list,
        )
        self.delete = async_to_raw_response_wrapper(
            onorbitsolararray.delete,
        )
        self.get = async_to_raw_response_wrapper(
            onorbitsolararray.get,
        )


class OnorbitsolararrayResourceWithStreamingResponse:
    def __init__(self, onorbitsolararray: OnorbitsolararrayResource) -> None:
        self._onorbitsolararray = onorbitsolararray

        self.create = to_streamed_response_wrapper(
            onorbitsolararray.create,
        )
        self.update = to_streamed_response_wrapper(
            onorbitsolararray.update,
        )
        self.list = to_streamed_response_wrapper(
            onorbitsolararray.list,
        )
        self.delete = to_streamed_response_wrapper(
            onorbitsolararray.delete,
        )
        self.get = to_streamed_response_wrapper(
            onorbitsolararray.get,
        )


class AsyncOnorbitsolararrayResourceWithStreamingResponse:
    def __init__(self, onorbitsolararray: AsyncOnorbitsolararrayResource) -> None:
        self._onorbitsolararray = onorbitsolararray

        self.create = async_to_streamed_response_wrapper(
            onorbitsolararray.create,
        )
        self.update = async_to_streamed_response_wrapper(
            onorbitsolararray.update,
        )
        self.list = async_to_streamed_response_wrapper(
            onorbitsolararray.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            onorbitsolararray.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            onorbitsolararray.get,
        )
