# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.scs.file_metadata_list_response import FileMetadataListResponse

__all__ = ["FileMetadataResource", "AsyncFileMetadataResource"]


class FileMetadataResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> FileMetadataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return FileMetadataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FileMetadataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return FileMetadataResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FileMetadataListResponse:
        """Returns a set of File Metadata that can be used for search endpoint."""
        return self._get(
            "/scs/listFileMetadata",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileMetadataListResponse,
        )


class AsyncFileMetadataResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncFileMetadataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncFileMetadataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFileMetadataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncFileMetadataResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FileMetadataListResponse:
        """Returns a set of File Metadata that can be used for search endpoint."""
        return await self._get(
            "/scs/listFileMetadata",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileMetadataListResponse,
        )


class FileMetadataResourceWithRawResponse:
    def __init__(self, file_metadata: FileMetadataResource) -> None:
        self._file_metadata = file_metadata

        self.list = to_raw_response_wrapper(
            file_metadata.list,
        )


class AsyncFileMetadataResourceWithRawResponse:
    def __init__(self, file_metadata: AsyncFileMetadataResource) -> None:
        self._file_metadata = file_metadata

        self.list = async_to_raw_response_wrapper(
            file_metadata.list,
        )


class FileMetadataResourceWithStreamingResponse:
    def __init__(self, file_metadata: FileMetadataResource) -> None:
        self._file_metadata = file_metadata

        self.list = to_streamed_response_wrapper(
            file_metadata.list,
        )


class AsyncFileMetadataResourceWithStreamingResponse:
    def __init__(self, file_metadata: AsyncFileMetadataResource) -> None:
        self._file_metadata = file_metadata

        self.list = async_to_streamed_response_wrapper(
            file_metadata.list,
        )
