# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal

import httpx

from ..types import solararraydetail_list_params, solararraydetail_create_params, solararraydetail_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.solar_array_details_full import SolarArrayDetailsFull
from ..types.solararraydetail_list_response import SolararraydetailListResponse

__all__ = ["SolararraydetailsResource", "AsyncSolararraydetailsResource"]


class SolararraydetailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SolararraydetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return SolararraydetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SolararraydetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return SolararraydetailsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_solar_array: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        area: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        junction_technology: str | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        span: float | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        technology: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single SolarArrayDetails as a POST body and ingest
        into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance. A SolarArray may have
        multiple details records compiled by various sources.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_solar_array: Unique identifier of the parent SolarArray.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          area: Solar Array area in square meters.

          description: Solar array description/notes.

          junction_technology: Solar array junction technology (e.g. Triple).

          manufacturer_org_id: Unique identifier of the organization that manufactures the solar array.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          span: Solar Array span in meters.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          technology: Solar array technology (e.g. Ga-As).

          type: Type of solar array (e.g. U Shaped).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/solararraydetails",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "id": id,
                    "area": area,
                    "description": description,
                    "junction_technology": junction_technology,
                    "manufacturer_org_id": manufacturer_org_id,
                    "origin": origin,
                    "span": span,
                    "tags": tags,
                    "technology": technology,
                    "type": type,
                },
                solararraydetail_create_params.SolararraydetailCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_solar_array: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        area: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        junction_technology: str | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        span: float | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        technology: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single SolarArrayDetails.

        A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance. A SolarArray may have multiple details records compiled by various
        sources.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_solar_array: Unique identifier of the parent SolarArray.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          area: Solar Array area in square meters.

          description: Solar array description/notes.

          junction_technology: Solar array junction technology (e.g. Triple).

          manufacturer_org_id: Unique identifier of the organization that manufactures the solar array.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          span: Solar Array span in meters.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          technology: Solar array technology (e.g. Ga-As).

          type: Type of solar array (e.g. U Shaped).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/solararraydetails/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "body_id": body_id,
                    "area": area,
                    "description": description,
                    "junction_technology": junction_technology,
                    "manufacturer_org_id": manufacturer_org_id,
                    "origin": origin,
                    "span": span,
                    "tags": tags,
                    "technology": technology,
                    "type": type,
                },
                solararraydetail_update_params.SolararraydetailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        classification_marking: str | NotGiven = NOT_GIVEN,
        data_mode: str | NotGiven = NOT_GIVEN,
        source: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SolararraydetailListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.

        Args:
          classification_marking: (One or more of fields 'classificationMarking, dataMode, source' are required.)
              Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode: (One or more of fields 'classificationMarking, dataMode, source' are required.)
              Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data. (REAL,
              TEST, SIMULATED, or EXERCISE)

          source: (One or more of fields 'classificationMarking, dataMode, source' are required.)
              Source of the data.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/solararraydetails",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "classification_marking": classification_marking,
                        "data_mode": data_mode,
                        "source": source,
                    },
                    solararraydetail_list_params.SolararraydetailListParams,
                ),
            ),
            cast_to=SolararraydetailListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a SolarArrayDetails object specified by the passed
        ID path parameter. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance. A SolarArray may have
        multiple details records compiled by various sources.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/solararraydetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SolarArrayDetailsFull:
        """
        Service operation to get a single SolarArrayDetails record by its unique ID
        passed as a path parameter. A SolarArray may have multiple details records
        compiled by various sources.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/solararraydetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SolarArrayDetailsFull,
        )


class AsyncSolararraydetailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSolararraydetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSolararraydetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSolararraydetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncSolararraydetailsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_solar_array: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        area: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        junction_technology: str | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        span: float | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        technology: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single SolarArrayDetails as a POST body and ingest
        into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance. A SolarArray may have
        multiple details records compiled by various sources.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_solar_array: Unique identifier of the parent SolarArray.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          area: Solar Array area in square meters.

          description: Solar array description/notes.

          junction_technology: Solar array junction technology (e.g. Triple).

          manufacturer_org_id: Unique identifier of the organization that manufactures the solar array.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          span: Solar Array span in meters.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          technology: Solar array technology (e.g. Ga-As).

          type: Type of solar array (e.g. U Shaped).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/solararraydetails",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "id": id,
                    "area": area,
                    "description": description,
                    "junction_technology": junction_technology,
                    "manufacturer_org_id": manufacturer_org_id,
                    "origin": origin,
                    "span": span,
                    "tags": tags,
                    "technology": technology,
                    "type": type,
                },
                solararraydetail_create_params.SolararraydetailCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_solar_array: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        area: float | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        junction_technology: str | NotGiven = NOT_GIVEN,
        manufacturer_org_id: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        span: float | NotGiven = NOT_GIVEN,
        tags: List[str] | NotGiven = NOT_GIVEN,
        technology: str | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single SolarArrayDetails.

        A specific role is
        required to perform this service operation. Please contact the UDL team for
        assistance. A SolarArray may have multiple details records compiled by various
        sources.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_solar_array: Unique identifier of the parent SolarArray.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          area: Solar Array area in square meters.

          description: Solar array description/notes.

          junction_technology: Solar array junction technology (e.g. Triple).

          manufacturer_org_id: Unique identifier of the organization that manufactures the solar array.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          span: Solar Array span in meters.

          tags: Optional array of provider/source specific tags for this data, where each
              element is no longer than 32 characters, used for implementing data owner
              conditional access controls to restrict access to the data. Should be left null
              by data providers unless conditional access controls are coordinated with the
              UDL team.

          technology: Solar array technology (e.g. Ga-As).

          type: Type of solar array (e.g. U Shaped).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/solararraydetails/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_solar_array": id_solar_array,
                    "source": source,
                    "body_id": body_id,
                    "area": area,
                    "description": description,
                    "junction_technology": junction_technology,
                    "manufacturer_org_id": manufacturer_org_id,
                    "origin": origin,
                    "span": span,
                    "tags": tags,
                    "technology": technology,
                    "type": type,
                },
                solararraydetail_update_params.SolararraydetailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        classification_marking: str | NotGiven = NOT_GIVEN,
        data_mode: str | NotGiven = NOT_GIVEN,
        source: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SolararraydetailListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.

        Args:
          classification_marking: (One or more of fields 'classificationMarking, dataMode, source' are required.)
              Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode: (One or more of fields 'classificationMarking, dataMode, source' are required.)
              Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data. (REAL,
              TEST, SIMULATED, or EXERCISE)

          source: (One or more of fields 'classificationMarking, dataMode, source' are required.)
              Source of the data.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/solararraydetails",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "classification_marking": classification_marking,
                        "data_mode": data_mode,
                        "source": source,
                    },
                    solararraydetail_list_params.SolararraydetailListParams,
                ),
            ),
            cast_to=SolararraydetailListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a SolarArrayDetails object specified by the passed
        ID path parameter. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance. A SolarArray may have
        multiple details records compiled by various sources.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/solararraydetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SolarArrayDetailsFull:
        """
        Service operation to get a single SolarArrayDetails record by its unique ID
        passed as a path parameter. A SolarArray may have multiple details records
        compiled by various sources.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/solararraydetails/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SolarArrayDetailsFull,
        )


class SolararraydetailsResourceWithRawResponse:
    def __init__(self, solararraydetails: SolararraydetailsResource) -> None:
        self._solararraydetails = solararraydetails

        self.create = to_raw_response_wrapper(
            solararraydetails.create,
        )
        self.update = to_raw_response_wrapper(
            solararraydetails.update,
        )
        self.list = to_raw_response_wrapper(
            solararraydetails.list,
        )
        self.delete = to_raw_response_wrapper(
            solararraydetails.delete,
        )
        self.get = to_raw_response_wrapper(
            solararraydetails.get,
        )


class AsyncSolararraydetailsResourceWithRawResponse:
    def __init__(self, solararraydetails: AsyncSolararraydetailsResource) -> None:
        self._solararraydetails = solararraydetails

        self.create = async_to_raw_response_wrapper(
            solararraydetails.create,
        )
        self.update = async_to_raw_response_wrapper(
            solararraydetails.update,
        )
        self.list = async_to_raw_response_wrapper(
            solararraydetails.list,
        )
        self.delete = async_to_raw_response_wrapper(
            solararraydetails.delete,
        )
        self.get = async_to_raw_response_wrapper(
            solararraydetails.get,
        )


class SolararraydetailsResourceWithStreamingResponse:
    def __init__(self, solararraydetails: SolararraydetailsResource) -> None:
        self._solararraydetails = solararraydetails

        self.create = to_streamed_response_wrapper(
            solararraydetails.create,
        )
        self.update = to_streamed_response_wrapper(
            solararraydetails.update,
        )
        self.list = to_streamed_response_wrapper(
            solararraydetails.list,
        )
        self.delete = to_streamed_response_wrapper(
            solararraydetails.delete,
        )
        self.get = to_streamed_response_wrapper(
            solararraydetails.get,
        )


class AsyncSolararraydetailsResourceWithStreamingResponse:
    def __init__(self, solararraydetails: AsyncSolararraydetailsResource) -> None:
        self._solararraydetails = solararraydetails

        self.create = async_to_streamed_response_wrapper(
            solararraydetails.create,
        )
        self.update = async_to_streamed_response_wrapper(
            solararraydetails.update,
        )
        self.list = async_to_streamed_response_wrapper(
            solararraydetails.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            solararraydetails.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            solararraydetails.get,
        )
