# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import status_tuple_params, status_create_params, status_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.status_get_response import StatusGetResponse
from ..types.status_list_response import StatusListResponse
from ..types.status_tuple_response import StatusTupleResponse
from ..types.status_get_by_entity_id_response import StatusGetByEntityIDResponse
from ..types.status_get_by_entity_type_response import StatusGetByEntityTypeResponse

__all__ = ["StatusResource", "AsyncStatusResource"]


class StatusResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> StatusResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return StatusResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> StatusResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return StatusResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_entity: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        declassification_date: Union[str, datetime] | NotGiven = NOT_GIVEN,
        declassification_string: str | NotGiven = NOT_GIVEN,
        derived_from: str | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        ops_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        state: Literal["UNKNOWN", "DEAD", "ACTIVE", "RF ACTIVE", "STANDBY"] | NotGiven = NOT_GIVEN,
        sub_status_collection: Iterable[status_create_params.SubStatusCollection] | NotGiven = NOT_GIVEN,
        sys_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Status as a POST body and ingest into the
        database. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_entity: Unique identifier of the parent entity.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          declassification_date: The declassification date of this data, in ISO 8601 UTC format.

          declassification_string: Declassification string of this data.

          derived_from: The sources or SCG references from which the classification of this data is
              derived.

          notes: Comments describing the status creation and or updates to an entity.

          ops_cap: Operation capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          state: Overall state of the entity, if applicable (e.g. UNKNOWN, DEAD, ACTIVE, RF
              ACTIVE, STANDBY).

          sys_cap: System capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/status",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_entity": id_entity,
                    "source": source,
                    "id": id,
                    "declassification_date": declassification_date,
                    "declassification_string": declassification_string,
                    "derived_from": derived_from,
                    "notes": notes,
                    "ops_cap": ops_cap,
                    "origin": origin,
                    "state": state,
                    "sub_status_collection": sub_status_collection,
                    "sys_cap": sys_cap,
                },
                status_create_params.StatusCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_entity: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        declassification_date: Union[str, datetime] | NotGiven = NOT_GIVEN,
        declassification_string: str | NotGiven = NOT_GIVEN,
        derived_from: str | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        ops_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        state: Literal["UNKNOWN", "DEAD", "ACTIVE", "RF ACTIVE", "STANDBY"] | NotGiven = NOT_GIVEN,
        sub_status_collection: Iterable[status_update_params.SubStatusCollection] | NotGiven = NOT_GIVEN,
        sys_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Status.

        A specific role is required to
        perform this service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_entity: Unique identifier of the parent entity.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          declassification_date: The declassification date of this data, in ISO 8601 UTC format.

          declassification_string: Declassification string of this data.

          derived_from: The sources or SCG references from which the classification of this data is
              derived.

          notes: Comments describing the status creation and or updates to an entity.

          ops_cap: Operation capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          state: Overall state of the entity, if applicable (e.g. UNKNOWN, DEAD, ACTIVE, RF
              ACTIVE, STANDBY).

          sys_cap: System capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/status/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_entity": id_entity,
                    "source": source,
                    "body_id": body_id,
                    "declassification_date": declassification_date,
                    "declassification_string": declassification_string,
                    "derived_from": derived_from,
                    "notes": notes,
                    "ops_cap": ops_cap,
                    "origin": origin,
                    "state": state,
                    "sub_status_collection": sub_status_collection,
                    "sys_cap": sys_cap,
                },
                status_update_params.StatusUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a Status object specified by the passed ID path
        parameter. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/status/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/status/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusGetResponse:
        """
        Service operation to get a single Status record by its unique ID passed as a
        path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/status/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusGetResponse,
        )

    def get_by_entity_id(
        self,
        id_entity: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusGetByEntityIDResponse:
        """
        Service operation to get all statuses related to a particular entity.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id_entity:
            raise ValueError(f"Expected a non-empty value for `id_entity` but received {id_entity!r}")
        return self._get(
            f"/udl/status/byIdEntity/{id_entity}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusGetByEntityIDResponse,
        )

    def get_by_entity_type(
        self,
        entity_type: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusGetByEntityTypeResponse:
        """
        Service operation to get all statuses related to a particular entity type.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not entity_type:
            raise ValueError(f"Expected a non-empty value for `entity_type` but received {entity_type!r}")
        return self._get(
            f"/udl/status/byEntityType/{entity_type}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusGetByEntityTypeResponse,
        )

    def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/status/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/status/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"columns": columns}, status_tuple_params.StatusTupleParams),
            ),
            cast_to=StatusTupleResponse,
        )


class AsyncStatusResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncStatusResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncStatusResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncStatusResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncStatusResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_entity: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        declassification_date: Union[str, datetime] | NotGiven = NOT_GIVEN,
        declassification_string: str | NotGiven = NOT_GIVEN,
        derived_from: str | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        ops_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        state: Literal["UNKNOWN", "DEAD", "ACTIVE", "RF ACTIVE", "STANDBY"] | NotGiven = NOT_GIVEN,
        sub_status_collection: Iterable[status_create_params.SubStatusCollection] | NotGiven = NOT_GIVEN,
        sys_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Status as a POST body and ingest into the
        database. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_entity: Unique identifier of the parent entity.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          declassification_date: The declassification date of this data, in ISO 8601 UTC format.

          declassification_string: Declassification string of this data.

          derived_from: The sources or SCG references from which the classification of this data is
              derived.

          notes: Comments describing the status creation and or updates to an entity.

          ops_cap: Operation capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          state: Overall state of the entity, if applicable (e.g. UNKNOWN, DEAD, ACTIVE, RF
              ACTIVE, STANDBY).

          sys_cap: System capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/status",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_entity": id_entity,
                    "source": source,
                    "id": id,
                    "declassification_date": declassification_date,
                    "declassification_string": declassification_string,
                    "derived_from": derived_from,
                    "notes": notes,
                    "ops_cap": ops_cap,
                    "origin": origin,
                    "state": state,
                    "sub_status_collection": sub_status_collection,
                    "sys_cap": sys_cap,
                },
                status_create_params.StatusCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_entity: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        declassification_date: Union[str, datetime] | NotGiven = NOT_GIVEN,
        declassification_string: str | NotGiven = NOT_GIVEN,
        derived_from: str | NotGiven = NOT_GIVEN,
        notes: str | NotGiven = NOT_GIVEN,
        ops_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        state: Literal["UNKNOWN", "DEAD", "ACTIVE", "RF ACTIVE", "STANDBY"] | NotGiven = NOT_GIVEN,
        sub_status_collection: Iterable[status_update_params.SubStatusCollection] | NotGiven = NOT_GIVEN,
        sys_cap: Literal["FMC", "NMC", "PMC", "UNK"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Status.

        A specific role is required to
        perform this service operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_entity: Unique identifier of the parent entity.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          declassification_date: The declassification date of this data, in ISO 8601 UTC format.

          declassification_string: Declassification string of this data.

          derived_from: The sources or SCG references from which the classification of this data is
              derived.

          notes: Comments describing the status creation and or updates to an entity.

          ops_cap: Operation capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          state: Overall state of the entity, if applicable (e.g. UNKNOWN, DEAD, ACTIVE, RF
              ACTIVE, STANDBY).

          sys_cap: System capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/status/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_entity": id_entity,
                    "source": source,
                    "body_id": body_id,
                    "declassification_date": declassification_date,
                    "declassification_string": declassification_string,
                    "derived_from": derived_from,
                    "notes": notes,
                    "ops_cap": ops_cap,
                    "origin": origin,
                    "state": state,
                    "sub_status_collection": sub_status_collection,
                    "sys_cap": sys_cap,
                },
                status_update_params.StatusUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a Status object specified by the passed ID path
        parameter. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/status/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/status/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusGetResponse:
        """
        Service operation to get a single Status record by its unique ID passed as a
        path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/status/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusGetResponse,
        )

    async def get_by_entity_id(
        self,
        id_entity: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusGetByEntityIDResponse:
        """
        Service operation to get all statuses related to a particular entity.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id_entity:
            raise ValueError(f"Expected a non-empty value for `id_entity` but received {id_entity!r}")
        return await self._get(
            f"/udl/status/byIdEntity/{id_entity}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusGetByEntityIDResponse,
        )

    async def get_by_entity_type(
        self,
        entity_type: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusGetByEntityTypeResponse:
        """
        Service operation to get all statuses related to a particular entity type.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not entity_type:
            raise ValueError(f"Expected a non-empty value for `entity_type` but received {entity_type!r}")
        return await self._get(
            f"/udl/status/byEntityType/{entity_type}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StatusGetByEntityTypeResponse,
        )

    async def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/status/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StatusTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/status/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"columns": columns}, status_tuple_params.StatusTupleParams),
            ),
            cast_to=StatusTupleResponse,
        )


class StatusResourceWithRawResponse:
    def __init__(self, status: StatusResource) -> None:
        self._status = status

        self.create = to_raw_response_wrapper(
            status.create,
        )
        self.update = to_raw_response_wrapper(
            status.update,
        )
        self.list = to_raw_response_wrapper(
            status.list,
        )
        self.delete = to_raw_response_wrapper(
            status.delete,
        )
        self.count = to_raw_response_wrapper(
            status.count,
        )
        self.get = to_raw_response_wrapper(
            status.get,
        )
        self.get_by_entity_id = to_raw_response_wrapper(
            status.get_by_entity_id,
        )
        self.get_by_entity_type = to_raw_response_wrapper(
            status.get_by_entity_type,
        )
        self.queryhelp = to_raw_response_wrapper(
            status.queryhelp,
        )
        self.tuple = to_raw_response_wrapper(
            status.tuple,
        )


class AsyncStatusResourceWithRawResponse:
    def __init__(self, status: AsyncStatusResource) -> None:
        self._status = status

        self.create = async_to_raw_response_wrapper(
            status.create,
        )
        self.update = async_to_raw_response_wrapper(
            status.update,
        )
        self.list = async_to_raw_response_wrapper(
            status.list,
        )
        self.delete = async_to_raw_response_wrapper(
            status.delete,
        )
        self.count = async_to_raw_response_wrapper(
            status.count,
        )
        self.get = async_to_raw_response_wrapper(
            status.get,
        )
        self.get_by_entity_id = async_to_raw_response_wrapper(
            status.get_by_entity_id,
        )
        self.get_by_entity_type = async_to_raw_response_wrapper(
            status.get_by_entity_type,
        )
        self.queryhelp = async_to_raw_response_wrapper(
            status.queryhelp,
        )
        self.tuple = async_to_raw_response_wrapper(
            status.tuple,
        )


class StatusResourceWithStreamingResponse:
    def __init__(self, status: StatusResource) -> None:
        self._status = status

        self.create = to_streamed_response_wrapper(
            status.create,
        )
        self.update = to_streamed_response_wrapper(
            status.update,
        )
        self.list = to_streamed_response_wrapper(
            status.list,
        )
        self.delete = to_streamed_response_wrapper(
            status.delete,
        )
        self.count = to_streamed_response_wrapper(
            status.count,
        )
        self.get = to_streamed_response_wrapper(
            status.get,
        )
        self.get_by_entity_id = to_streamed_response_wrapper(
            status.get_by_entity_id,
        )
        self.get_by_entity_type = to_streamed_response_wrapper(
            status.get_by_entity_type,
        )
        self.queryhelp = to_streamed_response_wrapper(
            status.queryhelp,
        )
        self.tuple = to_streamed_response_wrapper(
            status.tuple,
        )


class AsyncStatusResourceWithStreamingResponse:
    def __init__(self, status: AsyncStatusResource) -> None:
        self._status = status

        self.create = async_to_streamed_response_wrapper(
            status.create,
        )
        self.update = async_to_streamed_response_wrapper(
            status.update,
        )
        self.list = async_to_streamed_response_wrapper(
            status.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            status.delete,
        )
        self.count = async_to_streamed_response_wrapper(
            status.count,
        )
        self.get = async_to_streamed_response_wrapper(
            status.get,
        )
        self.get_by_entity_id = async_to_streamed_response_wrapper(
            status.get_by_entity_id,
        )
        self.get_by_entity_type = async_to_streamed_response_wrapper(
            status.get_by_entity_type,
        )
        self.queryhelp = async_to_streamed_response_wrapper(
            status.queryhelp,
        )
        self.tuple = async_to_streamed_response_wrapper(
            status.tuple,
        )
