# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Literal

import httpx

from ..types import (
    surfaceobstruction_tuple_params,
    surfaceobstruction_create_params,
    surfaceobstruction_update_params,
    surfaceobstruction_unvalidated_publish_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.surfaceobstruction_get_response import SurfaceobstructionGetResponse
from ..types.surfaceobstruction_list_response import SurfaceobstructionListResponse
from ..types.surfaceobstruction_tuple_response import SurfaceobstructionTupleResponse

__all__ = ["SurfaceobstructionResource", "AsyncSurfaceobstructionResource"]


class SurfaceobstructionResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SurfaceobstructionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return SurfaceobstructionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SurfaceobstructionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return SurfaceobstructionResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_surface: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        advisory_required: List[str] | NotGiven = NOT_GIVEN,
        approval_required: List[str] | NotGiven = NOT_GIVEN,
        distance_from_center_line: float | NotGiven = NOT_GIVEN,
        distance_from_edge: float | NotGiven = NOT_GIVEN,
        distance_from_threshold: float | NotGiven = NOT_GIVEN,
        id_navigational_obstruction: str | NotGiven = NOT_GIVEN,
        obstruction_desc: str | NotGiven = NOT_GIVEN,
        obstruction_height: float | NotGiven = NOT_GIVEN,
        obstruction_side_code: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single surfaceobstruction record as a POST body and
        ingest into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode: Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data.

          id_surface: The unique identifier of the associated surface record. This field is required
              when posting, updating, or deleting a SurfaceObstruction record.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          advisory_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an advisory for usage.

          approval_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an approval for usage.

          distance_from_center_line: The distance from the surface center line to this obstruction, in feet.

          distance_from_edge: The distance from the surface edge to this obstruction, in feet.

          distance_from_threshold: The distance from the surface threshold to this obstruction, in feet.

          id_navigational_obstruction: The unique identifier of the associated NavigationalObstruction record.

          obstruction_desc: Description of this surface obstruction.

          obstruction_height: The height above ground level of the surface obstruction, in feet.

          obstruction_side_code: A code that indicates which side of the surface end is affected by this
              obstruction.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/surfaceobstruction",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_surface": id_surface,
                    "source": source,
                    "id": id,
                    "advisory_required": advisory_required,
                    "approval_required": approval_required,
                    "distance_from_center_line": distance_from_center_line,
                    "distance_from_edge": distance_from_edge,
                    "distance_from_threshold": distance_from_threshold,
                    "id_navigational_obstruction": id_navigational_obstruction,
                    "obstruction_desc": obstruction_desc,
                    "obstruction_height": obstruction_height,
                    "obstruction_side_code": obstruction_side_code,
                    "origin": origin,
                },
                surfaceobstruction_create_params.SurfaceobstructionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_surface: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        advisory_required: List[str] | NotGiven = NOT_GIVEN,
        approval_required: List[str] | NotGiven = NOT_GIVEN,
        distance_from_center_line: float | NotGiven = NOT_GIVEN,
        distance_from_edge: float | NotGiven = NOT_GIVEN,
        distance_from_threshold: float | NotGiven = NOT_GIVEN,
        id_navigational_obstruction: str | NotGiven = NOT_GIVEN,
        obstruction_desc: str | NotGiven = NOT_GIVEN,
        obstruction_height: float | NotGiven = NOT_GIVEN,
        obstruction_side_code: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single surfaceobstruction record.

        A specific role
        is required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode: Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data.

          id_surface: The unique identifier of the associated surface record. This field is required
              when posting, updating, or deleting a SurfaceObstruction record.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          advisory_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an advisory for usage.

          approval_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an approval for usage.

          distance_from_center_line: The distance from the surface center line to this obstruction, in feet.

          distance_from_edge: The distance from the surface edge to this obstruction, in feet.

          distance_from_threshold: The distance from the surface threshold to this obstruction, in feet.

          id_navigational_obstruction: The unique identifier of the associated NavigationalObstruction record.

          obstruction_desc: Description of this surface obstruction.

          obstruction_height: The height above ground level of the surface obstruction, in feet.

          obstruction_side_code: A code that indicates which side of the surface end is affected by this
              obstruction.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/surfaceobstruction/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_surface": id_surface,
                    "source": source,
                    "body_id": body_id,
                    "advisory_required": advisory_required,
                    "approval_required": approval_required,
                    "distance_from_center_line": distance_from_center_line,
                    "distance_from_edge": distance_from_edge,
                    "distance_from_threshold": distance_from_threshold,
                    "id_navigational_obstruction": id_navigational_obstruction,
                    "obstruction_desc": obstruction_desc,
                    "obstruction_height": obstruction_height,
                    "obstruction_side_code": obstruction_side_code,
                    "origin": origin,
                },
                surfaceobstruction_update_params.SurfaceobstructionUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SurfaceobstructionListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/surfaceobstruction",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SurfaceobstructionListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a surfaceobstruction record specified by the passed
        ID path parameter. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/surfaceobstruction/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/surfaceobstruction/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SurfaceobstructionGetResponse:
        """
        Service operation to get a single surfaceobstruction record by its unique ID
        passed as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/surfaceobstruction/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SurfaceobstructionGetResponse,
        )

    def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/surfaceobstruction/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SurfaceobstructionTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/surfaceobstruction/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"columns": columns}, surfaceobstruction_tuple_params.SurfaceobstructionTupleParams
                ),
            ),
            cast_to=SurfaceobstructionTupleResponse,
        )

    def unvalidated_publish(
        self,
        *,
        body: Iterable[surfaceobstruction_unvalidated_publish_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take multiple surfaceobstruction records as a POST body and
        ingest into the database. This operation is intended to be used for automated
        feeds into UDL. A specific role is required to perform this service operation.
        Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/filedrop/udl-surfaceobstruction",
            body=maybe_transform(body, Iterable[surfaceobstruction_unvalidated_publish_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncSurfaceobstructionResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSurfaceobstructionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSurfaceobstructionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSurfaceobstructionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncSurfaceobstructionResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_surface: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        advisory_required: List[str] | NotGiven = NOT_GIVEN,
        approval_required: List[str] | NotGiven = NOT_GIVEN,
        distance_from_center_line: float | NotGiven = NOT_GIVEN,
        distance_from_edge: float | NotGiven = NOT_GIVEN,
        distance_from_threshold: float | NotGiven = NOT_GIVEN,
        id_navigational_obstruction: str | NotGiven = NOT_GIVEN,
        obstruction_desc: str | NotGiven = NOT_GIVEN,
        obstruction_height: float | NotGiven = NOT_GIVEN,
        obstruction_side_code: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single surfaceobstruction record as a POST body and
        ingest into the database. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode: Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data.

          id_surface: The unique identifier of the associated surface record. This field is required
              when posting, updating, or deleting a SurfaceObstruction record.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          advisory_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an advisory for usage.

          approval_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an approval for usage.

          distance_from_center_line: The distance from the surface center line to this obstruction, in feet.

          distance_from_edge: The distance from the surface edge to this obstruction, in feet.

          distance_from_threshold: The distance from the surface threshold to this obstruction, in feet.

          id_navigational_obstruction: The unique identifier of the associated NavigationalObstruction record.

          obstruction_desc: Description of this surface obstruction.

          obstruction_height: The height above ground level of the surface obstruction, in feet.

          obstruction_side_code: A code that indicates which side of the surface end is affected by this
              obstruction.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/surfaceobstruction",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_surface": id_surface,
                    "source": source,
                    "id": id,
                    "advisory_required": advisory_required,
                    "approval_required": approval_required,
                    "distance_from_center_line": distance_from_center_line,
                    "distance_from_edge": distance_from_edge,
                    "distance_from_threshold": distance_from_threshold,
                    "id_navigational_obstruction": id_navigational_obstruction,
                    "obstruction_desc": obstruction_desc,
                    "obstruction_height": obstruction_height,
                    "obstruction_side_code": obstruction_side_code,
                    "origin": origin,
                },
                surfaceobstruction_create_params.SurfaceobstructionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_surface: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        advisory_required: List[str] | NotGiven = NOT_GIVEN,
        approval_required: List[str] | NotGiven = NOT_GIVEN,
        distance_from_center_line: float | NotGiven = NOT_GIVEN,
        distance_from_edge: float | NotGiven = NOT_GIVEN,
        distance_from_threshold: float | NotGiven = NOT_GIVEN,
        id_navigational_obstruction: str | NotGiven = NOT_GIVEN,
        obstruction_desc: str | NotGiven = NOT_GIVEN,
        obstruction_height: float | NotGiven = NOT_GIVEN,
        obstruction_side_code: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single surfaceobstruction record.

        A specific role
        is required to perform this service operation. Please contact the UDL team for
        assistance.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode: Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data.

          id_surface: The unique identifier of the associated surface record. This field is required
              when posting, updating, or deleting a SurfaceObstruction record.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          advisory_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an advisory for usage.

          approval_required: Array of all vehicles that are affected by this obstruction at the surface
              end-point, and require an approval for usage.

          distance_from_center_line: The distance from the surface center line to this obstruction, in feet.

          distance_from_edge: The distance from the surface edge to this obstruction, in feet.

          distance_from_threshold: The distance from the surface threshold to this obstruction, in feet.

          id_navigational_obstruction: The unique identifier of the associated NavigationalObstruction record.

          obstruction_desc: Description of this surface obstruction.

          obstruction_height: The height above ground level of the surface obstruction, in feet.

          obstruction_side_code: A code that indicates which side of the surface end is affected by this
              obstruction.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/surfaceobstruction/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_surface": id_surface,
                    "source": source,
                    "body_id": body_id,
                    "advisory_required": advisory_required,
                    "approval_required": approval_required,
                    "distance_from_center_line": distance_from_center_line,
                    "distance_from_edge": distance_from_edge,
                    "distance_from_threshold": distance_from_threshold,
                    "id_navigational_obstruction": id_navigational_obstruction,
                    "obstruction_desc": obstruction_desc,
                    "obstruction_height": obstruction_height,
                    "obstruction_side_code": obstruction_side_code,
                    "origin": origin,
                },
                surfaceobstruction_update_params.SurfaceobstructionUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SurfaceobstructionListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/surfaceobstruction",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SurfaceobstructionListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a surfaceobstruction record specified by the passed
        ID path parameter. A specific role is required to perform this service
        operation. Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/surfaceobstruction/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/surfaceobstruction/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SurfaceobstructionGetResponse:
        """
        Service operation to get a single surfaceobstruction record by its unique ID
        passed as a path parameter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/surfaceobstruction/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SurfaceobstructionGetResponse,
        )

    async def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/surfaceobstruction/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SurfaceobstructionTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/surfaceobstruction/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"columns": columns}, surfaceobstruction_tuple_params.SurfaceobstructionTupleParams
                ),
            ),
            cast_to=SurfaceobstructionTupleResponse,
        )

    async def unvalidated_publish(
        self,
        *,
        body: Iterable[surfaceobstruction_unvalidated_publish_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take multiple surfaceobstruction records as a POST body and
        ingest into the database. This operation is intended to be used for automated
        feeds into UDL. A specific role is required to perform this service operation.
        Please contact the UDL team for assistance.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/filedrop/udl-surfaceobstruction",
            body=await async_maybe_transform(body, Iterable[surfaceobstruction_unvalidated_publish_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SurfaceobstructionResourceWithRawResponse:
    def __init__(self, surfaceobstruction: SurfaceobstructionResource) -> None:
        self._surfaceobstruction = surfaceobstruction

        self.create = to_raw_response_wrapper(
            surfaceobstruction.create,
        )
        self.update = to_raw_response_wrapper(
            surfaceobstruction.update,
        )
        self.list = to_raw_response_wrapper(
            surfaceobstruction.list,
        )
        self.delete = to_raw_response_wrapper(
            surfaceobstruction.delete,
        )
        self.count = to_raw_response_wrapper(
            surfaceobstruction.count,
        )
        self.get = to_raw_response_wrapper(
            surfaceobstruction.get,
        )
        self.queryhelp = to_raw_response_wrapper(
            surfaceobstruction.queryhelp,
        )
        self.tuple = to_raw_response_wrapper(
            surfaceobstruction.tuple,
        )
        self.unvalidated_publish = to_raw_response_wrapper(
            surfaceobstruction.unvalidated_publish,
        )


class AsyncSurfaceobstructionResourceWithRawResponse:
    def __init__(self, surfaceobstruction: AsyncSurfaceobstructionResource) -> None:
        self._surfaceobstruction = surfaceobstruction

        self.create = async_to_raw_response_wrapper(
            surfaceobstruction.create,
        )
        self.update = async_to_raw_response_wrapper(
            surfaceobstruction.update,
        )
        self.list = async_to_raw_response_wrapper(
            surfaceobstruction.list,
        )
        self.delete = async_to_raw_response_wrapper(
            surfaceobstruction.delete,
        )
        self.count = async_to_raw_response_wrapper(
            surfaceobstruction.count,
        )
        self.get = async_to_raw_response_wrapper(
            surfaceobstruction.get,
        )
        self.queryhelp = async_to_raw_response_wrapper(
            surfaceobstruction.queryhelp,
        )
        self.tuple = async_to_raw_response_wrapper(
            surfaceobstruction.tuple,
        )
        self.unvalidated_publish = async_to_raw_response_wrapper(
            surfaceobstruction.unvalidated_publish,
        )


class SurfaceobstructionResourceWithStreamingResponse:
    def __init__(self, surfaceobstruction: SurfaceobstructionResource) -> None:
        self._surfaceobstruction = surfaceobstruction

        self.create = to_streamed_response_wrapper(
            surfaceobstruction.create,
        )
        self.update = to_streamed_response_wrapper(
            surfaceobstruction.update,
        )
        self.list = to_streamed_response_wrapper(
            surfaceobstruction.list,
        )
        self.delete = to_streamed_response_wrapper(
            surfaceobstruction.delete,
        )
        self.count = to_streamed_response_wrapper(
            surfaceobstruction.count,
        )
        self.get = to_streamed_response_wrapper(
            surfaceobstruction.get,
        )
        self.queryhelp = to_streamed_response_wrapper(
            surfaceobstruction.queryhelp,
        )
        self.tuple = to_streamed_response_wrapper(
            surfaceobstruction.tuple,
        )
        self.unvalidated_publish = to_streamed_response_wrapper(
            surfaceobstruction.unvalidated_publish,
        )


class AsyncSurfaceobstructionResourceWithStreamingResponse:
    def __init__(self, surfaceobstruction: AsyncSurfaceobstructionResource) -> None:
        self._surfaceobstruction = surfaceobstruction

        self.create = async_to_streamed_response_wrapper(
            surfaceobstruction.create,
        )
        self.update = async_to_streamed_response_wrapper(
            surfaceobstruction.update,
        )
        self.list = async_to_streamed_response_wrapper(
            surfaceobstruction.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            surfaceobstruction.delete,
        )
        self.count = async_to_streamed_response_wrapper(
            surfaceobstruction.count,
        )
        self.get = async_to_streamed_response_wrapper(
            surfaceobstruction.get,
        )
        self.queryhelp = async_to_streamed_response_wrapper(
            surfaceobstruction.queryhelp,
        )
        self.tuple = async_to_streamed_response_wrapper(
            surfaceobstruction.tuple,
        )
        self.unvalidated_publish = async_to_streamed_response_wrapper(
            surfaceobstruction.unvalidated_publish,
        )
