# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import transponder_tuple_params, transponder_create_params, transponder_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.transponder_get_response import TransponderGetResponse
from ..types.transponder_list_response import TransponderListResponse
from ..types.transponder_tuple_response import TransponderTupleResponse

__all__ = ["TransponderResource", "AsyncTransponderResource"]


class TransponderResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TransponderResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return TransponderResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TransponderResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return TransponderResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_comm: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        fec: int | NotGiven = NOT_GIVEN,
        format: str | NotGiven = NOT_GIVEN,
        modulation: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        nid: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        symbol_rate: float | NotGiven = NOT_GIVEN,
        system: str | NotGiven = NOT_GIVEN,
        tid: str | NotGiven = NOT_GIVEN,
        ttf: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Transponder as a POST body and ingest into
        the database. A specific role is required to perform this service operation.
        Please contact the UDL team for assistance. A Comm payload may have multiple
        transponders and a transponder may have many channels.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_comm: ID of the parent Comm object for this transponder.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          fec: Forward error correction, e.g. 0=Auto, 1 = 1/2, 2 = 2/3, 3 = 3/4, 4 = 5/6, 5 =
              7/8, 6 = 8/9, 7 = 3/5, 8 = 4/5, 9 = 9/10, 15 = None.

          format: Format.

          modulation: Transponder modulation, e.g. Auto, QPSK, 8PSK.

          name: Optional name of the transponder.

          nid: Optional external network id as provided data source.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          symbol_rate: Symbol rate is the number of symbol changes, waveform changes, or signaling
              events, across the transmission medium per time unit using a digitally modulated
              signal or a line code. Also measured in Hz.

          system: Transponder system, e.g. DVB-S, DVB-S2.

          tid: Optional external transponder id as provided data source.

          ttf: Transponder Translation Factor. This is the frequency difference between the
              uplink received by a satellite, and the downlink transmitted back. It varies
              satellite to satellite dependent on the mission.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/udl/transponder",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_comm": id_comm,
                    "source": source,
                    "id": id,
                    "fec": fec,
                    "format": format,
                    "modulation": modulation,
                    "name": name,
                    "nid": nid,
                    "origin": origin,
                    "symbol_rate": symbol_rate,
                    "system": system,
                    "tid": tid,
                    "ttf": ttf,
                },
                transponder_create_params.TransponderCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_comm: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        fec: int | NotGiven = NOT_GIVEN,
        format: str | NotGiven = NOT_GIVEN,
        modulation: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        nid: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        symbol_rate: float | NotGiven = NOT_GIVEN,
        system: str | NotGiven = NOT_GIVEN,
        tid: str | NotGiven = NOT_GIVEN,
        ttf: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Transponder.

        A specific role is required to
        perform this service operation. Please contact the UDL team for assistance. A
        Comm payload may have multiple transponders and a transponder may have many
        channels.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_comm: ID of the parent Comm object for this transponder.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          fec: Forward error correction, e.g. 0=Auto, 1 = 1/2, 2 = 2/3, 3 = 3/4, 4 = 5/6, 5 =
              7/8, 6 = 8/9, 7 = 3/5, 8 = 4/5, 9 = 9/10, 15 = None.

          format: Format.

          modulation: Transponder modulation, e.g. Auto, QPSK, 8PSK.

          name: Optional name of the transponder.

          nid: Optional external network id as provided data source.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          symbol_rate: Symbol rate is the number of symbol changes, waveform changes, or signaling
              events, across the transmission medium per time unit using a digitally modulated
              signal or a line code. Also measured in Hz.

          system: Transponder system, e.g. DVB-S, DVB-S2.

          tid: Optional external transponder id as provided data source.

          ttf: Transponder Translation Factor. This is the frequency difference between the
              uplink received by a satellite, and the downlink transmitted back. It varies
              satellite to satellite dependent on the mission.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/udl/transponder/{path_id}",
            body=maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_comm": id_comm,
                    "source": source,
                    "body_id": body_id,
                    "fec": fec,
                    "format": format,
                    "modulation": modulation,
                    "name": name,
                    "nid": nid,
                    "origin": origin,
                    "symbol_rate": symbol_rate,
                    "system": system,
                    "tid": tid,
                    "ttf": ttf,
                },
                transponder_update_params.TransponderUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransponderListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return self._get(
            "/udl/transponder",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TransponderListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a Transponder object specified by the passed ID path
        parameter. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance. A Comm payload may have multiple
        transponders and a transponder may have many channels.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/udl/transponder/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            "/udl/transponder/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransponderGetResponse:
        """
        Service operation to get a single Transponder record by its unique ID passed as
        a path parameter. A Comm payload may have multiple transponders and a
        transponder may have many channels.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/udl/transponder/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TransponderGetResponse,
        )

    def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/udl/transponder/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransponderTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/udl/transponder/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"columns": columns}, transponder_tuple_params.TransponderTupleParams),
            ),
            cast_to=TransponderTupleResponse,
        )


class AsyncTransponderResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTransponderResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncTransponderResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTransponderResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/rsivilli-bluestaq/udl-python-sdk#with_streaming_response
        """
        return AsyncTransponderResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_comm: str,
        source: str,
        id: str | NotGiven = NOT_GIVEN,
        fec: int | NotGiven = NOT_GIVEN,
        format: str | NotGiven = NOT_GIVEN,
        modulation: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        nid: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        symbol_rate: float | NotGiven = NOT_GIVEN,
        system: str | NotGiven = NOT_GIVEN,
        tid: str | NotGiven = NOT_GIVEN,
        ttf: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to take a single Transponder as a POST body and ingest into
        the database. A specific role is required to perform this service operation.
        Please contact the UDL team for assistance. A Comm payload may have multiple
        transponders and a transponder may have many channels.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_comm: ID of the parent Comm object for this transponder.

          source: Source of the data.

          id: Unique identifier of the record, auto-generated by the system.

          fec: Forward error correction, e.g. 0=Auto, 1 = 1/2, 2 = 2/3, 3 = 3/4, 4 = 5/6, 5 =
              7/8, 6 = 8/9, 7 = 3/5, 8 = 4/5, 9 = 9/10, 15 = None.

          format: Format.

          modulation: Transponder modulation, e.g. Auto, QPSK, 8PSK.

          name: Optional name of the transponder.

          nid: Optional external network id as provided data source.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          symbol_rate: Symbol rate is the number of symbol changes, waveform changes, or signaling
              events, across the transmission medium per time unit using a digitally modulated
              signal or a line code. Also measured in Hz.

          system: Transponder system, e.g. DVB-S, DVB-S2.

          tid: Optional external transponder id as provided data source.

          ttf: Transponder Translation Factor. This is the frequency difference between the
              uplink received by a satellite, and the downlink transmitted back. It varies
              satellite to satellite dependent on the mission.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/udl/transponder",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_comm": id_comm,
                    "source": source,
                    "id": id,
                    "fec": fec,
                    "format": format,
                    "modulation": modulation,
                    "name": name,
                    "nid": nid,
                    "origin": origin,
                    "symbol_rate": symbol_rate,
                    "system": system,
                    "tid": tid,
                    "ttf": ttf,
                },
                transponder_create_params.TransponderCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        path_id: str,
        *,
        classification_marking: str,
        data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"],
        id_comm: str,
        source: str,
        body_id: str | NotGiven = NOT_GIVEN,
        fec: int | NotGiven = NOT_GIVEN,
        format: str | NotGiven = NOT_GIVEN,
        modulation: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        nid: str | NotGiven = NOT_GIVEN,
        origin: str | NotGiven = NOT_GIVEN,
        symbol_rate: float | NotGiven = NOT_GIVEN,
        system: str | NotGiven = NOT_GIVEN,
        tid: str | NotGiven = NOT_GIVEN,
        ttf: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Service operation to update a single Transponder.

        A specific role is required to
        perform this service operation. Please contact the UDL team for assistance. A
        Comm payload may have multiple transponders and a transponder may have many
        channels.

        Args:
          classification_marking: Classification marking of the data in IC/CAPCO Portion-marked format.

          data_mode:
              Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

              EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
              may include both real and simulated data.

              REAL:&nbsp;Data collected or produced that pertains to real-world objects,
              events, and analysis.

              SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
              datasets.

              TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
              requirements, and for validating technical, functional, and performance
              characteristics.

          id_comm: ID of the parent Comm object for this transponder.

          source: Source of the data.

          body_id: Unique identifier of the record, auto-generated by the system.

          fec: Forward error correction, e.g. 0=Auto, 1 = 1/2, 2 = 2/3, 3 = 3/4, 4 = 5/6, 5 =
              7/8, 6 = 8/9, 7 = 3/5, 8 = 4/5, 9 = 9/10, 15 = None.

          format: Format.

          modulation: Transponder modulation, e.g. Auto, QPSK, 8PSK.

          name: Optional name of the transponder.

          nid: Optional external network id as provided data source.

          origin: Originating system or organization which produced the data, if different from
              the source. The origin may be different than the source if the source was a
              mediating system which forwarded the data on behalf of the origin system. If
              null, the source may be assumed to be the origin.

          symbol_rate: Symbol rate is the number of symbol changes, waveform changes, or signaling
              events, across the transmission medium per time unit using a digitally modulated
              signal or a line code. Also measured in Hz.

          system: Transponder system, e.g. DVB-S, DVB-S2.

          tid: Optional external transponder id as provided data source.

          ttf: Transponder Translation Factor. This is the frequency difference between the
              uplink received by a satellite, and the downlink transmitted back. It varies
              satellite to satellite dependent on the mission.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/udl/transponder/{path_id}",
            body=await async_maybe_transform(
                {
                    "classification_marking": classification_marking,
                    "data_mode": data_mode,
                    "id_comm": id_comm,
                    "source": source,
                    "body_id": body_id,
                    "fec": fec,
                    "format": format,
                    "modulation": modulation,
                    "name": name,
                    "nid": nid,
                    "origin": origin,
                    "symbol_rate": symbol_rate,
                    "system": system,
                    "tid": tid,
                    "ttf": ttf,
                },
                transponder_update_params.TransponderUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransponderListResponse:
        """
        Service operation to dynamically query data by a variety of query parameters not
        specified in this API documentation. See the queryhelp operation
        (/udl/&lt;datatype&gt;/queryhelp) for more details on valid/required query
        parameter information.
        """
        return await self._get(
            "/udl/transponder",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TransponderListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to delete a Transponder object specified by the passed ID path
        parameter. A specific role is required to perform this service operation. Please
        contact the UDL team for assistance. A Comm payload may have multiple
        transponders and a transponder may have many channels.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/udl/transponder/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Service operation to return the count of records satisfying the specified query
        parameters. This operation is useful to determine how many records pass a
        particular query criteria without retrieving large amounts of data. See the
        queryhelp operation (/udl/&lt;datatype&gt;/queryhelp) for more details on
        valid/required query parameter information.
        """
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            "/udl/transponder/count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransponderGetResponse:
        """
        Service operation to get a single Transponder record by its unique ID passed as
        a path parameter. A Comm payload may have multiple transponders and a
        transponder may have many channels.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/udl/transponder/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TransponderGetResponse,
        )

    async def queryhelp(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Service operation to provide detailed information on available dynamic query
        parameters for a particular data type.
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/udl/transponder/queryhelp",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def tuple(
        self,
        *,
        columns: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TransponderTupleResponse:
        """
        Service operation to dynamically query data and only return specified
        columns/fields. Requested columns are specified by the 'columns' query parameter
        and should be a comma separated list of valid fields for the specified data
        type. classificationMarking is always returned. See the queryhelp operation
        (/udl/<datatype>/queryhelp) for more details on valid/required query parameter
        information. An example URI: /udl/elset/tuple?columns=satNo,period&epoch=>now-5
        hours would return the satNo and period of elsets with an epoch greater than 5
        hours ago.

        Args:
          columns: Comma-separated list of valid field names for this data type to be returned in
              the response. Only the fields specified will be returned as well as the
              classification marking of the data, if applicable. See the ‘queryhelp’ operation
              for a complete list of possible fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/udl/transponder/tuple",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"columns": columns}, transponder_tuple_params.TransponderTupleParams
                ),
            ),
            cast_to=TransponderTupleResponse,
        )


class TransponderResourceWithRawResponse:
    def __init__(self, transponder: TransponderResource) -> None:
        self._transponder = transponder

        self.create = to_raw_response_wrapper(
            transponder.create,
        )
        self.update = to_raw_response_wrapper(
            transponder.update,
        )
        self.list = to_raw_response_wrapper(
            transponder.list,
        )
        self.delete = to_raw_response_wrapper(
            transponder.delete,
        )
        self.count = to_raw_response_wrapper(
            transponder.count,
        )
        self.get = to_raw_response_wrapper(
            transponder.get,
        )
        self.queryhelp = to_raw_response_wrapper(
            transponder.queryhelp,
        )
        self.tuple = to_raw_response_wrapper(
            transponder.tuple,
        )


class AsyncTransponderResourceWithRawResponse:
    def __init__(self, transponder: AsyncTransponderResource) -> None:
        self._transponder = transponder

        self.create = async_to_raw_response_wrapper(
            transponder.create,
        )
        self.update = async_to_raw_response_wrapper(
            transponder.update,
        )
        self.list = async_to_raw_response_wrapper(
            transponder.list,
        )
        self.delete = async_to_raw_response_wrapper(
            transponder.delete,
        )
        self.count = async_to_raw_response_wrapper(
            transponder.count,
        )
        self.get = async_to_raw_response_wrapper(
            transponder.get,
        )
        self.queryhelp = async_to_raw_response_wrapper(
            transponder.queryhelp,
        )
        self.tuple = async_to_raw_response_wrapper(
            transponder.tuple,
        )


class TransponderResourceWithStreamingResponse:
    def __init__(self, transponder: TransponderResource) -> None:
        self._transponder = transponder

        self.create = to_streamed_response_wrapper(
            transponder.create,
        )
        self.update = to_streamed_response_wrapper(
            transponder.update,
        )
        self.list = to_streamed_response_wrapper(
            transponder.list,
        )
        self.delete = to_streamed_response_wrapper(
            transponder.delete,
        )
        self.count = to_streamed_response_wrapper(
            transponder.count,
        )
        self.get = to_streamed_response_wrapper(
            transponder.get,
        )
        self.queryhelp = to_streamed_response_wrapper(
            transponder.queryhelp,
        )
        self.tuple = to_streamed_response_wrapper(
            transponder.tuple,
        )


class AsyncTransponderResourceWithStreamingResponse:
    def __init__(self, transponder: AsyncTransponderResource) -> None:
        self._transponder = transponder

        self.create = async_to_streamed_response_wrapper(
            transponder.create,
        )
        self.update = async_to_streamed_response_wrapper(
            transponder.update,
        )
        self.list = async_to_streamed_response_wrapper(
            transponder.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            transponder.delete,
        )
        self.count = async_to_streamed_response_wrapper(
            transponder.count,
        )
        self.get = async_to_streamed_response_wrapper(
            transponder.get,
        )
        self.queryhelp = async_to_streamed_response_wrapper(
            transponder.queryhelp,
        )
        self.tuple = async_to_streamed_response_wrapper(
            transponder.tuple,
        )
