# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import date, datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["AircraftsortieAbridged"]


class AircraftsortieAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    planned_dep_time: datetime = FieldInfo(alias="plannedDepTime")
    """
    The scheduled time that the Aircraft sortie is planned to depart, in ISO 8601
    UTC format with millisecond precision.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    actual_arr_time: Optional[datetime] = FieldInfo(alias="actualArrTime", default=None)
    """The actual arrival time, in ISO 8601 UTC format with millisecond precision."""

    actual_block_in_time: Optional[datetime] = FieldInfo(alias="actualBlockInTime", default=None)
    """
    The actual time the Aircraft comes to a complete stop in its parking position,
    in ISO 8601 UTC format with millisecond precision.
    """

    actual_block_out_time: Optional[datetime] = FieldInfo(alias="actualBlockOutTime", default=None)
    """
    The actual time the Aircraft begins to taxi from its parking position, in ISO
    8601 UTC format with millisecond precision.
    """

    actual_dep_time: Optional[datetime] = FieldInfo(alias="actualDepTime", default=None)
    """The actual departure time, in ISO 8601 UTC format."""

    aircraft_adsb: Optional[str] = FieldInfo(alias="aircraftADSB", default=None)
    """The Automatic Dependent Surveillance-Broadcast (ADS-B) device identifier."""

    aircraft_alt_id: Optional[str] = FieldInfo(alias="aircraftAltId", default=None)
    """Alternate Aircraft Identifier provided by source."""

    aircraft_event: Optional[str] = FieldInfo(alias="aircraftEvent", default=None)
    """Aircraft event text."""

    aircraft_mds: Optional[str] = FieldInfo(alias="aircraftMDS", default=None)
    """The aircraft Model Design Series designation assigned to this sortie."""

    aircraft_remarks: Optional[str] = FieldInfo(alias="aircraftRemarks", default=None)
    """Remarks concerning the aircraft."""

    alert_status: Optional[int] = FieldInfo(alias="alertStatus", default=None)
    """The amount of time allowed between launch order and takeoff, in seconds."""

    alert_status_code: Optional[str] = FieldInfo(alias="alertStatusCode", default=None)
    """The Alert Status code."""

    amc_msn_num: Optional[str] = FieldInfo(alias="amcMsnNum", default=None)
    """The Air Mobility Command (AMC) mission number of the sortie."""

    amc_msn_type: Optional[str] = FieldInfo(alias="amcMsnType", default=None)
    """The type of mission (e.g. SAAM, CHNL, etc.)."""

    arr_faa: Optional[str] = FieldInfo(alias="arrFAA", default=None)
    """The arrival Federal Aviation Administration (FAA) code of this sortie."""

    arr_iata: Optional[str] = FieldInfo(alias="arrIATA", default=None)
    """
    The arrival International Aviation Transport Association (IATA) code of this
    sortie.
    """

    arr_icao: Optional[str] = FieldInfo(alias="arrICAO", default=None)
    """The arrival International Civil Aviation Organization (ICAO) of this sortie."""

    arr_itinerary: Optional[int] = FieldInfo(alias="arrItinerary", default=None)
    """The itinerary identifier of the arrival location."""

    arr_purpose_code: Optional[str] = FieldInfo(alias="arrPurposeCode", default=None)
    """Purpose code at the arrival location of this sortie."""

    call_sign: Optional[str] = FieldInfo(alias="callSign", default=None)
    """The call sign assigned to the aircraft on this sortie."""

    cargo_config: Optional[str] = FieldInfo(alias="cargoConfig", default=None)
    """Description of the cargo configuration (e.g.

    C-1, C-2, C-3, DV-1, DV-2, AE-1, etc.) currently on board the aircraft.
    Configuration meanings are determined by the data source.
    """

    commander_name: Optional[str] = FieldInfo(alias="commanderName", default=None)
    """The last name of the aircraft commander."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    current_state: Optional[str] = FieldInfo(alias="currentState", default=None)
    """The current state of this sortie."""

    delay_code: Optional[str] = FieldInfo(alias="delayCode", default=None)
    """The primary delay code."""

    dep_faa: Optional[str] = FieldInfo(alias="depFAA", default=None)
    """The departure Federal Aviation Administration (FAA) code of this sortie."""

    dep_iata: Optional[str] = FieldInfo(alias="depIATA", default=None)
    """
    The departure International Aviation Transport Association (IATA) code of this
    sortie.
    """

    dep_icao: Optional[str] = FieldInfo(alias="depICAO", default=None)
    """The departure International Civil Aviation Organization (ICAO) of this sortie."""

    dep_itinerary: Optional[int] = FieldInfo(alias="depItinerary", default=None)
    """The itinerary identifier of the departure location."""

    dep_purpose_code: Optional[str] = FieldInfo(alias="depPurposeCode", default=None)
    """Purpose code at the departure location of this sortie."""

    dhd: Optional[datetime] = None
    """
    Due home date by which the aircraft must return to its home station, in ISO 8601
    UTC format with millisecond precision.
    """

    dhd_reason: Optional[str] = FieldInfo(alias="dhdReason", default=None)
    """Reason the aircraft must return to home station by its due home date."""

    est_arr_time: Optional[datetime] = FieldInfo(alias="estArrTime", default=None)
    """
    The current estimated time that the Aircraft is planned to arrive, in ISO 8601
    UTC format with millisecond precision.
    """

    est_block_in_time: Optional[datetime] = FieldInfo(alias="estBlockInTime", default=None)
    """
    The estimated time the Aircraft will come to a complete stop in its parking
    position, in ISO 8601 UTC format with millisecond precision.
    """

    est_block_out_time: Optional[datetime] = FieldInfo(alias="estBlockOutTime", default=None)
    """
    The estimated time the Aircraft will begin to taxi from its parking position, in
    ISO 8601 UTC format with millisecond precision.
    """

    est_dep_time: Optional[datetime] = FieldInfo(alias="estDepTime", default=None)
    """
    The current estimated time that the Aircraft is planned to depart, in ISO 8601
    UTC format with millisecond precision.
    """

    filename: Optional[str] = None
    """Name of the uploaded PDF."""

    filesize: Optional[int] = None
    """Size of the supporting PDF, in bytes."""

    flight_time: Optional[float] = FieldInfo(alias="flightTime", default=None)
    """The planned flight time for this sortie, in minutes."""

    fm_desk_num: Optional[str] = FieldInfo(alias="fmDeskNum", default=None)
    """Desk phone number of the flight manager assigned to the sortie.

    Null when no flight manager is assigned.
    """

    fm_name: Optional[str] = FieldInfo(alias="fmName", default=None)
    """Last name of the flight manager assigned to the sortie.

    Null when no flight manager is assigned.
    """

    fuel_req: Optional[float] = FieldInfo(alias="fuelReq", default=None)
    """Mass of fuel required for this leg of the sortie, in kilograms."""

    gnd_time: Optional[float] = FieldInfo(alias="gndTime", default=None)
    """Scheduled ground time, in minutes."""

    id_aircraft: Optional[str] = FieldInfo(alias="idAircraft", default=None)
    """Unique identifier of the aircraft."""

    id_mission: Optional[str] = FieldInfo(alias="idMission", default=None)
    """The unique identifier of the mission to which this sortie is assigned."""

    jcs_priority: Optional[str] = FieldInfo(alias="jcsPriority", default=None)
    """Joint Chiefs of Staff priority of this sortie."""

    leg_num: Optional[int] = FieldInfo(alias="legNum", default=None)
    """The leg number of this sortie."""

    line_number: Optional[int] = FieldInfo(alias="lineNumber", default=None)
    """The external system line number of this sortie."""

    mission_id: Optional[str] = FieldInfo(alias="missionId", default=None)
    """The mission ID according to the source system."""

    mission_update: Optional[datetime] = FieldInfo(alias="missionUpdate", default=None)
    """
    Time the associated mission data was last updated in relation to the aircraft
    assignment, in ISO 8601 UTC format with millisecond precision. If this time is
    coming from an external system, it may not sync with the latest mission time
    associated to this record.
    """

    objective_remarks: Optional[str] = FieldInfo(alias="objectiveRemarks", default=None)
    """Remarks concerning the sortie objective."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_sortie_id: Optional[str] = FieldInfo(alias="origSortieId", default=None)
    """The sortie identifier provided by the originating source."""

    oxy_on_crew: Optional[float] = FieldInfo(alias="oxyOnCrew", default=None)
    """Liquid oxygen onboard the aircraft for the crew compartment, in liters."""

    oxy_on_pax: Optional[float] = FieldInfo(alias="oxyOnPax", default=None)
    """Liquid oxygen onboard the aircraft for the troop compartment, in liters."""

    oxy_req_crew: Optional[float] = FieldInfo(alias="oxyReqCrew", default=None)
    """Liquid oxygen required on the aircraft for the crew compartment, in liters."""

    oxy_req_pax: Optional[float] = FieldInfo(alias="oxyReqPax", default=None)
    """Liquid oxygen required on the aircraft for the troop compartment, in liters."""

    paper_status: Optional[Literal["PUBLISHED", "DELETED", "UPDATED", "READ"]] = FieldInfo(
        alias="paperStatus", default=None
    )
    """The status of the supporting document."""

    papers_version: Optional[str] = FieldInfo(alias="papersVersion", default=None)
    """The version number of the crew paper."""

    parking_loc: Optional[str] = FieldInfo(alias="parkingLoc", default=None)
    """The POI parking location."""

    passengers: Optional[int] = None
    """The number of passengers tasked for this sortie."""

    planned_arr_time: Optional[datetime] = FieldInfo(alias="plannedArrTime", default=None)
    """
    The scheduled time that the Aircraft sortie is planned to arrive, in ISO 8601
    UTC format with millisecond precision.
    """

    ppr_status: Optional[Literal["NOT REQUIRED", "REQUIRED NOT REQUESTED", "GRANTED", "PENDING"]] = FieldInfo(
        alias="pprStatus", default=None
    )
    """The prior permission required (PPR) status."""

    primary_scl: Optional[str] = FieldInfo(alias="primarySCL", default=None)
    """The planned primary Standard Conventional Load of the aircraft for this sortie."""

    raw_file_uri: Optional[str] = FieldInfo(alias="rawFileURI", default=None)
    """When crew papers are associated to this sortie, the system updates this value.

    This field is the URI location in the document repository of that raw file. To
    download the raw file, prepend https://udl-hostname/scs/download?id= to this
    field's value.
    """

    req_config: Optional[str] = FieldInfo(alias="reqConfig", default=None)
    """Aircraft configuration required for the mission."""

    result_remarks: Optional[str] = FieldInfo(alias="resultRemarks", default=None)
    """Remarks concerning the results of this sortie."""

    rvn_req: Optional[Literal["N", "R", "C6", "R6"]] = FieldInfo(alias="rvnReq", default=None)
    """
    Type of Ravens required for this sortie (N - None, R - Raven (Security Team)
    required, C6 - Consider ravens (Ground time over 6 hours), R6 - Ravens required
    (Ground time over 6 hours)).
    """

    schedule_remarks: Optional[str] = FieldInfo(alias="scheduleRemarks", default=None)
    """Remarks concerning the schedule."""

    secondary_scl: Optional[str] = FieldInfo(alias="secondarySCL", default=None)
    """
    The planned secondary Standard Conventional Load of the aircraft for this
    sortie.
    """

    soe: Optional[str] = None
    """
    Indicates the group responsible for recording the completion time of the next
    event in the sequence of events assigned to this sortie (e.g. OPS - Operations,
    MX - Maintenance, TR - Transportation, etc.).
    """

    sortie_date: Optional[date] = FieldInfo(alias="sortieDate", default=None)
    """The scheduled UTC date for this sortie, in ISO 8601 date-only format (ex.

    YYYY-MM-DD).
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    tail_number: Optional[str] = FieldInfo(alias="tailNumber", default=None)
    """The tail number of the aircraft assigned to this sortie."""
