# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["AirTransportMissionCreateParams", "HazMat", "Remark", "Requirement"]


class AirTransportMissionCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    abp: str
    """
    The Air Battle Plan used to coordinate and integrate air assets for this
    mission.
    """

    alias: str
    """Mission alias."""

    allocated_unit: Annotated[str, PropertyInfo(alias="allocatedUnit")]
    """The unit the mission is allocated to."""

    amc_mission_id: Annotated[str, PropertyInfo(alias="amcMissionId")]
    """
    Air Mobility Command (AMC) mission identifier according to Mobility Air Forces
    (MAF) Encode/Decode procedures.
    """

    apacs_id: Annotated[str, PropertyInfo(alias="apacsId")]
    """
    The Aircraft and Personnel Automated Clearance System (APACS) system identifier
    used to process and approve clearance requests.
    """

    ato_call_sign: Annotated[str, PropertyInfo(alias="atoCallSign")]
    """
    The call sign assigned to this mission according to the Air Tasking Order (ATO).
    """

    ato_mission_id: Annotated[str, PropertyInfo(alias="atoMissionId")]
    """The mission number according to the Air Tasking Order (ATO)."""

    call_sign: Annotated[str, PropertyInfo(alias="callSign")]
    """The call sign for this mission."""

    cw: bool
    """Flag indicating this is a close watch mission."""

    dip_worksheet_name: Annotated[str, PropertyInfo(alias="dipWorksheetName")]
    """
    Identifier of the Diplomatic Clearance Worksheet used to coordinate aircraft
    clearance requests.
    """

    first_pick_up: Annotated[str, PropertyInfo(alias="firstPickUp")]
    """
    The International Civil Aviation Organization (ICAO) site code of first cargo
    pick up.
    """

    gdss_mission_id: Annotated[str, PropertyInfo(alias="gdssMissionId")]
    """Global Decision Support System (GDSS) mission unique identifier."""

    haz_mat: Annotated[Iterable[HazMat], PropertyInfo(alias="hazMat")]
    """
    Collection of Hazardous Material information planned to be associated with this
    Air Transport Mission.
    """

    jcs_priority: Annotated[str, PropertyInfo(alias="jcsPriority")]
    """Highest Joint Chiefs of Staff priority of this mission."""

    last_drop_off: Annotated[str, PropertyInfo(alias="lastDropOff")]
    """
    The International Civil Aviation Organization (ICAO) site code of last cargo
    drop off.
    """

    load_category_type: Annotated[str, PropertyInfo(alias="loadCategoryType")]
    """Load type of this mission (e.g. CARGO, MIXED, PASSENGER)."""

    m1: str
    """
    Mode-1 interrogation response (mission code), indicating mission or aircraft
    type.
    """

    m2: str
    """Mode-2 interrogation response (military identification code)."""

    m3a: str
    """
    Mode-3/A interrogation response (aircraft identification), provides a 4-digit
    octal identification code for the aircraft, assigned by the air traffic
    controller. Mode-3/A is shared military/civilian use.
    """

    naf: str
    """Numbered Air Force (NAF) organization that owns the mission."""

    next_amc_mission_id: Annotated[str, PropertyInfo(alias="nextAMCMissionId")]
    """Air Mobility Command (AMC) mission identifier of the next air transport mission.

    Provides a method for AMC to link air transport missions together
    chronologically for tasking and planning purposes.
    """

    next_mission_id: Annotated[str, PropertyInfo(alias="nextMissionId")]
    """Unique identifier of the next mission provided by the originating source.

    Provides a method for the data provider to link air transport missions together
    chronologically for tasking and planning purposes.
    """

    node: str
    """
    Designates the location responsible for mission transportation, logistics, or
    distribution activities for an Area of Responsibility (AOR) within USTRANSCOM.
    """

    objective: str
    """A description of this mission's objective."""

    operation: str
    """The name of the operation that this mission supports."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_mission_id: Annotated[str, PropertyInfo(alias="origMissionId")]
    """The mission identifier provided by the originating source."""

    prev_amc_mission_id: Annotated[str, PropertyInfo(alias="prevAMCMissionId")]
    """
    Air Mobility Command (AMC) mission identifier of the previous air transport
    mission. Provides a method for AMC to link air transport missions together
    chronologically for tasking and planning purposes.
    """

    prev_mission_id: Annotated[str, PropertyInfo(alias="prevMissionId")]
    """
    Unique identifier of the previous air transport mission provided by the
    originating source. Provides a method for the data provider to link air
    transport missions together chronologically for tasking and planning purposes.
    """

    purpose: str
    """A description of this mission's purpose (e.g.

    why this mission needs to happen, what is the mission supporting, etc.).
    """

    remarks: Iterable[Remark]
    """
    Information related to the planning, load, status, and deployment or dispatch of
    one aircraft to carry out a mission.
    """

    requirements: Iterable[Requirement]
    """
    Collection of Requirements planned to be associated with this Air Transport
    Mission.
    """

    source_sys_deviation: Annotated[float, PropertyInfo(alias="sourceSysDeviation")]
    """
    The number of minutes a mission is off schedule based on the source system's
    business rules. Positive numbers are early, negative numbers are late.
    """

    state: str
    """Current state of the mission."""

    type: str
    """The type of mission (e.g. SAAM, CHNL, etc.)."""


class HazMat(TypedDict, total=False):
    applicable_notes: Annotated[str, PropertyInfo(alias="applicableNotes")]
    """
    Comma delimited list of Note IDs for Item Class Segregation groups, specific to
    GDSS systems.
    """

    cgc: str
    """
    Compatibility group code used to specify the controls for the transportation and
    storage of hazardous materials according to the Hazardous Materials Regulations
    issued by the U.S. Department of Transportation.
    """

    cgn: str
    """
    Comma delimited list of Note IDs for compatibility groups, specific to GDSS
    systems.
    """

    class_div: Annotated[float, PropertyInfo(alias="classDiv")]
    """
    Class and division of the hazardous material according to the Hazardous
    Materials Regulations issued by the U.S. Department of Transportation.
    """

    ext_haz_mat_id: Annotated[str, PropertyInfo(alias="extHazMatId")]
    """The hazMat identifier provided by the originating source."""

    item_name: Annotated[str, PropertyInfo(alias="itemName")]
    """
    United Nations proper shipping name of the hazardous material according to the
    Hazardous Materials Regulations issued by the U.S. Department of Transportation.
    """

    net_exp_wt: Annotated[float, PropertyInfo(alias="netExpWt")]
    """Net explosive weight of the hazardous material, in kilograms."""

    off_icao: Annotated[str, PropertyInfo(alias="offICAO")]
    """
    The International Civil Aviation Organization (ICAO) code of the site where the
    hazardous material is unloaded.
    """

    off_itin: Annotated[int, PropertyInfo(alias="offItin")]
    """Itinerary number that identifies where the hazardous material is unloaded."""

    on_icao: Annotated[str, PropertyInfo(alias="onICAO")]
    """
    The International Civil Aviation Organization (ICAO) code of the site where the
    hazardous material is loaded.
    """

    on_itin: Annotated[int, PropertyInfo(alias="onItin")]
    """Itinerary number that identifies where the hazardous material is loaded."""

    pieces: int
    """Number of pieces of hazardous cargo."""

    planned: str
    """
    Flag indicating if hazardous material is associated with this air transport
    mission. Possible values are P (planned to be associated with the mission) or A
    (actually associated with the mission). Enum: [P, A].
    """

    un_num: Annotated[str, PropertyInfo(alias="unNum")]
    """
    United Nations number or North America number that identifies hazardous
    materials according to the Hazardous Materials Regulations issued by the U.S.
    Department of Transportation.
    """

    weight: float
    """Total weight of hazardous cargo, including non-explosive parts, in kilograms."""


class Remark(TypedDict, total=False):
    date: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """
    Date the remark was published, in ISO 8601 UTC format, with millisecond
    precision.
    """

    gdss_remark_id: Annotated[str, PropertyInfo(alias="gdssRemarkId")]
    """Global Decision Support System (GDSS) remark identifier."""

    itinerary_num: Annotated[int, PropertyInfo(alias="itineraryNum")]
    """
    If the remark is sortie specific, this is the number of the sortie it applies
    to.
    """

    text: str
    """Text of the remark."""

    type: str
    """Remark type."""

    user: str
    """User who published the remark."""


class Requirement(TypedDict, total=False):
    bulk_weight: Annotated[float, PropertyInfo(alias="bulkWeight")]
    """Total weight of the bulk cargo, in kilograms."""

    ead: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """
    Earliest available date the cargo can be picked up, in ISO 8601 UTC format with
    millisecond precision.
    """

    gdss_req_id: Annotated[str, PropertyInfo(alias="gdssReqId")]
    """Global Decision Support System (GDSS) mission requirement identifier."""

    lad: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """
    Latest available date the cargo may be delivered, in ISO 8601 UTC format with
    millisecond precision.
    """

    num_ambulatory: Annotated[int, PropertyInfo(alias="numAmbulatory")]
    """Number of ambulatory patients tasked for the mission."""

    num_attendant: Annotated[int, PropertyInfo(alias="numAttendant")]
    """Number of attendants tasked for the mission."""

    num_litter: Annotated[int, PropertyInfo(alias="numLitter")]
    """Number of litter patients tasked for the mission."""

    num_pax: Annotated[int, PropertyInfo(alias="numPax")]
    """Number of passengers associated with the mission."""

    offload_id: Annotated[int, PropertyInfo(alias="offloadId")]
    """Identifier of the offload itinerary location."""

    offload_lo_code: Annotated[str, PropertyInfo(alias="offloadLOCode")]
    """Offload location code."""

    onload_id: Annotated[int, PropertyInfo(alias="onloadId")]
    """Identifier of the onload itinerary location."""

    onload_lo_code: Annotated[str, PropertyInfo(alias="onloadLOCode")]
    """Onload location code."""

    oplan: str
    """
    Identification number of the Operation Plan (OPLAN) associated with this
    mission.
    """

    outsize_weight: Annotated[float, PropertyInfo(alias="outsizeWeight")]
    """Total weight of the outsize cargo, in kilograms."""

    oversize_weight: Annotated[float, PropertyInfo(alias="oversizeWeight")]
    """Total weight of the oversized cargo, in kilograms."""

    proj_name: Annotated[str, PropertyInfo(alias="projName")]
    """Project name."""

    trans_req_num: Annotated[str, PropertyInfo(alias="transReqNum")]
    """Transportation requirement number."""

    uln: str
    """Unit line number."""
