# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["AircraftstatusAbridged"]


class AircraftstatusAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_aircraft: str = FieldInfo(alias="idAircraft")
    """Unique identifier of the aircraft."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    additional_sys: Optional[List[str]] = FieldInfo(alias="additionalSys", default=None)
    """
    List of additional operational systems on this aircraft beyond what is normally
    available.
    """

    air_to_air_status: Optional[Literal["OPERATIONAL", "NON-OPERATIONAL", "OFF"]] = FieldInfo(
        alias="airToAirStatus", default=None
    )
    """
    The status of the air-to-air weapon release system (OPERATIONAL,
    NON-OPERATIONAL, OFF).
    """

    air_to_ground_status: Optional[Literal["OPERATIONAL", "NON-OPERATIONAL", "OFF"]] = FieldInfo(
        alias="airToGroundStatus", default=None
    )
    """
    The status of the air-to-ground weapon release system (OPERATIONAL,
    NON-OPERATIONAL, OFF).
    """

    alpha_status_code: Optional[str] = FieldInfo(alias="alphaStatusCode", default=None)
    """
    Aircraft alpha status code that indicates the aircraft maintenance status
    estimated by the pilot.
    """

    alt_aircraft_id: Optional[str] = FieldInfo(alias="altAircraftId", default=None)
    """Alternate Aircraft Identifier provided by source."""

    contamination_status: Optional[str] = FieldInfo(alias="contaminationStatus", default=None)
    """The contamination status of the aircraft (e.g.

    CLEAR, CONTAMINATED, DECONTAMINATED, UNKNOWN, etc.).
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    current_icao: Optional[str] = FieldInfo(alias="currentICAO", default=None)
    """
    The International Civil Aviation Organization (ICAO) code at which this aircraft
    is currently located or has most recently departed, if airborne.
    """

    current_state: Optional[str] = FieldInfo(alias="currentState", default=None)
    """The current readiness state of the aircraft (e.g.

    AIRBORNE, ALERTCOCKED, AVAILABLE, BATTLESTATION, RUNWAY ALERT, SUITUP).
    """

    earliest_ta_end_time: Optional[datetime] = FieldInfo(alias="earliestTAEndTime", default=None)
    """
    The earliest time that turnaround of the aircraft may complete, in ISO 8601 UTC
    format with millisecond precision.
    """

    etic: Optional[datetime] = None
    """
    The Expected Time in Commission (ETIC) for this aircraft, in ISO 8601 UTC format
    with millisecond precision. This is the estimated time when the issue will be
    resolved.
    """

    flight_phase: Optional[str] = FieldInfo(alias="flightPhase", default=None)
    """Current flight phase (e.g.

    AIR REFUELING, GROUND, LANDING, etc.) of the aircraft.
    """

    fuel: Optional[int] = None
    """The mass of fuel remaining on the aircraft, in kilograms."""

    fuel_function: Optional[str] = FieldInfo(alias="fuelFunction", default=None)
    """
    Used in conjunction with the fuel field to indicate either burnable or offload
    fuel.
    """

    fuel_status: Optional[str] = FieldInfo(alias="fuelStatus", default=None)
    """The state of the aircraft fuel status (e.g.

    DELIVERED, DUMPED, EMPTY, FULL, OTHER, REQUESTED, etc.).
    """

    geo_loc: Optional[str] = FieldInfo(alias="geoLoc", default=None)
    """
    US Air Force geographic location code of the airfield where the aircraft is
    located.
    """

    ground_status: Optional[str] = FieldInfo(alias="groundStatus", default=None)
    """The ground status of the aircraft (e.g.

    ALERT, CREW READY, ENGINE START, HANGAR, etc.).
    """

    gun_capable: Optional[bool] = FieldInfo(alias="gunCapable", default=None)
    """Flag indicating that the aircraft is capable of making at least one gun pass."""

    gun_rds_max: Optional[int] = FieldInfo(alias="gunRdsMax", default=None)
    """The upper bound of the estimated number of gun rounds available."""

    gun_rds_min: Optional[int] = FieldInfo(alias="gunRdsMin", default=None)
    """The lower bound of the estimated number of gun rounds available."""

    gun_rds_type: Optional[str] = FieldInfo(alias="gunRdsType", default=None)
    """The type of gun rounds available (e.g. 7.62 MM, 20 MM, 25 MM, etc.)."""

    id_airfield: Optional[str] = FieldInfo(alias="idAirfield", default=None)
    """
    If not airborne, the unique identifier of the installation currently hosting the
    aircraft.
    """

    id_poi: Optional[str] = FieldInfo(alias="idPOI", default=None)
    """
    Unique identifier of the Point of Interest (POI) record related to this aircraft
    status. This will generally represent the location of an aircraft on the ground.
    """

    inventory: Optional[List[str]] = None
    """Array of inventory item(s) for which estimate(s) are available (e.g.

    AIM-9 SIDEWINDER, AIM-120 AMRAAM, AIM-92 STINGER, CHAFF DECOY, FLARE TP 400,
    etc.). Intended as, but not constrained to, MIL-STD-6016 environment dependent
    specific/store type designations. This array must be the same length as
    inventoryMin and inventoryMax.
    """

    inventory_max: Optional[List[int]] = FieldInfo(alias="inventoryMax", default=None)
    """Array of the upper bound quantity for each of the inventory items.

    The values in this array must correspond to position index in the inventory
    array. This array must be the same length as inventory and inventoryMin.
    """

    inventory_min: Optional[List[int]] = FieldInfo(alias="inventoryMin", default=None)
    """Array of the lower bound quantity for each of the inventory items.

    The values in this array must correspond to position index in the inventory
    array. This array must be the same length as inventory and inventoryMax.
    """

    last_inspection_date: Optional[datetime] = FieldInfo(alias="lastInspectionDate", default=None)
    """
    Date when the military aircraft inspection was last performed, in ISO 8601 UTC
    format with millisecond precision.
    """

    last_updated_by: Optional[str] = FieldInfo(alias="lastUpdatedBy", default=None)
    """The name or ID of the external user that updated this status."""

    maint_poc: Optional[str] = FieldInfo(alias="maintPoc", default=None)
    """Military aircraft maintenance point of contact for this aircraft."""

    maint_priority: Optional[str] = FieldInfo(alias="maintPriority", default=None)
    """Indicates the priority of the maintenance effort."""

    maint_status: Optional[str] = FieldInfo(alias="maintStatus", default=None)
    """The maintenance status of the aircraft."""

    maint_status_driver: Optional[str] = FieldInfo(alias="maintStatusDriver", default=None)
    """
    Indicates the maintenance discrepancy that drives the current maintenance
    status.
    """

    maint_status_update: Optional[datetime] = FieldInfo(alias="maintStatusUpdate", default=None)
    """
    The time of the last maintenance status update, in ISO 8601 UTC format with
    millisecond precision.
    """

    mission_readiness: Optional[str] = FieldInfo(alias="missionReadiness", default=None)
    """The Operational Capability of the reported aircraft (ABLE, LOFUEL, UNABLE)."""

    mx_remark: Optional[str] = FieldInfo(alias="mxRemark", default=None)
    """Maintenance pacing remarks assocociated with this aircraft."""

    next_icao: Optional[str] = FieldInfo(alias="nextICAO", default=None)
    """
    The International Civil Aviation Organization (ICAO) code of the next
    destination of this aircraft.
    """

    notes: Optional[str] = None
    """Optional notes/comments concerning this aircraft status."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    park_location: Optional[str] = FieldInfo(alias="parkLocation", default=None)
    """The parking location of this aircraft."""

    park_location_system: Optional[str] = FieldInfo(alias="parkLocationSystem", default=None)
    """The system that designated the parking location (e.g. EMOC, GDSS, PEX, etc.)."""

    previous_icao: Optional[str] = FieldInfo(alias="previousICAO", default=None)
    """
    The International Civil Aviation Organization (ICAO) code at which this aircraft
    was previously located.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    ta_start_time: Optional[datetime] = FieldInfo(alias="taStartTime", default=None)
    """The turnaround start time, in ISO 8601 UTC format with millisecond precision."""

    troubleshoot_etic: Optional[datetime] = FieldInfo(alias="troubleshootEtic", default=None)
    """
    Estimated Time for Completion (ETIC) of an aircraft issue, in ISO 8601 UTC
    format with millisecond precision. This is the estimated time when the course of
    action to resolve the issue will be determined.
    """

    unavailable_sys: Optional[List[str]] = FieldInfo(alias="unavailableSys", default=None)
    """List of unavailable systems that would normally be on this aircraft."""
