# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["AircraftstatusremarkUpdateParams"]


class AircraftstatusremarkUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_aircraft_status: Required[Annotated[str, PropertyInfo(alias="idAircraftStatus")]]
    """The ID of the Aircraft Status to which this remark applies."""

    source: Required[str]
    """Source of the data."""

    text: Required[str]
    """The text of the remark."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """
    Unique identifier of the record, auto-generated by the system if not provided on
    create operations.
    """

    alt_rmk_id: Annotated[str, PropertyInfo(alias="altRmkId")]
    """
    Unique identifier of the Aircraft Status Remark record from the originating
    system.
    """

    last_updated_at: Annotated[Union[str, datetime], PropertyInfo(alias="lastUpdatedAt", format="iso8601")]
    """
    Time the remark was last updated in the originating system in ISO 8601 UTC
    format with millisecond precision.
    """

    last_updated_by: Annotated[str, PropertyInfo(alias="lastUpdatedBy")]
    """
    The name or ID of the external user that updated this remark in the originating
    system.
    """

    name: str
    """The name of the remark."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    timestamp: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """
    Time the remark was created in the originating system in ISO 8601 UTC format
    with millisecond precision.
    """
