# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["AirfieldslotUpdateParams"]


class AirfieldslotUpdateParams(TypedDict, total=False):
    airfield_name: Required[Annotated[str, PropertyInfo(alias="airfieldName")]]
    """The name of the airfield where this slot is located."""

    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: Required[str]
    """Name of this slot."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    ac_slot_cat: Annotated[Literal["WIDE", "NARROW", "HELO", "ALL", "OTHER"], PropertyInfo(alias="acSlotCat")]
    """
    Largest category of aircraft supported in this slot (WIDE, NARROW, HELO, ALL,
    OTHER).
    """

    alt_airfield_id: Annotated[str, PropertyInfo(alias="altAirfieldId")]
    """Alternate airfield identifier provided by the source."""

    capacity: int
    """Number of aircraft that can fit in this slot at the same time."""

    end_time: Annotated[str, PropertyInfo(alias="endTime")]
    """Latest zulu time this slot is available based on daily standard hours.

    Not applicable to slots with type PARKING. Abnormal hours, such as holidays,
    should be marked via the AirfieldSlotConsumption schema.
    """

    icao: str
    """The International Civil Aviation Organization (ICAO) code of the airfield."""

    id_airfield: Annotated[str, PropertyInfo(alias="idAirfield")]
    """Unique identifier of the Airfield for which this slot information applies."""

    min_separation: Annotated[int, PropertyInfo(alias="minSeparation")]
    """
    Minimum time that must elapse between different aircraft leaving and entering
    this slot, in minutes.
    """

    notes: str
    """Optional notes/comments for this airfield slot."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    start_time: Annotated[str, PropertyInfo(alias="startTime")]
    """Zulu time this slot is first available based on daily standard hours.

    Not applicable to slots with type PARKING. Abnormal hours, such as holidays,
    should be marked via the AirfieldSlotConsumption schema.
    """

    type: Literal["WORKING", "PARKING", "TAKEOFF", "LANDING", "OTHER"]
    """
    Designates how this slot can be used (WORKING, PARKING, TAKEOFF, LANDING,
    OTHER).
    """
