# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["AirfieldslotconsumptionAbridged"]


class AirfieldslotconsumptionAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_airfield_slot: str = FieldInfo(alias="idAirfieldSlot")
    """
    Unique identifier of the airfield slot for which this slot consumption record is
    referencing.
    """

    num_aircraft: int = FieldInfo(alias="numAircraft")
    """Number of aircraft using this slot for this time."""

    source: str
    """Source of the data."""

    start_time: datetime = FieldInfo(alias="startTime")
    """The start of the slot window, in ISO 8601 UTC format."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    alt_arr_sortie_id: Optional[str] = FieldInfo(alias="altArrSortieId", default=None)
    """
    Alternate identifier of the sortie arriving at the slot start time provided by
    the source.
    """

    alt_dep_sortie_id: Optional[str] = FieldInfo(alias="altDepSortieId", default=None)
    """
    Alternate identifier of the sortie departing at the slot end time provided by
    the source.
    """

    app_comment: Optional[str] = FieldInfo(alias="appComment", default=None)
    """Comments from the approver."""

    app_initials: Optional[str] = FieldInfo(alias="appInitials", default=None)
    """Initials of the person approving the use of this slot.

    Use SYSTEM if auto-approved without human involvement.
    """

    app_org: Optional[str] = FieldInfo(alias="appOrg", default=None)
    """Short name of the organization approving the use of this slot."""

    call_signs: Optional[List[str]] = FieldInfo(alias="callSigns", default=None)
    """Array of call signs of the aircraft using this slot."""

    consumer: Optional[str] = None
    """Identifying name of the aircraft using this slot.

    Names are often Prior Permission Required (PPR) numbers or other similar
    human-readable identifiers.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    end_time: Optional[datetime] = FieldInfo(alias="endTime", default=None)
    """The end of the slot window, in ISO 8601 UTC format."""

    id_arr_sortie: Optional[str] = FieldInfo(alias="idArrSortie", default=None)
    """Unique identifier of the sortie arriving at the slot start time."""

    id_dep_sortie: Optional[str] = FieldInfo(alias="idDepSortie", default=None)
    """Unique identifier of the sortie departing at the slot end time."""

    mission_id: Optional[str] = FieldInfo(alias="missionId", default=None)
    """
    Mission identifier using this slot according to Mobility Air Forces (MAF)
    Encode/Decode procedures.
    """

    occ_aircraft_mds: Optional[str] = FieldInfo(alias="occAircraftMDS", default=None)
    """
    The aircraft Model Design Series designation of the aircraft occupying this
    slot.
    """

    occ_start_time: Optional[datetime] = FieldInfo(alias="occStartTime", default=None)
    """
    Time the aircraft began occupying this slot, in ISO 8601 UTC format with
    millisecond precision.
    """

    occ_tail_number: Optional[str] = FieldInfo(alias="occTailNumber", default=None)
    """The tail number of the aircraft occupying this slot."""

    occupied: Optional[bool] = None
    """Flag indicating if the slot is occupied."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    req_comment: Optional[str] = FieldInfo(alias="reqComment", default=None)
    """Comments from the requester."""

    req_initials: Optional[str] = FieldInfo(alias="reqInitials", default=None)
    """Initials of the person requesting the use of this slot.

    Use SYSTEM if this request is auto-generated by an auto-planning system.
    """

    req_org: Optional[str] = FieldInfo(alias="reqOrg", default=None)
    """Short name of the organization requesting use of this slot."""

    res_aircraft_mds: Optional[str] = FieldInfo(alias="resAircraftMDS", default=None)
    """
    The aircraft Model Design Series designation of the aircraft this slot is
    reserved for.
    """

    res_mission_id: Optional[str] = FieldInfo(alias="resMissionId", default=None)
    """
    Mission identifier reserving this slot according to Mobility Air Forces (MAF)
    Encode/Decode procedures.
    """

    res_reason: Optional[str] = FieldInfo(alias="resReason", default=None)
    """The reason the slot reservation was made."""

    res_tail_number: Optional[str] = FieldInfo(alias="resTailNumber", default=None)
    """The tail number of the aircraft this slot is reserved for."""

    res_type: Optional[str] = FieldInfo(alias="resType", default=None)
    """Indicates the type of reservation (e.g.

    M for Mission, A for Aircraft, O for Other).
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    status: Optional[Literal["REQUESTED", "APPROVED", "DENIED", "BLOCKED", "OTHER"]] = None
    """Current status of this slot (REQUESTED / APPROVED / DENIED / BLOCKED / OTHER)."""

    target_time: Optional[datetime] = FieldInfo(alias="targetTime", default=None)
    """
    The desired time for aircraft action such as landing, take off, parking, etc.,
    in ISO 8601 UTC format.
    """
