# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["AIsAbridged"]


class AIsAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    ts: datetime
    """The timestamp that the vessel position was recorded, in ISO 8601 UTC format."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    antenna_ref_dimensions: Optional[List[float]] = FieldInfo(alias="antennaRefDimensions", default=None)
    """The reference dimensions of the vessel, reported as [A, B, C, D], in meters.

    Where the array values represent the distance fore (A), aft (B), to port (C),
    and to starboard (D) of the navigation antenna. Array with values A = C = 0 and
    B, D > 0 indicate the length (B) and width (D) of the vessel without antenna
    position reference.
    """

    avg_speed: Optional[float] = FieldInfo(alias="avgSpeed", default=None)
    """
    The average speed, in kilometers/hour, calculated for the subject vessel during
    the latest voyage (port to port).
    """

    call_sign: Optional[str] = FieldInfo(alias="callSign", default=None)
    """A uniquely designated identifier for the vessel's transmitter station."""

    cargo_type: Optional[str] = FieldInfo(alias="cargoType", default=None)
    """The reported cargo type.

    Intended as, but not constrained to, the USCG NAVCEN AIS cargo definitions.
    Users should refer to USCG Navigation Center documentation for specific
    definitions associated with ship and cargo types. USCG NAVCEN documentation may
    be found at https://www.navcen.uscg.gov.
    """

    course: Optional[float] = None
    """The course-over-ground reported by the vessel, in degrees."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    current_port_guid: Optional[str] = FieldInfo(alias="currentPortGUID", default=None)
    """The US Geographic Unique Identifier of the current port hosting the vessel."""

    current_port_locode: Optional[str] = FieldInfo(alias="currentPortLOCODE", default=None)
    """The UN Location Code of the current port hosting the vessel."""

    destination: Optional[str] = None
    """The destination of the vessel according to the AIS transmission."""

    destination_eta: Optional[datetime] = FieldInfo(alias="destinationETA", default=None)
    """
    The Estimated Time of Arrival of the vessel at the destination, in ISO 8601 UTC
    format.
    """

    distance_to_go: Optional[float] = FieldInfo(alias="distanceToGo", default=None)
    """
    The remaining distance, in kilometers, for the vessel to reach the reported
    destination.
    """

    distance_travelled: Optional[float] = FieldInfo(alias="distanceTravelled", default=None)
    """
    The distance, in kilometers, that the vessel has travelled since departing the
    last port.
    """

    draught: Optional[float] = None
    """
    The maximum static draught, in meters, of the vessel according to the AIS
    transmission.
    """

    engaged_in: Optional[str] = FieldInfo(alias="engagedIn", default=None)
    """The activity that the vessel is engaged in.

    This entry applies only when the shipType = Other.
    """

    eta_calculated: Optional[datetime] = FieldInfo(alias="etaCalculated", default=None)
    """
    The Estimated Time of Arrival of the vessel at the destination port, according
    to MarineTraffic calculations, in ISO 8601 UTC format.
    """

    eta_updated: Optional[datetime] = FieldInfo(alias="etaUpdated", default=None)
    """
    The date and time that the ETA was calculated by MarineTraffic, in ISO 8601 UTC
    format.
    """

    id_track: Optional[str] = FieldInfo(alias="idTrack", default=None)
    """Unique identifier of the Track."""

    id_vessel: Optional[str] = FieldInfo(alias="idVessel", default=None)
    """Unique identifier of the vessel."""

    imon: Optional[int] = None
    """The International Maritime Organization Number of the vessel.

    IMON is a seven-digit number that uniquely identifies the vessel.
    """

    last_port_guid: Optional[str] = FieldInfo(alias="lastPortGUID", default=None)
    """The US Geographic Unique Identifier of the last port visited by the vessel."""

    last_port_locode: Optional[str] = FieldInfo(alias="lastPortLOCODE", default=None)
    """The UN Location Code of the last port visited by the vessel."""

    lat: Optional[float] = None
    """WGS-84 latitude of the vessel position, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    length: Optional[float] = None
    """The overall length of the vessel, in meters.

    A value of 511 indicates a vessel length of 511 meters or greater.
    """

    lon: Optional[float] = None
    """WGS-84 longitude of the vessel position, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    max_speed: Optional[float] = FieldInfo(alias="maxSpeed", default=None)
    """
    The maximum speed, in kilometers/hour, reported by the subject vessel during the
    latest voyage (port to port).
    """

    mmsi: Optional[int] = None
    """The Maritime Mobile Service Identity of the vessel.

    MMSI is a nine-digit number that identifies the transmitter station of the
    vessel.
    """

    nav_status: Optional[str] = FieldInfo(alias="navStatus", default=None)
    """The AIS Navigational Status of the vessel (e.g.

    Underway Using Engine, Moored, Aground, etc.). Intended as, but not constrained
    to, the USCG NAVCEN navigation status definitions. Users should refer to USCG
    Navigation Center documentation for specific definitions associated with
    navigation status. USCG NAVCEN documentation may be found at
    https://www.navcen.uscg.gov.
    """

    next_port_guid: Optional[str] = FieldInfo(alias="nextPortGUID", default=None)
    """The US Geographic Unique Identifier of the next destination port of the vessel."""

    next_port_locode: Optional[str] = FieldInfo(alias="nextPortLOCODE", default=None)
    """The UN Location Code of the next destination port of the vessel."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    pos_device_type: Optional[str] = FieldInfo(alias="posDeviceType", default=None)
    """The type of electronic position fixing device (e.g.

    GPS, GLONASS, etc.). Intended as, but not constrained to, the USCG NAVCEN
    electronic position fixing device definitions. Users should refer to USCG
    Navigation Center documentation for specific device type information. USCG
    NAVCEN documentation may be found at https://www.navcen.uscg.gov.
    """

    pos_hi_accuracy: Optional[bool] = FieldInfo(alias="posHiAccuracy", default=None)
    """
    Flag indicating high reported position accuracy (less than or equal to 10
    meters). A value of 0/false indicates low accuracy (greater than 10 meters).
    """

    pos_hi_latency: Optional[bool] = FieldInfo(alias="posHiLatency", default=None)
    """Flag indicating high reported position latency (greater than 5 seconds).

    A value of 0/false indicates low latency (less than 5 seconds).
    """

    rate_of_turn: Optional[float] = FieldInfo(alias="rateOfTurn", default=None)
    """The Rate-of-Turn for the vessel, in degrees/minute.

    Positive value indicates that the vessel is turning right.
    """

    ship_description: Optional[str] = FieldInfo(alias="shipDescription", default=None)
    """Further description or explanation of the vessel or type."""

    ship_name: Optional[str] = FieldInfo(alias="shipName", default=None)
    """The name of the vessel.

    Vessel names that exceed the AIS 20 character are shortened (not truncated) to
    15 character-spaces, followed by an underscore and the last 4 characters-spaces
    of the vessel full name.
    """

    ship_type: Optional[str] = FieldInfo(alias="shipType", default=None)
    """The reported ship type (e.g.

    Passenger, Tanker, Cargo, Other, etc.). See the engagedIn and specialCraft
    entries for additional information on certain types of vessels.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    special_craft: Optional[str] = FieldInfo(alias="specialCraft", default=None)
    """The type of special craft designation of the vessel.

    This entry applies only when the shipType = Special Craft.
    """

    special_maneuver: Optional[bool] = FieldInfo(alias="specialManeuver", default=None)
    """Flag indicating that the vessel is engaged in a special maneuver (e.g.

    Waterway Navigation).
    """

    speed: Optional[float] = None
    """The speed-over-ground reported by the vessel, in kilometers/hour."""

    true_heading: Optional[float] = FieldInfo(alias="trueHeading", default=None)
    """The true heading reported by the vessel, in degrees."""

    vessel_flag: Optional[str] = FieldInfo(alias="vesselFlag", default=None)
    """The flag of the subject vessel according to AIS transmission."""

    width: Optional[float] = None
    """The breadth of the vessel, in meters.

    A value of 63 indicates a vessel breadth of 63 meters or greater.
    """
