# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["AnalyticImageryFull"]


class AnalyticImageryFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    content: str
    """
    General type of content of this image (CONTOUR, DIAGRAM, HEATMAP, HISTOGRAM,
    PLOT, SCREENSHOT).
    """

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data."""

    description: str
    """Description of the image content and utility."""

    filename: str
    """The image file name."""

    filesize: int
    """The image file size, in bytes.

    The maximum file size for this service is 40,000,000 bytes (40MB). Files
    exceeding the maximum size will be rejected.
    """

    image_type: str = FieldInfo(alias="imageType")
    """The type of image associated with this record (GIF, JPG, PNG, TIF)."""

    msg_time: datetime = FieldInfo(alias="msgTime")
    """
    The message time of this image record, in ISO8601 UTC format with millisecond
    precision.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    agjson: Optional[str] = None
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. GeoJSON Reference: https://geojson.org/. Ignored if included with a POST
    or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    andims: Optional[int] = None
    """Number of dimensions of the geometry depicted by region."""

    ann_lims: Optional[List[List[int]]] = FieldInfo(alias="annLims", default=None)
    """
    Rectangular annotation limits, specified in pixels, as an array of arrays of the
    coordinates [ [UL1x, UL1y], [UR1x, UR1y], [LR1x, LR1y], [LL1x, LL1y] ],
    indicating the corners of a rectangle beginning with the Upper Left (UL) and
    moving clockwise. Allows the image provider to highlight one or more rectangular
    area(s) of interest. The array must contain Nx4 two-element arrays, where N is
    the number of rectangles of interest. The associated annotation(s) should be
    included in the annText array.
    """

    ann_text: Optional[List[str]] = FieldInfo(alias="annText", default=None)
    """
    Annotation text, a string array of annotation(s) corresponding to the
    rectangular areas specified in annLims. This array contains the annotation text
    associated with the areas of interest indicated in annLims, in order. This array
    should contain one annotation per four values of the area (annLims) array.
    """

    area: Optional[str] = None
    """
    Optional geographical region or polygon (lat/lon pairs) of the area surrounding
    the point of interest as projected on the ground.
    """

    asrid: Optional[int] = None
    """Geographical spatial_ref_sys for region."""

    atext: Optional[str] = None
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a POST or PUT request that also specifies a valid 'area' field.
    """

    atype: Optional[str] = None
    """Type of region as projected on the ground."""

    checksum_value: Optional[str] = FieldInfo(alias="checksumValue", default=None)
    """MD5 checksum value of the file.

    The ingest/create operation will automatically generate the value.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    data_start: Optional[datetime] = FieldInfo(alias="dataStart", default=None)
    """
    The start time, in ISO8601 UTC format with millisecond precision, of the data
    used in the analysis or composition of the image content, when applicable.
    """

    data_stop: Optional[datetime] = FieldInfo(alias="dataStop", default=None)
    """
    The stop time, in ISO8601 UTC format with millisecond precision, of the data
    used in the analysis or composition of the image content, when applicable.
    """

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the reporting sensor."""

    image_set_id: Optional[str] = FieldInfo(alias="imageSetId", default=None)
    """User-defined set ID of a sequence of images.

    Used to associate related analytic image records.
    """

    image_set_length: Optional[int] = FieldInfo(alias="imageSetLength", default=None)
    """The number of images in an image set."""

    img_height: Optional[int] = FieldInfo(alias="imgHeight", default=None)
    """The image height (vertical), in pixels."""

    img_width: Optional[int] = FieldInfo(alias="imgWidth", default=None)
    """The image width (horizontal), in pixels."""

    keywords: Optional[List[str]] = None
    """Array of searchable keywords for this analytic imagery record."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by the source to indicate the sensor for this
    collection. This may be an internal identifier and not necessarily a valid
    sensor ID.
    """

    sat_id: Optional[List[str]] = FieldInfo(alias="satId", default=None)
    """Assessed satellite ID (NORAD RSO object number).

    The 'satId' and 'satIdConf' arrays must match in size.
    """

    sat_id_conf: Optional[List[float]] = FieldInfo(alias="satIdConf", default=None)
    """Assessed satellite confidence corresponding to an assessment ID.

    Values are between 0.0 and 1.0. The 'satId' and 'satIdConf' arrays must match in
    size.
    """

    sequence_id: Optional[int] = FieldInfo(alias="sequenceId", default=None)
    """The sequence number of an image within an image set.

    If null, then it is assumed that the order of images in an imageSet is not
    relevant.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    src_ids: Optional[List[str]] = FieldInfo(alias="srcIds", default=None)
    """Array of UUIDs of the UDL data records that are related to this image.

    See the associated 'srcTyps' array for the specific types of data, positionally
    corresponding to the UUIDs in this array. The 'srcTyps' and 'srcIds' arrays must
    match in size. See the corresponding srcTyps array element for the data type of
    the UUID and use the appropriate API operation to retrieve that object.
    """

    src_typs: Optional[List[str]] = FieldInfo(alias="srcTyps", default=None)
    """
    Array of UDL record types (AIS, CONJUNCTION, DOA, ELSET, EO, ESID, GROUNDIMAGE,
    POI, MANEUVER, MTI, NOTIFICATION, RADAR, RF, SIGACT, SKYIMAGE, SV, TRACK) that
    are related to this image. See the associated 'srcIds' array for the record
    UUIDs, positionally corresponding to the record types in this array. The
    'srcTyps' and 'srcIds' arrays must match in size.
    """

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    x_units: Optional[str] = FieldInfo(alias="xUnits", default=None)
    """
    Optional field indicating the units that apply to the x-axis of the attached
    image, when applicable.
    """

    y_units: Optional[str] = FieldInfo(alias="yUnits", default=None)
    """
    Optional field indicating the units that apply to the y-axis of the attached
    image, when applicable.
    """

    z_units: Optional[str] = FieldInfo(alias="zUnits", default=None)
    """
    Optional field indicating the units that apply to the z-axis of the attached
    image, when applicable.
    """
