# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["BeamContourCreateBulkParams", "Body"]


class BeamContourCreateBulkParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_beam: Required[Annotated[str, PropertyInfo(alias="idBeam")]]
    """ID of the beam."""

    source: Required[str]
    """Source of the data."""

    type: Required[Literal["BORESIGHT", "CONTOUR", "SVC AREA"]]
    """The type of object represented in this record (BORESIGHT, CONTOUR, SVC AREA).

    Boresight refers to the point of maximum/peak gain, and should not be confused
    with the 'aim point' of the related beam. Gain contours are regions of coverage
    referenced to the relative gain of the related beam. Service Areas are composed
    of one or more service regions, with each region being either discrete point(s)
    or a continuous contour.
    """

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    contour_idx: Annotated[int, PropertyInfo(alias="contourIdx")]
    """The index number of this contour. The value is required if type = CONTOUR."""

    gain: float
    """The relative gain level in dB associated with this boresight or contour.

    Gain does not apply to service area records. The value is required if type =
    BORESIGHT or CONTOUR.
    """

    geography: str
    """
    GeoJSON or Well Known Text expression of the boresight point, service area point
    or region, or the gain contour region in geographic longitude, latitude pairs.
    Boresight and service area point(s) are represented as a 'Point' or
    'MultiPoint', service areas and closed gain contours as 'Polygon', and open
    contours as 'LineString'. This is an optional convenience field only used for
    create operations. The system will auto-detect the format (Well Known Text or
    GeoJSON) and populate both geographyText and geographyJson fields appropriately.
    A create request must contain one of the geography, geographyText, or
    geographyJson.
    """

    geography_json: Annotated[str, PropertyInfo(alias="geographyJson")]
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. GeoJSON Reference: https://geojson.org/. Ignored if included with a POST
    or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    geography_ndims: Annotated[int, PropertyInfo(alias="geographyNdims")]
    """Number of dimensions of the geometry depicted by region."""

    geography_srid: Annotated[int, PropertyInfo(alias="geographySrid")]
    """Geographical spatial_ref_sys for region."""

    geography_text: Annotated[str, PropertyInfo(alias="geographyText")]
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a POST or PUT request that also specifies a valid 'area' field.
    """

    geography_type: Annotated[str, PropertyInfo(alias="geographyType")]
    """Type of region as projected."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    region_name: Annotated[str, PropertyInfo(alias="regionName")]
    """The region name within the service area."""
