# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .entity_full import EntityFull

__all__ = ["BusFull"]


class BusFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Name of this bus."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    aocs_notes: Optional[str] = FieldInfo(alias="aocsNotes", default=None)
    """Attitude and Orbital Control Notes/description for the bus."""

    avg_dry_mass: Optional[float] = FieldInfo(alias="avgDryMass", default=None)
    """Average mass of this bus without payloads or fuel, in kilograms."""

    avg_payload_mass: Optional[float] = FieldInfo(alias="avgPayloadMass", default=None)
    """Average mass available on this bus for payloads, in kilograms."""

    avg_payload_power: Optional[float] = FieldInfo(alias="avgPayloadPower", default=None)
    """Average power available on this bus for payloads, in kilowatts."""

    avg_spacecraft_power: Optional[float] = FieldInfo(alias="avgSpacecraftPower", default=None)
    """Average power available on this bus, in kilowatts."""

    avg_wet_mass: Optional[float] = FieldInfo(alias="avgWetMass", default=None)
    """Average mass of this bus with fuel, but without payloads, in kilograms."""

    body_dimension_x: Optional[float] = FieldInfo(alias="bodyDimensionX", default=None)
    """Body dimension in X direction pertaining to length, in meters."""

    body_dimension_y: Optional[float] = FieldInfo(alias="bodyDimensionY", default=None)
    """Body dimension in Y direction pertaining to height, in meters."""

    body_dimension_z: Optional[float] = FieldInfo(alias="bodyDimensionZ", default=None)
    """Body dimension in Z direction pertaining to width, in meters."""

    bus_kit_designer_org_id: Optional[str] = FieldInfo(alias="busKitDesignerOrgId", default=None)
    """Unique identifier of the organization which designs the bus kit."""

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """Country where this bus was manufactured.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    description: Optional[str] = None
    """Notes/description of the bus."""

    entity: Optional[EntityFull] = None
    """
    An entity is a generic representation of any object within a space/SSA system
    such as sensors, on-orbit objects, RF Emitters, space craft buses, etc. An
    entity can have an operating unit, a location (if terrestrial), and statuses.
    """

    generic: Optional[bool] = None
    """Boolean indicating if this bus is generic."""

    id_entity: Optional[str] = FieldInfo(alias="idEntity", default=None)
    """ID of the parent entity for this bus."""

    launch_envelope_dimension_x: Optional[float] = FieldInfo(alias="launchEnvelopeDimensionX", default=None)
    """Launch envelope dimension in X direction, in meters."""

    launch_envelope_dimension_y: Optional[float] = FieldInfo(alias="launchEnvelopeDimensionY", default=None)
    """Launch envelope dimension in Y direction, in meters."""

    launch_envelope_dimension_z: Optional[float] = FieldInfo(alias="launchEnvelopeDimensionZ", default=None)
    """Launch envelope dimension in Z direction, in meters."""

    main_computer_manufacturer_org_id: Optional[str] = FieldInfo(alias="mainComputerManufacturerOrgId", default=None)
    """
    Unique identifier of the organization which manufactures the main onboard
    computer for this bus.
    """

    manufacturer_org_id: Optional[str] = FieldInfo(alias="manufacturerOrgId", default=None)
    """Unique identifier of the organization which manufactures this bus."""

    mass_category: Optional[str] = FieldInfo(alias="massCategory", default=None)
    """Mass category of this bus (e.g.

    1 - 10 kg: Nanosatellite, 10 - 100 kg: Microsatellite, 100 - 500 kg:
    Minisatellite, 1000 - 2500kg: Medium satellite, etc.).
    """

    max_bol_power_lower: Optional[float] = FieldInfo(alias="maxBOLPowerLower", default=None)
    """Maximum power at beginning of life, lower bounds, in kilowatts."""

    max_bol_power_upper: Optional[float] = FieldInfo(alias="maxBOLPowerUpper", default=None)
    """Maximum power at beginning of life, upper bounds, in kilowatts."""

    max_bol_station_mass: Optional[float] = FieldInfo(alias="maxBOLStationMass", default=None)
    """Maximum mass on station at beginning of life, in kilograms."""

    max_dry_mass: Optional[float] = FieldInfo(alias="maxDryMass", default=None)
    """Maximum mass of this bus without payloads or fuel, in kilograms."""

    max_eol_power_lower: Optional[float] = FieldInfo(alias="maxEOLPowerLower", default=None)
    """Maximum power at end of life, lower bounds, in kilowatts."""

    max_eol_power_upper: Optional[float] = FieldInfo(alias="maxEOLPowerUpper", default=None)
    """Maximum power at end of life, upper bounds, in kilowatts."""

    max_launch_mass_lower: Optional[float] = FieldInfo(alias="maxLaunchMassLower", default=None)
    """Maximum mass at launch, lower bounds, in kilograms."""

    max_launch_mass_upper: Optional[float] = FieldInfo(alias="maxLaunchMassUpper", default=None)
    """Maximum mass at launch, upper bounds, in kilograms."""

    max_payload_mass: Optional[float] = FieldInfo(alias="maxPayloadMass", default=None)
    """Maximum payload mass available, in kilograms."""

    max_payload_power: Optional[float] = FieldInfo(alias="maxPayloadPower", default=None)
    """Maximum payload power available, in kilowatts."""

    max_spacecraft_power: Optional[float] = FieldInfo(alias="maxSpacecraftPower", default=None)
    """Maximum power available on this bus, in kilowatts."""

    max_wet_mass: Optional[float] = FieldInfo(alias="maxWetMass", default=None)
    """Maximum mass of this bus with fuel, but without payloads, in kilograms."""

    median_dry_mass: Optional[float] = FieldInfo(alias="medianDryMass", default=None)
    """Median mass of this bus without payloads or fuel, in kilograms."""

    median_wet_mass: Optional[float] = FieldInfo(alias="medianWetMass", default=None)
    """Median mass of this bus with fuel, but without payloads, in kilograms."""

    min_dry_mass: Optional[float] = FieldInfo(alias="minDryMass", default=None)
    """Minimum mass of this bus without payloads or fuel, in kilograms."""

    min_wet_mass: Optional[float] = FieldInfo(alias="minWetMass", default=None)
    """Minimum mass of this bus with fuel, but without payloads, in kilograms."""

    num_orbit_type: Optional[int] = FieldInfo(alias="numOrbitType", default=None)
    """The number of orbit types this bus can support."""

    oap_payload_power: Optional[float] = FieldInfo(alias="oapPayloadPower", default=None)
    """
    Orbit averaged power (the power averaged over one orbit) available on this bus
    for payloads, in kilowatts.
    """

    oap_spacecraft_power: Optional[float] = FieldInfo(alias="oapSpacecraftPower", default=None)
    """
    Orbit averaged power (the power averaged over one orbit) available on this bus,
    in kilowatts.
    """

    orbit_types: Optional[List[str]] = FieldInfo(alias="orbitTypes", default=None)
    """Array of orbit types this bus can support (e.g.

    GEO, LEO, etc.). Must contain the same number of elements as the value of
    numOrbitType.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    payload_dimension_x: Optional[float] = FieldInfo(alias="payloadDimensionX", default=None)
    """The radial dimension available on this bus for payloads, in meters."""

    payload_dimension_y: Optional[float] = FieldInfo(alias="payloadDimensionY", default=None)
    """The in-track dimension available on this bus for payloads, in meters."""

    payload_dimension_z: Optional[float] = FieldInfo(alias="payloadDimensionZ", default=None)
    """The cross-track dimension available on this bus for payloads, in meters."""

    payload_volume: Optional[float] = FieldInfo(alias="payloadVolume", default=None)
    """The volume available on this bus for payloads, in cubic meters."""

    power_category: Optional[str] = FieldInfo(alias="powerCategory", default=None)
    """Power category of this bus (e.g. 0-1kW low power, etc)."""

    telemetry_tracking_manufacturer_org_id: Optional[str] = FieldInfo(
        alias="telemetryTrackingManufacturerOrgId", default=None
    )
    """
    Unique identifier of the organization which manufactures the telemetry tracking
    and command subsystem for this bus.
    """

    type: Optional[str] = None
    """Type of this bus."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """
