# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["CollectResponseUnvalidatedPublishParams", "Body"]


class CollectResponseUnvalidatedPublishParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_request: Required[Annotated[str, PropertyInfo(alias="idRequest")]]
    """Unique identifier of the request associated with this response."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    actual_end_time: Annotated[Union[str, datetime], PropertyInfo(alias="actualEndTime", format="iso8601")]
    """The actual end time of the collect or contact, in ISO 8601 UTC format."""

    actual_start_time: Annotated[Union[str, datetime], PropertyInfo(alias="actualStartTime", format="iso8601")]
    """The actual start time of the collect or contact, in ISO 8601 UTC format."""

    alt_end_time: Annotated[Union[str, datetime], PropertyInfo(alias="altEndTime", format="iso8601")]
    """Proposed alternative end time, in ISO 8601 UTC format."""

    alt_start_time: Annotated[Union[str, datetime], PropertyInfo(alias="altStartTime", format="iso8601")]
    """Proposed alternative start time, in ISO 8601 UTC format."""

    err_code: Annotated[str, PropertyInfo(alias="errCode")]
    """Error code associated with this request/response."""

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """UUID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of internal system generated ID.
    """

    id_plan: Annotated[str, PropertyInfo(alias="idPlan")]
    """
    Unique identifier of the parent plan or schedule associated with the
    request/response.
    """

    id_sensor: Annotated[str, PropertyInfo(alias="idSensor")]
    """Unique identifier of the reporting sensor."""

    notes: str
    """Notes or comments associated with this response."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Annotated[str, PropertyInfo(alias="origObjectId")]
    """
    Optional identifier provided by data source to indicate the target object of
    this response. This may be an internal identifier and not necessarily a valid
    satellite number.
    """

    orig_sensor_id: Annotated[str, PropertyInfo(alias="origSensorId")]
    """
    Optional identifier provided by the collection source to indicate the sensor
    identifier responding to this collect or contact. This may be an internal
    identifier and not necessarily a valid sensor ID.
    """

    sat_no: Annotated[int, PropertyInfo(alias="satNo")]
    """Satellite/catalog number of the target on-orbit object."""

    src_ids: Annotated[List[str], PropertyInfo(alias="srcIds")]
    """
    Array of UUIDs of the UDL data record(s) collected in response to the associated
    request. See the associated 'srcTyps' array for the specific types of data,
    positionally corresponding to the UUIDs in this array. The 'srcTyps' and
    'srcIds' arrays must match in size. The appropriate API operation can be used to
    retrieve the specified object(s) (e.g. /udl/rfobservation/{uuid}).
    """

    src_typs: Annotated[List[str], PropertyInfo(alias="srcTyps")]
    """
    Array of UDL record type(s) (DOA, ELSET, EO, RADAR, RF, SV) collected or
    produced in response to the associated request. See the associated 'srcIds'
    array for the record UUIDs, positionally corresponding to the record types in
    this array. The 'srcTyps' and 'srcIds' arrays must match in size. The
    appropriate API operation can be used to retrieve the specified object(s) (e.g.
    /udl/rfobservation/{uuid}).
    """

    status: str
    """
    The status of the request (ACCEPTED, CANCELLED, COLLECTED, COMPLETED, DELIVERED,
    FAILED, PARTIAL, PROPOSED, REJECTED, SCHEDULED):

    ACCEPTED: The collect or contact request has been received and accepted.

    CANCELLED: A previously scheduled collect or contact whose execution was
    cancelled.

    COLLECTED: The collect has been accomplished. A collected state implies that
    additional activity is required for delivery/completion.

    COMPLETED: The collect or contact has been completed. For many systems completed
    and delivered constitute an equivalent successful end state.

    DELIVERED: The collected observation(s) have been delivered to the requestor.
    For many systems completed and delivered constitute an equivalent successful end
    state. A DELIVERED state is typically used for systems that exhibit a delay
    between collect and delivery, such as with space-based systems which require
    ground contact to deliver observations.

    FAILED: The collect or contact was attempted and failed, or the delivery of the
    collected observation(s) failed. A FAILED status may be accompanied by an error
    code (errCode), if available.

    PARTIAL: A PARTIAL state indicates that a part of a multi-track request has been
    accomplished, but the full request is incomplete. A PARTIAL status should
    ultimately be resolved to an end state.

    PROPOSED: Indicates that the request was received and alternate collect or
    contact time(s) (altStartTime, altEndTime) have been proposed. If an alternate
    is accepted by the requestor the current request should be cancelled and a new
    request created.

    REJECTED: The request has been received and rejected by the provider. A REJECTED
    status may be accompanied by an explanation (notes) of the reason that the
    request was rejected.

    SCHEDULED: The request was received and has been scheduled for execution.
    """

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    task_id: Annotated[str, PropertyInfo(alias="taskId")]
    """Optional task ID associated with the request/response."""
