# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["CountryAbridged"]


class CountryAbridged(BaseModel):
    code: str
    """The country code.

    Optimally, this value is the ISO 3166 Alpha-2-two-character country code,
    however it can represent various consortiums that do not appear in the ISO
    document.
    """

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    code_alt: Optional[str] = FieldInfo(alias="codeAlt", default=None)
    """3 Digit or other alternate country code."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    fips_code: Optional[str] = FieldInfo(alias="fipsCode", default=None)
    """Federal Information Processing Standard (FIPS) two-character country code.

    This field is used when the country code for FIPS differs from the country code
    for ISO-3166 value. For example, the ISO-3166 Alpha-2-country code for Vanuatu
    is VU, whereas Vanuatu's FIPS equivalent country code is NH.
    """

    iso3_code: Optional[str] = FieldInfo(alias="iso3Code", default=None)
    """ISO 3166 Alpha-3 country code.

    This is a three-character code that represents a country name, which may be more
    closely related to the country name than its corresponding Alpha-2 code.
    """

    name: Optional[str] = None
    """Country name."""

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """
