# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = [
    "CountryCreateParams",
    "DiplomaticClearanceCountryContact",
    "DiplomaticClearanceCountryEntryExitPoint",
    "DiplomaticClearanceCountryProfile",
]


class CountryCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    country_code: Required[Annotated[str, PropertyInfo(alias="countryCode")]]
    """
    The DoD Standard Country Code designator for the country for which the
    diplomatic clearance will be issued. This field should be set to "OTHR" if the
    source value does not match a UDL country code value (ISO-3166-ALPHA-2).
    """

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    last_changed_date: Required[
        Annotated[Union[str, datetime], PropertyInfo(alias="lastChangedDate", format="iso8601")]
    ]
    """
    Last time this country's diplomatic clearance profile information was updated,
    in ISO 8601 UTC format with millisecond precision.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    accepts_dms: Annotated[bool, PropertyInfo(alias="acceptsDMS")]
    """
    Flag indicating whether this country's diplomatic clearance office can receive
    messages using the Defense Message System (DMS).
    """

    accepts_email: Annotated[bool, PropertyInfo(alias="acceptsEmail")]
    """
    Flag indicating whether this country's diplomatic clearance office can receive
    messages via email.
    """

    accepts_fax: Annotated[bool, PropertyInfo(alias="acceptsFax")]
    """
    Flag indicating whether this country's diplomatic clearance office can receive
    messages via fax.
    """

    accepts_sipr_net: Annotated[bool, PropertyInfo(alias="acceptsSIPRNet")]
    """
    Flag indicating whether this country's diplomatic clearance office can receive
    messages via SIPRNet.
    """

    agency: str
    """The source agency of the diplomatic clearance country data."""

    alt_country_code: Annotated[str, PropertyInfo(alias="altCountryCode")]
    """
    Specifies an alternate country code if the data provider code is not part of an
    official Country Code standard such as ISO-3166 or FIPS. This field will be set
    to the value provided by the source and should be used for all Queries
    specifying a Country Code.
    """

    close_time: Annotated[str, PropertyInfo(alias="closeTime")]
    """
    Zulu closing time of this country's diplomatic clearance office expressed in
    HH:MM format.
    """

    country_id: Annotated[str, PropertyInfo(alias="countryId")]
    """System generated code used to identify a country."""

    country_name: Annotated[str, PropertyInfo(alias="countryName")]
    """Name of the country for which the diplomatic clearance will be issued."""

    country_remark: Annotated[str, PropertyInfo(alias="countryRemark")]
    """
    Remarks concerning the country for which the diplomatic clearance will be
    issued.
    """

    diplomatic_clearance_country_contacts: Annotated[
        Iterable[DiplomaticClearanceCountryContact], PropertyInfo(alias="diplomaticClearanceCountryContacts")
    ]
    """Collection of diplomatic clearance profile information for this country."""

    diplomatic_clearance_country_entry_exit_points: Annotated[
        Iterable[DiplomaticClearanceCountryEntryExitPoint],
        PropertyInfo(alias="diplomaticClearanceCountryEntryExitPoints"),
    ]
    """Collection of diplomatic clearance profile information for this country."""

    diplomatic_clearance_country_profiles: Annotated[
        Iterable[DiplomaticClearanceCountryProfile], PropertyInfo(alias="diplomaticClearanceCountryProfiles")
    ]
    """Collection of diplomatic clearance profile information for this country."""

    existing_profile: Annotated[bool, PropertyInfo(alias="existingProfile")]
    """Flag indicating whether a diplomatic clearance profile exists for this country."""

    gmt_offset: Annotated[str, PropertyInfo(alias="gmtOffset")]
    """
    Time difference between the location of the country for which the diplomatic
    clearance will be issued and the Greenwich Mean Time (GMT), expressed as
    +/-HH:MM. Time zones east of Greenwich have positive offsets and time zones west
    of Greenwich are negative.
    """

    office_name: Annotated[str, PropertyInfo(alias="officeName")]
    """Name of this country's diplomatic clearance office."""

    office_poc: Annotated[str, PropertyInfo(alias="officePOC")]
    """Name of the point of contact for this country's diplomatic clearance office."""

    office_remark: Annotated[str, PropertyInfo(alias="officeRemark")]
    """Remarks concerning this country's diplomatic clearance office."""

    open_fri: Annotated[bool, PropertyInfo(alias="openFri")]
    """
    Flag indicating whether this country's diplomatic clearance office is open on
    Friday.
    """

    open_mon: Annotated[bool, PropertyInfo(alias="openMon")]
    """
    Flag indicating whether this country's diplomatic clearance office is open on
    Monday.
    """

    open_sat: Annotated[bool, PropertyInfo(alias="openSat")]
    """
    Flag indicating whether this country's diplomatic clearance office is open on
    Saturday.
    """

    open_sun: Annotated[bool, PropertyInfo(alias="openSun")]
    """
    Flag indicating whether this country's diplomatic clearance office is open on
    Sunday.
    """

    open_thu: Annotated[bool, PropertyInfo(alias="openThu")]
    """
    Flag indicating whether this country's diplomatic clearance office is open on
    Thursday.
    """

    open_time: Annotated[str, PropertyInfo(alias="openTime")]
    """
    Zulu opening time of this country's diplomatic clearance office expressed in
    HH:MM format.
    """

    open_tue: Annotated[bool, PropertyInfo(alias="openTue")]
    """
    Flag indicating whether this country's diplomatic clearance office is open on
    Tuesday.
    """

    open_wed: Annotated[bool, PropertyInfo(alias="openWed")]
    """
    Flag indicating whether this country's diplomatic clearance office is open on
    Wednesday.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """


class DiplomaticClearanceCountryContact(TypedDict, total=False):
    ah_num: Annotated[str, PropertyInfo(alias="ahNum")]
    """Phone number for this contact after regular business hours."""

    ah_spd_dial_code: Annotated[str, PropertyInfo(alias="ahSpdDialCode")]
    """Speed dial code for this contact after regular business hours."""

    comm_num: Annotated[str, PropertyInfo(alias="commNum")]
    """Commercial phone number for this contact."""

    comm_spd_dial_code: Annotated[str, PropertyInfo(alias="commSpdDialCode")]
    """Commercial speed dial code for this contact."""

    contact_id: Annotated[str, PropertyInfo(alias="contactId")]
    """Identifier of the contact for this country."""

    contact_name: Annotated[str, PropertyInfo(alias="contactName")]
    """Name of the contact for this country."""

    contact_remark: Annotated[str, PropertyInfo(alias="contactRemark")]
    """Remarks about this contact."""

    dsn_num: Annotated[str, PropertyInfo(alias="dsnNum")]
    """Defense Switched Network (DSN) phone number for this contact."""

    dsn_spd_dial_code: Annotated[str, PropertyInfo(alias="dsnSpdDialCode")]
    """Defense Switched Network (DSN) speed dial code for this contact."""

    fax_num: Annotated[str, PropertyInfo(alias="faxNum")]
    """Fax number for this contact."""

    nipr_num: Annotated[str, PropertyInfo(alias="niprNum")]
    """
    Phone number to contact the Diplomatic Attache Office (DAO) for this country
    over a secure NIPR line.
    """

    sipr_num: Annotated[str, PropertyInfo(alias="siprNum")]
    """
    Phone number to contact the Diplomatic Attache Office (DAO) for this country
    over a secure SIPR line.
    """


class DiplomaticClearanceCountryEntryExitPoint(TypedDict, total=False):
    is_entry: Annotated[bool, PropertyInfo(alias="isEntry")]
    """Flag indicating whether this is a point of entry for this country."""

    is_exit: Annotated[bool, PropertyInfo(alias="isExit")]
    """Flag indicating whether this is a point of exit for this country."""

    point_name: Annotated[str, PropertyInfo(alias="pointName")]
    """Name of this entry/exit point."""


class DiplomaticClearanceCountryProfile(TypedDict, total=False):
    cargo_pax_remark: Annotated[str, PropertyInfo(alias="cargoPaxRemark")]
    """
    Remarks concerning aircraft cargo and passenger information for this country
    profile.
    """

    clearance_id: Annotated[str, PropertyInfo(alias="clearanceId")]
    """Identifier of the associated diplomatic clearance issued by the host country."""

    crew_info_remark: Annotated[str, PropertyInfo(alias="crewInfoRemark")]
    """Remarks concerning crew information for this country profile."""

    def_clearance_status: Annotated[str, PropertyInfo(alias="defClearanceStatus")]
    """
    Code denoting the status of the default diplomatic clearance (e.g., A for
    Approved via APACS, E for Requested via email, etc.).
    """

    def_entry_remark: Annotated[str, PropertyInfo(alias="defEntryRemark")]
    """Remarks concerning the default entry point for this country."""

    def_entry_time: Annotated[str, PropertyInfo(alias="defEntryTime")]
    """Zulu default entry time for this country expressed in HH:MM format."""

    def_exit_remark: Annotated[str, PropertyInfo(alias="defExitRemark")]
    """Remarks concerning the default exit point for this country."""

    def_exit_time: Annotated[str, PropertyInfo(alias="defExitTime")]
    """Zulu default exit time for this country expressed in HH:MM format."""

    flt_info_remark: Annotated[str, PropertyInfo(alias="fltInfoRemark")]
    """Remarks concerning flight information for this country profile."""

    haz_info_remark: Annotated[str, PropertyInfo(alias="hazInfoRemark")]
    """Remarks concerning hazardous material information for this country profile."""

    land_def_prof: Annotated[bool, PropertyInfo(alias="landDefProf")]
    """Flag indicating whether this is the default landing profile for this country."""

    land_lead_time: Annotated[int, PropertyInfo(alias="landLeadTime")]
    """Amount of lead time required for an aircraft to land in this country.

    Units need to be specified in the landLeadTimeUnit field.
    """

    land_lead_time_remark: Annotated[str, PropertyInfo(alias="landLeadTimeRemark")]
    """Remarks concerning the landing lead time required for this country."""

    land_lead_time_unit: Annotated[str, PropertyInfo(alias="landLeadTimeUnit")]
    """
    Unit of time specified for the landLeadTime field to indicate the landing lead
    time required for this country.
    """

    land_valid_period_minus: Annotated[int, PropertyInfo(alias="landValidPeriodMinus")]
    """
    Amount of time before the landing valid period that an aircraft is allowed to
    land in this country for this profile. The unit of time should be specified in
    the landValidPeriodUnit field.
    """

    land_valid_period_plus: Annotated[int, PropertyInfo(alias="landValidPeriodPlus")]
    """
    Amount of time after the landing valid period that an aircraft is allowed to
    land in this country for this profile. The unit of time should be specified in
    the landValidPeriodUnit field.
    """

    land_valid_period_remark: Annotated[str, PropertyInfo(alias="landValidPeriodRemark")]
    """Remarks concerning the valid landing time period for this country."""

    land_valid_period_unit: Annotated[str, PropertyInfo(alias="landValidPeriodUnit")]
    """
    Unit of time specified for the landValidPeriodPlus and landValidPeriodMinus
    fields to indicate the valid landing period for this country.
    """

    overfly_def_prof: Annotated[bool, PropertyInfo(alias="overflyDefProf")]
    """Flag indicating whether this is the default overfly profile for this country."""

    overfly_lead_time: Annotated[int, PropertyInfo(alias="overflyLeadTime")]
    """
    Amount of lead time required for an aircraft to enter and fly over the airspace
    of this country. Units need to be specified in the overflyLeadTimeUnit field.
    """

    overfly_lead_time_remark: Annotated[str, PropertyInfo(alias="overflyLeadTimeRemark")]
    """Remarks concerning the overfly lead time required for this country."""

    overfly_lead_time_unit: Annotated[str, PropertyInfo(alias="overflyLeadTimeUnit")]
    """
    Unit of time specified for the overflyLeadTime field to indicate the overfly
    lead time required for this country.
    """

    overfly_valid_period_minus: Annotated[int, PropertyInfo(alias="overflyValidPeriodMinus")]
    """
    Amount of time before the overfly valid period that an aircraft is allowed to
    fly over this country for this profile. The unit of time should be specified in
    the overflyValidPeriodUnit field.
    """

    overfly_valid_period_plus: Annotated[int, PropertyInfo(alias="overflyValidPeriodPlus")]
    """
    Amount of time after the overfly valid period that an aircraft is allowed to fly
    over this country for this profile. The unit of time should be specified in the
    overflyValidPeriodUnit field.
    """

    overfly_valid_period_remark: Annotated[str, PropertyInfo(alias="overflyValidPeriodRemark")]
    """Remarks concerning the valid overfly time period for this country."""

    overfly_valid_period_unit: Annotated[str, PropertyInfo(alias="overflyValidPeriodUnit")]
    """
    Unit of time specified for the overflyValidPeriodPlus and
    overflyValidPeriodMinus fields to indicate the valid overfly period for this
    country.
    """

    profile: str
    """The diplomatic clearance profile name used within clearance management systems."""

    profile_agency: Annotated[str, PropertyInfo(alias="profileAgency")]
    """The agency to which this profile applies."""

    profile_id: Annotated[str, PropertyInfo(alias="profileId")]
    """Identifier of the diplomatic clearance country profile."""

    profile_remark: Annotated[str, PropertyInfo(alias="profileRemark")]
    """Remarks concerning this country profile."""

    req_ac_alt_name: Annotated[bool, PropertyInfo(alias="reqACAltName")]
    """
    Flag indicating whether alternate aircraft names are required to be reported to
    the country using this diplomatic clearance profile.
    """

    req_all_haz_info: Annotated[bool, PropertyInfo(alias="reqAllHazInfo")]
    """
    Flag indicating whether all hazardous material information is required to be
    reported to the country using this diplomatic clearance profile.
    """

    req_amc_std_info: Annotated[bool, PropertyInfo(alias="reqAMCStdInfo")]
    """
    Flag indicating whether standard AMC information is required to be reported to
    the country using this diplomatic clearance profile.
    """

    req_cargo_list: Annotated[bool, PropertyInfo(alias="reqCargoList")]
    """
    Flag indicating whether a cargo list is required to be reported to the country
    using this diplomatic clearance profile.
    """

    req_cargo_pax: Annotated[bool, PropertyInfo(alias="reqCargoPax")]
    """
    Flag indicating whether aircraft cargo and passenger information is required to
    be reported to the country using this diplomatic clearance profile.
    """

    req_class1_info: Annotated[bool, PropertyInfo(alias="reqClass1Info")]
    """
    Flag indicating whether Class 1 hazardous material information is required to be
    reported to the country using this diplomatic clearance profile.
    """

    req_class9_info: Annotated[bool, PropertyInfo(alias="reqClass9Info")]
    """
    Flag indicating whether Class 9 hazardous material information is required to be
    reported to the country using this diplomatic clearance profile.
    """

    req_crew_comp: Annotated[bool, PropertyInfo(alias="reqCrewComp")]
    """
    Flag indicating whether the number of crew members on a flight is required to be
    reported to the country using this diplomatic clearance profile.
    """

    req_crew_detail: Annotated[bool, PropertyInfo(alias="reqCrewDetail")]
    """
    Flag indicating whether the names, ranks, and positions of crew members are
    required to be reported to the country using this diplomatic clearance profile.
    """

    req_crew_info: Annotated[bool, PropertyInfo(alias="reqCrewInfo")]
    """
    Flag indicating whether crew information is required to be reported to the
    country using this diplomatic clearance profile.
    """

    req_div1_info: Annotated[bool, PropertyInfo(alias="reqDiv1Info")]
    """
    Flag indicating whether Division 1.1 hazardous material information is required
    to be reported to the country using this diplomatic clearance profile.
    """

    req_dv: Annotated[bool, PropertyInfo(alias="reqDV")]
    """
    Flag indicating whether distinguished visitors are required to be reported to
    the country using this diplomatic clearance profile.
    """

    req_entry_exit_coord: Annotated[bool, PropertyInfo(alias="reqEntryExitCoord")]
    """
    Flag indicating whether entry/exit coordinates need to be specified for this
    diplomatic clearance profile.
    """

    req_flt_info: Annotated[bool, PropertyInfo(alias="reqFltInfo")]
    """
    Flag indicating whether flight information is required to be reported to the
    country using this diplomatic clearance profile.
    """

    req_flt_plan_route: Annotated[bool, PropertyInfo(alias="reqFltPlanRoute")]
    """
    Flag indicating whether a flight plan route is required to be reported to the
    country using this diplomatic clearance profile.
    """

    req_fund_source: Annotated[bool, PropertyInfo(alias="reqFundSource")]
    """
    Flag indicating whether aviation funding sources are required to be reported to
    the country using this diplomatic clearance profile.
    """

    req_haz_info: Annotated[bool, PropertyInfo(alias="reqHazInfo")]
    """
    Flag indicating whether hazardous material information is required to be
    reported to the country using this diplomatic clearance profile.
    """

    req_icao: Annotated[bool, PropertyInfo(alias="reqICAO")]
    """
    Flag indicating whether this diplomatic clearance profile applies to specific
    ICAO(s). These specific ICAO(s) should be clarified in the fltInfoRemark field.
    """

    req_passport_info: Annotated[bool, PropertyInfo(alias="reqPassportInfo")]
    """
    Flag indicating whether passport information is required to be reported to the
    country using this diplomatic clearance profile.
    """

    req_raven: Annotated[bool, PropertyInfo(alias="reqRaven")]
    """
    Flag indicating whether ravens are required to be reported to the country using
    this diplomatic clearance profile.
    """

    req_rep_change: Annotated[bool, PropertyInfo(alias="reqRepChange")]
    """
    Flag indicating whether changes are required to be reported to the country using
    this diplomatic clearance profile.
    """

    req_tail_num: Annotated[bool, PropertyInfo(alias="reqTailNum")]
    """
    Flag indicating whether an aircraft tail number is required to be reported to
    the country using this diplomatic clearance profile.
    """

    req_weapons_info: Annotated[bool, PropertyInfo(alias="reqWeaponsInfo")]
    """
    Flag indicating whether weapons information is required to be reported to the
    country using this diplomatic clearance profile.
    """

    undefined_crew_reporting: Annotated[bool, PropertyInfo(alias="undefinedCrewReporting")]
    """
    Flag indicating whether crew reporting is undefined for the country using this
    diplomatic clearance profile.
    """
