# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["DropzoneUpdateParams"]


class DropzoneUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    lat: Required[float]
    """WGS84 latitude of the drop zone, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: Required[float]
    """WGS84 longitude of the drop zone, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    name: Required[str]
    """The name of the drop zone."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    alt_country_code: Annotated[str, PropertyInfo(alias="altCountryCode")]
    """
    Specifies an alternate country code for the drop zone if the data provider code
    is not part of an official Country Code standard such as ISO-3166 or FIPS. This
    field will be set to the value provided by the source and should be used for all
    Queries specifying a Country Code.
    """

    alt_country_name: Annotated[str, PropertyInfo(alias="altCountryName")]
    """
    Specifies the country name associated with the source provided alternate country
    code.
    """

    approval_date: Annotated[Union[str, datetime], PropertyInfo(alias="approvalDate", format="iso8601")]
    """
    The date the drop zone survey was approved, in ISO 8601 UTC format with
    millisecond precision.
    """

    code: str
    """The type code for the drop zone."""

    country_code: Annotated[str, PropertyInfo(alias="countryCode")]
    """The Country Code where the drop zone is located.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    country_name: Annotated[str, PropertyInfo(alias="countryName")]
    """The country name of the location for the drop zone."""

    expiration_date: Annotated[Union[str, datetime], PropertyInfo(alias="expirationDate", format="iso8601")]
    """
    The survey expiration date of the drop zone, in ISO 8601 UTC format with
    millisecond precision.
    """

    ext_identifier: Annotated[str, PropertyInfo(alias="extIdentifier")]
    """The external identifier assigned to the drop zone."""

    id_site: Annotated[str, PropertyInfo(alias="idSite")]
    """The ID of the site associated with the drop zone."""

    last_update: Annotated[Union[str, datetime], PropertyInfo(alias="lastUpdate", format="iso8601")]
    """
    Last time the drop zone information was updated, in ISO 8601 UTC format with
    millisecond precision.
    """

    length: float
    """The length dimension of the drop zone in meters for non-circular drop zones."""

    majcom: str
    """The Major Command (MAJCOM) responsible for management of the drop zone."""

    nearest_loc: Annotated[str, PropertyInfo(alias="nearestLoc")]
    """The nearest reference location to the drop zone."""

    operational_approval_date: Annotated[
        Union[str, datetime], PropertyInfo(alias="operationalApprovalDate", format="iso8601")
    ]
    """
    The approval date for the drop zone by an air drop authority certifying
    operational usage, in ISO 8601 UTC format with millisecond precision.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    point_name: Annotated[str, PropertyInfo(alias="pointName")]
    """The name assigned to the drop zone point."""

    radius: float
    """The radius dimension of the drop zone in meters for circular drop zones."""

    recert_date: Annotated[Union[str, datetime], PropertyInfo(alias="recertDate", format="iso8601")]
    """
    The date the drop zone was recertified, in ISO 8601 UTC format with millisecond
    precision.
    """

    remark: str
    """Remarks concerning the drop zone."""

    state_abbr: Annotated[str, PropertyInfo(alias="stateAbbr")]
    """The US alphabetical code for the state where the drop zone is located."""

    state_name: Annotated[str, PropertyInfo(alias="stateName")]
    """The name of the state where the drop zone is located."""

    survey_date: Annotated[Union[str, datetime], PropertyInfo(alias="surveyDate", format="iso8601")]
    """
    The date the drop zone survey was performed, in ISO 8601 UTC format with
    millisecond precision.
    """

    width: float
    """The width dimension of the drop zone in meters for non-circular drop zones."""

    zar_id: Annotated[str, PropertyInfo(alias="zarId")]
    """The identifier of the Zone Availability Report (ZAR) for the drop zone."""
