# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EffectRequestListResponse", "EffectRequestListResponseItem"]


class EffectRequestListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    effect_list: List[str] = FieldInfo(alias="effectList")
    """List of effects to be achieved on the target (e.g.

    COVER, DECEIVE, DEGRADE, DENY, DESTROY, DISRUPT, DIVERSION, DIVERT, FIX,
    INSPECT, INTERCEPT, ISOLATE, MANIPULATE, NEUTRALIZE, SHADOW, SUPPRESS, etc.).
    The effects included in this list are connected by implied AND.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    context: Optional[str] = None
    """Specific descriptive instantiation of the effect, e.g., playbook to be used."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    deadline_type: Optional[str] = FieldInfo(alias="deadlineType", default=None)
    """The indicator of deadline of the bid request (e.g.

    BETWEEN, IMMEDIATE, NOEARLIERTHAN, NOLATERTHAN, etc.): BETWEEN:&nbsp;Produce
    effect any time between the given start and end times, equal penalty for being
    early or late IMMEDIATE:&nbsp;Start as soon as possible, earlier is always
    better NOEARLIERTHAN:&nbsp;Produce effect at this time or later. Large penalty
    for being earlier, no reward for being later NOLATERTHAN:&nbsp;Produce effect no
    later than the given startTime. Large penalty for being later, no reward for
    being even earlier as long as the effect starts by the given time.
    """

    end_time: Optional[datetime] = FieldInfo(alias="endTime", default=None)
    """The time the effect should end, in ISO8601 UTC format."""

    external_request_id: Optional[str] = FieldInfo(alias="externalRequestId", default=None)
    """The extenal system identifier of this request. A human readable unique id."""

    metric_types: Optional[List[str]] = FieldInfo(alias="metricTypes", default=None)
    """Array of the the metric classes to be evaluated (e.g.

    Cost, GoalAchievement, OpportunityCost, Risk, Timeliness, Unavailable, etc.).
    See the associated 'metricWeights' array for the weighting values, positionally
    corresponding to these types. The 'metricTypes' and 'metricWeights' arrays must
    match in size.
    """

    metric_weights: Optional[List[float]] = FieldInfo(alias="metricWeights", default=None)
    """Array of the weights for the metric in the final evaluation score.

    Normalized (0 to 1). See the associated 'metricTypes' array for the metric
    classes, positionally corresponding to these values. The 'metricTypes' and
    'metricWeights' arrays must match in size.
    """

    api_model_class: Optional[str] = FieldInfo(alias="modelClass", default=None)
    """The type or class of the preference model used to evaluate this offer."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    priority: Optional[str] = None
    """The priority (LOW, MEDIUM, HIGH) of this request."""

    start_time: Optional[datetime] = FieldInfo(alias="startTime", default=None)
    """The time the effect should start, in ISO8601 UTC format."""

    state: Optional[str] = None
    """State of this effect request (e.g. CREATED, UPDATED, DELETED, etc.)."""

    target_src_id: Optional[str] = FieldInfo(alias="targetSrcId", default=None)
    """
    The record ID, depending on the type identified in targetSrcType, of the
    requested target. This identifier corresponds to either poi.poiid or track.trkId
    from their respective schemas.
    """

    target_src_type: Optional[str] = FieldInfo(alias="targetSrcType", default=None)
    """The source type of the targetId identifier (POI, TRACK)."""


EffectRequestListResponse: TypeAlias = List[EffectRequestListResponseItem]
