# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ElsetIngestParam"]


class ElsetIngestParam(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    epoch: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """Elset epoch time in ISO 8601 UTC format, with microsecond precision."""

    source: Required[str]
    """Source of the data."""

    agom: float
    """
    AGOM, expressed in m^2/kg, is the value of the (averaged) object Area times the
    solar radiation pressure coefficient(Gamma) over the object Mass. Applicable
    only with ephemType4.
    """

    algorithm: str
    """Optional algorithm used to produce this record."""

    apogee: float
    """The orbit point furthest from the center of the earth in kilometers.

    If not provided, apogee will be computed from the TLE according to the
    following. Using mu, the standard gravitational parameter for the earth
    (398600.4418), semi-major axis A = (mu/(n _ 2 _ pi/(24*3600))^2)(1/3). Using
    semi-major axis A, eccentricity E, apogee = (A * (1 + E)) in km. Note that the
    calculations are for computing the apogee radius from the center of the earth,
    to compute apogee altitude the radius of the earth should be subtracted
    (6378.135 km).
    """

    arg_of_perigee: Annotated[float, PropertyInfo(alias="argOfPerigee")]
    """
    The argument of perigee is the angle in degrees formed between the perigee and
    the ascending node. If the perigee would occur at the ascending node, the
    argument of perigee would be 0.
    """

    ballistic_coeff: Annotated[float, PropertyInfo(alias="ballisticCoeff")]
    """Ballistic coefficient, in m^2/kg. Applicable only with ephemType4."""

    b_star: Annotated[float, PropertyInfo(alias="bStar")]
    """
    The drag term for SGP4 orbital model, used for calculating decay constants for
    altitude, eccentricity etc, measured in inverse earth radii.
    """

    descriptor: str
    """Optional source-provided and searchable metadata or descriptor of the data."""

    eccentricity: float
    """
    The orbital eccentricity of an astronomical object is a parameter that
    determines the amount by which its orbit around another body deviates from a
    perfect circle. A value of 0 is a circular orbit, values between 0 and 1 form an
    elliptic orbit, 1 is a parabolic escape orbit, and greater than 1 is a
    hyperbolic escape orbit.
    """

    ephem_type: Annotated[int, PropertyInfo(alias="ephemType")]
    """The ephemeris type associated with this TLE:

    0:&nbsp;SGP (or SGP4 with Kozai mean motion)

    1:&nbsp;SGP (Kozai mean motion)

    2:&nbsp;SGP4 (Brouver mean motion)

    3:&nbsp;SDP4

    4:&nbsp;SGP4-XP

    5:&nbsp;SDP8

    6:&nbsp;SP (osculating mean motion)
    """

    id_elset: Annotated[str, PropertyInfo(alias="idElset")]
    """Unique identifier of the record, auto-generated by the system."""

    id_orbit_determination: Annotated[str, PropertyInfo(alias="idOrbitDetermination")]
    """Unique identifier of the OD solution record that produced this elset.

    This ID can be used to obtain additional information on an OrbitDetermination
    object using the 'get by ID' operation (e.g. /udl/orbitdetermination/{id}). For
    example, the OrbitDetermination with idOrbitDetermination = abc would be queried
    as /udl/orbitdetermination/abc.
    """

    inclination: float
    """
    The angle between the equator and the orbit when looking from the center of the
    Earth. If the orbit went exactly around the equator from left to right, then the
    inclination would be 0. The inclination ranges from 0 to 180 degrees.
    """

    mean_anomaly: Annotated[float, PropertyInfo(alias="meanAnomaly")]
    """Where the satellite is in its orbital path.

    The mean anomaly ranges from 0 to 360 degrees. The mean anomaly is referenced to
    the perigee. If the satellite were at the perigee, the mean anomaly would be 0.
    """

    mean_motion: Annotated[float, PropertyInfo(alias="meanMotion")]
    """
    Mean motion is the angular speed required for a body to complete one orbit,
    assuming constant speed in a circular orbit which completes in the same time as
    the variable speed, elliptical orbit of the actual body. Measured in revolutions
    per day.
    """

    mean_motion_d_dot: Annotated[float, PropertyInfo(alias="meanMotionDDot")]
    """2nd derivative of the mean motion with respect to time.

    Units are revolutions per day cubed.
    """

    mean_motion_dot: Annotated[float, PropertyInfo(alias="meanMotionDot")]
    """1st derivative of the mean motion with respect to time.

    Units are revolutions per day squared.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Annotated[str, PropertyInfo(alias="origObjectId")]
    """
    Optional identifier provided by elset source to indicate the target onorbit
    object of this elset. This may be an internal identifier and not necessarily map
    to a valid satellite number.
    """

    perigee: float
    """The orbit point nearest to the center of the earth in kilometers.

    If not provided, perigee will be computed from the TLE according to the
    following. Using mu, the standard gravitational parameter for the earth
    (398600.4418), semi-major axis A = (mu/(n _ 2 _ pi/(24*3600))^2)(1/3). Using
    semi-major axis A, eccentricity E, perigee = (A * (1 - E)) in km. Note that the
    calculations are for computing the perigee radius from the center of the earth,
    to compute perigee altitude the radius of the earth should be subtracted
    (6378.135 km).
    """

    period: float
    """Period of the orbit equal to inverse of mean motion, in minutes."""

    raan: float
    """
    Right ascension of the ascending node, or RAAN is the angle as measured in
    degrees eastwards (or, as seen from the north, counterclockwise) from the First
    Point of Aries to the ascending node, which is where the orbit crosses the
    equator when traveling north.
    """

    raw_file_uri: Annotated[str, PropertyInfo(alias="rawFileURI")]
    """
    Optional URI location in the document repository of the raw file parsed by the
    system to produce this record. To download the raw file, prepend
    https://udl-hostname/scs/download?id= to this value.
    """

    rev_no: Annotated[int, PropertyInfo(alias="revNo")]
    """The current revolution number.

    The value is incremented when a satellite crosses the equator on an ascending
    pass.
    """

    sat_no: Annotated[int, PropertyInfo(alias="satNo")]
    """Satellite/catalog number of the target on-orbit object."""

    semi_major_axis: Annotated[float, PropertyInfo(alias="semiMajorAxis")]
    """The sum of the periapsis and apoapsis distances divided by two.

    For circular orbits, the semimajor axis is the distance between the centers of
    the bodies, not the distance of the bodies from the center of mass. Units are
    kilometers.
    """

    sourced_data: Annotated[List[str], PropertyInfo(alias="sourcedData")]
    """Optional array of UDL data (observation) UUIDs used to build this element set.

    See the associated sourcedDataTypes array for the specific types of observations
    for the positionally corresponding UUIDs in this array (the two arrays must
    match in size).
    """

    sourced_data_types: Annotated[
        List[Literal["EO", "RADAR", "RF", "DOA", "ELSET", "SV"]], PropertyInfo(alias="sourcedDataTypes")
    ]
    """Optional array of UDL observation data types used to build this element set
    (e.g.

    EO, RADAR, RF, DOA). See the associated sourcedData array for the specific UUIDs
    of observations for the positionally corresponding data types in this array (the
    two arrays must match in size).
    """

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    transaction_id: Annotated[str, PropertyInfo(alias="transactionId")]
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    uct: bool
    """Boolean indicating this Elset was unable to be correlated to a known object.

    This flag should only be set to true by data providers after an attempt to
    correlate to an on-orbit object was made and failed. If unable to correlate, the
    'origObjectId' field may be populated with an internal data provider specific
    identifier.
    """
