# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.onorbit_full import OnorbitFull

__all__ = ["EmittergeolocationRetrieveResponse"]


class EmittergeolocationRetrieveResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    signal_of_interest_type: str = FieldInfo(alias="signalOfInterestType")
    """Type of the signal of interest of this Emitter Geo Location (e.g. RF)."""

    source: str
    """Source of the data."""

    start_time: datetime = FieldInfo(alias="startTime")
    """
    The start time for this Emitter Geo Location data set in ISO 8601 UTC with
    microsecond precision.
    """

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    agjson: Optional[str] = None
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. GeoJSON Reference: https://geojson.org/. Ignored if included with a POST
    or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    alg_version: Optional[str] = FieldInfo(alias="algVersion", default=None)
    """
    The EmitterGeo algorithm type and version used in Emitter geolocation
    calculations.
    """

    andims: Optional[int] = None
    """Number of dimensions of the geometry depicted by region."""

    area: Optional[str] = None
    """
    Optional geographical region or polygon (lat/lon pairs) of the area surrounding
    the Point of Interest as projected on the ground.
    """

    asrid: Optional[int] = None
    """Geographical spatial_ref_sys for region."""

    atext: Optional[str] = None
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a POST or PUT request that also specifies a valid 'area' field.
    """

    atype: Optional[str] = None
    """Type of region as projected on the ground."""

    center_freq: Optional[float] = FieldInfo(alias="centerFreq", default=None)
    """The detected signal frequency in megahertz."""

    cluster: Optional[str] = None
    """The name(s) of the subset of constellation spacecraft that made this detection."""

    conf_area: Optional[float] = FieldInfo(alias="confArea", default=None)
    """
    The area of the confidence ellipse specified in meters squared to contain the
    emitter with a 95% probability.
    """

    constellation: Optional[str] = None
    """The name of the satellite constellation."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    created_ts: Optional[datetime] = FieldInfo(alias="createdTs", default=None)
    """
    Specifies the creation time associated with the order in ISO 8601 UTC with
    microsecond precision.
    """

    detect_alt: Optional[float] = FieldInfo(alias="detectAlt", default=None)
    """The altitude relative to WGS-84 ellipsoid, in meters."""

    detect_lat: Optional[float] = FieldInfo(alias="detectLat", default=None)
    """WGS-84 latitude of the most likely emitter location coordinate point, in
    degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    detect_lon: Optional[float] = FieldInfo(alias="detectLon", default=None)
    """
    WGS-84 longitude of the most likely emitter location coordinate point, in
    degrees. -180 to 180 degrees (negative values west of Prime Meridian).
    """

    end_time: Optional[datetime] = FieldInfo(alias="endTime", default=None)
    """
    The end time for this Emitter Geo Location data set in ISO 8601 UTC with
    microsecond precision.
    """

    err_ellp: Optional[List[float]] = FieldInfo(alias="errEllp", default=None)
    """
    Confidence ellipsoid about the detection location [semi-major axis (m),
    semi-minor axis (m), orientation (deg)].
    """

    external_id: Optional[str] = FieldInfo(alias="externalId", default=None)
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """
    Unique identifier of the satellite used to identify and geolocate Emitter
    signals of interest. This ID can be used to obtain additional information on an
    OnOrbit object using the 'get by ID' operation (e.g. /udl/onorbit/{id}). For
    example, the onorbit object with idOnOrbit = abc would be queried as
    /udl/onorbit/abc. Used when Emitter geolocation is done by a single satellite.
    """

    id_rf_emitter: Optional[str] = FieldInfo(alias="idRFEmitter", default=None)
    """
    Optional identifier of the geolocated signal of interest RF Emitter for this
    observation. This ID can be used to obtain additional information on an RF
    Emitter object using the 'get by ID' operation (e.g. /udl/rfemitter/{id}). For
    example, the rfemitter object with idRFEmitter = abc would be queried as
    /udl/rfemitter/abc.
    """

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the reporting sensor.

    This ID can be used to obtain additional information on a sensor using the 'get
    by ID' operation (e.g. /udl/sensor/{id}). For example, the sensor with idSensor
    = abc would be queried as /udl/sensor/abc. Used when Emitter geolocation is done
    by a single sensor.
    """

    max_freq: Optional[float] = FieldInfo(alias="maxFreq", default=None)
    """The maximum detected frequency in megahertz."""

    min_freq: Optional[float] = FieldInfo(alias="minFreq", default=None)
    """The minimum detected frequency in megahertz."""

    num_bursts: Optional[int] = FieldInfo(alias="numBursts", default=None)
    """The count of single-burst observations used for this geolocation observation."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    order_id: Optional[str] = FieldInfo(alias="orderId", default=None)
    """The order identifier for this Emitter Geo Location data set."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier of the satellite used to identify and geolocate Emitter
    signals of interest of this observation. This may be an internal identifier and
    not necessarily a valid satellite number. Used when Emitter geolocation is done
    by a single satellite.
    """

    orig_rf_emitter_id: Optional[str] = FieldInfo(alias="origRFEmitterId", default=None)
    """Optional identifier of the emitter of interest for this observation.

    This may be an internal identifier and not necessarily a valid emitter Id.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by observation source to indicate the sensor
    identifier which produced this Emitter Geo Location. This may be an internal
    identifier and not necessarily a valid sensor ID. Used when Emitter geolocation
    is done by a single sensor.
    """

    pass_group_id: Optional[str] = FieldInfo(alias="passGroupId", default=None)
    """
    Optional external identifier referencing the entity used in the calculation of
    the geolocation.
    """

    received_ts: Optional[datetime] = FieldInfo(alias="receivedTs", default=None)
    """
    The time representing the mean of the constituent single-burst observations in
    ISO 8601 UTC with microsecond precision.
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """
    Satellite/catalog number of the on-orbit spacecraft used to identify and
    geolocate Emitter signals of interest of this detection. Used when Emitter
    geolocation is done by a single satellite.
    """

    signal_of_interest: Optional[str] = FieldInfo(alias="signalOfInterest", default=None)
    """The name of the signal of interest."""

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """
