# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EmittergeolocationUnvalidatedPublishParams", "Body"]


class EmittergeolocationUnvalidatedPublishParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    signal_of_interest_type: Required[Annotated[str, PropertyInfo(alias="signalOfInterestType")]]
    """Type of the signal of interest of this Emitter Geo Location (e.g. RF)."""

    source: Required[str]
    """Source of the data."""

    start_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="startTime", format="iso8601")]]
    """
    The start time for this Emitter Geo Location data set in ISO 8601 UTC with
    microsecond precision.
    """

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    agjson: str
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. GeoJSON Reference: https://geojson.org/. Ignored if included with a POST
    or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    alg_version: Annotated[str, PropertyInfo(alias="algVersion")]
    """
    The EmitterGeo algorithm type and version used in Emitter geolocation
    calculations.
    """

    andims: int
    """Number of dimensions of the geometry depicted by region."""

    area: str
    """
    Optional geographical region or polygon (lat/lon pairs) of the area surrounding
    the Point of Interest as projected on the ground.
    """

    asrid: int
    """Geographical spatial_ref_sys for region."""

    atext: str
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a POST or PUT request that also specifies a valid 'area' field.
    """

    atype: str
    """Type of region as projected on the ground."""

    center_freq: Annotated[float, PropertyInfo(alias="centerFreq")]
    """The detected signal frequency in megahertz."""

    cluster: str
    """The name(s) of the subset of constellation spacecraft that made this detection."""

    conf_area: Annotated[float, PropertyInfo(alias="confArea")]
    """
    The area of the confidence ellipse specified in meters squared to contain the
    emitter with a 95% probability.
    """

    constellation: str
    """The name of the satellite constellation."""

    created_ts: Annotated[Union[str, datetime], PropertyInfo(alias="createdTs", format="iso8601")]
    """
    Specifies the creation time associated with the order in ISO 8601 UTC with
    microsecond precision.
    """

    detect_alt: Annotated[float, PropertyInfo(alias="detectAlt")]
    """The altitude relative to WGS-84 ellipsoid, in meters."""

    detect_lat: Annotated[float, PropertyInfo(alias="detectLat")]
    """WGS-84 latitude of the most likely emitter location coordinate point, in
    degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    detect_lon: Annotated[float, PropertyInfo(alias="detectLon")]
    """
    WGS-84 longitude of the most likely emitter location coordinate point, in
    degrees. -180 to 180 degrees (negative values west of Prime Meridian).
    """

    end_time: Annotated[Union[str, datetime], PropertyInfo(alias="endTime", format="iso8601")]
    """
    The end time for this Emitter Geo Location data set in ISO 8601 UTC with
    microsecond precision.
    """

    err_ellp: Annotated[Iterable[float], PropertyInfo(alias="errEllp")]
    """
    Confidence ellipsoid about the detection location [semi-major axis (m),
    semi-minor axis (m), orientation (deg)].
    """

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    id_rf_emitter: Annotated[str, PropertyInfo(alias="idRFEmitter")]
    """
    Optional identifier of the geolocated signal of interest RF Emitter for this
    observation. This ID can be used to obtain additional information on an RF
    Emitter object using the 'get by ID' operation (e.g. /udl/rfemitter/{id}). For
    example, the rfemitter object with idRFEmitter = abc would be queried as
    /udl/rfemitter/abc.
    """

    id_sensor: Annotated[str, PropertyInfo(alias="idSensor")]
    """Unique identifier of the reporting sensor.

    This ID can be used to obtain additional information on a sensor using the 'get
    by ID' operation (e.g. /udl/sensor/{id}). For example, the sensor with idSensor
    = abc would be queried as /udl/sensor/abc. Used when Emitter geolocation is done
    by a single sensor.
    """

    max_freq: Annotated[float, PropertyInfo(alias="maxFreq")]
    """The maximum detected frequency in megahertz."""

    min_freq: Annotated[float, PropertyInfo(alias="minFreq")]
    """The minimum detected frequency in megahertz."""

    num_bursts: Annotated[int, PropertyInfo(alias="numBursts")]
    """The count of single-burst observations used for this geolocation observation."""

    order_id: Annotated[str, PropertyInfo(alias="orderId")]
    """The order identifier for this Emitter Geo Location data set."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Annotated[str, PropertyInfo(alias="origObjectId")]
    """
    Optional identifier of the satellite used to identify and geolocate Emitter
    signals of interest of this observation. This may be an internal identifier and
    not necessarily a valid satellite number. Used when Emitter geolocation is done
    by a single satellite.
    """

    orig_rf_emitter_id: Annotated[str, PropertyInfo(alias="origRFEmitterId")]
    """Optional identifier of the emitter of interest for this observation.

    This may be an internal identifier and not necessarily a valid emitter Id.
    """

    orig_sensor_id: Annotated[str, PropertyInfo(alias="origSensorId")]
    """
    Optional identifier provided by observation source to indicate the sensor
    identifier which produced this Emitter Geo Location. This may be an internal
    identifier and not necessarily a valid sensor ID. Used when Emitter geolocation
    is done by a single sensor.
    """

    pass_group_id: Annotated[str, PropertyInfo(alias="passGroupId")]
    """
    Optional external identifier referencing the entity used in the calculation of
    the geolocation.
    """

    received_ts: Annotated[Union[str, datetime], PropertyInfo(alias="receivedTs", format="iso8601")]
    """
    The time representing the mean of the constituent single-burst observations in
    ISO 8601 UTC with microsecond precision.
    """

    sat_no: Annotated[int, PropertyInfo(alias="satNo")]
    """
    Satellite/catalog number of the on-orbit spacecraft used to identify and
    geolocate Emitter signals of interest of this detection. Used when Emitter
    geolocation is done by a single satellite.
    """

    signal_of_interest: Annotated[str, PropertyInfo(alias="signalOfInterest")]
    """The name of the signal of interest."""

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """
