# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EopAbridged"]


class EopAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    eop_date: datetime = FieldInfo(alias="eopDate")
    """Effective date/time for the EOP values in ISO8601 UTC format.

    The values could be current or predicted.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    d_epsilon: Optional[float] = FieldInfo(alias="dEpsilon", default=None)
    """
    The Bulletin A offset in obliquity dDe1980 with respect to the IAU 1976 Theory
    of Precession and the IAU 1980 Theory of Nutation, measured in milliseconds of
    arc. Note: dEpsilon is not used when this record represents IAU 2000 data.
    """

    d_epsilon_b: Optional[float] = FieldInfo(alias="dEpsilonB", default=None)
    """
    The Bulletin B offset in obliquity dDe1980 with respect to the IAU 1976 Theory
    of Precession and the IAU 1980 Theory of Nutation, measured in milliseconds of
    arc. Note: dEpsilonB is not used when this record represents IAU 2000 data.
    """

    d_epsilon_unc: Optional[float] = FieldInfo(alias="dEpsilonUnc", default=None)
    """The estimated uncertainty/error in the dEpsilon value in milliseconds of arc."""

    d_psi: Optional[float] = FieldInfo(alias="dPSI", default=None)
    """
    The Bulletin A offset in longitude dDy1980 with respect to the IAU 1976 Theory
    of Precession and the IAU 1980 Theory of Nutation, measured in milliseconds of
    arc. Note: dPSI is not used when this record represents IAU 2000 data.
    """

    d_psib: Optional[float] = FieldInfo(alias="dPSIB", default=None)
    """
    The Bulletin B offset in longitude dDy1980 with respect to the IAU 1976 Theory
    of Precession and the IAU 1980 Theory of Nutation, measured in milliseconds of
    arc. Note: dPSIB is not used when this record represents IAU 2000 data.
    """

    d_psi_unc: Optional[float] = FieldInfo(alias="dPSIUnc", default=None)
    """The estimated uncertainty/error in the dPSI value in milliseconds of arc."""

    d_x: Optional[float] = FieldInfo(alias="dX", default=None)
    """
    The Bulletin A celestial pole offset along x-axis with respect to the IAU 2000A
    Theory of Precession and Nutation, measured in milliseconds of arc. Note: dX is
    not used when this record represents IAU 1980 data.
    """

    d_xb: Optional[float] = FieldInfo(alias="dXB", default=None)
    """
    The Bulletin B celestial pole offset along the X-axis with respect to the IAU
    2000A Theory of Precession and Nutation, measured in milliseconds of arc. Note:
    dXB is not used when this record represents IAU 1980 data.
    """

    d_x_unc: Optional[float] = FieldInfo(alias="dXUnc", default=None)
    """
    The estimated uncertainty/error in the Bulletin A dX value, in milliseconds of
    arc.
    """

    d_y: Optional[float] = FieldInfo(alias="dY", default=None)
    """
    The Bulletin A celestial pole offset along y-axis with respect to the IAU 2000A
    Theory of Precession and Nutation, measured in milliseconds of arc. Note: dY is
    not used when this record represents IAU 1980 data.
    """

    d_yb: Optional[float] = FieldInfo(alias="dYB", default=None)
    """
    The Bulletin B celestial pole offset along the Y-axis with respect to the IAU
    2000A Theory of Precession and Nutation, measured in milliseconds of arc. Note:
    dYB is not used when this record represents IAU 1980 data.
    """

    d_y_unc: Optional[float] = FieldInfo(alias="dYUnc", default=None)
    """
    The estimated uncertainty/error in the Bulletin A dY value, in milliseconds of
    arc.
    """

    lod: Optional[float] = None
    """Bulletin A length of day or LOD in milliseconds.

    Universal time (UT1) is the time of the earth clock, which performs one
    revolution in about 24h. It is practically proportional to the sidereal time.
    The excess revolution time is called length of day (LOD).
    """

    lod_unc: Optional[float] = FieldInfo(alias="lodUnc", default=None)
    """The estimated uncertainty/error in the lod value in seconds."""

    nutation_state: Optional[Literal["I", "P"]] = FieldInfo(alias="nutationState", default=None)
    """
    Flag indicating Issued (I), or Predicted (P) for this record's nutation values
    (dPSI and dEpsilon).
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    polar_motion_state: Optional[Literal["I", "P"]] = FieldInfo(alias="polarMotionState", default=None)
    """
    Flag indicating Issued (I), or Predicted (P) for this record's polar motion
    values.
    """

    polar_motion_x: Optional[float] = FieldInfo(alias="polarMotionX", default=None)
    """The Bulletin A X coordinate value of earth polar motion at eopDate.

    Polar motion of the Earth is the motion of the Earth's rotational axis relative
    to its crust. This is measured with respect to a reference frame in which the
    solid Earth is fixed (a so-called Earth-centered, Earth-fixed or ECEF reference
    frame). Measured in arc seconds.
    """

    polar_motion_xb: Optional[float] = FieldInfo(alias="polarMotionXB", default=None)
    """Bulletin B X coordinate value of earth polar motion at eopDate.

    Polar motion of the Earth is the motion of the Earth's rotational axis relative
    to its crust. This is measured with respect to a reference frame in which the
    solid Earth is fixed (a so-called Earth-centered, Earth-fixed or ECEF reference
    frame). Measured in arc seconds.
    """

    polar_motion_x_unc: Optional[float] = FieldInfo(alias="polarMotionXUnc", default=None)
    """Estimated uncertainty/error in polarMotionX value in arc seconds."""

    polar_motion_y: Optional[float] = FieldInfo(alias="polarMotionY", default=None)
    """The Bulletin A Y coordinate value of earth polar motion at eopDate.

    Polar motion of the Earth is the motion of the Earth's rotational axis relative
    to its crust. This is measured with respect to a reference frame in which the
    solid Earth is fixed (a so-called Earth-centered, Earth-fixed or ECEF reference
    frame). Measured in arc seconds.
    """

    polar_motion_yb: Optional[float] = FieldInfo(alias="polarMotionYB", default=None)
    """Bulletin B Y coordinate value of earth polar motion at eopDate.

    Polar motion of the Earth is the motion of the Earth's rotational axis relative
    to its crust. This is measured with respect to a reference frame in which the
    solid Earth is fixed (a so-called Earth-centered, Earth-fixed or ECEF reference
    frame). Measured in arc seconds.
    """

    polar_motion_y_unc: Optional[float] = FieldInfo(alias="polarMotionYUnc", default=None)
    """Estimated uncertainty/error in polarMotionY value in arc seconds."""

    precession_nutation_std: Optional[str] = FieldInfo(alias="precessionNutationStd", default=None)
    """
    The IAU Theory of Precession and Theory of Nutation applied to the data in this
    record. IAU1980 records employ the IAU 1976 Theory of Precession and IAU 1980
    Theory of Nutation, and IAU2000 records employ the IAU 2000A Theory of
    Precession and Nutation.
    """

    raw_file_uri: Optional[str] = FieldInfo(alias="rawFileURI", default=None)
    """
    Optional URI location in the document repository of the raw file parsed by the
    system to produce this record. To download the raw file, prepend
    https://udl-hostname/scs/download?id= to this value.
    """

    ut1_utc: Optional[float] = FieldInfo(alias="ut1UTC", default=None)
    """
    The difference between the Bulletin A UT1 and UTC time scales as of eopDate in
    seconds.
    """

    ut1_utcb: Optional[float] = FieldInfo(alias="ut1UTCB", default=None)
    """
    The Bulletin B difference between the UT1 and UTC time scales as of eopDate in
    seconds.
    """

    ut1_utc_state: Optional[Literal["I", "P"]] = FieldInfo(alias="ut1UTCState", default=None)
    """
    Flag indicating Issued (I), or Predicted (P) for this record''s Bulletin A
    UT1-UTC values.
    """

    ut1_utc_unc: Optional[float] = FieldInfo(alias="ut1UTCUnc", default=None)
    """The estimated uncertainty/error in the ut1UTC value in seconds."""
