# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EphemerisAbridged"]


class EphemerisAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    ts: datetime
    """Time associated with the Ephemeris Point, in ISO8601 UTC format."""

    xpos: float
    """
    Cartesian X position of target, in km, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    xvel: float
    """
    Cartesian X velocity of target, in km/sec, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    ypos: float
    """
    Cartesian Y position of target, in km, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    yvel: float
    """
    Cartesian Y velocity of target, in km/sec, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    zpos: float
    """
    Cartesian Z position of target, in km, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    zvel: float
    """
    Cartesian Z velocity of target, in km/sec, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    cov: Optional[List[float]] = None
    """
    Covariance matrix, in kilometer and second based units, in the specified
    Ephemeris Set covReferenceFrame. If the covReferenceFrame from the EphemerisSet
    table is null it is assumed to be J2000. The array values represent the lower
    triangular half of the position-velocity covariance matrix. The size of the
    covariance matrix is dynamic, depending on whether the covariance for position
    only or position & velocity. The covariance elements are position dependent
    within the array with values ordered as follows:

    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;x&nbsp;&nbsp;y&nbsp;&nbsp;z&nbsp;&nbsp;&nbsp;x'&nbsp;&nbsp;y'&nbsp;z'&nbsp;&nbsp;

    x&nbsp;&nbsp;&nbsp;&nbsp;1

    y&nbsp;&nbsp;&nbsp;&nbsp;2&nbsp;&nbsp;&nbsp;3

    z&nbsp;&nbsp;&nbsp;&nbsp;4&nbsp;&nbsp;&nbsp;5&nbsp;&nbsp;&nbsp;6

    x'&nbsp;&nbsp;&nbsp;7&nbsp;&nbsp;&nbsp;8&nbsp;&nbsp;&nbsp;9&nbsp;&nbsp;10

    y'&nbsp;&nbsp;11&nbsp;&nbsp;12&nbsp;&nbsp;13&nbsp;&nbsp;14&nbsp;&nbsp;15

    z'&nbsp;&nbsp;16&nbsp;&nbsp;17&nbsp;&nbsp;18&nbsp;&nbsp;19&nbsp;&nbsp;20&nbsp;&nbsp;
    21

    The array containing the covariance matrix elements will be of length 6 for
    position only covariance, or length 21 for position-velocity covariance. The cov
    array should contain only the lower left triangle values from top left down to
    bottom right, in order.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    es_id: Optional[str] = FieldInfo(alias="esId", default=None)
    """Unique identifier of the parent EphemerisSet, auto-generated by the system.

    The esId (ephemerisSet id) is used to identify all individual ephemeris states
    associated with a parent ephemerisSet.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the on-orbit satellite object."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by ephemeris source to indicate the target object
    of this ephemeris. This may be an internal identifier and not necessarily map to
    a valid satellite number.
    """

    xaccel: Optional[float] = None
    """
    Cartesian X acceleration of target, in km/sec^2, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    yaccel: Optional[float] = None
    """
    Cartesian Y acceleration of target, in km/sec^2, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """

    zaccel: Optional[float] = None
    """
    Cartesian Z acceleration of target, in km/sec^2, in the specified EphemerisSet
    referenceFrame. If referenceFrame is null then J2K should be assumed.
    """
