# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EphemerisSetAbridged"]


class EphemerisSetAbridged(BaseModel):
    category: str
    """The source category of the ephemeris (e.g. OWNER_OPERATOR, ANALYST, EXTERNAL)."""

    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    num_points: int = FieldInfo(alias="numPoints")
    """Number of points contained in the ephemeris."""

    point_end_time: datetime = FieldInfo(alias="pointEndTime")
    """End time/last time point of the ephemeris, in ISO 8601 UTC format."""

    point_start_time: datetime = FieldInfo(alias="pointStartTime")
    """Start time/first time point of the ephemeris, in ISO 8601 UTC format."""

    source: str
    """Source of the data."""

    type: str
    """
    The type/purpose of the ephemeris (e.g., CALIBRATION, LAUNCH, MNVR_PLAN,
    ROUTINE, SCREENING).
    """

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    b_dot: Optional[float] = FieldInfo(alias="bDot", default=None)
    """First derivative of ballistic coefficient (m^2/kg-s)."""

    cent_body: Optional[str] = FieldInfo(alias="centBody", default=None)
    """The Central Body of the ephemeris.

    Assumed to be Earth, unless otherwise indicated.
    """

    comments: Optional[str] = None
    """Additional source provided comments associated with the ephemeris."""

    cov_reference_frame: Optional[Literal["J2000", "UVW"]] = FieldInfo(alias="covReferenceFrame", default=None)
    """The reference frame of the covariance matrix elements.

    If the covReferenceFrame is null it is assumed to be J2000.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, in UTC."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """Application user who created the row in the database."""

    description: Optional[str] = None
    """Notes/description of the provided ephemeris.

    A value of DSTOP signifies the ephemeris were generated using the last
    observation available.
    """

    descriptor: Optional[str] = None
    """Optional source-provided and searchable metadata or descriptor of the data."""

    drag_model: Optional[str] = FieldInfo(alias="dragModel", default=None)
    """Drag model used in ephemeris generation (e.g. JAC70, MSIS90, NONE, etc.)."""

    edr: Optional[float] = None
    """Model parameter value for energy dissipation rate (EDR), expressed in w/kg."""

    filename: Optional[str] = None
    """
    Filename of the raw file used to provide the ephemeris data including filetype
    extension, if applicable. This file may be retrieved using the 'getFile'
    operation as specified in the 'EphemerisSet' OpenAPI docs.
    """

    geopotential_model: Optional[str] = FieldInfo(alias="geopotentialModel", default=None)
    """Geopotential model used in ephemeris generation (e.g.

    EGM-96, WGS-84, WGS-72, JGM-2, GEM-T3), including mm degree zonals, nn
    degree/order tesserals (e.g. EGM-96 24Z,24T).
    """

    has_accel: Optional[bool] = FieldInfo(alias="hasAccel", default=None)
    """Boolean indicating whether acceleration data is provided with the ephemeris."""

    has_cov: Optional[bool] = FieldInfo(alias="hasCov", default=None)
    """Boolean indicating whether covariance data is provided with the ephemeris."""

    has_mnvr: Optional[bool] = FieldInfo(alias="hasMnvr", default=None)
    """Boolean indicating whether maneuver(s) are incorporated into the ephemeris."""

    id_maneuvers: Optional[List[str]] = FieldInfo(alias="idManeuvers", default=None)
    """Array of the maneuver IDs of all maneuvers incorporated in the ephemeris."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the primary satellite on-orbit object."""

    id_state_vector: Optional[str] = FieldInfo(alias="idStateVector", default=None)
    """ID of the State Vector used to generate the ephemeris."""

    integrator: Optional[str] = None
    """Integrator used in ephemeris generation (e.g.

    RK7(8), RK8(9), COWELL, TWO-BODY).
    """

    interpolation: Optional[str] = None
    """The recommended interpolation method for the ephemeris data."""

    interpolation_degree: Optional[int] = FieldInfo(alias="interpolationDegree", default=None)
    """The recommended interpolation degree for the ephemeris data."""

    lunar_solar: Optional[bool] = FieldInfo(alias="lunarSolar", default=None)
    """Boolean indicating use of lunar/solar data in ephemeris generation."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by ephemeris source to indicate the target object
    of this ephemeris. This may be an internal identifier and not necessarily map to
    a valid satellite number.
    """

    pedigree: Optional[str] = None
    """The pedigree of the ephemeris or source data used for ephemeris generation (e.g.

    DOPPLER, GPS, HYBRID, PROPAGATED, RANGING, SLR).
    """

    reference_frame: Optional[Literal["J2000", "EFG/TDR", "ECR/ECEF", "TEME", "ITRF", "GCRF"]] = FieldInfo(
        alias="referenceFrame", default=None
    )
    """The reference frame of the cartesian orbital states.

    If the referenceFrame is null it is assumed to be J2000.
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/catalog number of the target on-orbit object."""

    solid_earth_tides: Optional[bool] = FieldInfo(alias="solidEarthTides", default=None)
    """Boolean indicating use of solid earth tide data in ephemeris generation."""

    step_size: Optional[int] = FieldInfo(alias="stepSize", default=None)
    """Ephemeris step size, in seconds."""

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    usable_end_time: Optional[datetime] = FieldInfo(alias="usableEndTime", default=None)
    """
    Optional end time of the usable time span for the ephemeris data, in ISO 8601
    UTC format with microsecond precision.
    """

    usable_start_time: Optional[datetime] = FieldInfo(alias="usableStartTime", default=None)
    """
    Optional start time of the usable time span for the ephemeris data, in ISO 8601
    UTC format with microsecond precision.
    """
