# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EquipmentRemarkAbridged"]


class EquipmentRemarkAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_equipment: str = FieldInfo(alias="idEquipment")
    """The ID of the Equipment to which this remark applies."""

    source: str
    """Source of the data."""

    text: str
    """The text of the remark."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    alt_rmk_id: Optional[str] = FieldInfo(alias="altRmkId", default=None)
    """Unique identifier of the Equipment Remark record from the originating system."""

    code: Optional[str] = None
    """The remark type identifier.

    For example, the Mobility Air Forces (MAF) remark code, defined in the Airfield
    Suitability and Restriction Report (ASRR).
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    name: Optional[str] = None
    """The name of the remark."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    type: Optional[str] = None
    """The remark type (e.g. Caution, Information, Misc, Restriction, etc.)."""
