# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import date
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EquipmentUpdateParams"]


class EquipmentUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    country_code: Required[Annotated[str, PropertyInfo(alias="countryCode")]]
    """
    The DoD Standard Country Code designator for the country or political entity to
    which the equipment geographic coordinates reside. This field will be set to
    "OTHR" if the source value does not match a UDL Country code value
    (ISO-3166-ALPHA-2).
    """

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    lat: Required[float]
    """WGS84 latitude of the location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: Required[float]
    """WGS84 longitude of the location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    air_def_area: Annotated[str, PropertyInfo(alias="airDefArea")]
    """
    Air Defense District (ADD) or Air Defense Area (ADA) in which the geographic
    coordinates reside.
    """

    allegiance: str
    """
    The DoD Standard Country Code designator for the country or political entity to
    which the equipment owes its allegiance. This field will be set to "OTHR" if the
    source value does not match a UDL Country code value (ISO-3166-ALPHA-2).
    """

    alt_allegiance: Annotated[str, PropertyInfo(alias="altAllegiance")]
    """
    Specifies an alternate allegiance code if the data provider code is not part of
    an official Country Code standard such as ISO-3166 or FIPS. This field will be
    set to the value provided by the source and should be used for all Queries
    specifying allegiance.
    """

    alt_country_code: Annotated[str, PropertyInfo(alias="altCountryCode")]
    """
    Specifies an alternate country code if the data provider code is not part of an
    official Country Code standard such as ISO-3166 or FIPS. This field will be set
    to the value provided by the source and should be used for all Queries
    specifying a Country Code.
    """

    alt_eqp_id: Annotated[str, PropertyInfo(alias="altEqpId")]
    """Unique identifier of the Equipment record from the originating system."""

    class_rating: Annotated[str, PropertyInfo(alias="classRating")]
    """Indicates the importance of the equipment.

    Referenced, but not constrained to, the following class ratings type
    classifications.

    0 - Not of significant importance of the system

    1 - Primary importance to system

    2 - Secondary importance to system

    3 - Tertiary importance to system

    O - Other. Explain in Remarks.
    """

    condition: str
    """The physical manner of being or state of existence of the entity.

    A physical condition that must be considered in the determining of a course of
    action. The specific usage and enumerations contained in this field may be found
    in the documentation provided in the referenceDoc field. If referenceDoc not
    provided, users may consult the data provider.
    """

    condition_avail: Annotated[str, PropertyInfo(alias="conditionAvail")]
    """Availability of the entity relative to its condition.

    Indicates the reason the entity is not fully operational. The specific usage and
    enumerations contained in this field may be found in the documentation provided
    in the referenceDoc field. If referenceDoc not provided, users may consult the
    data provider.
    """

    coord: str
    """
    Indicates any of the magnitudes that serve to define the position of a point by
    reference to a fixed figure, system of lines, etc. specified in degrees, minute,
    and seconds.

    Pos. 1-2. Latitude Degrees [00-90]

    Pos. 3-4. Latitude Minutes [00-59]

    Pos. 5-6. Latitude Seconds [00-59]

    Pos. 7-9. Latitude Thousandths Of Seconds [000-999]

    Pos. 10. Latitude Hemisphere [NS]

    Pos. 11-13. Longitude Degrees [00-180]

    Pos. 14-15. Longitude Minutes [00-59]

    Pos. 16-17. Longitude Seconds [00-59]

    Pos. 18-20. Longitude Thousandths Of Seconds [000-999]

    Pos. 21. Longitude Hemisphere [EW]

    Pos. 1-21. Unknown Latitude and Unknown Longitude [000000000U000000000U]].
    """

    coord_datum: Annotated[str, PropertyInfo(alias="coordDatum")]
    """A mathematical model of the earth used to calculate coordinates on a map.

    US Forces use the World Geodetic System 1984 (WGS 84), but also use maps by
    allied countries with local datums. The datum must be specified to ensure
    accuracy of coordinates. The specific usage and enumerations contained in this
    field may be found in the documentation provided in the referenceDoc field. If
    referenceDoc not provided, users may consult the data provider.
    """

    coord_deriv_acc: Annotated[float, PropertyInfo(alias="coordDerivAcc")]
    """
    Indicates the plus or minus error assessed against the method used to derive the
    coordinate.
    """

    elev_msl: Annotated[float, PropertyInfo(alias="elevMsl")]
    """
    Ground elevation, in meters, of the geographic coordinates referenced to (above
    or below) Mean Sea Level (MSL) vertical datum.
    """

    elev_msl_conf_lvl: Annotated[int, PropertyInfo(alias="elevMslConfLvl")]
    """
    Indicates the confidence level expressed as a percent that a specific geometric
    spatial element, ELEVATION_MSL linear accuracy, has been vertically positioned
    to within a specified vertical accuracy. Confidence level has a range of values
    from 0 to 100, with 100 being highest level of confidence.
    """

    elev_msl_deriv_acc: Annotated[float, PropertyInfo(alias="elevMslDerivAcc")]
    """
    Indicates the plus or minus error assessed against the method used to derive the
    elevation, measured in meters.
    """

    eqp_code: Annotated[str, PropertyInfo(alias="eqpCode")]
    """
    Designated equipment code assigned to the item of equipment or an abbreviation
    record type unique identifier. Users should consult the data provider for
    information on the equipment code structure.
    """

    eqp_id_num: Annotated[str, PropertyInfo(alias="eqpIdNum")]
    """
    Uniquely identifies each item or group of equipment associated with a unit,
    facility or site.
    """

    eval: int
    """
    Eval represents the Intelligence Confidence Level or the Reliability/degree of
    confidence that the analyst has assigned to the data within this record. The
    numerical range is from 1 to 9 with 1 representing the highest confidence level.
    """

    fpa: str
    """Functional Production Area (FPA) under the Shared Production Program (SPP).

    Producers are defined per country per FPA. The specific usage and enumerations
    contained in this field may be found in the documentation provided in the
    referenceDoc field. If referenceDoc not provided, users may consult the data
    provider.
    """

    function: str
    """
    Indicates the function or mission of this equipment, which may or may not be
    engaged in at any particular time. Typically refers to a unit, organization, or
    installation/facility performing a specific function or mission such as a
    redistribution center or naval shipyard. The specific usage and enumerations
    contained in this field may be found in the documentation provided in the
    referenceDoc field. If referenceDoc not provided, users may consult the data
    provider.
    """

    funct_primary: Annotated[str, PropertyInfo(alias="functPrimary")]
    """Principal operational function being performed.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    geoidal_msl_sep: Annotated[float, PropertyInfo(alias="geoidalMslSep")]
    """
    The distance between Mean Sea Level and a referenced ellipsoid, measured in
    meters.
    """

    ident: str
    """
    Estimated identity of the Site (ASSUMED FRIEND, FRIEND, HOSTILE, FAKER, JOKER,
    NEUTRAL, PENDING, SUSPECT, UNKNOWN):

    ASSUMED FRIEND: Track assumed to be a friend due to the object characteristics,
    behavior, and/or origin.

    FRIEND: Track object supporting friendly forces and belonging to a declared
    friendly nation or entity.

    HOSTILE: Track object belonging to an opposing nation, party, group, or entity
    deemed to contribute to a threat to friendly forces or their mission due to its
    behavior, characteristics, nationality, or origin.

    FAKER: Friendly track, object, or entity acting as an exercise hostile.

    JOKER: Friendly track, object, or entity acting as an exercise suspect.

    NEUTRAL: Track object whose characteristics, behavior, nationality, and/or
    origin indicate that it is neither supporting nor opposing friendly forces or
    their mission.

    PENDING: Track object which has not been evaluated.

    SUSPECT: Track object deemed potentially hostile due to the object
    characteristics, behavior, nationality, and/or origin.

    UNKNOWN: Track object which has been evaluated and does not meet criteria for
    any standard identity.
    """

    id_operating_unit: Annotated[str, PropertyInfo(alias="idOperatingUnit")]
    """Unique identifier of the operating unit associated with the equipment record."""

    id_parent_equipment: Annotated[str, PropertyInfo(alias="idParentEquipment")]
    """
    Unique identifier of the Parent equipment record associated with this equipment
    record.
    """

    id_site: Annotated[str, PropertyInfo(alias="idSite")]
    """Unique identifier of the Site Entity associated with the equipment record."""

    loc_reason: Annotated[str, PropertyInfo(alias="locReason")]
    """Indicates the reason that the equipment is at that location.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    mil_grid: Annotated[str, PropertyInfo(alias="milGrid")]
    """
    The Military Grid Reference System is the geocoordinate standard used by NATO
    militaries for locating points on Earth. The MGRS is derived from the Universal
    Transverse Mercator (UTM) grid system and the Universal Polar Stereographic
    (UPS) grid system, but uses a different labeling convention. The MGRS is used as
    geocode for the entire Earth. Example of an milgrid coordinate, or grid
    reference, would be 4QFJ12345678, which consists of three parts:

    4Q (grid zone designator, GZD)

    FJ (the 100,000-meter square identifier)

    12345678 (numerical location; easting is 1234 and northing is 5678, in this case
    specifying a location with 10 m resolution).
    """

    mil_grid_sys: Annotated[str, PropertyInfo(alias="milGridSys")]
    """Indicates the grid system used in the development of the milGrid coordinates.

    Values are:

    UPS - Universal Polar System

    UTM - Universal Transverse Mercator.
    """

    nomen: str
    """
    Generic type this specific piece of equipment belongs to, and the identifying
    nomenclature which describes the equipment.
    """

    oper_area_primary: Annotated[str, PropertyInfo(alias="operAreaPrimary")]
    """
    Internationally recognized water area in which the vessel is most likely to be
    deployed or in which it normally operates most frequently.
    """

    oper_status: Annotated[str, PropertyInfo(alias="operStatus")]
    """
    The Degree to which an entity is ready to perform the overall operational
    mission(s) for which it was organized and equipped. The specific usage and
    enumerations contained in this field may be found in the documentation provided
    in the referenceDoc field. If referenceDoc not provided, users may consult the
    data provider.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    pol_subdiv: Annotated[str, PropertyInfo(alias="polSubdiv")]
    """Political subdivision in which the geographic coordinates reside.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    qty_oh: Annotated[int, PropertyInfo(alias="qtyOH")]
    """
    Relative to the parent entity, the total number of military personnel or
    equipment assessed to be on-hand (OH).
    """

    rec_status: Annotated[str, PropertyInfo(alias="recStatus")]
    """
    Validity and currency of the data in the record to be used in conjunction with
    the other elements in the record as defined by SOPs. Referenced, but not
    constrained to, the following record status type classifications.

    A - Active

    I - Inactive

    K - Acknowledged

    L - Local

    Q - A nominated (NOM) or Data Change Request (DCR) record

    R - Production reduced by CMD decision

    W - Working Record.
    """

    reference_doc: Annotated[str, PropertyInfo(alias="referenceDoc")]
    """
    The reference documentiation that specifies the usage and enumerations contained
    in this record. If referenceDoc not provided, users may consult the data
    provider.
    """

    res_prod: Annotated[str, PropertyInfo(alias="resProd")]
    """
    Responsible Producer - Organization that is responsible for the maintenance of
    the record.
    """

    review_date: Annotated[Union[str, date], PropertyInfo(alias="reviewDate", format="iso8601")]
    """
    Date on which the data in the record was last reviewed by the responsible
    analyst for accuracy and currency. This date cannot be greater than the current
    date.
    """

    seq_num: Annotated[int, PropertyInfo(alias="seqNum")]
    """Provider specific sequential number assigned to the equipment."""

    src_ids: Annotated[List[str], PropertyInfo(alias="srcIds")]
    """
    Array of UUID(s) of the UDL data record(s) that are related to this equipment
    record. See the associated 'srcTyps' array for the specific types of data,
    positionally corresponding to the UUIDs in this array. The 'srcTyps' and
    'srcIds' arrays must match in size. See the corresponding srcTyps array element
    for the data type of the UUID and use the appropriate API operation to retrieve
    that object.
    """

    src_typs: Annotated[List[str], PropertyInfo(alias="srcTyps")]
    """
    Array of UDL record types such as AIRCRAFT, VESSEL, EO, MTI that are related to
    this equipment record. See the associated 'srcIds' array for the record UUIDs,
    positionally corresponding to the record types in this array. The 'srcTyps' and
    'srcIds' arrays must match in size.
    """

    sym_code: Annotated[str, PropertyInfo(alias="symCode")]
    """
    A standard scheme for symbol coding enabling the transfer, display and use of
    symbols and graphics among information systems, as per MIL-STD 2525B, and
    supported by the element AFFILIATION.
    """

    utm: str
    """Universal Transverse Mercator (UTM) grid coordinates.

    Pos. 1-2, UTM Zone Column [01-60

    Pos. 3, UTM Zone Row [C-HJ-NP-X]

    Pos. 4, UTM False Easting [0-9]

    Pos. 5-9, UTM Meter Easting [0-9][0-9][0-9][0-9][0-9]

    Pos. 10-11, UTM False Northing [0-9][0-9]

    Pos. 12-16, UTM Meter Northing [0-9][0-9][0-9][0-9][0-9].
    """

    wac: str
    """
    World Aeronautical Chart identifier for the area in which a designated place is
    located.
    """
