# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["FeatureassessmentTupleResponse", "FeatureassessmentTupleResponseItem"]


class FeatureassessmentTupleResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    feature_ts: datetime = FieldInfo(alias="featureTs")
    """
    Datetime type value associated with this record, in ISO 8601 UTC format with
    millisecond precision.
    """

    feature_uo_m: str = FieldInfo(alias="featureUoM")
    """The Unit of Measure associated with this feature.

    If there are no physical units associated with the feature a value of NONE
    should be specified.
    """

    id_analytic_imagery: str = FieldInfo(alias="idAnalyticImagery")
    """
    Unique identifier of the Analytic Imagery associated with this Feature
    Assessment record.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    agjson: Optional[str] = None
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the feature assessment as projected
    on the ground. GeoJSON Reference: https://geojson.org/. Ignored if included with
    a POST or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    andims: Optional[int] = None
    """Number of dimensions of the geometry depicted by region."""

    ann_lims: Optional[List[List[int]]] = FieldInfo(alias="annLims", default=None)
    """Polygonal annotation limits, specified in pixels, as an array of arrays N x M.

    Allows the image provider to highlight one or more polygonal area(s) of
    interest. The array must contain NxM two-element arrays, where N is the number
    of polygons of interest. The associated annotation(s) should be included in the
    annText array.
    """

    ann_text: Optional[List[str]] = FieldInfo(alias="annText", default=None)
    """
    Annotation text, a string array of annotation(s) corresponding to the
    rectangular areas specified in annLims. This array contains the annotation text
    associated with the areas of interest indicated in annLims, in order. This array
    should contain one annotation per four values of the area (annLims) array.
    """

    area: Optional[str] = None
    """
    Optional geographical region or polygon (lat/lon pairs) of the area surrounding
    the feature assessment as projected on the ground.
    """

    asrid: Optional[int] = None
    """Geographical spatial_ref_sys for region."""

    assessment: Optional[str] = None
    """Descriptive or additional information associated with this feature/assessment."""

    atext: Optional[str] = None
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the feature assessment as
    projected on the ground. WKT reference:
    https://www.opengeospatial.org/standards/wkt-crs. Ignored if included with a
    POST or PUT request that also specifies a valid 'area' field.
    """

    atype: Optional[str] = None
    """Type of region as projected on the ground (POLYGON, POINT, LINE)."""

    confidence: Optional[float] = None
    """Analytic confidence of feature accuracy (0 to 1)."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    external_id: Optional[str] = FieldInfo(alias="externalId", default=None)
    """Feature Assessment ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    feature_array: Optional[List[float]] = FieldInfo(alias="featureArray", default=None)
    """
    An array of numeric feature/assessment values expressed in the specified unit of
    measure (obUoM). Because of the variability of the Feature Assessment data
    types, each record may employ a numeric observation value (featureValue), a
    string observation value (featureString), a Boolean observation value
    (featureBool), an array of numeric observation values (featureArray), or any
    combination of these.
    """

    feature_bool: Optional[bool] = FieldInfo(alias="featureBool", default=None)
    """A boolean feature/assessment.

    Because of the variability of the Feature Assessment data types, each record may
    employ a numeric observation value (featureValue), a string observation value
    (featureString), a Boolean observation value (featureBool), an array of numeric
    observation values (featureArray), or any combination of these.
    """

    feature_string: Optional[str] = FieldInfo(alias="featureString", default=None)
    """
    A single feature/assessment string expressed in the specified unit of measure
    (obUoM). Because of the variability of the Feature Assessment data types, each
    record may employ a numeric observation value (featureValue), a string
    observation value (featureString), a Boolean observation value (featureBool), an
    array of numeric observation values (featureArray), or any combination of these.
    """

    feature_string_array: Optional[List[str]] = FieldInfo(alias="featureStringArray", default=None)
    """An array of string feature/assessment expressions.

    Because of the variability of the Feature Assessment data types, each record may
    employ a numeric observation value (featureValue), a string observation value
    (featureString), a Boolean observation value (featureBool), an array of numeric
    observation values (featureArray), or any combination of these.
    """

    feature_value: Optional[float] = FieldInfo(alias="featureValue", default=None)
    """
    A single feature/assessment value expressed in the specified unit of measure
    (obUoM). Because of the variability of the Feature Assessment data types, each
    record may employ a numeric observation value (featureValue), a string
    observation value (featureString), a Boolean observation value (featureBool), an
    array of numeric observation values (featureArray), or any combination of these.
    """

    heading: Optional[float] = None
    """
    The feature object heading, in degrees clockwise from true North at the object
    location.
    """

    height: Optional[float] = None
    """Estimated physical height of the feature, in meters."""

    length: Optional[float] = None
    """Estimated physical length of the feature, in meters."""

    name: Optional[str] = None
    """Source defined name of the feature associated with this record.

    If an annotation for this feature element exists on the parent image it can be
    referenced here.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    speed: Optional[float] = None
    """Feature's speed of travel, in meters per second."""

    src_ids: Optional[List[str]] = FieldInfo(alias="srcIds", default=None)
    """
    Array of UUIDs of the UDL data records that are related to the determination of
    this activity or event. See the associated 'srcTyps' array for the specific
    types of data, positionally corresponding to the UUIDs in this array. The
    'srcTyps', 'srcIds', and 'srcTs' arrays must contain the same number of
    elements. See the corresponding srcTyps array element for the data type of the
    UUID and use the appropriate API operation to retrieve that object.
    """

    src_ts: Optional[List[datetime]] = FieldInfo(alias="srcTs", default=None)
    """
    Array of the primary timestamps, in ISO 8601 UTC format, with appropriate
    precision for the datatype of each correspondng srcTyp/srcId record. See the
    associated 'srcTyps' and 'srcIds' arrays for the record type and UUID,
    respectively, positionally corresponding to the record types in this array. The
    'srcTyps', 'srcIds', and 'srcTs' arrays must contain the same number of
    elements. These timestamps are included to support services which do not include
    a GET by {id} operation. If referencing a datatype which does not include a
    primary timestamp, the corresponding srcTs array element should be included as
    null.
    """

    src_typs: Optional[List[str]] = FieldInfo(alias="srcTyps", default=None)
    """
    Array of UDL record types (AIS, GROUNDIMAGE, MTI, ONORBIT, POI, SAR, SKYIMAGE,
    SOI, TRACK) related to this feature assessment. See the associated 'srcIds' and
    'srcTs' arrays for the record UUIDs and timetsmps. respectively, positionally
    corresponding to the record types in this array. The 'srcTyps', 'srcIds', and
    'srcTs' arrays must contain the same number of elements.
    """

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    type: Optional[str] = None
    """The type of feature (e.g.

    AIRCRAFT, ANTENNA, SOLAR ARRAY, SITE, STRUCTURE, VESSEL, VEHICLE, UNKNOWN, etc.)
    detailed in this feature assessment record. This type may be a primary feature
    within an image, for example a VESSEL, or may be a component or characteristic
    of a primary feature, for example an ANTENNA mounted on a vessel.
    """

    width: Optional[float] = None
    """Estimated physical width of the feature, in meters."""


FeatureassessmentTupleResponse: TypeAlias = List[FeatureassessmentTupleResponseItem]
