# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = [
    "FlightplanCreateParams",
    "AirRefuelEvent",
    "FlightPlanMessage",
    "FlightPlanPointGroup",
    "FlightPlanPointGroupFlightPlanPoint",
    "FlightPlanWaypoint",
]


class FlightplanCreateParams(TypedDict, total=False):
    arr_airfield: Required[Annotated[str, PropertyInfo(alias="arrAirfield")]]
    """
    The airfield identifier of the arrival location, International Civil Aviation
    Organization (ICAO) code preferred.
    """

    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    dep_airfield: Required[Annotated[str, PropertyInfo(alias="depAirfield")]]
    """
    The airfield identifier of the departure location, International Civil Aviation
    Organization (ICAO) code preferred.
    """

    gen_ts: Required[Annotated[Union[str, datetime], PropertyInfo(alias="genTS", format="iso8601")]]
    """
    The generation time of this flight plan in ISO 8601 UTC format, with millisecond
    precision.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """
    Unique identifier of the record, auto-generated by the system if not provided on
    create operations.
    """

    aircraft_mds: Annotated[str, PropertyInfo(alias="aircraftMDS")]
    """The aircraft Model Design Series (MDS) designation (e.g.

    E-2C HAWKEYE, F-15 EAGLE, KC-130 HERCULES, etc.) of the aircraft associated with
    this flight plan. Intended as, but not constrained to, MIL-STD-6016 environment
    dependent specific type designations.
    """

    air_refuel_events: Annotated[Iterable[AirRefuelEvent], PropertyInfo(alias="airRefuelEvents")]
    """Collection of air refueling events occurring on this flight."""

    amc_mission_id: Annotated[str, PropertyInfo(alias="amcMissionId")]
    """
    Air Mobility Command (AMC) mission identifier according to Mobility Air Forces
    (MAF) encode/decode procedures.
    """

    app_landing_fuel: Annotated[float, PropertyInfo(alias="appLandingFuel")]
    """Fuel burned from the initial approach point to landing in pounds."""

    arr_alternate1: Annotated[str, PropertyInfo(alias="arrAlternate1")]
    """
    The first designated alternate arrival airfield, International Civil Aviation
    Organization (ICAO) code preferred.
    """

    arr_alternate1_fuel: Annotated[float, PropertyInfo(alias="arrAlternate1Fuel")]
    """Fuel required to fly to alternate landing site 1 and land in pounds."""

    arr_alternate2: Annotated[str, PropertyInfo(alias="arrAlternate2")]
    """
    The second designated alternate arrival airfield, International Civil Aviation
    Organization (ICAO) code preferred.
    """

    arr_alternate2_fuel: Annotated[float, PropertyInfo(alias="arrAlternate2Fuel")]
    """Fuel required to fly to alternate landing site 2 and land in pounds."""

    arr_ice_fuel: Annotated[float, PropertyInfo(alias="arrIceFuel")]
    """
    Additional fuel burned at landing/missed approach for icing during arrival in
    pounds.
    """

    arr_runway: Annotated[str, PropertyInfo(alias="arrRunway")]
    """The arrival runway for this flight."""

    atc_addresses: Annotated[List[str], PropertyInfo(alias="atcAddresses")]
    """Array of Air Traffic Control (ATC) addresses."""

    avg_temp_dev: Annotated[float, PropertyInfo(alias="avgTempDev")]
    """
    Average temperature deviation of the primary, divert, and alternate path for the
    route between first Top of Climb and last Top of Descent in degrees Celsius.
    """

    burned_fuel: Annotated[float, PropertyInfo(alias="burnedFuel")]
    """Fuel planned to be burned during the flight in pounds."""

    call_sign: Annotated[str, PropertyInfo(alias="callSign")]
    """The call sign assigned to the aircraft for this flight plan."""

    cargo_remark: Annotated[str, PropertyInfo(alias="cargoRemark")]
    """Remarks about the planned cargo associated with this flight plan."""

    climb_fuel: Annotated[float, PropertyInfo(alias="climbFuel")]
    """Fuel required from brake release to Top of Climb in pounds."""

    climb_time: Annotated[str, PropertyInfo(alias="climbTime")]
    """Time required from brake release to Top of Climb expressed as HH:MM."""

    contingency_fuel: Annotated[float, PropertyInfo(alias="contingencyFuel")]
    """The amount of contingency fuel in pounds."""

    country_codes: Annotated[List[str], PropertyInfo(alias="countryCodes")]
    """
    Array of country codes for the countries overflown during this flight in ISO
    3166-1 Alpha-2 format.
    """

    dep_alternate: Annotated[str, PropertyInfo(alias="depAlternate")]
    """
    The designated alternate departure airfield, International Civil Aviation
    Organization (ICAO) code preferred.
    """

    depress_fuel: Annotated[float, PropertyInfo(alias="depressFuel")]
    """
    The depressurization fuel required to fly from the Equal Time Point to the Last
    Suitable/First Suitable airfield at depressurization altitude in pounds.
    """

    dep_runway: Annotated[str, PropertyInfo(alias="depRunway")]
    """The departure runway for this flight."""

    drag_index: Annotated[float, PropertyInfo(alias="dragIndex")]
    """The percent degrade due to drag for this aircraft."""

    early_descent_fuel: Annotated[float, PropertyInfo(alias="earlyDescentFuel")]
    """
    Additional fuel burned at landing/missed approach for an early descent in
    pounds.
    """

    endurance_time: Annotated[str, PropertyInfo(alias="enduranceTime")]
    """Total endurance time based on the fuel on board expressed as HH:MM."""

    enroute_fuel: Annotated[float, PropertyInfo(alias="enrouteFuel")]
    """Fuel required to fly from Top of Climb to Top of Descent in pounds."""

    enroute_time: Annotated[str, PropertyInfo(alias="enrouteTime")]
    """Time required to fly from Top of Climb to Top of Descent expressed as HH:MM."""

    equipment: str
    """
    The list of equipment on the aircraft as defined in the Flight Information
    Publications (FLIP) General Planning (GP) manual.
    """

    est_dep_time: Annotated[Union[str, datetime], PropertyInfo(alias="estDepTime", format="iso8601")]
    """
    The estimated time of departure for the aircraft, in ISO 8601 UTC format, with
    millisecond precision.
    """

    etops_airfields: Annotated[List[str], PropertyInfo(alias="etopsAirfields")]
    """
    Array of Extended Operations (ETOPS) adequate landing airfields that are within
    the mission region.
    """

    etops_alt_airfields: Annotated[List[str], PropertyInfo(alias="etopsAltAirfields")]
    """
    Array of Extended Operations (ETOPS) alternate suitable landing airfields that
    are within the mission region.
    """

    etops_rating: Annotated[str, PropertyInfo(alias="etopsRating")]
    """The Extended Operations (ETOPS) rating used to calculate this flight plan."""

    etops_val_window: Annotated[str, PropertyInfo(alias="etopsValWindow")]
    """The Extended Operations (ETOPS) validity window for the alternate airfield."""

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """The source ID of the flight plan from the generating system."""

    flight_plan_messages: Annotated[Iterable[FlightPlanMessage], PropertyInfo(alias="flightPlanMessages")]
    """
    Collection of messages associated with this flight plan indicating the severity,
    the point where the message was generated, the path (Primary, Alternate, etc.),
    and the text of the message.
    """

    flight_plan_point_groups: Annotated[Iterable[FlightPlanPointGroup], PropertyInfo(alias="flightPlanPointGroups")]
    """Collection of point groups generated for this flight plan.

    Groups include point sets for Extended Operations (ETOPS), Critical Fuel Point,
    and Equal Time Point (ETP).
    """

    flight_plan_waypoints: Annotated[Iterable[FlightPlanWaypoint], PropertyInfo(alias="flightPlanWaypoints")]
    """Collection of waypoints associated with this flight plan."""

    flight_rules: Annotated[str, PropertyInfo(alias="flightRules")]
    """The flight rules this flight plan is being filed under."""

    flight_type: Annotated[str, PropertyInfo(alias="flightType")]
    """The type of flight (MILITARY, CIVILIAN, etc)."""

    fuel_degrade: Annotated[float, PropertyInfo(alias="fuelDegrade")]
    """The fuel degrade percentage used for this mission."""

    gps_raim: Annotated[str, PropertyInfo(alias="gpsRAIM")]
    """The GPS Receiver Autonomous Integrity Monitoring (RAIM) message.

    A RAIM system assesses the integrity of the GPS signals. This system predicts
    outages for a specified geographical area. These predictions are based on the
    location, path, and scheduled GPS satellite outages.
    """

    hold_down_fuel: Annotated[float, PropertyInfo(alias="holdDownFuel")]
    """Additional fuel burned at Top of Climb in pounds."""

    hold_fuel: Annotated[float, PropertyInfo(alias="holdFuel")]
    """Additional fuel burned at the destination for holding in pounds."""

    hold_time: Annotated[str, PropertyInfo(alias="holdTime")]
    """Additional time for holding at the destination expressed as HH:MM."""

    id_aircraft: Annotated[str, PropertyInfo(alias="idAircraft")]
    """The UDL unique identifier of the aircraft associated with this flight plan."""

    id_arr_airfield: Annotated[str, PropertyInfo(alias="idArrAirfield")]
    """
    The UDL unique identifier of the arrival airfield associated with this flight
    plan.
    """

    id_dep_airfield: Annotated[str, PropertyInfo(alias="idDepAirfield")]
    """
    The UDL unique identifier of the departure airfield associated with this flight
    plan.
    """

    ident_extra_fuel: Annotated[float, PropertyInfo(alias="identExtraFuel")]
    """
    The amount of identified extra fuel carried and not available in the burn plan
    in pounds.
    """

    id_sortie: Annotated[str, PropertyInfo(alias="idSortie")]
    """
    The UDL unique identifier of the aircraft sortie associated with this flight
    plan.
    """

    initial_cruise_speed: Annotated[str, PropertyInfo(alias="initialCruiseSpeed")]
    """
    A character string representation of the initial filed cruise speed for this
    flight (prepended values of K, N, and M represent kilometers per hour, knots,
    and Mach, respectively).
    """

    initial_flight_level: Annotated[str, PropertyInfo(alias="initialFlightLevel")]
    """
    A character string representation of the initial filed altitude level for this
    flight (prepended values of F, S, A, and M represent flight level in hundreds of
    feet, standard metric level in tens of meters, altitude in hundreds of feet, and
    altitude in tens of meters, respectively).
    """

    landing_fuel: Annotated[float, PropertyInfo(alias="landingFuel")]
    """Fuel planned to be remaining on the airplane at landing in pounds."""

    leg_num: Annotated[int, PropertyInfo(alias="legNum")]
    """The leg number of this flight plan."""

    min_divert_fuel: Annotated[float, PropertyInfo(alias="minDivertFuel")]
    """The minimum fuel on board required to divert in pounds."""

    msn_index: Annotated[float, PropertyInfo(alias="msnIndex")]
    """The mission index value for this mission.

    The mission index is the ratio of time-related cost of aircraft operation to the
    cost of fuel.
    """

    notes: str
    """Additional remarks for air traffic control for this flight."""

    num_aircraft: Annotated[int, PropertyInfo(alias="numAircraft")]
    """The number of aircraft flying this flight plan."""

    op_condition_fuel: Annotated[float, PropertyInfo(alias="opConditionFuel")]
    """
    Additional fuel burned at Top of Descent for the operational condition in
    pounds.
    """

    op_weight: Annotated[float, PropertyInfo(alias="opWeight")]
    """Operating weight of the aircraft in pounds."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    originator: str
    """Air Traffic Control address filing the flight plan."""

    planner_remark: Annotated[str, PropertyInfo(alias="plannerRemark")]
    """Remarks from the planners concerning this flight plan."""

    ramp_fuel: Annotated[float, PropertyInfo(alias="rampFuel")]
    """
    Total of all fuel required to complete the flight in pounds, including fuel to
    be dispensed on a refueling mission.
    """

    rem_alternate1_fuel: Annotated[float, PropertyInfo(alias="remAlternate1Fuel")]
    """Total fuel remaining at alternate landing site 1 in pounds."""

    rem_alternate2_fuel: Annotated[float, PropertyInfo(alias="remAlternate2Fuel")]
    """Total fuel remaining at alternate landing site 2 in pounds."""

    reserve_fuel: Annotated[float, PropertyInfo(alias="reserveFuel")]
    """The amount of reserve fuel in pounds."""

    route_string: Annotated[str, PropertyInfo(alias="routeString")]
    """The 1801 fileable route of flight string for this flight.

    The route of flight string contains route designators, significant points,
    change of speed/altitude, change of flight rules, and cruise climbs.
    """

    sid: str
    """Name of the planned Standard Instrument Departure (SID) procedure."""

    star: str
    """Name of the planned Standard Terminal Arrival (STAR) procedure."""

    status: str
    """Status of this flight plan (e.g., ACTIVE, APPROVED, PLANNED, etc.)."""

    tail_number: Annotated[str, PropertyInfo(alias="tailNumber")]
    """The tail number of the aircraft associated with this flight plan."""

    takeoff_fuel: Annotated[float, PropertyInfo(alias="takeoffFuel")]
    """
    Fuel at takeoff, which is calculated as the ramp fuel minus the taxi fuel in
    pounds.
    """

    taxi_fuel: Annotated[float, PropertyInfo(alias="taxiFuel")]
    """Fuel required to start engines and taxi to the end of the runway in pounds."""

    thunder_avoid_fuel: Annotated[float, PropertyInfo(alias="thunderAvoidFuel")]
    """Additional fuel burned at Top of Descent for thunderstorm avoidance in pounds."""

    toc_fuel: Annotated[float, PropertyInfo(alias="tocFuel")]
    """Fuel remaining at Top of Climb in pounds."""

    toc_ice_fuel: Annotated[float, PropertyInfo(alias="tocIceFuel")]
    """Additional fuel burned at Top of Climb for icing in pounds."""

    tod_fuel: Annotated[float, PropertyInfo(alias="todFuel")]
    """Fuel remaining at Top of Descent in pounds."""

    tod_ice_fuel: Annotated[float, PropertyInfo(alias="todIceFuel")]
    """Additional fuel burned at Top of Descent for icing in pounds."""

    unident_extra_fuel: Annotated[float, PropertyInfo(alias="unidentExtraFuel")]
    """The amount of unidentified extra fuel required to get to min landing in pounds."""

    unusable_fuel: Annotated[float, PropertyInfo(alias="unusableFuel")]
    """The amount of unusable fuel in pounds."""

    wake_turb_cat: Annotated[str, PropertyInfo(alias="wakeTurbCat")]
    """The wake turbulence category for this flight.

    The categories are assigned by the International Civil Aviation Organization
    (ICAO) and are based on maximum certified takeoff mass for the purpose of
    separating aircraft in flight due to wake turbulence. Valid values include
    LIGHT, MEDIUM, LARGE, HEAVY, and SUPER.
    """

    wind_fac1: Annotated[float, PropertyInfo(alias="windFac1")]
    """Wind factor for the first half of the route.

    This is the average wind factor from first Top of Climb to the mid-time of the
    entire route in knots. A positive value indicates a headwind, while a negative
    value indicates a tailwind.
    """

    wind_fac2: Annotated[float, PropertyInfo(alias="windFac2")]
    """Wind factor for the second half of the route.

    This is the average wind factor from the mid-time of the entire route to last
    Top of Descent in knots. A positive value indicates a headwind, while a negative
    value indicates a tailwind.
    """

    wind_fac_avg: Annotated[float, PropertyInfo(alias="windFacAvg")]
    """Average wind factor from Top of Climb to Top of Descent in knots.

    A positive value indicates a headwind, while a negative value indicates a
    tailwind.
    """

    wx_valid_end: Annotated[Union[str, datetime], PropertyInfo(alias="wxValidEnd", format="iso8601")]
    """
    The date and time the weather valid period ends in ISO 8601 UTC format, with
    millisecond precision.
    """

    wx_valid_start: Annotated[Union[str, datetime], PropertyInfo(alias="wxValidStart", format="iso8601")]
    """
    The date and time the weather valid period begins in ISO 8601 UTC format, with
    millisecond precision.
    """


class AirRefuelEvent(TypedDict, total=False):
    ar_degrade: Annotated[float, PropertyInfo(alias="arDegrade")]
    """
    Additional degrade for air refueling, cumulative with fuelDegrade field percent.
    """

    ar_exchanged_fuel: Annotated[float, PropertyInfo(alias="arExchangedFuel")]
    """
    Fuel onloaded (use positive numbers) or fuel offloaded (use negative numbers) in
    pounds.
    """

    ar_num: Annotated[int, PropertyInfo(alias="arNum")]
    """The number of this air refueling event within the flight plan."""

    divert_fuel: Annotated[float, PropertyInfo(alias="divertFuel")]
    """
    Fuel required to fly from air refueling exit point to air refueling divert
    alternate airfield in pounds.
    """

    exit_fuel: Annotated[float, PropertyInfo(alias="exitFuel")]
    """Fuel remaining at the air refueling exit in pounds."""


class FlightPlanMessage(TypedDict, total=False):
    msg_text: Annotated[str, PropertyInfo(alias="msgText")]
    """The text of the message."""

    route_path: Annotated[str, PropertyInfo(alias="routePath")]
    """The flight path that generated the message (PRIMARY, ALTERNATE, etc.)."""

    severity: str
    """The severity of the message."""

    wp_num: Annotated[str, PropertyInfo(alias="wpNum")]
    """
    The waypoint number for which the message was generated, or enter "PLAN" for a
    message impacting the entire route.
    """


class FlightPlanPointGroupFlightPlanPoint(TypedDict, total=False):
    fpp_eta: Annotated[Union[str, datetime], PropertyInfo(alias="fppEta", format="iso8601")]
    """
    Estimated Time of Arrival (ETA) at this point in ISO 8601 UTC format, with
    millisecond precision.
    """

    fpp_lat: Annotated[float, PropertyInfo(alias="fppLat")]
    """WGS84 latitude of the point location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    fpp_lon: Annotated[float, PropertyInfo(alias="fppLon")]
    """WGS84 longitude of the point location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    fpp_req_fuel: Annotated[float, PropertyInfo(alias="fppReqFuel")]
    """
    Fuel required at this point to execute an Equal Time Point (ETP) or Extended
    Operations (ETOPS) plan in pounds.
    """

    point_name: Annotated[str, PropertyInfo(alias="pointName")]
    """Name of this point."""


class FlightPlanPointGroup(TypedDict, total=False):
    avg_fuel_flow: Annotated[float, PropertyInfo(alias="avgFuelFlow")]
    """Average fuel flow at which the fuel was calculated in pounds per hour."""

    etops_avg_wind_factor: Annotated[float, PropertyInfo(alias="etopsAvgWindFactor")]
    """
    Average wind factor from the Extended Operations (ETOPS) point to the recovery
    airfield in knots.
    """

    etops_distance: Annotated[float, PropertyInfo(alias="etopsDistance")]
    """
    Distance from the Extended Operations (ETOPS) point to the recovery airfield in
    nautical miles.
    """

    etops_req_fuel: Annotated[float, PropertyInfo(alias="etopsReqFuel")]
    """
    Fuel required to fly from the Extended Operations (ETOPS) point to the recovery
    airfield in pounds.
    """

    etops_temp_dev: Annotated[float, PropertyInfo(alias="etopsTempDev")]
    """
    Temperature deviation from the Extended Operations (ETOPS) point to the recovery
    airfield in degrees Celsius.
    """

    etops_time: Annotated[str, PropertyInfo(alias="etopsTime")]
    """
    Time to fly from the Extended Operations (ETOPS) point to the recovery airfield
    expressed in HH:MM format.
    """

    flight_plan_points: Annotated[Iterable[FlightPlanPointGroupFlightPlanPoint], PropertyInfo(alias="flightPlanPoints")]
    """Array of point data for this Point Group."""

    from_takeoff_time: Annotated[str, PropertyInfo(alias="fromTakeoffTime")]
    """Total time from takeoff when the point is reached expressed in HH:MM format."""

    fsaf_avg_wind_factor: Annotated[float, PropertyInfo(alias="fsafAvgWindFactor")]
    """
    Average wind factor from the Equal Time Point (ETP) to the first suitable
    airfield in knots.
    """

    fsaf_distance: Annotated[float, PropertyInfo(alias="fsafDistance")]
    """
    Distance from the Equal Time Point (ETP) to the first suitable airfield in
    nautical miles.
    """

    fsaf_req_fuel: Annotated[float, PropertyInfo(alias="fsafReqFuel")]
    """
    Fuel required to fly from the Equal Time Point (ETP) to the first suitable
    airfield in pounds.
    """

    fsaf_temp_dev: Annotated[float, PropertyInfo(alias="fsafTempDev")]
    """
    Temperature deviation from the Equal Time Point (ETP) to the first suitable
    airfield in degrees Celsius.
    """

    fsaf_time: Annotated[str, PropertyInfo(alias="fsafTime")]
    """
    Time to fly from the Equal Time Point (ETP) to the first suitable airfield
    expressed in HH:MM format.
    """

    fuel_calc_alt: Annotated[float, PropertyInfo(alias="fuelCalcAlt")]
    """Flight level of the point at which the fuel was calculated in feet."""

    fuel_calc_spd: Annotated[float, PropertyInfo(alias="fuelCalcSpd")]
    """True airspeed at which the fuel was calculated in knots."""

    lsaf_avg_wind_factor: Annotated[float, PropertyInfo(alias="lsafAvgWindFactor")]
    """
    Average wind factor from the Equal Time Point (ETP) to the last suitable
    airfield in knots.
    """

    lsaf_distance: Annotated[float, PropertyInfo(alias="lsafDistance")]
    """
    Distance from the Equal Time Point (ETP) to the last suitable airfield in
    nautical miles.
    """

    lsaf_name: Annotated[str, PropertyInfo(alias="lsafName")]
    """
    Name of the last suitable airfield, International Civil Aviation Organization
    (ICAO) code preferred.
    """

    lsaf_req_fuel: Annotated[float, PropertyInfo(alias="lsafReqFuel")]
    """
    Fuel required to fly from the Equal Time Point (ETP) to the last suitable
    airfield in pounds.
    """

    lsaf_temp_dev: Annotated[float, PropertyInfo(alias="lsafTempDev")]
    """
    Temperature deviation from the Equal Time Point (ETP) to the last suitable
    airfield in degrees Celsius.
    """

    lsaf_time: Annotated[str, PropertyInfo(alias="lsafTime")]
    """
    Time to fly from the Equal Time Point (ETP) to the last suitable airfield
    expressed in HH:MM format.
    """

    planned_fuel: Annotated[float, PropertyInfo(alias="plannedFuel")]
    """Amount of planned fuel on board when the point is reached in pounds."""

    point_group_name: Annotated[str, PropertyInfo(alias="pointGroupName")]
    """
    Name of the point group, usually Extended Operations (ETOPS), Critical Fuel
    Point, and Equal Time Point (ETP) sections.
    """

    worst_fuel_case: Annotated[str, PropertyInfo(alias="worstFuelCase")]
    """Specifies which Point Group case requires the most fuel."""


class FlightPlanWaypoint(TypedDict, total=False):
    type: Required[str]
    """Points are designated by type as either a comment point or a waypoint.

    A comment point conveys important information about the point for pilots but is
    not entered into a flight management system. A waypoint is a point that is
    entered into a flight management system and/or filed with Air Traffic Control.
    """

    waypoint_name: Required[Annotated[str, PropertyInfo(alias="waypointName")]]
    """Name of the point.

    The name of a comment point identifies important information about that point,
    e.g. Top of Climb. The name of a waypoint identifies the location of that point.
    """

    aa_tacan_channel: Annotated[str, PropertyInfo(alias="aaTacanChannel")]
    """
    The air-to-air Tactical Air Navigation (TACAN) channels used by the
    receiver/tanker during air refueling.
    """

    air_distance: Annotated[float, PropertyInfo(alias="airDistance")]
    """The air distance of this leg in nautical miles."""

    airway: str
    """The flight path flown for this leg."""

    alt: float
    """Altitude of a level, point, or object measured in feet above mean sea level."""

    ar_id: Annotated[str, PropertyInfo(alias="arId")]
    """The ID of the air refueling track/anchor or fixed track."""

    arpt: str
    """Point identifying an air refueling track/anchor or fixed track."""

    ata: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """
    Actual Time of Arrival (ATA) at this waypoint in ISO 8601 UTC format, with
    millisecond precision.
    """

    avg_cal_airspeed: Annotated[float, PropertyInfo(alias="avgCalAirspeed")]
    """The average calibrated airspeed (CAS) for this leg in knots."""

    avg_drift_ang: Annotated[float, PropertyInfo(alias="avgDriftAng")]
    """The average drift angle for this leg in degrees from true north."""

    avg_ground_speed: Annotated[float, PropertyInfo(alias="avgGroundSpeed")]
    """The average ground speed for this leg in knots."""

    avg_true_airspeed: Annotated[float, PropertyInfo(alias="avgTrueAirspeed")]
    """The average true airspeed (TAS) for this leg in knots."""

    avg_wind_dir: Annotated[float, PropertyInfo(alias="avgWindDir")]
    """The average wind direction for this leg in degrees from true north."""

    avg_wind_speed: Annotated[float, PropertyInfo(alias="avgWindSpeed")]
    """The average wind speed for this leg in knots."""

    day_low_alt: Annotated[float, PropertyInfo(alias="dayLowAlt")]
    """
    The day low level altitude in feet above sea level for the leg ending at this
    waypoint.
    """

    eta: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """
    Estimated Time of Arrival (ETA) at this waypoint in ISO 8601 UTC format, with
    millisecond precision.
    """

    exchanged_fuel: Annotated[float, PropertyInfo(alias="exchangedFuel")]
    """
    The amount of fuel onloaded or offloaded at this waypoint in pounds (negative
    value for offload).
    """

    fuel_flow: Annotated[float, PropertyInfo(alias="fuelFlow")]
    """The leg fuel flow in pounds per hour."""

    ice_cat: Annotated[str, PropertyInfo(alias="iceCat")]
    """The icing intensity classification for this flight (LIGHT, MODERATE, etc)."""

    lat: float
    """WGS84 latitude of the point location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    leg_alternate: Annotated[str, PropertyInfo(alias="legAlternate")]
    """
    The planned alternate leg based on user-defined constraints, International Civil
    Aviation Organization (ICAO) code preferred.
    """

    leg_drag_index: Annotated[float, PropertyInfo(alias="legDragIndex")]
    """The percent degrade due to drag for this aircraft for this leg."""

    leg_fuel_degrade: Annotated[float, PropertyInfo(alias="legFuelDegrade")]
    """The fuel degrade percentage used for this leg."""

    leg_mach: Annotated[float, PropertyInfo(alias="legMach")]
    """The average Mach speed for this leg."""

    leg_msn_index: Annotated[float, PropertyInfo(alias="legMsnIndex")]
    """The mission index value for this leg.

    The mission index is the ratio of time-related cost of aircraft operation to the
    cost of fuel.
    """

    leg_wind_fac: Annotated[float, PropertyInfo(alias="legWindFac")]
    """The wind factor for this leg in knots.

    A positive value indicates a headwind, while a negative value indicates a
    tailwind.
    """

    lon: float
    """WGS84 longitude of the point location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    mag_course: Annotated[float, PropertyInfo(alias="magCourse")]
    """The magnetic course at leg midpoint in degrees from true north."""

    mag_heading: Annotated[float, PropertyInfo(alias="magHeading")]
    """The magnetic heading at leg midpoint in degrees from true north."""

    mag_var: Annotated[float, PropertyInfo(alias="magVar")]
    """The magnetic variation for this leg in degrees."""

    navaid: str
    """Navigational Aid (NAVAID) identification code."""

    night_low_alt: Annotated[float, PropertyInfo(alias="nightLowAlt")]
    """
    The night low level altitude in feet above sea level for the leg ending at this
    waypoint.
    """

    nvg_low_alt: Annotated[float, PropertyInfo(alias="nvgLowAlt")]
    """
    The night vision goggle low level altitude in feet above sea level for the leg
    ending at this waypoint.
    """

    point_wind_dir: Annotated[float, PropertyInfo(alias="pointWindDir")]
    """The wind direction at this specific point in degrees from true north."""

    point_wind_speed: Annotated[float, PropertyInfo(alias="pointWindSpeed")]
    """The wind velocity at this specific point in knots."""

    pri_freq: Annotated[float, PropertyInfo(alias="priFreq")]
    """
    The primary UHF radio frequency used for the air refueling track or anchor in
    megahertz.
    """

    sec_freq: Annotated[float, PropertyInfo(alias="secFreq")]
    """
    The secondary UHF radio frequency used for the air refueling track or anchor in
    megahertz.
    """

    tacan_channel: Annotated[str, PropertyInfo(alias="tacanChannel")]
    """Tactical Air Navigation (TACAN) channel for the Navigational Aid (NAVAID)."""

    temp_dev: Annotated[float, PropertyInfo(alias="tempDev")]
    """
    Average temperature deviation from standard day profile for this leg in degrees
    Celsius.
    """

    thunder_cat: Annotated[str, PropertyInfo(alias="thunderCat")]
    """
    The thunderstorm intensity classification for this flight (LIGHT, MODERATE,
    etc).
    """

    total_air_distance: Annotated[float, PropertyInfo(alias="totalAirDistance")]
    """The total air distance to this waypoint in nautical miles."""

    total_flown_distance: Annotated[float, PropertyInfo(alias="totalFlownDistance")]
    """
    The total distance flown to this waypoint calculated from point of departure in
    nautical miles.
    """

    total_rem_distance: Annotated[float, PropertyInfo(alias="totalRemDistance")]
    """
    The total distance remaining from this waypoint to the point of arrival in
    nautical miles.
    """

    total_rem_fuel: Annotated[float, PropertyInfo(alias="totalRemFuel")]
    """The total fuel remaining at this waypoint in pounds."""

    total_time: Annotated[str, PropertyInfo(alias="totalTime")]
    """The total time accumulated from takeoff to this waypoint expressed as HH:MM."""

    total_time_rem: Annotated[str, PropertyInfo(alias="totalTimeRem")]
    """
    The total time remaining from this waypoint to the point of arrival expressed as
    HH:MM.
    """

    total_used_fuel: Annotated[float, PropertyInfo(alias="totalUsedFuel")]
    """The total fuel used to this waypoint from point of departure in pounds."""

    total_weight: Annotated[float, PropertyInfo(alias="totalWeight")]
    """The total weight of the aircraft at this waypoint in pounds."""

    true_course: Annotated[float, PropertyInfo(alias="trueCourse")]
    """The true course at leg midpoint in degrees from true north."""

    turb_cat: Annotated[str, PropertyInfo(alias="turbCat")]
    """The turbulence intensity classification for this flight (LIGHT, MODERATE, etc)."""

    vor_freq: Annotated[float, PropertyInfo(alias="vorFreq")]
    """
    VHF Omni-directional Range (VOR) frequency for the Navigational Aid (NAVAID) in
    megahertz.
    """

    waypoint_num: Annotated[int, PropertyInfo(alias="waypointNum")]
    """The waypoint number on the route. Comment points do not get a waypoint number."""

    zone_distance: Annotated[float, PropertyInfo(alias="zoneDistance")]
    """The zone/leg distance flown in nautical miles."""

    zone_fuel: Annotated[float, PropertyInfo(alias="zoneFuel")]
    """The amount of fuel used on this zone/leg in pounds."""

    zone_time: Annotated[float, PropertyInfo(alias="zoneTime")]
    """The time to fly this zone/leg in minutes."""
