# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["GeostatusCreateBulkParams", "Body"]


class GeostatusCreateBulkParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    confidence_level: Annotated[str, PropertyInfo(alias="confidenceLevel")]
    """Indicates the confidence level in the entry. (Low, Medium, High)."""

    longitude_max: Annotated[float, PropertyInfo(alias="longitudeMax")]
    """Maximum longitude for this object.

    WGS-84 longitude of the spacecraft position, in degrees. 0 to 360 degrees.
    """

    longitude_min: Annotated[float, PropertyInfo(alias="longitudeMin")]
    """Minimum longitude for this object.

    WGS-84 longitude of the spacecraft position, in degrees. 0 to 360 degrees.
    """

    longitude_rate: Annotated[float, PropertyInfo(alias="longitudeRate")]
    """
    Corrective or overriding long term trend for longitudinal change in degrees/day.
    """

    lost_flag: Annotated[bool, PropertyInfo(alias="lostFlag")]
    """Lost space object indicator. (True or False)."""

    object_status: Annotated[str, PropertyInfo(alias="objectStatus")]
    """Space object status. (Active, Dead, Unknown)."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Annotated[str, PropertyInfo(alias="origObjectId")]
    """Optional identifier provided to indicate the target onorbit.

    This may be an internal identifier and not necessarily map to a valid satellite
    number.
    """

    plane_change_status: Annotated[str, PropertyInfo(alias="planeChangeStatus")]
    """Geosynchronous plane changing status. (Current, Never, Former, Future)."""

    raw_file_uri: Annotated[str, PropertyInfo(alias="rawFileURI")]
    """
    Optional URI location in the document repository of the raw file parsed by the
    system to produce this record. To download the raw file, prepend
    https://udl-hostname/scs/download?id= to this value.
    """

    relative_energy: Annotated[float, PropertyInfo(alias="relativeEnergy")]
    """Objects displacement from geostationary orbit in deg^2/day^2."""

    sat_no: Annotated[int, PropertyInfo(alias="satNo")]
    """Satellite/catalog number of the target on-orbit object."""

    sc: float
    """Sine of inclination times the cosine of right ascension."""

    semi_annual_corr_flag: Annotated[bool, PropertyInfo(alias="semiAnnualCorrFlag")]
    """Semi-annual correction. (True or False)."""

    ss: float
    """Sine of inclination times the sine of right ascension."""

    trough_type: Annotated[str, PropertyInfo(alias="troughType")]
    """Indicates the trough (gravity well) or drift direction of a space object:

    255 - Influenced by 255° longitude trough.

    75 - Influenced by 75° longitude trough.

    Both - Oscillating between both 255 and 75 troughs.

    East - Drifting eastward; large relative energy and a period less than 1436.1
    minutes.

    West - Drifting westward; large relative energy and a period greater than 1436.2
    minutes.
    """
