# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["GeostatusListResponse", "GeostatusListResponseItem"]


class GeostatusListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    confidence_level: Optional[str] = FieldInfo(alias="confidenceLevel", default=None)
    """Indicates the confidence level in the entry. (Low, Medium, High)."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the object on-orbit object."""

    longitude_max: Optional[float] = FieldInfo(alias="longitudeMax", default=None)
    """Maximum longitude for this object.

    WGS-84 longitude of the spacecraft position, in degrees. 0 to 360 degrees.
    """

    longitude_min: Optional[float] = FieldInfo(alias="longitudeMin", default=None)
    """Minimum longitude for this object.

    WGS-84 longitude of the spacecraft position, in degrees. 0 to 360 degrees.
    """

    longitude_rate: Optional[float] = FieldInfo(alias="longitudeRate", default=None)
    """
    Corrective or overriding long term trend for longitudinal change in degrees/day.
    """

    lost_flag: Optional[bool] = FieldInfo(alias="lostFlag", default=None)
    """Lost space object indicator. (True or False)."""

    object_status: Optional[str] = FieldInfo(alias="objectStatus", default=None)
    """Space object status. (Active, Dead, Unknown)."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """Optional identifier provided to indicate the target onorbit.

    This may be an internal identifier and not necessarily map to a valid satellite
    number.
    """

    plane_change_status: Optional[str] = FieldInfo(alias="planeChangeStatus", default=None)
    """Geosynchronous plane changing status. (Current, Never, Former, Future)."""

    raw_file_uri: Optional[str] = FieldInfo(alias="rawFileURI", default=None)
    """
    Optional URI location in the document repository of the raw file parsed by the
    system to produce this record. To download the raw file, prepend
    https://udl-hostname/scs/download?id= to this value.
    """

    relative_energy: Optional[float] = FieldInfo(alias="relativeEnergy", default=None)
    """Objects displacement from geostationary orbit in deg^2/day^2."""

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/catalog number of the target on-orbit object."""

    sc: Optional[float] = None
    """Sine of inclination times the cosine of right ascension."""

    semi_annual_corr_flag: Optional[bool] = FieldInfo(alias="semiAnnualCorrFlag", default=None)
    """Semi-annual correction. (True or False)."""

    ss: Optional[float] = None
    """Sine of inclination times the sine of right ascension."""

    trough_type: Optional[str] = FieldInfo(alias="troughType", default=None)
    """Indicates the trough (gravity well) or drift direction of a space object:

    255 - Influenced by 255° longitude trough.

    75 - Influenced by 75° longitude trough.

    Both - Oscillating between both 255 and 75 troughs.

    East - Drifting eastward; large relative energy and a period less than 1436.1
    minutes.

    West - Drifting westward; large relative energy and a period greater than 1436.2
    minutes.
    """


GeostatusListResponse: TypeAlias = List[GeostatusListResponseItem]
