# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["GnssobservationsetCreateBulkParams", "Body", "BodyGnssObservationList"]


class GnssobservationsetCreateBulkParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class BodyGnssObservationList(TypedDict, total=False):
    agc_state: Annotated[int, PropertyInfo(alias="agcState")]
    """GNSS Automatic Gain Control State."""

    gnss_sat_id: Annotated[str, PropertyInfo(alias="gnssSatId")]
    """
    RINEX 3+ compliant GNSS System and Satellite Identifier (represented as SNN,
    where S is the system code, and NN is the satellite identifier) associated with
    this observation:

    G - GPS (NN = PRN)

    R - GLONASS (NN = Slot Number)

    S - SBAS Payload (NN = PRN-100)

    E - Galileo (NN = PRN)

    C - BeiDou (NN = PRN)

    J - QZSS (NN = PRN - 1923)

    I - IRNSS (NN = PRN)
    """

    ob: Iterable[float]
    """Array of observation(s).

    The ob array must be the same length as the obsCodeSet. Pseudorange (C) is
    expressed meters, carrier phase (L) in cycles, doppler (D) in Hz where + values
    indicate approaching sats, and signal strength C/No (S) in dB-Hz.
    """

    obs_code_set: Annotated[List[str], PropertyInfo(alias="obsCodeSet")]
    """The observation code set that applies to this observation record.

    Reference RINEX 3+ for further information concerning observation code set
    conventions.
    """

    tracking_status: Annotated[int, PropertyInfo(alias="trackingStatus")]
    """Status of the GNSS receiver signal.

    Status options are 0, 1 or 2 (0 being the best).
    """


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: Required[str]
    """Source of the data."""

    ts: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """Observation Time, in ISO8601 UTC format with microsecond precision.

    This timestamp applies to all observations within the set.
    """

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    agc_state: Annotated[int, PropertyInfo(alias="agcState")]
    """GNSS Automatic Gain Control State."""

    alt: float
    """
    Spacecraft altitude at observation time (ts), expressed in kilometers above
    WGS-84 ellipsoid.
    """

    boresight: Iterable[float]
    """
    unit vector of the outward facing direction of the receiver boresight in a
    body-fixed coordinate system.
    """

    es_id: Annotated[str, PropertyInfo(alias="esId")]
    """
    Unique identifier of the parent Ephemeris Set, if this data is correlated with
    an Ephemeris. If reporting for a spacecraft with multiple onboard GNSS
    receivers, this ID may be associated with multiple GNSS Observation records if
    each receiver is synced to the ephemeris points.
    """

    event_id: Annotated[str, PropertyInfo(alias="eventId")]
    """Optional source-provided identifier for this collection event.

    This field can be used to associate records related to the same event.
    """

    g_dop: Annotated[float, PropertyInfo(alias="gDop")]
    """Geometric Dilution of Precision."""

    gnss_observation_list: Annotated[Iterable[BodyGnssObservationList], PropertyInfo(alias="gnssObservationList")]
    """GNSSObservations associated with this GNSSObservationSet."""

    h_dop: Annotated[float, PropertyInfo(alias="hDop")]
    """Horizontal Dilution of Precision."""

    lat: float
    """
    WGS-84 spacecraft latitude sub-point at observation time (ts), represented as
    -90 to 90 degrees (negative values south of equator).
    """

    lon: float
    """
    WGS-84 spacecraft longitude sub-point at observation time (ts), represented as
    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    marker_type: Annotated[str, PropertyInfo(alias="markerType")]
    """
    The marker type of the observing receiver (AIRBORNE, ANIMAL, BALLISTIC, FIXED
    BUOY, FLOATING BUOY, FLOATING ICE, GEODETIC, GLACIER, GROUNDCRAFT, HUMAN, NON
    GEODETIC, NON PHYSICAL, SPACEBORNE, WATERCRAFT). Reference RINEX 3+ for further
    information concerning marker types.
    """

    navigation_status: Annotated[str, PropertyInfo(alias="navigationStatus")]
    """The current navigation status as defined by the data source.

    In general the navigation status specifies whether the signal is normal,
    degraded, or unavailable. For status value definitions please reach out to data
    source provider.
    """

    obs_codes: Annotated[List[str], PropertyInfo(alias="obsCodes")]
    """
    Array of the strings containing the individual observation code sets that are
    contained within this GNSS Observation set. Each string is a three-character
    representation of the measurement type, the channel, and the coding, in
    compliance with the RINEX 3+ standard (Pseudorange (C), Carrier Phase (L),
    Doppler (D), Signal Strength C/No (S), or Channel Number (X)). See the GNSS
    Observation ob field for the units of measure associated with each observation
    type.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Annotated[str, PropertyInfo(alias="origObjectId")]
    """
    Optional identifier provided by ephemeris source to indicate the target object
    of this ephemeris. This may be an internal identifier and not necessarily map to
    a valid satellite number.
    """

    outage: int
    """Time, in seconds, that the receiver has been unable to compute a GNSS fix."""

    p_dop: Annotated[float, PropertyInfo(alias="pDop")]
    """Position Dilution of Precision."""

    quat: Iterable[float]
    """
    The quaternion describing the rotation of the body-fixed frame used for this
    system into the local geodetic frame, at observation time (ts). The array
    element order convention is scalar component first, followed by the three vector
    components. For a vector u in the body-fixed frame, the corresponding vector u'
    in the geodetic frame should satisfy u' = quq\\**, where q is this quaternion.
    """

    receiver: str
    """The number or ID of the GNSS receiver associated with this data.

    Each GNSS Observation Set is associated with only one receiver. If reporting for
    multiple receivers a separate set should be generated for each. A null value is
    assumed to indicate that only one receiver is present, or reported.
    """

    sat_no: Annotated[int, PropertyInfo(alias="satNo")]
    """Satellite/catalog number of the target on-orbit object."""

    sat_position: Annotated[Iterable[float], PropertyInfo(alias="satPosition")]
    """
    Three element array, expressing the ECI J2K spacecraft position components, in
    kilometers, at observation time (ts). The array element order is [x, y, z].
    """

    sat_velocity: Annotated[Iterable[float], PropertyInfo(alias="satVelocity")]
    """
    Three element array, expressing the ECI J2K spacecraft velocity components, in
    km/second, at observation time (ts). The array element order is [xvel, yvel,
    zvel].
    """

    src_ids: Annotated[List[str], PropertyInfo(alias="srcIds")]
    """
    Array of UUIDs of the UDL data records that are related to this GNSS Observation
    Set. See the associated 'srcTyps' array for the specific types of data,
    positionally corresponding to the UUIDs in this array. The 'srcTyps' and
    'srcIds' arrays must match in size. See the corresponding srcTyps array element
    for the data type of the UUID and use the appropriate API operation to retrieve
    that object (e.g. /udl/statevector/{uuid}).
    """

    src_typs: Annotated[List[str], PropertyInfo(alias="srcTyps")]
    """
    Array of UDL record types (AIS, CONJUNCTION, DOA, ELSET, EO, ESID, GROUNDIMAGE,
    POI, MANEUVER, MTI, NOTIFICATION, RADAR, RF, SIGACT, SKYIMAGE, SV, TRACK) that
    are related to this GNSS Observation Set. See the associated 'srcIds' array for
    the record UUIDs, positionally corresponding to the record types in this array.
    The 'srcTyps' and 'srcIds' arrays must match in size.
    """

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    t_dop: Annotated[float, PropertyInfo(alias="tDop")]
    """Time Dilution of Precision."""

    tracking_status: Annotated[int, PropertyInfo(alias="trackingStatus")]
    """Status of the GNSS receiver signal.

    Status options are 0, 1 or 2 (0 being the best).
    """

    transaction_id: Annotated[str, PropertyInfo(alias="transactionId")]
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    v_dop: Annotated[float, PropertyInfo(alias="vDop")]
    """Vertical Dilution of Precision."""
