# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["GnssrawifListResponse", "GnssrawifListResponseItem"]


class GnssrawifListResponseItem(BaseModel):
    center_freq: List[float] = FieldInfo(alias="centerFreq")
    """The center frequency, in MHz, of the observation bands.

    More than one band may be reported in each binary file, so this is an array of
    the center frequency of each band (including an array of length 1 if only one
    band is present).
    """

    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    end_time: datetime = FieldInfo(alias="endTime")
    """
    End time of the data contained in the associated binary file, in ISO 8601 UTC
    format with microsecond precision.
    """

    file_name: str = FieldInfo(alias="fileName")
    """The file name of the Raw IF Binary file.

    The files should be in the Hierarchical Data Format (HDF5).
    """

    source: str
    """Source of the data."""

    start_time: datetime = FieldInfo(alias="startTime")
    """
    Start time of the data contained in the associated binary file, in ISO 8601 UTC
    format with microsecond precision.
    """

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    bit_depth: Optional[int] = FieldInfo(alias="bitDepth", default=None)
    """
    The number of bits in each datum, for example 2 for 2-bit integers or 8 for
    8-bit integers.
    """

    boresight: Optional[List[float]] = None
    """
    Unit vector of the outward facing direction of the receiver boresight in a
    body-fixed coordinate system.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    data_rate: Optional[float] = FieldInfo(alias="dataRate", default=None)
    """The amount of data generated per unit time, expressed in Megabytes/minute."""

    diff_code_bias: Optional[List[float]] = FieldInfo(alias="diffCodeBias", default=None)
    """
    Differential Code Biases (DCBs) are the systematic errors, or biases, between
    two GNSS code observations at the same or different frequencies. If applicable,
    this field should contain an array of DBC with length equal to the number of
    frequencies in the binary file. The reference frequency should show DCB equal
    to 0. If null, it is assumed that there is no DCB (all values are 0).
    """

    end_alt: Optional[float] = FieldInfo(alias="endAlt", default=None)
    """
    Spacecraft altitude at end time (endTime), expressed in kilometers above WGS-84
    ellipsoid.
    """

    end_lat: Optional[float] = FieldInfo(alias="endLat", default=None)
    """
    WGS-84 spacecraft latitude sub-point at end time (endTime), represented as -90
    to 90 degrees (negative values south of equator).
    """

    end_lon: Optional[float] = FieldInfo(alias="endLon", default=None)
    """
    WGS-84 spacecraft longitude sub-point at end time (endTime), represented as -180
    to 180 degrees (negative values west of Prime Meridian).
    """

    es_id: Optional[str] = FieldInfo(alias="esId", default=None)
    """
    Unique identifier of the parent Ephemeris Set, if this data is correlated with
    an Ephemeris. If reporting for a spacecraft with multiple onboard GNSS
    receivers, this ID may be associated with multiple GNSS Raw IF records if each
    receiver is synced to the ephemeris points.
    """

    event_id: Optional[str] = FieldInfo(alias="eventId", default=None)
    """Optional source-provided identifier for this collection event.

    This field can be used to associate records related to the same event.
    """

    file_size: Optional[int] = FieldInfo(alias="fileSize", default=None)
    """The binary file size, in bytes, auto-populated by the system.

    The maximum file size for this service is 5,000,000 Bytes (5 MB). Files
    exceeding the maximum size will be rejected.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the primary satellite on-orbit object."""

    if_freq: Optional[List[float]] = FieldInfo(alias="ifFreq", default=None)
    """The center frequency, in MHz, after downconversion to intermediate frequency.

    If provided, this array should have the same length as centerFreqs.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by the data source to indicate the target object of
    this record. This may be an internal identifier and not necessarily map to a
    valid satellite number.
    """

    post_fourier: Optional[List[str]] = FieldInfo(alias="postFourier", default=None)
    """
    After converting the raw data in the file, to generate (frequency-space) spectra
    some sets require an additional transformation or correction based on details of
    the hardware that recorded it. This field marks any such transformations.
    Currently supported options are NONE (no correction) and MIRRORED (frequency
    axis is flipped around the corresponding value of ifFreq). If null, it is
    assumed that NONE applies to all frequency bands.
    """

    quat: Optional[List[float]] = None
    """
    The quaternion describing the rotation of the body-fixed frame used for this
    system into the local geodetic frame, at the sample start time (startTime). The
    array element order convention is scalar component first, followed by the three
    vector components. For a vector u in the body-fixed frame, the corresponding
    vector u' in the geodetic frame should satisfy u' = quq\\**, where q is this
    quaternion. The quaternion should be normalized to 1.
    """

    receiver: Optional[str] = None
    """The number or ID of the GNSS receiver associated with this data.

    If reporting for multiple receivers a separate record should be generated for
    each. If null, it is assumed to indicate that only one receiver is present, or
    reported.
    """

    sample_rate: Optional[List[int]] = FieldInfo(alias="sampleRate", default=None)
    """The number of samples taken per second."""

    sample_type: Optional[str] = FieldInfo(alias="sampleType", default=None)
    """The sample type associated with the IF data.

    REAL for data with only an I-component or COMPLEX for data with both I & Q
    components.
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/catalog number of the target on-orbit object."""

    sequence_id: Optional[int] = FieldInfo(alias="sequenceID", default=None)
    """The sequence number of a raw IF record/file within a set.

    Sequence number should start at 1. If null, then it is assumed that the order of
    records within a raw IF set is not relevant.
    """

    set_id: Optional[str] = FieldInfo(alias="setId", default=None)
    """User-defined ID of a set or sequence of records/files.

    Used to associate a set of related raw IF records.
    """

    set_length: Optional[int] = FieldInfo(alias="setLength", default=None)
    """The number of raw IF records/files in a set."""

    src_ids: Optional[List[str]] = FieldInfo(alias="srcIds", default=None)
    """Array of UUIDs of the UDL data records associated with this GNSSRawIF record.

    See the associated 'srcTyps' array for the specific types of data, positionally
    corresponding to the UUIDs in this array. The 'srcTyps' and 'srcIds' arrays must
    match in size. See the corresponding srcTyps array element for the data type of
    the UUID and use the appropriate API operation to retrieve that object (e.g.
    /udl/gnssobservationset/{uuid}).
    """

    src_typs: Optional[List[str]] = FieldInfo(alias="srcTyps", default=None)
    """Array of UDL record types (GNSSSET) associated with this GNSSRawIF record.

    See the associated 'srcIds' array for the record UUIDs, positionally
    corresponding to the record types in this array. The 'srcTyps' and 'srcIds'
    arrays must match in size.
    """

    start_alt: Optional[float] = FieldInfo(alias="startAlt", default=None)
    """
    Spacecraft altitude at start time (startTime), expressed in kilometers above
    WGS-84 ellipsoid.
    """

    start_index: Optional[int] = FieldInfo(alias="startIndex", default=None)
    """
    The index of the sample within the associated binary file that corresponds to
    the startTime indicated in this record. This is especially useful on high
    sample-rate sensors when some samples are less than one microsecond before the
    value of startTime. This index is 0-based. If null, the startIndex is assumed to
    be 0.
    """

    start_lat: Optional[float] = FieldInfo(alias="startLat", default=None)
    """
    WGS-84 spacecraft latitude sub-point at start time (startTime), represented as
    -90 to 90 degrees (negative values south of equator).
    """

    start_lon: Optional[float] = FieldInfo(alias="startLon", default=None)
    """
    WGS-84 spacecraft longitude sub-point at start time (startTime), represented as
    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """


GnssrawifListResponse: TypeAlias = List[GnssrawifListResponseItem]
