# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["GroundimageryCreateParams"]


class GroundimageryCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    filename: Required[str]
    """Name of the image file."""

    image_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="imageTime", format="iso8601")]]
    """Timestamp the image was captured/produced."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    checksum_value: Annotated[str, PropertyInfo(alias="checksumValue")]
    """MD5 value of the file.

    The ingest/create operation will automatically generate the value.
    """

    filesize: int
    """Size of the image file.

    Units in bytes. If filesize is provided without an associated file, it defaults
    to 0.
    """

    format: str
    """Optional, field indicating type of image, NITF, PNG, etc."""

    id_sensor: Annotated[str, PropertyInfo(alias="idSensor")]
    """Optional ID of the sensor that produced this ground image."""

    keywords: List[str]
    """Optional array of keywords for this image."""

    name: str
    """Optional name/description associated with this image."""

    notes: str
    """Description and notes of the image."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_sensor_id: Annotated[str, PropertyInfo(alias="origSensorId")]
    """
    Optional identifier provided by source to indicate the sensor identifier used to
    detect this event. This may be an internal identifier and not necessarily a
    valid sensor ID.
    """

    region: str
    """
    Geographical region or polygon (lon/lat pairs) of the image as projected on the
    ground in geoJSON or geoText format. This is an optional convenience field only
    used for create operations. The system will auto-detect the format (Well Known
    Text or GeoJSON) and populate both regionText and regionGeoJSON fields
    appropriately. When omitted, regionText or regionGeoJSON is expected.
    """

    region_geo_json: Annotated[str, PropertyInfo(alias="regionGeoJSON")]
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. Reference: https://geojson.org/. Ignored if included with a create
    operation that also specifies a valid region or regionText.
    """

    region_n_dims: Annotated[int, PropertyInfo(alias="regionNDims")]
    """Number of dimensions of the geometry depicted by region."""

    region_s_rid: Annotated[int, PropertyInfo(alias="regionSRid")]
    """Geographical spatial_ref_sys for region."""

    region_text: Annotated[str, PropertyInfo(alias="regionText")]
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a create operation that also specifies a valid region.
    """

    region_type: Annotated[str, PropertyInfo(alias="regionType")]
    """Type of region as projected on the ground."""

    subject_id: Annotated[str, PropertyInfo(alias="subjectId")]
    """
    Optional identifier of the subject/target of the image, useful for correlating
    multiple images of the same subject.
    """

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    transaction_id: Annotated[str, PropertyInfo(alias="transactionId")]
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """
