# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["H3geoListResponse", "H3geoListResponseItem"]


class H3geoListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    num_cells: int = FieldInfo(alias="numCells")
    """The number of cells associated with this H3 Geo data set.

    At this time, UDL supports up to 50,000 cells.
    """

    source: str
    """Source of the data."""

    start_time: datetime = FieldInfo(alias="startTime")
    """Start time for this H3 Geo data set in ISO 8601 UTC with millisecond precision."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    center_freq: Optional[float] = FieldInfo(alias="centerFreq", default=None)
    """The center frequency of this H3 Geo data set measured in megahertz."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    end_time: Optional[datetime] = FieldInfo(alias="endTime", default=None)
    """End time for this H3 Geo data set in ISO 8601 UTC with millisecond precision."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    resolution: Optional[int] = None
    """H3 resolution (0 – 15) for the data set.

    At this time, UDL supports a resolution of 3 or less.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    type: Optional[str] = None
    """
    An optional field containing the type of data that is represented by this H3 Geo
    data set.
    """


H3geoListResponse: TypeAlias = List[H3geoListResponseItem]
