# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["H3geohexcellTupleResponse", "H3geohexcellTupleResponseItem"]


class H3geohexcellTupleResponseItem(BaseModel):
    cell_id: str = FieldInfo(alias="cellId")
    """The H3 index represented as a 16 character hexadecimal string."""

    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    alt_mean: Optional[float] = FieldInfo(alias="altMean", default=None)
    """
    The mean altitude of the set of observations within this cell, measured in
    kilometers.
    """

    alt_sigma: Optional[float] = FieldInfo(alias="altSigma", default=None)
    """
    The standard deviation of alttitude in the set of observations within this cell,
    measured in kilometers.
    """

    anom_score_interference: Optional[float] = FieldInfo(alias="anomScoreInterference", default=None)
    """
    The anomaly score for probable manufactured interference or RF interference;
    calculated as a ratio of #anomalous obs / #total obs or coverage.
    """

    anom_score_spoofing: Optional[float] = FieldInfo(alias="anomScoreSpoofing", default=None)
    """
    The anomaly score for probable spoofing; calculated as a ratio of #anomalous obs
    / #total obs or coverage.
    """

    change_score: Optional[float] = FieldInfo(alias="changeScore", default=None)
    """
    The percentage degree of change in the aggregated observables for a particular
    H3 bin.
    """

    coverage: Optional[int] = None
    """
    The total number of available observations in the H3 cell during the start/end
    times.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_h3_geo: Optional[str] = FieldInfo(alias="idH3Geo", default=None)
    """Unique identifier of the parent H3 Geo record containing this hex cell."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    rpm_max: Optional[float] = FieldInfo(alias="rpmMax", default=None)
    """
    The max received power monitor (RPM) output value for the set of data contained
    within this cell.
    """

    rpm_mean: Optional[float] = FieldInfo(alias="rpmMean", default=None)
    """
    The mean received power monitor (RPM) output value for the set of data contained
    within this cell.
    """

    rpm_median: Optional[float] = FieldInfo(alias="rpmMedian", default=None)
    """
    The median received power monitor (RPM) output value for the set of data
    contained within this cell.
    """

    rpm_min: Optional[float] = FieldInfo(alias="rpmMin", default=None)
    """
    The min received power monitor (RPM) output value for the set of data contained
    within this cell.
    """

    rpm_sigma: Optional[float] = FieldInfo(alias="rpmSigma", default=None)
    """
    The standard deviation of the received power monitor (RPM) output value for the
    set of data contained within this cell.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """


H3geohexcellTupleResponse: TypeAlias = List[H3geohexcellTupleResponseItem]
