# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["HazardCreateParams"]


class HazardCreateParams(TypedDict, total=False):
    alarms: Required[List[str]]
    """Array of the specific alarms associated with this detection.

    The alarms and alarmValues arrays must contain the same number of elements.
    """

    alarm_values: Required[Annotated[Iterable[float], PropertyInfo(alias="alarmValues")]]
    """Array of the values that correspond to each of the alarms contained in alarms.

    The alarms and alarmValues arrays must contain the same number of elements.
    """

    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    detect_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="detectTime", format="iso8601")]]
    """The detect time, in ISO 8601 UTC format, with millisecond precision."""

    detect_type: Required[Annotated[str, PropertyInfo(alias="detectType")]]
    """
    The type of hazard (Chemical, Biological, Radiological, Nuclear) detect
    associated with this record.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    a: int
    """The (rounded) Mass Number of the material associated with this detection.

    The rounded value is the mass number of the most abundant isotope of the
    element.
    """

    activity: float
    """
    The radioactivity measurement of the material associated with this detection, in
    becquerels (Bq). One becquerel (Bq) is equal to one nuclear decay per second.
    """

    bottle_id: Annotated[str, PropertyInfo(alias="bottleId")]
    """The specific bottle ID associated with this detection."""

    cas_rn: Annotated[str, PropertyInfo(alias="casRN")]
    """
    The CAS Registry Number, also referred to as CAS Number or CAS RN, associated
    with the this detection. The CAS Number is a unique numerical identifier
    assigned by the Chemical Abstracts Service (CAS), to every chemical substance
    described in the open scientific literature. It includes organic and inorganic
    compounds, minerals, isotopes, alloys, mixtures, and nonstructurable materials
    (UVCBs, substances of unknown or variable composition, complex reaction
    products, or biological origin). For further information, reference
    https://www.cas.org/cas-data/cas-registry.
    """

    channel: str
    """The applicable channel involved in this biological material detection (e.g.

    Digestive, Eyes, Respiratory, Skin, etc.) .
    """

    ctrn_time: Annotated[float, PropertyInfo(alias="ctrnTime")]
    """
    The concentration time, in (kg/sec)/m^3, associated with this material
    detection.
    """

    density: float
    """Measure of density of the material associated with this detection, in kg/m^3."""

    dep: float
    """The deposition measurement of the contaminant to surface area, in kg/m^2."""

    dep_ctrn: Annotated[float, PropertyInfo(alias="depCtrn")]
    """
    The deposition concentration of the contaminant to surface area, in
    becquerels/m^2.
    """

    dose: float
    """The dose associated with this detection, in gray.

    Dose is the measure of the energy deposited in matter by ionizing radiation per
    unit mass. One gray is defined as one Joule of energy absorbed per kilogram of
    matter.
    """

    dose_rate: Annotated[float, PropertyInfo(alias="doseRate")]
    """The dose rate associated with this detection, in gray/sec.

    One gray is defined as one Joule of energy absorbed per kilogram of matter.
    """

    duration: int
    """
    The known or projected hazard duration, in seconds, associated with this
    material detection.
    """

    g_bar: Annotated[float, PropertyInfo(alias="gBar")]
    """Chemical Agent Monitor (CAM) G-type agent measurement, in number of display
    bars.

    In G-mode, CAMs monitor for G-series nerve agents.
    """

    harmful: bool
    """Flag indicating whether this detection is harmful to humans."""

    h_bar: Annotated[float, PropertyInfo(alias="hBar")]
    """Chemical Agent Monitor (CAM) H-type agent measurement, in number of display
    bars.

    In H-mode, CAMs monitor for blister agents.
    """

    id_poi: Annotated[str, PropertyInfo(alias="idPOI")]
    """ID of the Point of Interest (POI) record related to this hazard record."""

    id_track: Annotated[str, PropertyInfo(alias="idTrack")]
    """ID of the Track record related to this hazard record."""

    mass_frac: Annotated[float, PropertyInfo(alias="massFrac")]
    """Ratio of the chemical substance mass to the total mass of the mixture."""

    mat_cat: Annotated[int, PropertyInfo(alias="matCat")]
    """
    The Radiological Category (1 - 5) which applies to the material associated with
    this detection, according to the following definitions:

    Category 1: If not safely or securely managed, would be likely to cause
    permanent injury to a person who handled them or was otherwise in contact with
    them for more than a few minutes. It would probably be fatal to be close to this
    amount of unshielded material for a period of a few minutes to an hour.

    Category 2: If not safely or securely managed, could cause permanent injury to a
    person who handled them or was otherwise in contact with them for a short time
    (minutes to hours). It could possibly be fatal to be close to this amount of
    unshielded radioactive material for a period of hours to days.

    Category 3: If not safely or securely managed, could cause permanent injury to a
    person who handled them or was otherwise in contact with them for hours. It
    could possibly - although it is unlikely to be - fatal to be close to this
    amount of unshielded radioactive material for a period of days to weeks.

    Category 4: If not safely managed or securely protected, could possibly cause
    temporary injury to someone who handled them or was otherwise in contact with or
    close to them for a period of many weeks, though this is unlikely. It is very
    unlikely anyone would be permanently injured by this amount of radioactive
    material.

    Category 5: Cannot cause permanent injury. This category applies to x-ray
    fluorescence devices and electron capture devices.
    """

    mat_class: Annotated[str, PropertyInfo(alias="matClass")]
    """The specific Material Class for the material associated with this detect.

    The material class is generally associated with chemical and biological
    detections.
    """

    mat_name: Annotated[str, PropertyInfo(alias="matName")]
    """The material common name associated with this detection."""

    mat_type: Annotated[str, PropertyInfo(alias="matType")]
    """
    The specific material type (MT) or MT Code involved in this detection, when
    applicable. The material type is generally associated with radiological and/or
    nuclear detections. For further information, reference Nuclear Materials
    Management and Safeguards System (NMMSS) Users Guide Rev. 2.1.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    ppm: int
    """
    Measure of the concentration of the material associated with this detection, in
    parts per million (units of contaminant mass per million parts of total mass).
    """

    rad_ctrn: Annotated[float, PropertyInfo(alias="radCtrn")]
    """
    Measure of radioactive concentration of the material associated with this
    detection, in becquerels/m^3. One becquerel (Bq) is equal to one nuclear decay
    per second.
    """

    readings: List[str]
    """Array of the specific readings associated with this detection.

    The readings, readingUnits, and readingValues arrays must contain the same
    number of elements.
    """

    reading_units: Annotated[List[str], PropertyInfo(alias="readingUnits")]
    """Array of the units that correspond to each of the readingValues.

    The readings, readingUnits, and readingValues arrays must contain the same
    number of elements.
    """

    reading_values: Annotated[Iterable[float], PropertyInfo(alias="readingValues")]
    """
    Array of the values that correspond to each of the readings contained in
    readings. The readings, readingUnits, and readingValues arrays must contain the
    same number of elements.
    """

    z: int
    """The Atomic Number of the material associated with this detection."""
