# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import date, datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ItemCreateParams"]


class ItemCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    scan_code: Required[Annotated[str, PropertyInfo(alias="scanCode")]]
    """The tracking identifier of an item or person.

    May be similar in representation of a barcode or UPC. If no scanCode or tracking
    number equivalent is available, 'NONE' should be used.
    """

    source: Required[str]
    """Source of the data."""

    type: Required[str]
    """The item type of this record (e.g. EQUIPMENT, CARGO, PASSENGER)."""

    id: str
    """
    Unique identifier of the record, auto-generated by the system if not provided on
    create operations.
    """

    acc_sys_keys: Annotated[List[str], PropertyInfo(alias="accSysKeys")]
    """Array of keys that may be associated to the accepting system data.

    The entries in this array must correspond to the position index in accSysValues
    array. This array must be the same length as accSysValues.
    """

    acc_sys_notes: Annotated[str, PropertyInfo(alias="accSysNotes")]
    """Additional data required to find this item in the accepting system."""

    acc_system: Annotated[str, PropertyInfo(alias="accSystem")]
    """Name of the system that accepted this item from a customer.

    Where a user or application could go look for additional information.
    """

    acc_sys_values: Annotated[List[str], PropertyInfo(alias="accSysValues")]
    """Array of values for the keys that may be associated to the accepting system
    data.

    The entries in this array must correspond to the position index in accSysKeys
    array. This array must be the same length as accSysKeys.
    """

    airdrop: bool
    """Flag indicating this item is planned to be airdropped.

    Applicable for cargo and passenger item types only.
    """

    alt_data_format: Annotated[str, PropertyInfo(alias="altDataFormat")]
    """
    Name of the additional data format so downstream consuming applications can know
    how to parse it. Typically includes the source system name and the format name.
    """

    cargo_type: Annotated[str, PropertyInfo(alias="cargoType")]
    """The type of cargo (e.g.

    PALLET, ROLLING STOCK, LOOSE, OTHER). Applicable for cargo item types only.
    """

    centerline_offset: Annotated[float, PropertyInfo(alias="centerlineOffset")]
    """How far left or right of centerline is the item in meters.

    Applicable for cargo and passenger item types only.
    """

    cg: float
    """
    Center of gravity position of the item, measured from the item's front datum, in
    centimeters.
    """

    commodity_code: Annotated[str, PropertyInfo(alias="commodityCode")]
    """The classification code of the commodity or group of commodities."""

    commodity_sys: Annotated[str, PropertyInfo(alias="commoditySys")]
    """The classification system denoting the commodity code, commodityCode (e.g.

    AIR, WATER, NMFC, UFC, STCC, DODUNQ, etc.).
    """

    container: bool
    """Flag indicating this item acts as a container and contains additional items."""

    departure: str
    """The departure code or location where this item has left or is leaving."""

    destination: str
    """The destination of the item, typically an ICAO or port code.

    Applicable for cargo and passenger item types only.
    """

    dv_code: Annotated[str, PropertyInfo(alias="dvCode")]
    """United States Distinguished Visitor Code, only applicable to people."""

    fs: float
    """
    The fuselage station of the item measured from the reference datum, in
    centimeters. Applicable for cargo and passenger item types only.
    """

    haz_codes: Annotated[Iterable[float], PropertyInfo(alias="hazCodes")]
    """Array of UN hazard classes or division codes that apply to this item."""

    height: float
    """Height of the cargo in meters. Applicable for cargo item types only."""

    id_air_load_plan: Annotated[str, PropertyInfo(alias="idAirLoadPlan")]
    """The UDL ID of the air load plan this item is associated with."""

    item_contains: Annotated[List[str], PropertyInfo(alias="itemContains")]
    """Array of tracking identifiers that are contained within this item."""

    keys: List[str]
    """Array of keys that may be associated to this item.

    The entries in this array must correspond to the position index in the values
    array. This array must be the same length as values..
    """

    last_arr_date: Annotated[Union[str, date], PropertyInfo(alias="lastArrDate", format="iso8601")]
    """
    The latest acceptable arrival date of the item at the destination, in ISO 8601
    date-only format (e.g. YYYY-MM-DD).
    """

    length: float
    """Length of the cargo in meters. Applicable for cargo item types only."""

    moment: float
    """Moment of the item in Newton-meters.

    Applicable for equipment and cargo item types only.
    """

    name: str
    """Name of the item. Applicable for equipment and cargo item types only."""

    net_exp_wt: Annotated[float, PropertyInfo(alias="netExpWt")]
    """Net explosive weight of the item, in kilograms."""

    notes: str
    """Optional notes or comments about this item."""

    num_pallet_pos: Annotated[int, PropertyInfo(alias="numPalletPos")]
    """
    Number of pallet positions or equivalent on the aircraft, ship, or conveyance
    equipment that this item occupies.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    product_code: Annotated[str, PropertyInfo(alias="productCode")]
    """The code denoting the type of material item."""

    product_sys: Annotated[str, PropertyInfo(alias="productSys")]
    """The assigning system that denotes the type of material item, productCode (e.g.

    NSN-national stock number, NDC-national drug code, MPN-manufacturer part number,
    etc.).
    """

    receiving_branch: Annotated[str, PropertyInfo(alias="receivingBranch")]
    """The military branch receiving this item."""

    receiving_unit: Annotated[str, PropertyInfo(alias="receivingUnit")]
    """The name of the unit receiving this item."""

    sc_gen_tool: Annotated[str, PropertyInfo(alias="scGenTool")]
    """The algorithm name or standard that generated the scanCode (e.g.

    UPC-A, EAN-13, GTIN, SSCC, bID, JAN, etc.).
    """

    tcn: str
    """Transportation Control Number of the cargo.

    Applicable for cargo item types only.
    """

    uln: str
    """The unit line number of this item."""

    values: List[str]
    """Array of values for the keys that may be associated to this tracked item.

    The entries in this array must correspond to the position index in the keys
    array. This array must be the same length as keys.
    """

    volume: float
    """The volume of the item, in cubic meters. Applicable for cargo item types only."""

    weight: float
    """
    Weight of the item in kilograms (if item is a passenger, include on-person
    bags).
    """

    weight_ts: Annotated[Union[str, datetime], PropertyInfo(alias="weightTS", format="iso8601")]
    """
    Timestamp when the weight was taken, in ISO 8601 UTC format with millisecond
    precision.
    """

    width: float
    """Width of the cargo in meters. Applicable for cargo item types only."""
