# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ItemTrackingCreateParams"]


class ItemTrackingCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    scan_code: Required[Annotated[str, PropertyInfo(alias="scanCode")]]
    """The tracking identifier of an item or person.

    May be similar in representation of a barcode or UPC.
    """

    scanner_id: Required[Annotated[str, PropertyInfo(alias="scannerId")]]
    """The ID of the scanner or input device."""

    source: Required[str]
    """Source of the data."""

    ts: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """The timestamp of the scan, in ISO 8601 UTC format with millisecond precision."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    dv_code: Annotated[str, PropertyInfo(alias="dvCode")]
    """
    The United States distinguished visitor code of the person scanned, only
    applicable to people.
    """

    id_item: Annotated[str, PropertyInfo(alias="idItem")]
    """The UDL ID of the item this record is associated with."""

    keys: List[str]
    """Array of keys that may be associated with this tracked item."""

    lat: float
    """WGS84 latitude where the item was scanned, in degrees."""

    lon: float
    """WGS84 longitude where the item was scanned, in degrees."""

    notes: str
    """Optional notes or comments about the tracking data."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    scan_type: Annotated[str, PropertyInfo(alias="scanType")]
    """The type of scan for tracking the item within it's journey (e.g.

    IN, OUT, RECEIVED, DELIVERED, TRANSIT, ABANDONDED, REFUSED, UNABLE, RETURNED,
    HELD, OTHER). For example, received and delivered are for when an item is
    received from or delivered to the end customer. In and out are for stops in
    between such as being loaded on an airplane or received at a warehouse.
    """

    sc_gen_tool: Annotated[str, PropertyInfo(alias="scGenTool")]
    """The algorithm name or standard that generated the scanCode (e.g.

    UPC-A, EAN-13, GTIN, SSCC, bID, JAN, etc.).
    """

    type: str
    """The type of item that is being scanned (e.g.

    CARGO, PERSON, MAIL, MICAP, OTHER).
    """

    values: List[str]
    """Array of values for the keys that may be associated to this tracked item.

    The entries in this array must correspond to the position index in the keys
    array. This array must be the same length as keys.
    """
