# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from ..shared.onorbit_full import OnorbitFull

__all__ = ["HistoryListResponse", "HistoryListResponseItem"]


class HistoryListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    msg_create_date: datetime = FieldInfo(alias="msgCreateDate")
    """Timestamp of the originating message in ISO8601 UTC format."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    be_number: Optional[str] = FieldInfo(alias="beNumber", default=None)
    """The Basic Encyclopedia Number, if applicable."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    declassification_date: Optional[datetime] = FieldInfo(alias="declassificationDate", default=None)
    """The declassification date of this data, in ISO 8601 UTC format."""

    declassification_string: Optional[str] = FieldInfo(alias="declassificationString", default=None)
    """Declassification string of this data."""

    derived_from: Optional[str] = FieldInfo(alias="derivedFrom", default=None)
    """
    The sources or SCG references from which the classification of this data is
    derived.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the target on-orbit object, if correlated."""

    launch_date: Optional[datetime] = FieldInfo(alias="launchDate", default=None)
    """The launch date, in ISO8601 UTC format."""

    launch_facility_name: Optional[str] = FieldInfo(alias="launchFacilityName", default=None)
    """The Launch facility name."""

    launch_failure_code: Optional[str] = FieldInfo(alias="launchFailureCode", default=None)
    """The DISOB launch Failure Code, if applicable."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """Optional target-id, if missing in UDL."""

    o_suffix: Optional[str] = FieldInfo(alias="oSuffix", default=None)
    """The OSuffix, if applicable."""

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/catalog number of the target on-orbit object."""


HistoryListResponse: TypeAlias = List[HistoryListResponseItem]
