# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["LaunchdetectionCreateParams"]


class LaunchdetectionCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    message_type: Required[Annotated[str, PropertyInfo(alias="messageType")]]
    """Type of message for the data."""

    observation_latitude: Required[Annotated[float, PropertyInfo(alias="observationLatitude")]]
    """Latitude of launch vehicle at observation time (in Degrees).

    -90 to 90 degrees (negative values south of equator).
    """

    observation_longitude: Required[Annotated[float, PropertyInfo(alias="observationLongitude")]]
    """Longitude of launch vehicle at observation time (in Degrees)."""

    observation_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="observationTime", format="iso8601")]]
    """Time of observation."""

    sequence_number: Required[Annotated[int, PropertyInfo(alias="sequenceNumber")]]
    """Integer indicating how messages should be sequenced for a specific event."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    descriptor: str
    """Optional source-provided and searchable metadata or descriptor of the data."""

    event_id: Annotated[str, PropertyInfo(alias="eventId")]
    """Id to be able to correlate different messages to a specific event."""

    high_zenith_azimuth: Annotated[bool, PropertyInfo(alias="highZenithAzimuth")]
    """
    Flag indicating that the Launch azimuth is uncertain due to near vertical flight
    path.
    """

    inclination: float
    """Orbit Inclination (in Degrees)."""

    launch_azimuth: Annotated[float, PropertyInfo(alias="launchAzimuth")]
    """Angle measured clockwise from North for the launch heading (in Degrees)."""

    launch_latitude: Annotated[float, PropertyInfo(alias="launchLatitude")]
    """Geodetic Latitude of launch origin (in Degrees).

    -90 to 90 degrees (negative values south of equator).
    """

    launch_longitude: Annotated[float, PropertyInfo(alias="launchLongitude")]
    """Geodetic Longitude of launch origin (in Degrees).

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    launch_time: Annotated[Union[str, datetime], PropertyInfo(alias="launchTime", format="iso8601")]
    """Time of Launch."""

    observation_altitude: Annotated[float, PropertyInfo(alias="observationAltitude")]
    """Altitude of launch vehicle at observation time (in KM)."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    raan: float
    """Orbit Right Ascension of Ascending Node (in Degrees)."""

    stereo_flag: Annotated[bool, PropertyInfo(alias="stereoFlag")]
    """Flag indicating multiple observers were used."""

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """
