# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["LaunchdetectionGetResponse"]


class LaunchdetectionGetResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    message_type: str = FieldInfo(alias="messageType")
    """Type of message for the data."""

    observation_latitude: float = FieldInfo(alias="observationLatitude")
    """Latitude of launch vehicle at observation time (in Degrees).

    -90 to 90 degrees (negative values south of equator).
    """

    observation_longitude: float = FieldInfo(alias="observationLongitude")
    """Longitude of launch vehicle at observation time (in Degrees)."""

    observation_time: datetime = FieldInfo(alias="observationTime")
    """Time of observation."""

    sequence_number: int = FieldInfo(alias="sequenceNumber")
    """Integer indicating how messages should be sequenced for a specific event."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """Application user who created the row in the database."""

    descriptor: Optional[str] = None
    """Optional source-provided and searchable metadata or descriptor of the data."""

    event_id: Optional[str] = FieldInfo(alias="eventId", default=None)
    """Id to be able to correlate different messages to a specific event."""

    high_zenith_azimuth: Optional[bool] = FieldInfo(alias="highZenithAzimuth", default=None)
    """
    Flag indicating that the Launch azimuth is uncertain due to near vertical flight
    path.
    """

    inclination: Optional[float] = None
    """Orbit Inclination (in Degrees)."""

    launch_azimuth: Optional[float] = FieldInfo(alias="launchAzimuth", default=None)
    """Angle measured clockwise from North for the launch heading (in Degrees)."""

    launch_latitude: Optional[float] = FieldInfo(alias="launchLatitude", default=None)
    """Geodetic Latitude of launch origin (in Degrees).

    -90 to 90 degrees (negative values south of equator).
    """

    launch_longitude: Optional[float] = FieldInfo(alias="launchLongitude", default=None)
    """Geodetic Longitude of launch origin (in Degrees).

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    launch_time: Optional[datetime] = FieldInfo(alias="launchTime", default=None)
    """Time of Launch."""

    observation_altitude: Optional[float] = FieldInfo(alias="observationAltitude", default=None)
    """Altitude of launch vehicle at observation time (in KM)."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    raan: Optional[float] = None
    """Orbit Right Ascension of Ascending Node (in Degrees)."""

    stereo_flag: Optional[bool] = FieldInfo(alias="stereoFlag", default=None)
    """Flag indicating multiple observers were used."""

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """
    Read-only time the row was updated in the database, set automatically by the
    system on update.
    """

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who last updated the row in the database, set by the system
    automatically and ignored on create/edit operations.
    """
