# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .location_ingest_param import LocationIngestParam

__all__ = ["LaunchsitedetailCreateParams"]


class LaunchsitedetailCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_launch_site: Required[Annotated[str, PropertyInfo(alias="idLaunchSite")]]
    """Identifier of the parent launch site record."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    available_inclinations: Annotated[Iterable[float], PropertyInfo(alias="availableInclinations")]
    """Array of supported launch inclinations known for this site.

    The array is always sized as a multiple of two and includes start/end values to
    support ranges. For example, if a site support inclinations of 10 and 12-14, the
    array would have the following values: [10,10, 12,14].
    """

    description: str
    """Notes/description of the launch site."""

    id_location: Annotated[str, PropertyInfo(alias="idLocation")]
    """ID of the location data for the launch site, or null if mobile (e.g.

    sea launch platform in international waters).
    """

    launch_group: Annotated[str, PropertyInfo(alias="launchGroup")]
    """Launch site group name.

    Multiple launch sites may be colocated within a launch ''group''.
    """

    location: LocationIngestParam
    """
    Model representation of a location, which is a specific fixed point on the earth
    and is used to denote the locations of fixed sensors, operating units, etc.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """
