# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "LaunchsitedetailFindBySourceResponse",
    "LaunchsitedetailFindBySourceResponseItem",
    "LaunchsitedetailFindBySourceResponseItemLocation",
]


class LaunchsitedetailFindBySourceResponseItemLocation(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Location name."""

    source: str
    """Source of the data."""

    altitude: Optional[float] = None
    """Altitude of the location, in kilometers."""

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country code.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_location: Optional[str] = FieldInfo(alias="idLocation", default=None)
    """Unique identifier of the location, auto-generated by the system."""

    lat: Optional[float] = None
    """WGS84 latitude of the location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: Optional[float] = None
    """WGS84 longitude of the location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """


class LaunchsitedetailFindBySourceResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_launch_site: str = FieldInfo(alias="idLaunchSite")
    """Identifier of the parent launch site record."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    available_inclinations: Optional[List[float]] = FieldInfo(alias="availableInclinations", default=None)
    """Array of supported launch inclinations known for this site.

    The array is always sized as a multiple of two and includes start/end values to
    support ranges. For example, if a site support inclinations of 10 and 12-14, the
    array would have the following values: [10,10, 12,14].
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    description: Optional[str] = None
    """Notes/description of the launch site."""

    id_location: Optional[str] = FieldInfo(alias="idLocation", default=None)
    """ID of the location data for the launch site, or null if mobile (e.g.

    sea launch platform in international waters).
    """

    launch_group: Optional[str] = FieldInfo(alias="launchGroup", default=None)
    """Launch site group name.

    Multiple launch sites may be colocated within a launch ''group''.
    """

    location: Optional[LaunchsitedetailFindBySourceResponseItemLocation] = None
    """
    Model representation of a location, which is a specific fixed point on the earth
    and is used to denote the locations of fixed sensors, operating units, etc.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """


LaunchsitedetailFindBySourceResponse: TypeAlias = List[LaunchsitedetailFindBySourceResponseItem]
