# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["LinkStatusCreateParams"]


class LinkStatusCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    end_point1_lat: Required[Annotated[float, PropertyInfo(alias="endPoint1Lat")]]
    """Latitude of link endpoint-1, WGS-84 in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    end_point1_lon: Required[Annotated[float, PropertyInfo(alias="endPoint1Lon")]]
    """Longitude of link endpoint-1, WGS-84 longitude in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    end_point1_name: Required[Annotated[str, PropertyInfo(alias="endPoint1Name")]]
    """The name or description of link endpoint-1, corresponding to beam-1."""

    end_point2_lat: Required[Annotated[float, PropertyInfo(alias="endPoint2Lat")]]
    """Latitude of link endpoint-2, WGS-84 in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    end_point2_lon: Required[Annotated[float, PropertyInfo(alias="endPoint2Lon")]]
    """Longitude of link endpoint-2, WGS-84 longitude in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    end_point2_name: Required[Annotated[str, PropertyInfo(alias="endPoint2Name")]]
    """The name or description of link endpoint-2, corresponding to beam-2."""

    link_name: Required[Annotated[str, PropertyInfo(alias="linkName")]]
    """The name or description of the link."""

    link_start_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="linkStartTime", format="iso8601")]]
    """
    The link establishment time, or the time that the link becomes available for
    use, in ISO8601 UTC format.
    """

    link_stop_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="linkStopTime", format="iso8601")]]
    """
    The link termination time, or the time that the link becomes unavailable for
    use, in ISO8601 UTC format.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    band: str
    """The RF band employed by the link (e.g. MIL-KA, COM-KA, X-BAND, C-BAND, etc.)."""

    constellation: str
    """The constellation name if the link is established over a LEO/MEO constellation.

    In this case, idOnOrbit1 and idOnOrbit2 will be null.
    """

    data_rate1_to2: Annotated[float, PropertyInfo(alias="dataRate1To2")]
    """The endpoint-1 to endpoint-2 data rate, in kbps."""

    data_rate2_to1: Annotated[float, PropertyInfo(alias="dataRate2To1")]
    """The endpoint-2 to endpoint-1 data rate, in kbps."""

    id_beam1: Annotated[str, PropertyInfo(alias="idBeam1")]
    """The ID of beam-1 forming the link.

    In the case of two sat link, beam-1 corresponds to Sat-1.
    """

    id_beam2: Annotated[str, PropertyInfo(alias="idBeam2")]
    """The ID of beam-2 forming the link.

    In the case of two sat link, beam-2 corresponds to Sat-2.
    """

    link_state: Annotated[str, PropertyInfo(alias="linkState")]
    """The state of the link (e.g. OK, DEGRADED-WEATHER, DEGRADED-EMI, etc.)."""

    link_type: Annotated[str, PropertyInfo(alias="linkType")]
    """The type of the link."""

    ops_cap: Annotated[str, PropertyInfo(alias="opsCap")]
    """The OPSCAP mission status of the system(s) forming the link."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    sat_no1: Annotated[int, PropertyInfo(alias="satNo1")]
    """Satellite/catalog number of the target on-orbit primary object."""

    sat_no2: Annotated[int, PropertyInfo(alias="satNo2")]
    """Satellite/catalog number of the target on-orbit secondary object."""

    sys_cap: Annotated[str, PropertyInfo(alias="sysCap")]
    """The SYSCAP mission status of the system(s) forming the link."""
