# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ManifoldCreateParams"]


class ManifoldCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_object_of_interest: Required[Annotated[str, PropertyInfo(alias="idObjectOfInterest")]]
    """ID of the parent object of interest."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    delta_t: Annotated[float, PropertyInfo(alias="deltaT")]
    """Applied delta V duration for this manifold's calculations in seconds."""

    delta_v: Annotated[float, PropertyInfo(alias="deltaV")]
    """Applied delta V for this manifold's calculations, in km/sec."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    status: str
    """Status of the manifold and its associated ManifoldElsets (e.g.

    PENDING, COMPLETE). PENDING status means element set generation is in progress
    and COMPLETE indicates all ManifoldElsets have been generated.
    """

    weight: float
    """
    Weight or probability of this manifold for prioritization purposes, between 0
    and 1.
    """
