# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ManifoldTupleResponse", "ManifoldTupleResponseItem"]


class ManifoldTupleResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_object_of_interest: str = FieldInfo(alias="idObjectOfInterest")
    """ID of the parent object of interest."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    delta_t: Optional[float] = FieldInfo(alias="deltaT", default=None)
    """Applied delta V duration for this manifold's calculations in seconds."""

    delta_v: Optional[float] = FieldInfo(alias="deltaV", default=None)
    """Applied delta V for this manifold's calculations, in km/sec."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    status: Optional[str] = None
    """Status of the manifold and its associated ManifoldElsets (e.g.

    PENDING, COMPLETE). PENDING status means element set generation is in progress
    and COMPLETE indicates all ManifoldElsets have been generated.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """
    Read-only time the row was updated in the database, set automatically by the
    system on update.
    """

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who last updated the row in the database, set by the system
    automatically and ignored on create/edit operations.
    """

    weight: Optional[float] = None
    """
    Weight or probability of this manifold for prioritization purposes, between 0
    and 1.
    """


ManifoldTupleResponse: TypeAlias = List[ManifoldTupleResponseItem]
