# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["MissionassignmentListResponse", "MissionassignmentListResponseItem"]


class MissionassignmentListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    mad: str
    """The mission assignment discrete value."""

    source: str
    """Source of the data."""

    ts: datetime
    """The timestamp of the mission data, in ISO 8601 UTC format."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    c1associateddmpis: Optional[int] = None
    """TARGET POSITION CONTINUATION WORD - number of associated dmpis."""

    c2air: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - air specific type, see TABLE B-21."""

    c2alt: Optional[int] = None
    """TARGET DATA CONTINUATION WORD - altitude, 100 FT, 2047=NS."""

    c2crs: Optional[int] = None
    """TARGET DATA CONTINUATION WORD - course in increments of 1 degree."""

    c2exerciseindicator: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - exercise indicator."""

    c2exercisemof: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - method of fire."""

    c2id: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - identity."""

    c2idamplifyingdescriptor: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - identity amplifying descriptor."""

    c2lnd: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - land specific type, see TABLE B-21."""

    c2spc: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - space specific type, see TABLE B-39."""

    c2spd: Optional[int] = None
    """TARGET DATA CONTINUATION WORD - speed in 2 DM/HR, 2047=NS."""

    c2specialinterestindicator: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - special interest indicator."""

    c2sur: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - surface specific type, see TABLE B-21."""

    c3elv: Optional[float] = None
    """POINT LOCATION CONTINUATION WORD - elevation, 25 FT, 1023=NS."""

    c3lat: Optional[float] = None
    """POINT LOCATION CONTINUATION WORD - latitude, 0.0013 MINUTE."""

    c3lon: Optional[float] = None
    """POINT LOCATION CONTINUATION WORD - longitude, 0.0013 MINUTE."""

    c3ptl: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - point type 1."""

    c3ptnum: Optional[str] = None
    """TARGET DATA CONTINUATION WORD - point number."""

    c4colon: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - minute."""

    c4def: Optional[str] = None
    """SURFACE ATTACK CONTINUATION WORD - target defenses."""

    c4egress: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - run in heading, NS=511."""

    c4mod: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - mode of delivery."""

    c4numberofstores: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - number of stores, NS=63."""

    c4runin: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - run in heading, NS=511."""

    c4tgt: Optional[str] = None
    """SURFACE ATTACK CONTINUATION WORD - target type - see TABLE B-32."""

    c4timediscrete: Optional[str] = None
    """SURFACE ATTACK CONTINUATION WORD - time discrete."""

    c4tm: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - hour."""

    c4typeofstores: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - type of stores."""

    c5colon: Optional[int] = None
    """SURFACE ATTACK CONTINUATION WORD - seconds in increments of 1 sec."""

    c5elevationlsbs: Optional[int] = None
    """CONTINUATION WORD - used with c3_elv to double precision to approx 3 ft."""

    c5haeadj: Optional[int] = None
    """CONTINUATION WORD - hae adjustment, measured in 3.125 FT."""

    c5latlsb: Optional[int] = None
    """CONTINUATION WORD - used with c3_lat to double precision to approx 4 ft."""

    c5lonlsb: Optional[int] = None
    """CONTINUATION WORD - used with c3_lon to double precision to approx 4 ft."""

    c5tgtbrng: Optional[int] = None
    """CONTINUATION WORD - target bearing."""

    c5tw: Optional[int] = None
    """CONTINUATION WORD - time window."""

    c6dspc: Optional[str] = None
    """TARGETING CONTINUATION WORD - designator/seeker pulse code."""

    c6dspct: Optional[str] = None
    """TARGETING CONTINUATION WORD - designator/seeker pulse code type."""

    c6fplpm: Optional[str] = None
    """TARGETING CONTINUATION WORD - first pulse/last pulse mode."""

    c6intel: Optional[int] = None
    """TARGETING CONTINUATION WORD - index number, related, 0=NS."""

    c6laser: Optional[int] = None
    """TARGETING CONTINUATION WORD - laser illuminator code."""

    c6longpm: Optional[str] = None
    """TARGETING CONTINUATION WORD - long pulse mode."""

    c6tnr3: Optional[int] = None
    """TARGETING CONTINUATION WORD - track number, related to 3."""

    c7elang2: Optional[float] = None
    """THIRD PARTY CONTINUATION WORD - elevation angle, 2."""

    c7in3p: Optional[int] = None
    """THIRD PARTY CONTINUATION WORD - index number, third party."""

    c7tnor: Optional[str] = None
    """THIRD PARTY CONTINUATION WORD - track number, index originator."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    env: Optional[str] = None
    """Environment."""

    index: Optional[int] = None
    """Index number."""

    lat: Optional[float] = None
    """WGS84 latitude, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: Optional[float] = None
    """WGS84 longitude, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    orginx: Optional[str] = None
    """Origin of index number."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    rc: Optional[str] = None
    """Receipt/Compliance, values from TABLE B-9."""

    rr: Optional[int] = None
    """Recurrence rate, receipt/compliance."""

    sz: Optional[str] = None
    """Strength."""

    tno: Optional[str] = None
    """Track number objective."""

    trk_id: Optional[str] = FieldInfo(alias="trkId", default=None)
    """The track ID that the status is referencing, addressee."""

    twenv: Optional[str] = None
    """Threat warning environment."""


MissionassignmentListResponse: TypeAlias = List[MissionassignmentListResponseItem]
