# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["MissionassignmentUpdateParams"]


class MissionassignmentUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    mad: Required[str]
    """The mission assignment discrete value."""

    source: Required[str]
    """Source of the data."""

    ts: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """The timestamp of the mission data, in ISO 8601 UTC format."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    c1associateddmpis: int
    """TARGET POSITION CONTINUATION WORD - number of associated dmpis."""

    c2air: str
    """TARGET DATA CONTINUATION WORD - air specific type, see TABLE B-21."""

    c2alt: int
    """TARGET DATA CONTINUATION WORD - altitude, 100 FT, 2047=NS."""

    c2crs: int
    """TARGET DATA CONTINUATION WORD - course in increments of 1 degree."""

    c2exerciseindicator: str
    """TARGET DATA CONTINUATION WORD - exercise indicator."""

    c2exercisemof: str
    """TARGET DATA CONTINUATION WORD - method of fire."""

    c2id: str
    """TARGET DATA CONTINUATION WORD - identity."""

    c2idamplifyingdescriptor: str
    """TARGET DATA CONTINUATION WORD - identity amplifying descriptor."""

    c2lnd: str
    """TARGET DATA CONTINUATION WORD - land specific type, see TABLE B-21."""

    c2spc: str
    """TARGET DATA CONTINUATION WORD - space specific type, see TABLE B-39."""

    c2spd: int
    """TARGET DATA CONTINUATION WORD - speed in 2 DM/HR, 2047=NS."""

    c2specialinterestindicator: str
    """TARGET DATA CONTINUATION WORD - special interest indicator."""

    c2sur: str
    """TARGET DATA CONTINUATION WORD - surface specific type, see TABLE B-21."""

    c3elv: float
    """POINT LOCATION CONTINUATION WORD - elevation, 25 FT, 1023=NS."""

    c3lat: float
    """POINT LOCATION CONTINUATION WORD - latitude, 0.0013 MINUTE."""

    c3lon: float
    """POINT LOCATION CONTINUATION WORD - longitude, 0.0013 MINUTE."""

    c3ptl: str
    """TARGET DATA CONTINUATION WORD - point type 1."""

    c3ptnum: str
    """TARGET DATA CONTINUATION WORD - point number."""

    c4colon: int
    """SURFACE ATTACK CONTINUATION WORD - minute."""

    c4def: str
    """SURFACE ATTACK CONTINUATION WORD - target defenses."""

    c4egress: int
    """SURFACE ATTACK CONTINUATION WORD - run in heading, NS=511."""

    c4mod: int
    """SURFACE ATTACK CONTINUATION WORD - mode of delivery."""

    c4numberofstores: int
    """SURFACE ATTACK CONTINUATION WORD - number of stores, NS=63."""

    c4runin: int
    """SURFACE ATTACK CONTINUATION WORD - run in heading, NS=511."""

    c4tgt: str
    """SURFACE ATTACK CONTINUATION WORD - target type - see TABLE B-32."""

    c4timediscrete: str
    """SURFACE ATTACK CONTINUATION WORD - time discrete."""

    c4tm: int
    """SURFACE ATTACK CONTINUATION WORD - hour."""

    c4typeofstores: int
    """SURFACE ATTACK CONTINUATION WORD - type of stores."""

    c5colon: int
    """SURFACE ATTACK CONTINUATION WORD - seconds in increments of 1 sec."""

    c5elevationlsbs: int
    """CONTINUATION WORD - used with c3_elv to double precision to approx 3 ft."""

    c5haeadj: int
    """CONTINUATION WORD - hae adjustment, measured in 3.125 FT."""

    c5latlsb: int
    """CONTINUATION WORD - used with c3_lat to double precision to approx 4 ft."""

    c5lonlsb: int
    """CONTINUATION WORD - used with c3_lon to double precision to approx 4 ft."""

    c5tgtbrng: int
    """CONTINUATION WORD - target bearing."""

    c5tw: int
    """CONTINUATION WORD - time window."""

    c6dspc: str
    """TARGETING CONTINUATION WORD - designator/seeker pulse code."""

    c6dspct: str
    """TARGETING CONTINUATION WORD - designator/seeker pulse code type."""

    c6fplpm: str
    """TARGETING CONTINUATION WORD - first pulse/last pulse mode."""

    c6intel: int
    """TARGETING CONTINUATION WORD - index number, related, 0=NS."""

    c6laser: int
    """TARGETING CONTINUATION WORD - laser illuminator code."""

    c6longpm: str
    """TARGETING CONTINUATION WORD - long pulse mode."""

    c6tnr3: int
    """TARGETING CONTINUATION WORD - track number, related to 3."""

    c7elang2: float
    """THIRD PARTY CONTINUATION WORD - elevation angle, 2."""

    c7in3p: int
    """THIRD PARTY CONTINUATION WORD - index number, third party."""

    c7tnor: str
    """THIRD PARTY CONTINUATION WORD - track number, index originator."""

    env: str
    """Environment."""

    index: int
    """Index number."""

    lat: float
    """WGS84 latitude, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: float
    """WGS84 longitude, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    orginx: str
    """Origin of index number."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    rc: str
    """Receipt/Compliance, values from TABLE B-9."""

    rr: int
    """Recurrence rate, receipt/compliance."""

    sz: str
    """Strength."""

    tno: str
    """Track number objective."""

    trk_id: Annotated[str, PropertyInfo(alias="trkId")]
    """The track ID that the status is referencing, addressee."""

    twenv: str
    """Threat warning environment."""
