# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["MonoradarListResponse", "MonoradarListResponseItem"]


class MonoradarListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    msgfmt: str
    """Message format received (i.e. 'ASR9', 'CAT48', 'TPS70', etc..)."""

    msgts: datetime
    """Message time, in ISO 8601 UTC format with microsecond precision.

    This is the time that the data message was released from the site.
    """

    msgtyp: str
    """Message report type received (i.e.

    'SRCH', 'BCN', 'REINF', 'BRTQC', 'PSR', etc..).
    """

    source: str
    """Source of the data."""

    ts: datetime
    """Target detection time, in ISO 8601 UTC format with microsecond precision."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    acp: Optional[int] = None
    """Azimuth Change Pulse count at target detection."""

    addr: Optional[str] = None
    """Aircraft address (24-bits Mode S address) assigned uniquely to each aircraft."""

    af: Optional[bool] = None
    """Flag indicating military message."""

    aims: Optional[bool] = None
    """Flag indicating whether AIMS present."""

    alt3d: Optional[float] = None
    """Measured height of the target, in km. (for 3D radars)."""

    artsqual: Optional[str] = None
    """ARTS quality."""

    az: Optional[float] = None
    """Target azimuth, measured from the observing site, in degrees from true North.

    If Azimuth Change Pulse (acp) count is provided, az represents the computed
    angle.
    """

    azdelt: Optional[float] = None
    """Target azimuth delta between PSR and SSR (reference PSR-SSR), in degrees."""

    bcnhits: Optional[int] = None
    """Number of beacon hits received on the target."""

    cartpos: Optional[List[float]] = None
    """Array of local 2d-cartesian [x, y] coordinates of target, in km."""

    cdm: Optional[str] = None
    """Climbing/Descending mode indicator."""

    code7500: Optional[bool] = None
    """7500 squawk present (hijack)."""

    code7600: Optional[bool] = None
    """7600 squawk present (loss of comm)."""

    code7700: Optional[bool] = None
    """7700 squawk present (general emergency)."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """Application user who created the row in the database."""

    faa: Optional[bool] = None
    """Flag indicating FAA/Civ message."""

    grndspd: Optional[float] = None
    """Target ground speed, in meters/second."""

    hdng: Optional[float] = None
    """Target heading, in degrees from true North at the target position."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """ID of the radar site or station providing the data."""

    m1: Optional[str] = None
    """Mode-1 interrogation response (mission code)."""

    m1g: Optional[bool] = None
    """Indicator that the mode-1 response was garbled."""

    m1v: Optional[str] = None
    """Status of the mode-1 validity bit."""

    m2: Optional[str] = None
    """Mode-2 interrogation response (military identification code)."""

    m2g: Optional[bool] = None
    """Indicator that the mode-2 response was garbled."""

    m2v: Optional[str] = None
    """Status of the mode-2 validity bit."""

    m2xv: Optional[str] = None
    """Status of the mode-2 X-Pulse response validation."""

    m3a: Optional[str] = None
    """Mode-3/A interrogation response (aircraft identification)."""

    m3ag: Optional[bool] = None
    """Indicator that the mode-3/A response was garbled."""

    m3av: Optional[str] = None
    """Status of the mode-3/A validity bit."""

    m3axv: Optional[str] = None
    """Status of the mode-3 X-Pulse response validation."""

    m4: Optional[str] = None
    """Mode-4 interrogation response (Identification Friend/Foe)."""

    m4d1d2: Optional[str] = None
    """Mode-4 D1 & D2 response status."""

    m4v: Optional[str] = None
    """Status of the mode-4 validity bit."""

    mah: Optional[str] = None
    """Indication of Horizontal Maneuver detection."""

    mc: Optional[float] = None
    """Mode-C altitude (uncorrected pressure altitude), in km."""

    mcg: Optional[bool] = None
    """Indicator that the mode-C response was garbled."""

    mcv: Optional[str] = None
    """Status of the mode-C validity bit."""

    milemrgcy: Optional[bool] = None
    """Flag indicating military emergency."""

    mrgrpt: Optional[bool] = None
    """Flag indicating report separated from different responses at same range.

    Azimuth may have larger than normal error when present.
    """

    mscommb: Optional[str] = None
    """Mode-S Comm B message data."""

    mti: Optional[bool] = None
    """Flag indicating that target was detected using data from an MTI receiver."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by observation source to indicate the sensor
    identifier which produced this observation.This may be an internal identifier
    and not necessarily a valid sensor ID.
    """

    psrrl: Optional[float] = None
    """Runlength of the primary surveillance radar track, in degrees."""

    rad: Optional[str] = None
    """Type of sensor(s) maintaining track."""

    rng: Optional[float] = None
    """Measured slant range to target from the observing site, in km."""

    rngdelt: Optional[float] = None
    """Target range delta between PSR and SSR (reference PSR-SSR), in km."""

    sac: Optional[int] = None
    """System Area Code."""

    senalt: Optional[float] = None
    """Sensor altitude, in kilometers, at time of observation (ts)."""

    senlat: Optional[float] = None
    """Sensor WGS84 latitude, in degrees, at time of observation (ts).

    -90 to 90 degrees (negative values south of equator).
    """

    senlon: Optional[float] = None
    """Sensor WGS84 longitude, in degrees, at time of observation (ts).

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    sic: Optional[int] = None
    """System Identification Code."""

    spi: Optional[bool] = None
    """
    Flag indicating whether Special Position Indicator (SPI) present in
    interrogation response.
    """

    ssrl: Optional[float] = None
    """Runlength of the secondary surveillance radar track, in degrees."""

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    tgtconf: Optional[str] = None
    """Target confidence."""

    tgtcorr: Optional[str] = None
    """Target correlation flag."""

    tgtid: Optional[str] = None
    """Aircraft identification from an aircraft equipped with a Mode S transponder."""

    tis: Optional[float] = None
    """Data time-in-storage, in seconds.

    This is the amount of time elapsed between target detection and message
    transmission.
    """

    trkelig: Optional[str] = None
    """Track eligibility flag."""

    trknum: Optional[int] = None
    """
    Value representing a unique reference to a track record within a particular
    track file. Included when the radar station outputs tracks.
    """

    tti: Optional[str] = None
    """Test target indicator."""

    wectc: Optional[List[str]] = None
    """Warning/Error Conditions and Target Classification."""


MonoradarListResponse: TypeAlias = List[MonoradarListResponseItem]
