# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import date
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["NavigationalobstructionUpdateParams"]


class NavigationalobstructionUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    cycle_date: Required[Annotated[Union[str, date], PropertyInfo(alias="cycleDate", format="iso8601")]]
    """
    Start date of this obstruction data set's currency, in ISO 8601 date-only
    format.
    """

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    obstacle_id: Required[Annotated[str, PropertyInfo(alias="obstacleId")]]
    """The ID of this obstacle."""

    obstacle_type: Required[Annotated[str, PropertyInfo(alias="obstacleType")]]
    """Type of obstacle (e.g. P for point, V for vector, L for line)."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    act_del_code: Annotated[str, PropertyInfo(alias="actDelCode")]
    """Indicates if this obstacle record is Active (A) or Deleted (D)."""

    airac_cycle: Annotated[int, PropertyInfo(alias="airacCycle")]
    """
    The Aeronautical Information Regulation and Control (AIRAC) cycle of this
    obstruction data set. The format is YYNN where YY is the last two digits of the
    year and NN is the cycle number.
    """

    base_airac_cycle: Annotated[int, PropertyInfo(alias="baseAiracCycle")]
    """
    The baseline Aeronautical Information Regulation and Control (AIRAC) cycle for
    change sets only. The format is YYNN where YY is the last two digits of the year
    and NN is the cycle number.
    """

    baseline_cutoff_date: Annotated[Union[str, date], PropertyInfo(alias="baselineCutoffDate", format="iso8601")]
    """
    Earliest record date possible in this obstruction data set (not the earliest
    data item), in ISO 8601 date-only format (e.g. YYYY-MM-DD). If null, this data
    set is assumed to be a full data pull of holdings until the cutoffDate. If this
    field is populated, this data set only contains updates since the last baseline
    data set.
    """

    bound_ne_lat: Annotated[float, PropertyInfo(alias="boundNELat")]
    """
    WGS-84 latitude of the northeastern boundary for obstructions contained in this
    data set, in degrees. -90 to 90 degrees (negative values south of equator).
    """

    bound_ne_lon: Annotated[float, PropertyInfo(alias="boundNELon")]
    """
    WGS-84 longitude of the northeastern boundary for obstructions contained in this
    data set, in degrees. -180 to 180 degrees (negative values west of Prime
    Meridian).
    """

    bound_sw_lat: Annotated[float, PropertyInfo(alias="boundSWLat")]
    """
    WGS-84 latitude of the southwestern boundary for obstructions contained in this
    data set, in degrees. -90 to 90 degrees (negative values south of equator).
    """

    bound_sw_lon: Annotated[float, PropertyInfo(alias="boundSWLon")]
    """
    WGS-84 longitude of the southwestern boundary for obstructions contained in this
    data set, in degrees. -180 to 180 degrees (negative values west of Prime
    Meridian).
    """

    country_code: Annotated[str, PropertyInfo(alias="countryCode")]
    """
    The DoD Standard Country Code designator for the country issuing the diplomatic
    clearance. This field will be set to "OTHR" if the source value does not match a
    UDL Country code value (ISO-3166-ALPHA-2).
    """

    cutoff_date: Annotated[Union[str, date], PropertyInfo(alias="cutoffDate", format="iso8601")]
    """
    Latest record date possible in this obstruction data set (not the most recent
    data item), in ISO 8601 date-only format (e.g. YYYY-MM-DD).
    """

    data_set_remarks: Annotated[str, PropertyInfo(alias="dataSetRemarks")]
    """Remarks concerning this obstruction's data set."""

    deleting_org: Annotated[str, PropertyInfo(alias="deletingOrg")]
    """The organization that deleted this obstacle record."""

    deriving_org: Annotated[str, PropertyInfo(alias="derivingOrg")]
    """The organization that entered obstacle data other than the producer."""

    directivity_code: Annotated[int, PropertyInfo(alias="directivityCode")]
    """
    The side or sides of this obstruction feature which produces the greatest
    reflectivity potential.
    """

    elevation: float
    """The elevation at the point obstacle's location in feet."""

    elevation_acc: Annotated[float, PropertyInfo(alias="elevationAcc")]
    """
    The difference between the assigned elevation of this point and its true
    elevation, in feet.
    """

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """Optional obstacle ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    facc: str
    """
    FACC (Feature and Attribute Coding Catalog) is a five-character code for
    encoding real-world entities and objects. The first letter of the code is an
    alphabetic value from "A" to "Z" which will map to a feature category. The
    second character will map to a subcategory. Characters three to five are numeric
    and range from 000 to 999. This value will provide a unit feature type
    identification within the categories.
    """

    feature_code: Annotated[str, PropertyInfo(alias="featureCode")]
    """Identifying code for the type of this point obstacle."""

    feature_description: Annotated[str, PropertyInfo(alias="featureDescription")]
    """
    Description of this obstacle, corresponding to the FACC (Feature and Attribute
    Coding Catalog) value.
    """

    feature_name: Annotated[str, PropertyInfo(alias="featureName")]
    """Type name of point obstacle."""

    feature_type: Annotated[str, PropertyInfo(alias="featureType")]
    """Identifying code for the type of this point obstacle."""

    height_agl: Annotated[float, PropertyInfo(alias="heightAGL")]
    """The height Above Ground Level (AGL) of the point obstacle in feet."""

    height_agl_acc: Annotated[float, PropertyInfo(alias="heightAGLAcc")]
    """
    The accuracy of the height Above Ground Level (AGL) value for this point
    obstacle, in feet.
    """

    height_msl: Annotated[float, PropertyInfo(alias="heightMSL")]
    """The height Above Mean Sea Level (AMSL) of the point obstacle in feet."""

    height_msl_acc: Annotated[float, PropertyInfo(alias="heightMSLAcc")]
    """
    The accuracy of the height Above Mean Sea Level (AMSL) value for this point
    obstacle in feet.
    """

    horiz_acc: Annotated[float, PropertyInfo(alias="horizAcc")]
    """
    The difference between the recorded horizontal coordinates of this point
    obstacle and its true position, in feet.
    """

    horiz_datum_code: Annotated[str, PropertyInfo(alias="horizDatumCode")]
    """
    Code representing the mathematical model of Earth used to calculate coordinates
    for this obstacle (e.g. WGS-84, U for undetermined, etc.). US Forces use the
    World Geodetic System 1984 (WGS-84), but also use maps by allied countries with
    local datums.
    """

    init_record_date: Annotated[Union[str, date], PropertyInfo(alias="initRecordDate", format="iso8601")]
    """
    Date this obstacle was initially added to the data set, in ISO 8601 date-only
    format (ex. YYYY-MM-DD).
    """

    keys: List[str]
    """
    This field provides an array of keys that can be added to any obstruction
    feature to provide information that is not already supported. The entries in
    this array must correspond to the position index in the values array. This array
    must be the same length as values.
    """

    lighting_code: Annotated[str, PropertyInfo(alias="lightingCode")]
    """Code specifying if this obstacle is lit (e.g. Y = Yes, N = No, U = Unknown)."""

    line_ne_lat: Annotated[float, PropertyInfo(alias="lineNELat")]
    """WGS-84 latitude of the northeastern point of the line, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    line_ne_lon: Annotated[float, PropertyInfo(alias="lineNELon")]
    """WGS-84 longitude of the northeastern point of the line, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    lines_filename: Annotated[str, PropertyInfo(alias="linesFilename")]
    """The name of the line file associated with this obstruction data set."""

    line_sw_lat: Annotated[float, PropertyInfo(alias="lineSWLat")]
    """WGS-84 latitude of the southwestern point of the line, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    line_sw_lon: Annotated[float, PropertyInfo(alias="lineSWLon")]
    """WGS-84 longitude of the southwestern point of the line, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    min_height_agl: Annotated[float, PropertyInfo(alias="minHeightAGL")]
    """
    The minimum height Above Ground Level (AGL) of the shortest obstruction
    contained in this data set, in feet.
    """

    mult_obs: Annotated[str, PropertyInfo(alias="multObs")]
    """Indicates if the feature has multiple obstructions (e.g.

    S = Single, M = Multiple, U = Undetermined).
    """

    next_cycle_date: Annotated[Union[str, date], PropertyInfo(alias="nextCycleDate", format="iso8601")]
    """
    The date after which this obstruction data set’s currency is stale and should be
    refreshed, in ISO 8601 date-only format (e.g. YYYY-MM-DD).
    """

    num_lines: Annotated[int, PropertyInfo(alias="numLines")]
    """The number of line features associated with this obstruction data set."""

    num_obs: Annotated[int, PropertyInfo(alias="numObs")]
    """Indicates the number of obstructions associated with a feature."""

    num_points: Annotated[int, PropertyInfo(alias="numPoints")]
    """The number of point features associated with this obstruction data set."""

    obstacle_remarks: Annotated[str, PropertyInfo(alias="obstacleRemarks")]
    """Remarks regarding this obstacle."""

    orig_id: Annotated[str, PropertyInfo(alias="origId")]
    """The original ID for this obstacle."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    owner_country_code: Annotated[str, PropertyInfo(alias="ownerCountryCode")]
    """
    The DoD Standard Country Code designator for the country or political entity
    that owns the data set associated with this obstruction. This field will be set
    to "OTHR" if the source value does not match a UDL Country code value
    (ISO-3166-ALPHA-2).
    """

    point_lat: Annotated[float, PropertyInfo(alias="pointLat")]
    """WGS-84 latitude of this point obstacle, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    point_lon: Annotated[float, PropertyInfo(alias="pointLon")]
    """WGS-84 longitude of this point obstacle, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    points_filename: Annotated[str, PropertyInfo(alias="pointsFilename")]
    """The name of the point file associated with this obstruction data set."""

    process_code: Annotated[str, PropertyInfo(alias="processCode")]
    """Code denoting the action, review, or process that updated this obstacle."""

    producer: str
    """Name of the agency that produced this obstruction data set."""

    province_code: Annotated[str, PropertyInfo(alias="provinceCode")]
    """
    The Federal Information Processing Standards (FIPS) state/province numeric code
    of this obstacle's location.
    """

    quality: str
    """
    When horizontal and/or vertical accuracy requirements cannot be met because of
    inadequate source material, this code indicates the quality of the data.
    """

    rev_date: Annotated[Union[str, date], PropertyInfo(alias="revDate", format="iso8601")]
    """Date this obstacle data was revised, in ISO 8601 date-only format (ex.

    YYYY-MM-DD).
    """

    seg_end_point: Annotated[int, PropertyInfo(alias="segEndPoint")]
    """ID of the end point of a line segment."""

    seg_num: Annotated[int, PropertyInfo(alias="segNum")]
    """Identifies the sequence number of a line segment."""

    seg_start_point: Annotated[int, PropertyInfo(alias="segStartPoint")]
    """ID of the starting point of a line segment."""

    source_date: Annotated[Union[str, date], PropertyInfo(alias="sourceDate", format="iso8601")]
    """Source date of this obstacle data, in ISO 8601 date-only format (ex.

    YYYY-MM-DD).
    """

    surface_mat_code: Annotated[str, PropertyInfo(alias="surfaceMatCode")]
    """The surface material composition code of this point obstacle."""

    transaction_code: Annotated[str, PropertyInfo(alias="transactionCode")]
    """The transaction type/code for this obstacle (e.g.

    "D", "N", "R", "S", "V", "X").
    """

    validation_code: Annotated[int, PropertyInfo(alias="validationCode")]
    """Method used to confirm the existence of this obstacle."""

    values: List[str]
    """
    This field provides an array of values that can be added to any obstruction
    feature to provide information that is not already supported. The entries in
    this array must correspond to the position index in the keys array. This array
    must be the same length as keys.
    """

    vectors_filename: Annotated[str, PropertyInfo(alias="vectorsFilename")]
    """The name of the vector file associated with this obstruction data set."""

    wac: str
    """
    The World Aeronautical Chart (WAC) identifier for the area in which this
    obstacle is located.
    """

    wac_innr: Annotated[str, PropertyInfo(alias="wacINNR")]
    """This obstacle's World Area Code installation number (WAC-INNR)."""
