# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.onorbit_full import OnorbitFull

__all__ = ["ObjectofinterestGetResponse", "Manifold"]


class Manifold(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_object_of_interest: str = FieldInfo(alias="idObjectOfInterest")
    """ID of the parent object of interest."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    delta_t: Optional[float] = FieldInfo(alias="deltaT", default=None)
    """Applied delta V duration for this manifold's calculations in seconds."""

    delta_v: Optional[float] = FieldInfo(alias="deltaV", default=None)
    """Applied delta V for this manifold's calculations, in km/sec."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    status: Optional[str] = None
    """Status of the manifold and its associated ManifoldElsets (e.g.

    PENDING, COMPLETE). PENDING status means element set generation is in progress
    and COMPLETE indicates all ManifoldElsets have been generated.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """
    Read-only time the row was updated in the database, set automatically by the
    system on update.
    """

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who last updated the row in the database, set by the system
    automatically and ignored on create/edit operations.
    """

    weight: Optional[float] = None
    """
    Weight or probability of this manifold for prioritization purposes, between 0
    and 1.
    """


class ObjectofinterestGetResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_on_orbit: str = FieldInfo(alias="idOnOrbit")
    """UUID of the parent Onorbit record."""

    sensor_tasking_start_time: datetime = FieldInfo(alias="sensorTaskingStartTime")
    """Sensor tasking start time for object of interest."""

    source: str
    """Source of the data."""

    status_date: datetime = FieldInfo(alias="statusDate")
    """Time of last status change of the object of interest event."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    affected_objects: Optional[List[str]] = FieldInfo(alias="affectedObjects", default=None)
    """
    Optional array of Onorbit IDs (idOnOrbit) representing satellites potentially
    affected by this object of interest.
    """

    apogee: Optional[float] = None
    """Last reported apogee.

    The Orbit point furthest from the center of the earth in kilometers.
    """

    arg_of_perigee: Optional[float] = FieldInfo(alias="argOfPerigee", default=None)
    """Last reported argument of perigee.

    The argument of perigee is the angle in degrees formed between the perigee and
    the ascending node. If the perigee would occur at the ascending node, the
    argument of perigee would be 0.
    """

    b_star: Optional[float] = FieldInfo(alias="bStar", default=None)
    """
    Last reported drag term for SGP4 orbital model, used for calculating decay
    constants for altitude, eccentricity etc, measured in inverse earth radii.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    delta_ts: Optional[List[float]] = FieldInfo(alias="deltaTs", default=None)
    """Possible delta time applications for the object of interest, in seconds."""

    delta_vs: Optional[List[float]] = FieldInfo(alias="deltaVs", default=None)
    """Possible delta V applications for the object of interest, in km/sec."""

    description: Optional[str] = None
    """Description of the object of interest event."""

    eccentricity: Optional[float] = None
    """Last reported eccentricity of the object.

    The orbital eccentricity of an astronomical object is a parameter that
    determines the amount by which its orbit around another body deviates from a
    perfect circle. A value of 0 is a circular orbit, values between 0 and 1 form an
    elliptic orbit, 1 is a parabolic escape orbit, and greater than 1 is a
    hyperbolic escape orbit.
    """

    elset_epoch: Optional[datetime] = FieldInfo(alias="elsetEpoch", default=None)
    """
    Last reported elset epoch time in ISO 8601 UTC time, with microsecond precision.
    """

    inclination: Optional[float] = None
    """Last reported inclination of the object.

    Inclination is the angle between the equator and the orbit when looking from the
    center of the Earth. If the orbit went exactly around the equator from left to
    right, then the inclination would be 0. The inclination ranges from 0 to 180
    degrees.
    """

    last_ob_time: Optional[datetime] = FieldInfo(alias="lastObTime", default=None)
    """
    Last reported observation time in ISO 8601 UTC time, with microsecond precision.
    """

    manifolds: Optional[List[Manifold]] = None
    """Manifolds associated with this object of interest."""

    mean_anomaly: Optional[float] = FieldInfo(alias="meanAnomaly", default=None)
    """Last reported meanAnomaly.

    Mean anomoly is where the satellite is in its orbital path. The mean anomaly
    ranges from 0 to 360 degrees. The mean anomaly is referenced to the perigee. If
    the satellite were at the perigee, the mean anomaly would be 0.
    """

    mean_motion: Optional[float] = FieldInfo(alias="meanMotion", default=None)
    """Last reported mean motion of the object.

    Mean motion is the angular speed required for a body to complete one orbit,
    assuming constant speed in a circular orbit which completes in the same time as
    the variable speed, elliptical orbit of the actual body. Measured in revolutions
    per day.
    """

    mean_motion_d_dot: Optional[float] = FieldInfo(alias="meanMotionDDot", default=None)
    """Last reported 2nd derivative of the mean motion with respect to time.

    Units are revolutions per day cubed.
    """

    mean_motion_dot: Optional[float] = FieldInfo(alias="meanMotionDot", default=None)
    """Last reported 1st derivative of the mean motion with respect to time.

    Units are revolutions per day squared.
    """

    missed_ob_time: Optional[datetime] = FieldInfo(alias="missedObTime", default=None)
    """
    The time at which an attempted observation of the object of interest noticed it
    was missing, in ISO 8601 UTC time, with microsecond precision.
    """

    name: Optional[str] = None
    """Unique name of the object of interest event."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    perigee: Optional[float] = None
    """Last reported perigee.

    The orbit point nearest to the center of the earth in kilometers.
    """

    period: Optional[float] = None
    """Last reported orbit period.

    Period of the orbit is equal to inverse of mean motion.
    """

    priority: Optional[int] = None
    """Priority of the object of interest as an integer (1=highest priority)."""

    raan: Optional[float] = None
    """Last reported raan.

    Right ascension of the ascending node, or RAAN is the angle as measured in
    degrees eastwards (or, as seen from the north, counterclockwise) from the First
    Point of Aries to the ascending node, which is where the orbit crosses the
    equator when traveling north.
    """

    rev_no: Optional[int] = FieldInfo(alias="revNo", default=None)
    """The last reported revolution number.

    The value is incremented when a satellite crosses the equator on an ascending
    pass.
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/Catalog number of the target on-orbit object."""

    semi_major_axis: Optional[float] = FieldInfo(alias="semiMajorAxis", default=None)
    """
    Last reported semi major axis, which is the sum of the periapsis and apoapsis
    distances divided by two. For circular orbits, the semimajor axis is the
    distance between the centers of the bodies, not the distance of the bodies from
    the center of mass.
    """

    sensor_tasking_stop_time: Optional[datetime] = FieldInfo(alias="sensorTaskingStopTime", default=None)
    """Sensor tasking stop time for object of interest."""

    status: Optional[str] = None
    """Status of the object of interest event (e.g. OPEN, CLOSED, CANCELLED)."""

    sv_epoch: Optional[datetime] = FieldInfo(alias="svEpoch", default=None)
    """
    Last reported state vector epoch time in ISO 8601 UTC time, with microsecond
    precision.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    x: Optional[float] = None
    """Last reported x position of the object in km, in J2000 coordinates."""

    xvel: Optional[float] = None
    """Last reported x velocity of the object in km/sec, in J2000 coordinates."""

    y: Optional[float] = None
    """Last reported y position of the object in km, in J2000 coordinates."""

    yvel: Optional[float] = None
    """Last reported y velocity of the object in km/sec, in J2000 coordinates."""

    z: Optional[float] = None
    """Last reported z position of the object in km, in J2000 coordinates."""

    zvel: Optional[float] = None
    """Last reported z velocity of the object in km/sec, in J2000 coordinates."""
