# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from ..shared.onorbit_full import OnorbitFull

__all__ = ["Ecpsdr"]


class Ecpsdr(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    msg_time: datetime = FieldInfo(alias="msgTime")
    """
    Time stamp of time packet receipt on ground, in ISO 8601 UTC format with
    millisecond precision.
    """

    source: str
    """Source of the data."""

    type: str
    """The type of data associated with this record (STANDARD, TRANSIENT)."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    asl5_v_curr_mon: Optional[int] = FieldInfo(alias="asl5VCurrMon", default=None)
    """Internal 5V current monitor for analog supply line.

    This is sensor status telemetry. See vRef for conversion factor to Volts.
    """

    cds_plate_v_mon: Optional[int] = FieldInfo(alias="cdsPlateVMon", default=None)
    """CDS Charge Plate voltage monitor. See vRef for conversion factor to Volts."""

    cds_ref_v_mon: Optional[int] = FieldInfo(alias="cdsRefVMon", default=None)
    """CDS reference voltage monitor. See vRef for conversion factor to Volts."""

    cds_threshold: Optional[int] = FieldInfo(alias="cdsThreshold", default=None)
    """CDS Threshold setting for ESD detection threshold.

    The CDS Threshold is the adjustable sensitivity of recording/digitizing an ESD
    as a transient packet.
    """

    cds_throttle: Optional[int] = FieldInfo(alias="cdsThrottle", default=None)
    """CDS throttle number of seconds between CDS transient capture readouts."""

    checksum: Optional[int] = None
    """Two byte CRC-16-CCITT checksum (ordered as first byte, second byte)."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    dos_bias: Optional[int] = FieldInfo(alias="dosBias", default=None)
    """Unitless dosimeter detector bias for MedLET and HiLET.

    MedLET (Linear Energy Transfer) and HiLET subsensors detect particles above LET
    thresholds, 300keV and 1MeV, respectively.
    """

    dsl5_v_curr_mon: Optional[int] = FieldInfo(alias="dsl5VCurrMon", default=None)
    """Internal 5V current monitor for digital supply line.

    This is sensor status telemetry. See vRef for conversion factor to Volts.
    """

    esd_trig_count_h: Optional[int] = FieldInfo(alias="esdTrigCountH", default=None)
    """Number of ESD triggers, high byte of 2-byte counter."""

    esd_trig_count_l: Optional[int] = FieldInfo(alias="esdTrigCountL", default=None)
    """Number of ESD triggers, low byte of 2-byte counter."""

    hi_let_l: Optional[int] = FieldInfo(alias="hiLetL", default=None)
    """HiLET dosimeter low range output. Low byte of scaler (HiLET) dosimeter output."""

    hi_let_m: Optional[int] = FieldInfo(alias="hiLetM", default=None)
    """Unitless HiLET dosimeter medium range output.

    Medium byte of (HiLET) dosimeter output.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the on-orbit satellite hosting the sensor."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the reporting sensor."""

    low_let_l: Optional[int] = FieldInfo(alias="lowLetL", default=None)
    """LowLET dosimeter low range output. Low byte of (LowLET) dosimeter output."""

    low_let_m: Optional[int] = FieldInfo(alias="lowLetM", default=None)
    """LowLET dosimeter medium range output. Medium byte of (LowLET) dosimeter output."""

    med_let1_l: Optional[int] = FieldInfo(alias="medLet1L", default=None)
    """MedLET1 dosimeter low range output.

    Low byte of the 1st (MedLET) dosimeter output.
    """

    med_let1_m: Optional[int] = FieldInfo(alias="medLet1M", default=None)
    """MedLET1 dosimeter medium range output.

    Medium byte of the 1st (MedLET) dosimeter output.
    """

    med_let2_l: Optional[int] = FieldInfo(alias="medLet2L", default=None)
    """MedLET2 dosimeter low range output.

    Low byte of the 2nd (MedLET) dosimeter output.
    """

    med_let2_m: Optional[int] = FieldInfo(alias="medLet2M", default=None)
    """MedLET2 dosimeter medium range output.

    Medium byte of the 2nd (MedLET) dosimeter output.
    """

    med_let3_l: Optional[int] = FieldInfo(alias="medLet3L", default=None)
    """MedLET3 dosimeter low range output.

    Low byte of the 3rd (MedLET) dosimeter output.
    """

    med_let3_m: Optional[int] = FieldInfo(alias="medLet3M", default=None)
    """MedLET3 dosimeter medium range output.

    Medium byte of the 3rd (MedLET) dosimeter output.
    """

    med_let4_l: Optional[int] = FieldInfo(alias="medLet4L", default=None)
    """MedLET4 dosimeter low range output.

    Low byte of the 4th (MedLET) dosimeter output.
    """

    med_let4_m: Optional[int] = FieldInfo(alias="medLet4M", default=None)
    """MedLET4 dosimeter medium range output.

    Medium byte of the 4th (MedLET) dosimeter output.
    """

    mp_temp: Optional[int] = FieldInfo(alias="mpTemp", default=None)
    """Unitless sensor mounting plate temperature."""

    ob_time: Optional[datetime] = FieldInfo(alias="obTime", default=None)
    """Time of the observation, in ISO 8601 UTC format with millisecond precision."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by the record source to indicate the satellite
    hosting the sensor. This may be an internal identifier and not necessarily map
    to a valid satellite number.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by the record source to indicate the sensor
    identifier which produced this data. This may be an internal identifier and not
    necessarily a valid sensor ID.
    """

    pd1_sig_lev: Optional[int] = FieldInfo(alias="pd1SigLev", default=None)
    """Photodiode 1 signal level."""

    pd2_sig_lev: Optional[int] = FieldInfo(alias="pd2SigLev", default=None)
    """Photodiode 2 signal level."""

    ps_temp_mon: Optional[int] = FieldInfo(alias="psTempMon", default=None)
    """Power supply temperature monitor. This is sensor status telemetry."""

    retransmit: Optional[bool] = None
    """
    Flag indicating whether this record is an original or re-transmitted dataset
    (TRUE indicates a retransmit from the host).
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/catalog number of the on-orbit satellite hosting the sensor."""

    sen_mode: Optional[str] = FieldInfo(alias="senMode", default=None)
    """The sensor mode associated with this measurements (NORMAL, TEST)."""

    surf_dos_charge_h: Optional[int] = FieldInfo(alias="surfDosChargeH", default=None)
    """Surface dosimeter charge rate high output (converts to pico-amps/bit).

    High byte of 2 bytes.
    """

    surf_dos_charge_l: Optional[int] = FieldInfo(alias="surfDosChargeL", default=None)
    """Surface dosimeter charge rate low output (converts to pico-amps/bit).

    Low byte of 2 bytes.
    """

    surf_dos_h: Optional[int] = FieldInfo(alias="surfDosH", default=None)
    """Surface dosimeter high range output (converts to pico-coulombs/bit).

    High byte of 3 bytes.
    """

    surf_dos_l: Optional[int] = FieldInfo(alias="surfDosL", default=None)
    """Surface dosimeter low range output (converts to pico-coulombs/bit).

    Low byte of 3 bytes.
    """

    surf_dos_m: Optional[int] = FieldInfo(alias="surfDosM", default=None)
    """Surface dosimeter medium range output (converts to pico-coulombs/bit).

    Middle byte of 3 bytes.
    """

    surf_dos_stat: Optional[int] = FieldInfo(alias="surfDosStat", default=None)
    """Surface dosimeter status byte."""

    transient_data: Optional[List[int]] = FieldInfo(alias="transientData", default=None)
    """Array of 144 digitized samples of ESD waveform for transient packets."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    v_ref: Optional[int] = FieldInfo(alias="vRef", default=None)
    """Reference voltage (volts/bit).

    Conversion factor used to convert analog V monitor data from bytes to volts.
    """
