# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["AntennaDetailUpdateParams"]


class AntennaDetailUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_antenna: Required[Annotated[str, PropertyInfo(alias="idAntenna")]]
    """Unique identifier of the parent Antenna."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    beam_forming: Annotated[bool, PropertyInfo(alias="beamForming")]
    """Boolean indicating if this is a beam forming antenna."""

    beamwidth: float
    """
    Array of angles between the half-power (-3 dB) points of the main lobe of the
    antenna, in degrees.
    """

    description: str
    """Antenna description."""

    diameter: float
    """Antenna diameter in meters."""

    end_frequency: Annotated[float, PropertyInfo(alias="endFrequency")]
    """Antenna end of frequency range in Mhz."""

    gain: float
    """Antenna maximum gain in dBi."""

    gain_tolerance: Annotated[float, PropertyInfo(alias="gainTolerance")]
    """Antenna gain tolerance in dB."""

    manufacturer_org_id: Annotated[str, PropertyInfo(alias="manufacturerOrgId")]
    """ID of the organization that manufactures the antenna."""

    mode: Literal["TX", "RX"]
    """Antenna mode (e.g. TX,RX)."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    polarization: float
    """Antenna polarization in degrees."""

    position: str
    """Antenna position (e.g. Top, Nadir, Side)."""

    size: Iterable[float]
    """
    Array with 1-2 values specifying the length and width (for rectangular) and just
    length for dipole antennas in meters.
    """

    start_frequency: Annotated[float, PropertyInfo(alias="startFrequency")]
    """Antenna start of frequency range in Mhz."""

    steerable: bool
    """Boolean indicating if this antenna is steerable."""

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    type: str
    """Type of antenna (e.g.

    Reflector, Double Reflector, Shaped Reflector, Horn, Parabolic, etc.).
    """
