# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OnorbitdetailListResponse", "OnorbitdetailListResponseItem"]


class OnorbitdetailListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_on_orbit: str = FieldInfo(alias="idOnOrbit")
    """UUID of the parent Onorbit record."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    additional_mass: Optional[float] = FieldInfo(alias="additionalMass", default=None)
    """Mass of fuel and disposables at launch time in kilograms."""

    adept_radius: Optional[float] = FieldInfo(alias="adeptRadius", default=None)
    """
    The radius used for long-term debris environment projection analyses that is not
    as conservative as COLA Radius, in meters.
    """

    bol_delta_v: Optional[float] = FieldInfo(alias="bolDeltaV", default=None)
    """The total beginning of life delta V of the spacecraft, in meters per second."""

    bol_fuel_mass: Optional[float] = FieldInfo(alias="bolFuelMass", default=None)
    """Spacecraft beginning of life fuel mass, in orbit, in kilograms."""

    bus_cross_section: Optional[float] = FieldInfo(alias="busCrossSection", default=None)
    """Average cross sectional area of the bus in meters squared."""

    bus_type: Optional[str] = FieldInfo(alias="busType", default=None)
    """Type of the bus on the spacecraft."""

    cola_radius: Optional[float] = FieldInfo(alias="colaRadius", default=None)
    """
    Maximum dimension of the box circumscribing the spacecraft (d = sqrt(a*a + b*b +
    c\\**c) where a is the tip-to-tip dimension, b and c are perpendicular to that.)
    in meters.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    cross_section: Optional[float] = FieldInfo(alias="crossSection", default=None)
    """Average cross sectional area in meters squared."""

    current_mass: Optional[float] = FieldInfo(alias="currentMass", default=None)
    """The estimated total current mass of the spacecraft, in kilograms."""

    delta_v_unc: Optional[float] = FieldInfo(alias="deltaVUnc", default=None)
    """The 1-sigma uncertainty of the total spacecraft delta V, in meters per second."""

    dep_est_masses: Optional[List[float]] = FieldInfo(alias="depEstMasses", default=None)
    """Array of the estimated mass of each deployable object, in kilograms.

    Must contain the same number of elements as the value of numDeployable.
    """

    dep_mass_uncs: Optional[List[float]] = FieldInfo(alias="depMassUncs", default=None)
    """
    Array of the 1-sigma uncertainty of the mass for each deployable object, in
    kilograms. Must contain the same number of elements as the value of
    numDeployable.
    """

    dep_names: Optional[List[str]] = FieldInfo(alias="depNames", default=None)
    """Array of satellite deployable objects.

    Must contain the same number of elements as the value of numDeployable.
    """

    drift_rate: Optional[float] = FieldInfo(alias="driftRate", default=None)
    """GEO drift rate, if applicable in degrees per day."""

    dry_mass: Optional[float] = FieldInfo(alias="dryMass", default=None)
    """Spacecraft dry mass (without fuel or disposables) in kilograms."""

    est_delta_v_duration: Optional[float] = FieldInfo(alias="estDeltaVDuration", default=None)
    """Estimated maximum burn duration for the object, in seconds."""

    fuel_remaining: Optional[float] = FieldInfo(alias="fuelRemaining", default=None)
    """Estimated remaining fuel for the object in kilograms."""

    geo_slot: Optional[float] = FieldInfo(alias="geoSlot", default=None)
    """GEO slot if applicable, in degrees.

    -180 (West of Prime Meridian) to 180 degrees (East of Prime Meridian). Prime
    Meridian is 0.
    """

    last_ob_source: Optional[str] = FieldInfo(alias="lastObSource", default=None)
    """The name of the source who last provided an observation for this idOnOrbit."""

    last_ob_time: Optional[datetime] = FieldInfo(alias="lastObTime", default=None)
    """
    Time of last reported observation for this object in ISO 8601 UTC with
    microsecond precision.
    """

    launch_mass: Optional[float] = FieldInfo(alias="launchMass", default=None)
    """Nominal mass of spacecraft and fuel at launch time, in kilograms."""

    launch_mass_max: Optional[float] = FieldInfo(alias="launchMassMax", default=None)
    """Maximum (estimated) mass of spacecraft and fuel at launch time, in kilograms."""

    launch_mass_min: Optional[float] = FieldInfo(alias="launchMassMin", default=None)
    """Minimum (estimated) mass of spacecraft and fuel at launch time, in kilograms."""

    maneuverable: Optional[bool] = None
    """Boolean indicating whether a spacecraft is maneuverable.

    Note that a spacecraft may have propulsion capability but may not be
    maneuverable due to lack of fuel, anomalous condition, or other operational
    constraints.
    """

    max_delta_v: Optional[float] = FieldInfo(alias="maxDeltaV", default=None)
    """Maximum delta V available for this on-orbit spacecraft, in meters per second."""

    max_radius: Optional[float] = FieldInfo(alias="maxRadius", default=None)
    """
    Maximum dimension across the spacecraft (e.g., tip-to-tip across the solar panel
    arrays) in meters.
    """

    mission_types: Optional[List[str]] = FieldInfo(alias="missionTypes", default=None)
    """Array of the type of missions the spacecraft performs.

    Must contain the same number of elements as the value of numMission.
    """

    num_deployable: Optional[int] = FieldInfo(alias="numDeployable", default=None)
    """The number of sub-satellites or deployable objects on the spacecraft."""

    num_mission: Optional[int] = FieldInfo(alias="numMission", default=None)
    """The number of distinct missions the spacecraft performs."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    rcs: Optional[float] = None
    """Current/latest radar cross section in meters squared."""

    rcs_max: Optional[float] = FieldInfo(alias="rcsMax", default=None)
    """Maximum radar cross section in meters squared."""

    rcs_mean: Optional[float] = FieldInfo(alias="rcsMean", default=None)
    """Mean radar cross section in meters squared."""

    rcs_min: Optional[float] = FieldInfo(alias="rcsMin", default=None)
    """Minimum radar cross section in meters squared."""

    ref_source: Optional[str] = FieldInfo(alias="refSource", default=None)
    """
    The reference source, sources, or URL from which the data in this record was
    obtained.
    """

    solar_array_area: Optional[float] = FieldInfo(alias="solarArrayArea", default=None)
    """Spacecraft deployed area of solar array in meters squared."""

    total_mass_unc: Optional[float] = FieldInfo(alias="totalMassUnc", default=None)
    """The 1-sigma uncertainty of the total spacecraft mass, in kilograms."""

    vismag: Optional[float] = None
    """Current/latest visual magnitude in M."""

    vismag_max: Optional[float] = FieldInfo(alias="vismagMax", default=None)
    """Maximum visual magnitude in M."""

    vismag_mean: Optional[float] = FieldInfo(alias="vismagMean", default=None)
    """Mean visual magnitude in M."""

    vismag_min: Optional[float] = FieldInfo(alias="vismagMin", default=None)
    """Minimum visual magnitude in M."""


OnorbitdetailListResponse: TypeAlias = List[OnorbitdetailListResponseItem]
