# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["OnorbitdetailUpdateParams"]


class OnorbitdetailUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_on_orbit: Required[Annotated[str, PropertyInfo(alias="idOnOrbit")]]
    """UUID of the parent Onorbit record."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    additional_mass: Annotated[float, PropertyInfo(alias="additionalMass")]
    """Mass of fuel and disposables at launch time in kilograms."""

    adept_radius: Annotated[float, PropertyInfo(alias="adeptRadius")]
    """
    The radius used for long-term debris environment projection analyses that is not
    as conservative as COLA Radius, in meters.
    """

    bol_delta_v: Annotated[float, PropertyInfo(alias="bolDeltaV")]
    """The total beginning of life delta V of the spacecraft, in meters per second."""

    bol_fuel_mass: Annotated[float, PropertyInfo(alias="bolFuelMass")]
    """Spacecraft beginning of life fuel mass, in orbit, in kilograms."""

    bus_cross_section: Annotated[float, PropertyInfo(alias="busCrossSection")]
    """Average cross sectional area of the bus in meters squared."""

    bus_type: Annotated[str, PropertyInfo(alias="busType")]
    """Type of the bus on the spacecraft."""

    cola_radius: Annotated[float, PropertyInfo(alias="colaRadius")]
    """
    Maximum dimension of the box circumscribing the spacecraft (d = sqrt(a*a + b*b +
    c\\**c) where a is the tip-to-tip dimension, b and c are perpendicular to that.)
    in meters.
    """

    cross_section: Annotated[float, PropertyInfo(alias="crossSection")]
    """Average cross sectional area in meters squared."""

    current_mass: Annotated[float, PropertyInfo(alias="currentMass")]
    """The estimated total current mass of the spacecraft, in kilograms."""

    delta_v_unc: Annotated[float, PropertyInfo(alias="deltaVUnc")]
    """The 1-sigma uncertainty of the total spacecraft delta V, in meters per second."""

    dep_est_masses: Annotated[Iterable[float], PropertyInfo(alias="depEstMasses")]
    """Array of the estimated mass of each deployable object, in kilograms.

    Must contain the same number of elements as the value of numDeployable.
    """

    dep_mass_uncs: Annotated[Iterable[float], PropertyInfo(alias="depMassUncs")]
    """
    Array of the 1-sigma uncertainty of the mass for each deployable object, in
    kilograms. Must contain the same number of elements as the value of
    numDeployable.
    """

    dep_names: Annotated[List[str], PropertyInfo(alias="depNames")]
    """Array of satellite deployable objects.

    Must contain the same number of elements as the value of numDeployable.
    """

    drift_rate: Annotated[float, PropertyInfo(alias="driftRate")]
    """GEO drift rate, if applicable in degrees per day."""

    dry_mass: Annotated[float, PropertyInfo(alias="dryMass")]
    """Spacecraft dry mass (without fuel or disposables) in kilograms."""

    est_delta_v_duration: Annotated[float, PropertyInfo(alias="estDeltaVDuration")]
    """Estimated maximum burn duration for the object, in seconds."""

    fuel_remaining: Annotated[float, PropertyInfo(alias="fuelRemaining")]
    """Estimated remaining fuel for the object in kilograms."""

    geo_slot: Annotated[float, PropertyInfo(alias="geoSlot")]
    """GEO slot if applicable, in degrees.

    -180 (West of Prime Meridian) to 180 degrees (East of Prime Meridian). Prime
    Meridian is 0.
    """

    last_ob_source: Annotated[str, PropertyInfo(alias="lastObSource")]
    """The name of the source who last provided an observation for this idOnOrbit."""

    last_ob_time: Annotated[Union[str, datetime], PropertyInfo(alias="lastObTime", format="iso8601")]
    """
    Time of last reported observation for this object in ISO 8601 UTC with
    microsecond precision.
    """

    launch_mass: Annotated[float, PropertyInfo(alias="launchMass")]
    """Nominal mass of spacecraft and fuel at launch time, in kilograms."""

    launch_mass_max: Annotated[float, PropertyInfo(alias="launchMassMax")]
    """Maximum (estimated) mass of spacecraft and fuel at launch time, in kilograms."""

    launch_mass_min: Annotated[float, PropertyInfo(alias="launchMassMin")]
    """Minimum (estimated) mass of spacecraft and fuel at launch time, in kilograms."""

    maneuverable: bool
    """Boolean indicating whether a spacecraft is maneuverable.

    Note that a spacecraft may have propulsion capability but may not be
    maneuverable due to lack of fuel, anomalous condition, or other operational
    constraints.
    """

    max_delta_v: Annotated[float, PropertyInfo(alias="maxDeltaV")]
    """Maximum delta V available for this on-orbit spacecraft, in meters per second."""

    max_radius: Annotated[float, PropertyInfo(alias="maxRadius")]
    """
    Maximum dimension across the spacecraft (e.g., tip-to-tip across the solar panel
    arrays) in meters.
    """

    mission_types: Annotated[List[str], PropertyInfo(alias="missionTypes")]
    """Array of the type of missions the spacecraft performs.

    Must contain the same number of elements as the value of numMission.
    """

    num_deployable: Annotated[int, PropertyInfo(alias="numDeployable")]
    """The number of sub-satellites or deployable objects on the spacecraft."""

    num_mission: Annotated[int, PropertyInfo(alias="numMission")]
    """The number of distinct missions the spacecraft performs."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    rcs: float
    """Current/latest radar cross section in meters squared."""

    rcs_max: Annotated[float, PropertyInfo(alias="rcsMax")]
    """Maximum radar cross section in meters squared."""

    rcs_mean: Annotated[float, PropertyInfo(alias="rcsMean")]
    """Mean radar cross section in meters squared."""

    rcs_min: Annotated[float, PropertyInfo(alias="rcsMin")]
    """Minimum radar cross section in meters squared."""

    ref_source: Annotated[str, PropertyInfo(alias="refSource")]
    """
    The reference source, sources, or URL from which the data in this record was
    obtained.
    """

    solar_array_area: Annotated[float, PropertyInfo(alias="solarArrayArea")]
    """Spacecraft deployed area of solar array in meters squared."""

    total_mass_unc: Annotated[float, PropertyInfo(alias="totalMassUnc")]
    """The 1-sigma uncertainty of the total spacecraft mass, in kilograms."""

    vismag: float
    """Current/latest visual magnitude in M."""

    vismag_max: Annotated[float, PropertyInfo(alias="vismagMax")]
    """Maximum visual magnitude in M."""

    vismag_mean: Annotated[float, PropertyInfo(alias="vismagMean")]
    """Mean visual magnitude in M."""

    vismag_min: Annotated[float, PropertyInfo(alias="vismagMin")]
    """Minimum visual magnitude in M."""
