# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.onorbit_full import OnorbitFull

__all__ = ["OnorbiteventGetResponse"]


class OnorbiteventGetResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    event_time: datetime = FieldInfo(alias="eventTime")
    """Date/Time of the event.

    See eventTimeNotes for remarks on the accuracy of the date time.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    achieved_flight_phase: Optional[str] = FieldInfo(alias="achievedFlightPhase", default=None)
    """Achieved phase of flight prior to the event."""

    age_at_event: Optional[float] = FieldInfo(alias="ageAtEvent", default=None)
    """Spacecraft age at the event in years."""

    capability_loss: Optional[float] = FieldInfo(alias="capabilityLoss", default=None)
    """Spacecraft capability loss incurred, as a fraction of 1."""

    capability_loss_notes: Optional[str] = FieldInfo(alias="capabilityLossNotes", default=None)
    """Notes on capability loss at the time of event."""

    capacity_loss: Optional[float] = FieldInfo(alias="capacityLoss", default=None)
    """Spacecraft capacity loss incurred, as a fraction of 1."""

    consequential_equipment_failure: Optional[str] = FieldInfo(alias="consequentialEquipmentFailure", default=None)
    """
    Additional equipment which failed as a result of faulty equipment on the
    spacecraft during the event.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    declassification_date: Optional[datetime] = FieldInfo(alias="declassificationDate", default=None)
    """The declassification date of this data, in ISO 8601 UTC format."""

    declassification_string: Optional[str] = FieldInfo(alias="declassificationString", default=None)
    """Declassification string of this data."""

    derived_from: Optional[str] = FieldInfo(alias="derivedFrom", default=None)
    """
    The sources or SCG references from which the classification of this data is
    derived.
    """

    description: Optional[str] = None
    """Notes/description of the event."""

    equipment_at_fault: Optional[str] = FieldInfo(alias="equipmentAtFault", default=None)
    """Equipment on the spacecraft which caused the event."""

    equipment_causing_loss_notes: Optional[str] = FieldInfo(alias="equipmentCausingLossNotes", default=None)
    """Additional notes on the equipment causing the event/loss."""

    equipment_part_at_fault: Optional[str] = FieldInfo(alias="equipmentPartAtFault", default=None)
    """Specific part of the equipment on the spacecraft which caused the event."""

    equipment_type_at_fault: Optional[str] = FieldInfo(alias="equipmentTypeAtFault", default=None)
    """Type of the equipment on the spacecraft which caused the event."""

    event_result: Optional[str] = FieldInfo(alias="eventResult", default=None)
    """The result of the reported event."""

    event_time_notes: Optional[str] = FieldInfo(alias="eventTimeNotes", default=None)
    """Notes/remarks on the validity/accuracy of the eventTime."""

    event_type: Optional[str] = FieldInfo(alias="eventType", default=None)
    """The type of on-orbit event being reported."""

    geo_position: Optional[float] = FieldInfo(alias="geoPosition", default=None)
    """GEO position longitude at event time if applicable. Negative values are west."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the on-orbit object for this event."""

    inclined: Optional[bool] = None
    """Boolean indicating if the spacecraft is inclined."""

    injured: Optional[int] = None
    """Number of humans injured in the event."""

    insurance_carried_notes: Optional[str] = FieldInfo(alias="insuranceCarriedNotes", default=None)
    """Additional insurance notes on coverages at the time of event."""

    insurance_loss: Optional[float] = FieldInfo(alias="insuranceLoss", default=None)
    """Insurance loss incurred, as a fraction of 1."""

    insurance_loss_notes: Optional[str] = FieldInfo(alias="insuranceLossNotes", default=None)
    """Additional insurance notes if the event is an official loss."""

    killed: Optional[int] = None
    """Number of humans killed in the event."""

    lessee_org_id: Optional[str] = FieldInfo(alias="lesseeOrgId", default=None)
    """Unique identifier of the organization which leases this on-orbit spacecraft."""

    life_lost: Optional[float] = FieldInfo(alias="lifeLost", default=None)
    """Spacecraft life lost due to the event as a percent/fraction of 1."""

    net_amount: Optional[float] = FieldInfo(alias="netAmount", default=None)
    """Net amount of the insurance claim for the event, in USD."""

    object_status: Optional[str] = FieldInfo(alias="objectStatus", default=None)
    """The status of the on-orbit object."""

    occurrence_flight_phase: Optional[str] = FieldInfo(alias="occurrenceFlightPhase", default=None)
    """Phase of flight during which the event occurred."""

    official_loss_date: Optional[datetime] = FieldInfo(alias="officialLossDate", default=None)
    """Date time of official loss of the spacecraft."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    operated_on_behalf_of_org_id: Optional[str] = FieldInfo(alias="operatedOnBehalfOfOrgId", default=None)
    """
    Unique identifier of the organization on whose behalf the on-orbit spacecraft is
    operated.
    """

    operator_org_id: Optional[str] = FieldInfo(alias="operatorOrgId", default=None)
    """
    Organization ID of the operator of the on-orbit spacecraft at the time of the
    event.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Original object ID or Catalog Number provided by source (may not map to an
    existing idOnOrbit in UDL).
    """

    owner_org_id: Optional[str] = FieldInfo(alias="ownerOrgId", default=None)
    """
    Organization ID of the owner of the on-orbit spacecraft at the time of the
    event.
    """

    plane_number: Optional[str] = FieldInfo(alias="planeNumber", default=None)
    """GEO slot plane number/designator of the spacecraft at event time."""

    plane_slot: Optional[str] = FieldInfo(alias="planeSlot", default=None)
    """GEO plane slot of the spacecraft at event time."""

    position_status: Optional[str] = FieldInfo(alias="positionStatus", default=None)
    """Position status of the spacecraft at event time (e.g.

    Stable, Drifting/Tumbling, etc).
    """

    remarks: Optional[str] = None
    """Additional remarks on the event description."""

    satellite_position: Optional[str] = FieldInfo(alias="satellitePosition", default=None)
    """Description of the satellite orbital position or regime."""

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/Catalog number of the target on-orbit object."""

    stage_at_fault: Optional[str] = FieldInfo(alias="stageAtFault", default=None)
    """Faulty stage of flight for the event."""

    third_party_insurance_loss: Optional[float] = FieldInfo(alias="thirdPartyInsuranceLoss", default=None)
    """Insurance loss incurred by 3rd party insurance, in USD."""

    underlying_cause: Optional[str] = FieldInfo(alias="underlyingCause", default=None)
    """Underlying cause of the event."""

    until_time: Optional[datetime] = FieldInfo(alias="untilTime", default=None)
    """Maximum validity time of the event."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """
