# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OnorbitthrusterstatusListResponse", "OnorbitthrusterstatusListResponseItem"]


class OnorbitthrusterstatusListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_onorbit_thruster: str = FieldInfo(alias="idOnorbitThruster")
    """ID of the associated OnorbitThruster record.

    This ID can be used to obtain additional information on an onorbit thruster
    object using the 'get by ID' operation (e.g. /udl/onorbitthruster/{id}). For
    example, the OnorbitThruster object with idOnorbitThruster = abc would be
    queried as /udl/onorbitthruster/abc.
    """

    source: str
    """Source of the data."""

    status_time: datetime = FieldInfo(alias="statusTime")
    """
    Datetime of the thruster status observation in ISO 8601 UTC datetime format with
    millisecond precision.
    """

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    est_delta_v: Optional[float] = FieldInfo(alias="estDeltaV", default=None)
    """Estimated available delta-velocity for this thruster, in meters per second."""

    fuel_mass: Optional[float] = FieldInfo(alias="fuelMass", default=None)
    """Total fuel mass available for this thruster's type, in kilograms."""

    fuel_mass_unc: Optional[float] = FieldInfo(alias="fuelMassUnc", default=None)
    """
    1-sigma uncertainty of the total fuel mass available for this thruster type, in
    kilograms.
    """

    isp: Optional[float] = None
    """Specific impulse for this thruster, in seconds."""

    max_delta_v: Optional[float] = FieldInfo(alias="maxDeltaV", default=None)
    """Maximum available delta-velocity for this thruster, in meters per second."""

    min_delta_v: Optional[float] = FieldInfo(alias="minDeltaV", default=None)
    """Minimum available delta-velocity for this thruster, in meters per second."""

    name: Optional[str] = None
    """Identifier of this thruster."""

    operational: Optional[bool] = None
    """Flag indicating if this thruster is operational."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    prop_mass_avg: Optional[float] = FieldInfo(alias="propMassAvg", default=None)
    """Average available propellant mass for this thruster's type, in kilograms."""

    prop_mass_max: Optional[float] = FieldInfo(alias="propMassMax", default=None)
    """Maximum available propellant mass for this thruster's type, in kilograms."""

    prop_mass_median: Optional[float] = FieldInfo(alias="propMassMedian", default=None)
    """Median available propellant mass for this thruster's type, in kilograms."""

    prop_mass_min: Optional[float] = FieldInfo(alias="propMassMin", default=None)
    """Minimum available propellant mass for this thruster's type, in kilograms."""

    thrust_max: Optional[float] = FieldInfo(alias="thrustMax", default=None)
    """Maximum available thrust for this thruster, in newtons."""

    total_delta_v: Optional[float] = FieldInfo(alias="totalDeltaV", default=None)
    """Total delta-velocity available for this thruster's type, in meters per second."""


OnorbitthrusterstatusListResponse: TypeAlias = List[OnorbitthrusterstatusListResponseItem]
