# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .organization_details_full import OrganizationDetailsFull

__all__ = ["OrganizationFull"]


class OrganizationFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Organization name."""

    source: str
    """Source of the data."""

    type: str
    """Type of organization (e.g. GOVERNMENT, CORPORATION, CONSORTIUM, ACADEMIC)."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    active: Optional[bool] = None
    """Boolean indicating if this organization is currently active."""

    category: Optional[str] = None
    """Subtype or category of the organization (e.g.

    Private company, stock market quoted company, subsidiary, goverment
    department/agency, etc).
    """

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """Country of the physical location of the organization.

    This value is typically the ISO 3166 Alpha-2 two-character country code.
    However, it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    description: Optional[str] = None
    """Organization description."""

    external_id: Optional[str] = FieldInfo(alias="externalId", default=None)
    """Optional externally provided identifier for this row."""

    nationality: Optional[str] = None
    """Country of registration or ownership of the organization.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    organization_details: Optional[List[OrganizationDetailsFull]] = FieldInfo(alias="organizationDetails", default=None)
    """
    Read-only collection of additional OrganizationDetails by various sources for
    this organization, ignored on create/update. These details must be created
    separately via the /udl/organizationdetails operations.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """
