# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OrganizationdetailFindBySourceResponse", "OrganizationdetailFindBySourceResponseItem"]


class OrganizationdetailFindBySourceResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_organization: str = FieldInfo(alias="idOrganization")
    """Unique identifier of the parent organization."""

    name: str
    """Organization details name."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    address1: Optional[str] = None
    """Street number of the organization."""

    address2: Optional[str] = None
    """
    Field for additional organization address information such as PO Box and unit
    number.
    """

    address3: Optional[str] = None
    """Contains the third line of address information for an organization."""

    broker: Optional[str] = None
    """Designated broker for this organization."""

    ceo: Optional[str] = None
    """For organizations of type CORPORATION, the name of the Chief Executive Officer."""

    cfo: Optional[str] = None
    """For organizations of type CORPORATION, the name of the Chief Financial Officer."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    cto: Optional[str] = None
    """
    For organizations of type CORPORATION, the name of the Chief Technology Officer.
    """

    description: Optional[str] = None
    """Organization description."""

    ebitda: Optional[float] = None
    """
    For organizations of type CORPORATION, the company EBITDA value as of
    financialYearEndDate in US Dollars.
    """

    email: Optional[str] = None
    """Listed contact email address for the organization."""

    financial_notes: Optional[str] = FieldInfo(alias="financialNotes", default=None)
    """For organizations of type CORPORATION, notes on company financials."""

    financial_year_end_date: Optional[datetime] = FieldInfo(alias="financialYearEndDate", default=None)
    """
    For organizations of type CORPORATION, the effective financial year end date for
    revenue, EBITDA, and profit values.
    """

    fleet_plan_notes: Optional[str] = FieldInfo(alias="fleetPlanNotes", default=None)
    """Satellite fleet planning notes for this organization."""

    former_org_id: Optional[str] = FieldInfo(alias="formerOrgId", default=None)
    """
    Former organization ID (if this organization previously existed as another
    organization).
    """

    ftes: Optional[int] = None
    """Total number of FTEs in this organization."""

    geo_admin_level1: Optional[str] = FieldInfo(alias="geoAdminLevel1", default=None)
    """Administrative boundaries of the first sub-national level.

    Level 1 is simply the largest demarcation under whatever demarcation criteria
    has been determined by the governing body. For example, this may be a state or
    province.
    """

    geo_admin_level2: Optional[str] = FieldInfo(alias="geoAdminLevel2", default=None)
    """Administrative boundaries of the second sub-national level.

    Level 2 is simply the second largest demarcation under whatever demarcation
    criteria has been determined by the governing body. For example, this may be a
    county or district.
    """

    geo_admin_level3: Optional[str] = FieldInfo(alias="geoAdminLevel3", default=None)
    """Administrative boundaries of the third sub-national level.

    Level 3 is simply the third largest demarcation under whatever demarcation
    criteria has been determined by the governing body. For example, this may be a
    city or township.
    """

    mass_ranking: Optional[int] = FieldInfo(alias="massRanking", default=None)
    """Mass ranking for this organization."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    parent_org_id: Optional[str] = FieldInfo(alias="parentOrgId", default=None)
    """Parent organization ID of this organization if it is a child organization."""

    postal_code: Optional[str] = FieldInfo(alias="postalCode", default=None)
    """
    A postal code, such as PIN or ZIP Code, is a series of letters or digits or both
    included in the postal address of the organization.
    """

    profit: Optional[float] = None
    """
    For organizations of type CORPORATION, total annual profit as of
    financialYearEndDate in US Dollars.
    """

    revenue: Optional[float] = None
    """
    For organizations of type CORPORATION, total annual revenue as of
    financialYearEndDate in US Dollars.
    """

    revenue_ranking: Optional[int] = FieldInfo(alias="revenueRanking", default=None)
    """Revenue ranking for this organization."""

    risk_manager: Optional[str] = FieldInfo(alias="riskManager", default=None)
    """The name of the risk manager for the organization."""

    services_notes: Optional[str] = FieldInfo(alias="servicesNotes", default=None)
    """Notes on the services provided by the organization."""


OrganizationdetailFindBySourceResponse: TypeAlias = List[OrganizationdetailFindBySourceResponseItem]
