# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["OrganizationdetailUpdateParams"]


class OrganizationdetailUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_organization: Required[Annotated[str, PropertyInfo(alias="idOrganization")]]
    """Unique identifier of the parent organization."""

    name: Required[str]
    """Organization details name."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    address1: str
    """Street number of the organization."""

    address2: str
    """
    Field for additional organization address information such as PO Box and unit
    number.
    """

    address3: str
    """Contains the third line of address information for an organization."""

    broker: str
    """Designated broker for this organization."""

    ceo: str
    """For organizations of type CORPORATION, the name of the Chief Executive Officer."""

    cfo: str
    """For organizations of type CORPORATION, the name of the Chief Financial Officer."""

    cto: str
    """
    For organizations of type CORPORATION, the name of the Chief Technology Officer.
    """

    description: str
    """Organization description."""

    ebitda: float
    """
    For organizations of type CORPORATION, the company EBITDA value as of
    financialYearEndDate in US Dollars.
    """

    email: str
    """Listed contact email address for the organization."""

    financial_notes: Annotated[str, PropertyInfo(alias="financialNotes")]
    """For organizations of type CORPORATION, notes on company financials."""

    financial_year_end_date: Annotated[
        Union[str, datetime], PropertyInfo(alias="financialYearEndDate", format="iso8601")
    ]
    """
    For organizations of type CORPORATION, the effective financial year end date for
    revenue, EBITDA, and profit values.
    """

    fleet_plan_notes: Annotated[str, PropertyInfo(alias="fleetPlanNotes")]
    """Satellite fleet planning notes for this organization."""

    former_org_id: Annotated[str, PropertyInfo(alias="formerOrgId")]
    """
    Former organization ID (if this organization previously existed as another
    organization).
    """

    ftes: int
    """Total number of FTEs in this organization."""

    geo_admin_level1: Annotated[str, PropertyInfo(alias="geoAdminLevel1")]
    """Administrative boundaries of the first sub-national level.

    Level 1 is simply the largest demarcation under whatever demarcation criteria
    has been determined by the governing body. For example, this may be a state or
    province.
    """

    geo_admin_level2: Annotated[str, PropertyInfo(alias="geoAdminLevel2")]
    """Administrative boundaries of the second sub-national level.

    Level 2 is simply the second largest demarcation under whatever demarcation
    criteria has been determined by the governing body. For example, this may be a
    county or district.
    """

    geo_admin_level3: Annotated[str, PropertyInfo(alias="geoAdminLevel3")]
    """Administrative boundaries of the third sub-national level.

    Level 3 is simply the third largest demarcation under whatever demarcation
    criteria has been determined by the governing body. For example, this may be a
    city or township.
    """

    mass_ranking: Annotated[int, PropertyInfo(alias="massRanking")]
    """Mass ranking for this organization."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    parent_org_id: Annotated[str, PropertyInfo(alias="parentOrgId")]
    """Parent organization ID of this organization if it is a child organization."""

    postal_code: Annotated[str, PropertyInfo(alias="postalCode")]
    """
    A postal code, such as PIN or ZIP Code, is a series of letters or digits or both
    included in the postal address of the organization.
    """

    profit: float
    """
    For organizations of type CORPORATION, total annual profit as of
    financialYearEndDate in US Dollars.
    """

    revenue: float
    """
    For organizations of type CORPORATION, total annual revenue as of
    financialYearEndDate in US Dollars.
    """

    revenue_ranking: Annotated[int, PropertyInfo(alias="revenueRanking")]
    """Revenue ranking for this organization."""

    risk_manager: Annotated[str, PropertyInfo(alias="riskManager")]
    """The name of the risk manager for the organization."""

    services_notes: Annotated[str, PropertyInfo(alias="servicesNotes")]
    """Notes on the services provided by the organization."""

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """
