# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["PassiveradarobservationListResponse", "PassiveradarobservationListResponseItem"]


class PassiveradarobservationListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    ob_time: datetime = FieldInfo(alias="obTime")
    """Ob detection time in ISO 8601 UTC with microsecond precision."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    accel: Optional[float] = None
    """The target Acceleration measurement in kilometers/sec^2 for this observation."""

    accel_unc: Optional[float] = FieldInfo(alias="accelUnc", default=None)
    """
    The target Acceleration uncertainty measurement in kilometers/sec^2 for this
    observation.
    """

    alt: Optional[float] = None
    """
    The target altitude relative to WGS-84 ellipsoid, in kilometers for this
    observation.
    """

    azimuth: Optional[float] = None
    """Line of sight azimuth angle in degrees and topocentric frame."""

    azimuth_bias: Optional[float] = FieldInfo(alias="azimuthBias", default=None)
    """Sensor azimuth angle bias in degrees."""

    azimuth_rate: Optional[float] = FieldInfo(alias="azimuthRate", default=None)
    """Rate of change of the line of sight azimuth in degrees per second."""

    azimuth_unc: Optional[float] = FieldInfo(alias="azimuthUnc", default=None)
    """
    One sigma uncertainty in the line of sight azimuth angle measurement, in
    degrees.
    """

    bistatic_range: Optional[float] = FieldInfo(alias="bistaticRange", default=None)
    """Target bistatic path distance in kilometers.

    This is the transmitter-to-target-to-surveillance site distance.
    """

    bistatic_range_accel: Optional[float] = FieldInfo(alias="bistaticRangeAccel", default=None)
    """Bistatic range acceleration in kilometers/sec^2."""

    bistatic_range_accel_unc: Optional[float] = FieldInfo(alias="bistaticRangeAccelUnc", default=None)
    """
    One sigma uncertainty in the bistatic range acceleration measurement, in
    kilometers/sec^2.
    """

    bistatic_range_bias: Optional[float] = FieldInfo(alias="bistaticRangeBias", default=None)
    """Sensor bistatic range bias in kilometers."""

    bistatic_range_rate: Optional[float] = FieldInfo(alias="bistaticRangeRate", default=None)
    """Rate of change of the bistatic path in kilometers/sec."""

    bistatic_range_rate_unc: Optional[float] = FieldInfo(alias="bistaticRangeRateUnc", default=None)
    """One sigma uncertainty in rate of change of the bistatic path in kilometers/sec."""

    bistatic_range_unc: Optional[float] = FieldInfo(alias="bistaticRangeUnc", default=None)
    """One sigma uncertainty in bistatic range in kilometers."""

    coning: Optional[float] = None
    """Coning angle in degrees."""

    coning_unc: Optional[float] = FieldInfo(alias="coningUnc", default=None)
    """One sigma uncertainty in the coning angle measurement, in degrees."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    declination: Optional[float] = None
    """Line of sight declination angle in degrees and J2000 coordinate frame."""

    delay: Optional[float] = None
    """
    The time difference, in seconds, between the signal collected at the
    surveillance site (after being reflected from the target) and the reference site
    (direct path line-of-sight signal).
    """

    delay_bias: Optional[float] = FieldInfo(alias="delayBias", default=None)
    """Delay bias in seconds."""

    delay_unc: Optional[float] = FieldInfo(alias="delayUnc", default=None)
    """One sigma uncertainty in the delay measurement, in seconds."""

    descriptor: Optional[str] = None
    """Optional source-provided and searchable metadata or descriptor of the data."""

    doppler: Optional[float] = None
    """Doppler measurement in hertz."""

    doppler_unc: Optional[float] = FieldInfo(alias="dopplerUnc", default=None)
    """One sigma uncertainty in the Doppler measurement in hertz."""

    elevation: Optional[float] = None
    """Line of sight elevation in degrees and topocentric frame."""

    elevation_bias: Optional[float] = FieldInfo(alias="elevationBias", default=None)
    """Sensor elevation bias in degrees."""

    elevation_rate: Optional[float] = FieldInfo(alias="elevationRate", default=None)
    """Rate of change of the line of sight elevation in degrees per second."""

    elevation_unc: Optional[float] = FieldInfo(alias="elevationUnc", default=None)
    """
    One sigma uncertainty in the line of sight elevation angle measurement, in
    degrees.
    """

    ext_observation_id: Optional[str] = FieldInfo(alias="extObservationId", default=None)
    """Optional external observation identifier provided by the source."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the target satellite on-orbit object.

    This ID can be used to obtain additional information on an OnOrbit object using
    the 'get by ID' operation (e.g. /udl/onorbit/{id}). For example, the OnOrbit
    with idOnOrbit = 25544 would be queried as /udl/onorbit/25544.
    """

    id_rf_emitter: Optional[str] = FieldInfo(alias="idRFEmitter", default=None)
    """Unique identifier of the transmitter.

    This ID can be used to obtain additional information on an RFEmitter using the
    'get by ID' operation (e.g. /udl/rfemitter/{id}). For example, the RFEmitter
    with idRFEmitter = abc would be queried as /udl/rfemitter/abc.
    """

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the reporting surveillance sensor.

    This ID can be used to obtain additional information on a sensor using the 'get
    by ID' operation (e.g. /udl/sensor/{id}). For example, the sensor with idSensor
    = abc would be queried as /udl/sensor/abc.
    """

    id_sensor_ref_receiver: Optional[str] = FieldInfo(alias="idSensorRefReceiver", default=None)
    """Unique identifier of the reference receiver sensor.

    This ID can be used to obtain additional information on a sensor using the 'get
    by ID' operation (e.g. /udl/sensor/{id}). For example, the sensor with idSensor
    = abc would be queried as /udl/sensor/abc.
    """

    lat: Optional[float] = None
    """
    WGS-84 target latitude sub-point at observation time (obTime), represented as
    -90 to 90 degrees (negative values south of equator).
    """

    lon: Optional[float] = None
    """
    WGS-84 target longitude sub-point at observation time (obTime), represented as
    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    ob_position: Optional[str] = FieldInfo(alias="obPosition", default=None)
    """The position of this observation within a track (FENCE, FIRST, IN, LAST,
    SINGLE).

    This identifier is optional and, if null, no assumption should be made regarding
    whether other observations may or may not exist to compose a track.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by observation source to indicate the target
    onorbit object of this observation. This may be an internal identifier and not
    necessarily a valid satellite number.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by observation source to indicate the sensor
    identifier which produced this observation. This may be an internal identifier
    and not necessarily a valid sensor ID.
    """

    orthogonal_rcs: Optional[float] = FieldInfo(alias="orthogonalRcs", default=None)
    """Radar cross section in meters squared for orthogonal polarization."""

    orthogonal_rcs_unc: Optional[float] = FieldInfo(alias="orthogonalRcsUnc", default=None)
    """
    One sigma uncertainty in orthogonal polarization Radar Cross Section, in
    meters^2.
    """

    ra: Optional[float] = None
    """Line of sight right ascension in degrees and J2000 coordinate frame."""

    rcs: Optional[float] = None
    """Radar cross section in meters squared for polarization principal."""

    rcs_unc: Optional[float] = FieldInfo(alias="rcsUnc", default=None)
    """
    One sigma uncertainty in principal polarization Radar Cross Section, in
    meters^2.
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/Catalog number of the target on-orbit object."""

    snr: Optional[float] = None
    """Signal to noise ratio, in dB."""

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    task_id: Optional[str] = FieldInfo(alias="taskId", default=None)
    """
    Optional identifier to indicate the specific tasking which produced this
    observation.
    """

    timing_bias: Optional[float] = FieldInfo(alias="timingBias", default=None)
    """Sensor timing bias in seconds."""

    tof: Optional[float] = None
    """Time of flight (TOF) in seconds.

    This is the calculated propagation time from
    transmitter-to-target-to-surveillance site.
    """

    tof_bias: Optional[float] = FieldInfo(alias="tofBias", default=None)
    """The Time of Flight (TOF) bias in seconds."""

    tof_unc: Optional[float] = FieldInfo(alias="tofUnc", default=None)
    """One sigma uncertainty in time of flight in seconds."""

    track_id: Optional[str] = FieldInfo(alias="trackId", default=None)
    """Unique identifier of a track that represents a tracklet for this observation."""

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    type: Optional[str] = None
    """Read only enumeration specifying the type of observation (e.g.

    OPTICAL, RADAR, RF, etc).
    """

    uct: Optional[bool] = None
    """
    Boolean indicating this observation is part of an uncorrelated track or was
    unable to be correlated to a known object. This flag should only be set to true
    by data providers after an attempt to correlate to an on-orbit object was made
    and failed. If unable to correlate, the 'origObjectId' field may be populated
    with an internal data provider specific identifier.
    """

    xvel: Optional[float] = None
    """X velocity of target in kilometers/sec in J2000 coordinate frame."""

    yvel: Optional[float] = None
    """Y velocity of target in kilometers/sec in J2000 coordinate frame."""

    zvel: Optional[float] = None
    """Z velocity of target in kilometers/sec in J2000 coordinate frame."""


PassiveradarobservationListResponse: TypeAlias = List[PassiveradarobservationListResponseItem]
