# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PoiCreateBulkParams", "Body"]


class PoiCreateBulkParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: Required[str]
    """Name of the POI target object."""

    poiid: Required[str]
    """
    Identifier of the actual Point of Interest or target object, which should remain
    the same on subsequent POI records of the same Point of Interest.
    """

    source: Required[str]
    """Source of the data."""

    ts: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """Activity/POI timestamp in ISO8601 UTC format."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    activity: str
    """The activity in which the POI subject is engaged.

    Intended as, but not constrained to, MIL-STD-6016 environment dependent activity
    designations. The activity can be reported as either a combination of the code
    and environment (e.g. 30/LAND) or as the descriptive enumeration (e.g.
    TRAINING), which are equivalent.
    """

    agjson: str
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. GeoJSON Reference: https://geojson.org/. Ignored if included with a POST
    or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    alt: float
    """Point height above ellipsoid (WGS-84), in meters."""

    andims: int
    """Number of dimensions of the geometry depicted by region."""

    area: str
    """
    Optional geographical region or polygon (lat/lon pairs) of the area surrounding
    the Point of Interest as projected on the ground.
    """

    asrid: int
    """Geographical spatial_ref_sys for region."""

    asset: str
    """ID/name of the platform or entity providing the POI data."""

    atext: str
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a POST or PUT request that also specifies a valid 'area' field.
    """

    atype: str
    """Type of region as projected on the ground."""

    az: float
    """
    Target object pointing azimuth angle, in degrees (for target with sensing or
    emitting capability).
    """

    be_number: Annotated[str, PropertyInfo(alias="beNumber")]
    """The Basic Encyclopedia Number associated with the POI, if applicable."""

    ce: float
    """
    Radius of circular area about lat/lon point, in meters (1-sigma, if representing
    error).
    """

    cntct: str
    """
    Contact information for assets reporting PPLI (Precise Participant Location and
    Identification). PPLI is a Link 16 message that is used by units to transmit
    complete location, identification, and limited status information.
    """

    conf: float
    """
    POI confidence estimate (not standardized, but typically a value between 0 and
    1, with 0 indicating lowest confidence.
    """

    desc: str
    """Description of the POI target object."""

    el: float
    """
    Target object pointing elevation angle, in degrees (for target with sensing or
    emitting capability).
    """

    elle: Iterable[float]
    """
    Elliptical area about the lat/lon point, specified as [semi-major axis (m),
    semi-minor axis (m), orientation (deg) off true North at POI].
    """

    env: str
    """POI environment type (e.g., LAND, SURFACE, SUBSURFACE, UNKNOWN, etc.)."""

    groups: List[str]
    """Optional array of groups used when a POI msg originates from a TAK server.

    Each group must be no longer than 256 characters. Groups identify a set of users
    targeted by the cot/poi msg.
    """

    how: str
    """
    How the event point was generated, in CoT object heirarchy notation (optional,
    CoT).
    """

    ident: str
    """
    Estimated identity of the point/object (e.g., FRIEND, HOSTILE, SUSPECT,
    ASSUMED_FRIEND, UNKNOWN, etc.).
    """

    id_weather_report: Annotated[List[str], PropertyInfo(alias="idWeatherReport")]
    """
    Array of one or more unique identifiers of weather records associated with this
    POI. Each element in array must be 36 characters or less in length.
    """

    lat: float
    """WGS-84 latitude of the POI, in degrees (+N, -S), -90 to 90."""

    le: float
    """Height above lat/lon point, in meters (1-sigma, if representing linear error)."""

    lon: float
    """WGS-84 longitude of the POI, in degrees (+E, -W), -180 to 180."""

    msnid: str
    """Optional mission ID related to the POI."""

    orientation: float
    """The orientation of a vehicle, platform or other entity described by the POI.

    The orientation is defined as the pointing direction of the front/nose of the
    object in degrees clockwise from true North at the object point.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    plat: str
    """POI/object platform type (e.g., 14/GROUND, COMBAT_VEHICLE, etc.)."""

    pps: str
    """
    The purpose of this Point of Interest record (e.g., BDA, EQPT, EVENT, GEOL,
    HZRD, PPLI, SHOTBOX, SURVL, TGT, TSK, WTHR).
    """

    pri: int
    """Priority of the POI target object."""

    spec: str
    """Specific point/object type (e.g., 82/GROUND, LIGHT_TANK, etc.)."""

    src_ids: Annotated[List[str], PropertyInfo(alias="srcIds")]
    """
    Array of UUIDs of the UDL data records that are related to the determination of
    this Point of Interest. See the associated 'srcTyps' array for the specific
    types of data, positionally corresponding to the UUIDs in this array. The
    'srcTyps' and 'srcIds' arrays must match in size. See the corresponding srcTyps
    array element for the data type of the UUID and use the appropriate API
    operation to retrieve that object (e.g. /udl/rfobservation/{uuid}).
    """

    src_typs: Annotated[List[str], PropertyInfo(alias="srcTyps")]
    """
    Array of UDL record types (GROUNDIMAGE, RFOBS) that are related to the
    determination of this Point of Interest. See the associated 'srcIds' array for
    the record UUIDs, positionally corresponding to the record types in this array.
    The 'srcTyps' and 'srcIds' arrays must match in size.
    """

    stale: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Stale timestamp (optional), in ISO8601 UTC format."""

    start: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Start time of event validity (optional), in ISO8601 UTC format."""

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    transaction_id: Annotated[str, PropertyInfo(alias="transactionId")]
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    trkid: str
    """Optional ID of an associated track related to the POI object, if applicable.

    This track ID should correlate the Point of Interest to a track from the Track
    service.
    """

    type: str
    """Event type, in CoT object heirarchy notation (optional, CoT)."""

    urls: List[str]
    """List of URLs to before/after images of this Point of Interest entity."""
