# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PortCreateBulkParams", "Body"]


class PortCreateBulkParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """
    Unique identifier of the record, auto-generated by the system if not provided on
    create operations.
    """

    avg_duration: Annotated[float, PropertyInfo(alias="avgDuration")]
    """Average time for a vessel at this port in hours."""

    country_code: Annotated[str, PropertyInfo(alias="countryCode")]
    """The country where this port is located."""

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    harbor_size: Annotated[float, PropertyInfo(alias="harborSize")]
    """The size of the harbor for this port measured in square kilometers."""

    harbor_type: Annotated[str, PropertyInfo(alias="harborType")]
    """The type of harbor for this port.

    The harbor type refers to how a port is physically positioned.

    COASTAL BREAKWATER (CB)

    COASTAL NATURAL (CN)

    COASTAL TIDE GATE (CT)

    LAKE OR CANAL (LC)

    OPEN ROADSTEAD (OR)

    RIVER BASIN (RB)

    RIVER NATURAL (RN)

    RIVER TIDE GATE (RT)

    TYPHOON HARBOR (TH).
    """

    id_site: Annotated[str, PropertyInfo(alias="idSite")]
    """Unique identifier of the Site Entity associated with the Port record."""

    lat: float
    """WGS84 latitude of the location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    locode: str
    """
    The five-character United Nations Code for Trade and Transport Locations
    (UN/LOCODE) of this port. The first two letters of the code contains the ISO
    3166-1 alpha-2 country designation of the port country. The three remaining
    characters identify a location within that country. Letters are preferred, but
    if necessary digits 2 through 9 may be used, excluding "0" and "1" to avoid
    confusion with the letters "O" and "I" respectively.
    """

    lon: float
    """WGS84 longitude of the location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    max_draught: Annotated[float, PropertyInfo(alias="maxDraught")]
    """Maximum allowed vessel draught.

    Draught is the principal dimensions of any waterborne vessel defined as the
    distance between the ship’s keel and the waterline of the vessel measured in
    meters.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    pilot_reqd: Annotated[bool, PropertyInfo(alias="pilotReqd")]
    """Flag indicating whether a pilot is required at this port."""

    port_name: Annotated[str, PropertyInfo(alias="portName")]
    """The name of this port."""

    shelter: str
    """
    The shelter afforded from wind, sea, and swell refers to the area where normal
    port operations are conducted, usually the wharf area. Shelter afforded by the
    anchorage area may be given for ports where cargo is handled by lighters. Values
    given are EXCELLENT, FAIR, GOOD, POOR, or NONE.
    """

    tide_range: Annotated[float, PropertyInfo(alias="tideRange")]
    """The tide range of this port in meters."""
