# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["PortGetResponse"]


class PortGetResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """
    Unique identifier of the record, auto-generated by the system if not provided on
    create operations.
    """

    avg_duration: Optional[float] = FieldInfo(alias="avgDuration", default=None)
    """Average time for a vessel at this port in hours."""

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country where this port is located."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    external_id: Optional[str] = FieldInfo(alias="externalId", default=None)
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    harbor_size: Optional[float] = FieldInfo(alias="harborSize", default=None)
    """The size of the harbor for this port measured in square kilometers."""

    harbor_type: Optional[str] = FieldInfo(alias="harborType", default=None)
    """The type of harbor for this port.

    The harbor type refers to how a port is physically positioned.

    COASTAL BREAKWATER (CB)

    COASTAL NATURAL (CN)

    COASTAL TIDE GATE (CT)

    LAKE OR CANAL (LC)

    OPEN ROADSTEAD (OR)

    RIVER BASIN (RB)

    RIVER NATURAL (RN)

    RIVER TIDE GATE (RT)

    TYPHOON HARBOR (TH).
    """

    id_site: Optional[str] = FieldInfo(alias="idSite", default=None)
    """Unique identifier of the Site Entity associated with the Port record."""

    lat: Optional[float] = None
    """WGS84 latitude of the location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    locode: Optional[str] = None
    """
    The five-character United Nations Code for Trade and Transport Locations
    (UN/LOCODE) of this port. The first two letters of the code contains the ISO
    3166-1 alpha-2 country designation of the port country. The three remaining
    characters identify a location within that country. Letters are preferred, but
    if necessary digits 2 through 9 may be used, excluding "0" and "1" to avoid
    confusion with the letters "O" and "I" respectively.
    """

    lon: Optional[float] = None
    """WGS84 longitude of the location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    max_draught: Optional[float] = FieldInfo(alias="maxDraught", default=None)
    """Maximum allowed vessel draught.

    Draught is the principal dimensions of any waterborne vessel defined as the
    distance between the ship’s keel and the waterline of the vessel measured in
    meters.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    pilot_reqd: Optional[bool] = FieldInfo(alias="pilotReqd", default=None)
    """Flag indicating whether a pilot is required at this port."""

    port_name: Optional[str] = FieldInfo(alias="portName", default=None)
    """The name of this port."""

    shelter: Optional[str] = None
    """
    The shelter afforded from wind, sea, and swell refers to the area where normal
    port operations are conducted, usually the wharf area. Shelter afforded by the
    anchorage area may be given for ports where cargo is handled by lighters. Values
    given are EXCELLENT, FAIR, GOOD, POOR, or NONE.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    tide_range: Optional[float] = FieldInfo(alias="tideRange", default=None)
    """The tide range of this port in meters."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """
