# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["UdlH3geoUnvalidatedPublishParams", "Cell"]


class UdlH3geoUnvalidatedPublishParams(TypedDict, total=False):
    cells: Required[Iterable[Cell]]
    """The collection of hex cells contained in this H3 data set.

    The number of cells is a function of the specified resolution.
    """

    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    num_cells: Required[Annotated[int, PropertyInfo(alias="numCells")]]
    """The number of cells associated with this H3 Geo data set.

    At this time, UDL supports up to 50,000 cells.
    """

    source: Required[str]
    """Source of the data."""

    start_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="startTime", format="iso8601")]]
    """Start time for this H3 Geo data set in ISO 8601 UTC with millisecond precision."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    center_freq: Annotated[float, PropertyInfo(alias="centerFreq")]
    """The center frequency of this H3 Geo data set measured in megahertz."""

    end_time: Annotated[Union[str, datetime], PropertyInfo(alias="endTime", format="iso8601")]
    """End time for this H3 Geo data set in ISO 8601 UTC with millisecond precision."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    resolution: int
    """H3 resolution (0 – 15) for the data set.

    At this time, UDL supports a resolution of 3 or less.
    """

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    type: str
    """
    An optional field containing the type of data that is represented by this H3 Geo
    data set.
    """


class Cell(TypedDict, total=False):
    cell_id: Required[Annotated[str, PropertyInfo(alias="cellId")]]
    """The H3 index represented as a 16 character hexadecimal string."""

    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    alt_mean: Annotated[float, PropertyInfo(alias="altMean")]
    """
    The mean altitude of the set of observations within this cell, measured in
    kilometers.
    """

    alt_sigma: Annotated[float, PropertyInfo(alias="altSigma")]
    """
    The standard deviation of alttitude in the set of observations within this cell,
    measured in kilometers.
    """

    anom_score_interference: Annotated[float, PropertyInfo(alias="anomScoreInterference")]
    """
    The anomaly score for probable manufactured interference or RF interference;
    calculated as a ratio of #anomalous obs / #total obs or coverage.
    """

    anom_score_spoofing: Annotated[float, PropertyInfo(alias="anomScoreSpoofing")]
    """
    The anomaly score for probable spoofing; calculated as a ratio of #anomalous obs
    / #total obs or coverage.
    """

    change_score: Annotated[float, PropertyInfo(alias="changeScore")]
    """
    The percentage degree of change in the aggregated observables for a particular
    H3 bin.
    """

    coverage: int
    """
    The total number of available observations in the H3 cell during the start/end
    times.
    """

    id_h3_geo: Annotated[str, PropertyInfo(alias="idH3Geo")]
    """Unique identifier of the parent H3 Geo record containing this hex cell."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    rpm_max: Annotated[float, PropertyInfo(alias="rpmMax")]
    """
    The max received power monitor (RPM) output value for the set of data contained
    within this cell.
    """

    rpm_mean: Annotated[float, PropertyInfo(alias="rpmMean")]
    """
    The mean received power monitor (RPM) output value for the set of data contained
    within this cell.
    """

    rpm_median: Annotated[float, PropertyInfo(alias="rpmMedian")]
    """
    The median received power monitor (RPM) output value for the set of data
    contained within this cell.
    """

    rpm_min: Annotated[float, PropertyInfo(alias="rpmMin")]
    """
    The min received power monitor (RPM) output value for the set of data contained
    within this cell.
    """

    rpm_sigma: Annotated[float, PropertyInfo(alias="rpmSigma")]
    """
    The standard deviation of the received power monitor (RPM) output value for the
    set of data contained within this cell.
    """
