# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["RfbandUpdateParams"]


class RfbandUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_entity: Required[Annotated[str, PropertyInfo(alias="idEntity")]]
    """Unique identifier of the parent Entity which uses this band."""

    name: Required[str]
    """RF Band name."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    band: str
    """Name of the band of this RF range (e.g.

    X,K,Ku,Ka,L,S,C,UHF,VHF,EHF,SHF,UNK,VLF,HF,E,Q,V,W). See RFBandType for more
    details and descriptions of each band name.
    """

    bandwidth: float
    """RF Band frequency range bandwidth in Mhz."""

    beamwidth: float
    """
    Angle between the half-power (-3 dB) points of the main lobe of the antenna, in
    degrees.
    """

    center_freq: Annotated[float, PropertyInfo(alias="centerFreq")]
    """Center frequency of RF frequency range, if applicable, in Mhz."""

    edge_gain: Annotated[float, PropertyInfo(alias="edgeGain")]
    """RF Range edge gain, in dBi."""

    eirp: float
    """
    EIRP is defined as the RMS power input in decibel watts required to a lossless
    half-wave dipole antenna to give the same maximum power density far from the
    antenna as the actual transmitter. It is equal to the power input to the
    transmitter's antenna multiplied by the antenna gain relative to a half-wave
    dipole. Effective radiated power and effective isotropic radiated power both
    measure the amount of power a radio transmitter and antenna (or other source of
    electromagnetic waves) radiates in a specific direction: in the direction of
    maximum signal strength (the "main lobe") of its radiation pattern.
    """

    erp: float
    """
    Effective Radiated Power (ERP) is the total power in decibel watts radiated by
    an actual antenna relative to a half-wave dipole rather than a theoretical
    isotropic antenna. A half-wave dipole has a gain of 2.15 dB compared to an
    isotropic antenna. EIRP(dB) = ERP (dB)+2.15 dB or EIRP (W) = 1.64\\**ERP(W).
    Effective radiated power and effective isotropic radiated power both measure the
    amount of power a radio transmitter and antenna (or other source of
    electromagnetic waves) radiates in a specific direction: in the direction of
    maximum signal strength (the "main lobe") of its radiation pattern.
    """

    freq_max: Annotated[float, PropertyInfo(alias="freqMax")]
    """End/maximum of transmit RF frequency range, if applicable, in Mhz."""

    freq_min: Annotated[float, PropertyInfo(alias="freqMin")]
    """Start/minimum of transmit RF frequency range, if applicable, in Mhz."""

    mode: Literal["TX", "RX"]
    """RF Band mode (e.g. TX, RX)."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    peak_gain: Annotated[float, PropertyInfo(alias="peakGain")]
    """RF Range maximum gain, in dBi."""

    polarization: Literal["H", "V", "R", "L"]
    """Transponder polarization e.g.

    H - (Horizontally Polarized) Perpendicular to Earth's surface, V - (Vertically
    Polarized) Parallel to Earth's surface, L - (Left Hand Circularly Polarized)
    Rotating left relative to the Earth's surface, R - (Right Hand Circularly
    Polarized) Rotating right relative to the Earth's surface.
    """

    purpose: Literal["COMM", "TTC", "OPS", "OTHER"]
    """
    Purpose or use of the RF Band -- COMM = communications, TTC =
    Telemetry/Tracking/Control, OPS = Operations, OTHER = Other).
    """
