# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["RoutestatQueryResponse", "RoutestatQueryResponseItem"]


class RoutestatQueryResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    location_end: str = FieldInfo(alias="locationEnd")
    """End location of the vehicle."""

    location_start: str = FieldInfo(alias="locationStart")
    """Starting location of the vehicle."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    avg_duration: Optional[float] = FieldInfo(alias="avgDuration", default=None)
    """
    Average travel duration for the indicated distance and type of vehicle in hours.
    """

    avg_speed: Optional[float] = FieldInfo(alias="avgSpeed", default=None)
    """Average speed during travel in the indicated unit of measurement, speedUnit."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    data_pts_used: Optional[int] = FieldInfo(alias="dataPtsUsed", default=None)
    """The number of data points used in this travel duration calculation."""

    distance: Optional[float] = None
    """
    Distance between the departure and arrival locations in the indicated unit of
    measurement, distUnit.
    """

    dist_unit: Optional[str] = FieldInfo(alias="distUnit", default=None)
    """The unit of measurement used for distance in this calculation."""

    first_pt: Optional[datetime] = FieldInfo(alias="firstPt", default=None)
    """
    Date of the first data point used in this calculation, in ISO8601 UTC format
    with millisecond precision.
    """

    ideal_desc: Optional[str] = FieldInfo(alias="idealDesc", default=None)
    """
    Description of the portion of travel used to estimate the value of the
    idealDuration field.
    """

    ideal_duration: Optional[float] = FieldInfo(alias="idealDuration", default=None)
    """
    Estimated ideal travel duration in hours for the full distance using the
    indicated vehicle type. The field "idealDesc" should be used to describe the
    ideal travel route.
    """

    id_site_end: Optional[str] = FieldInfo(alias="idSiteEnd", default=None)
    """Unique identifier of the Site at the route's end location.

    This ID can be used to obtain additional information on a Site using the 'get by
    ID' operation (e.g. /udl/site/{id}). For example, the Site object with idSite =
    abc would be queried as /udl/site/abc.
    """

    id_site_start: Optional[str] = FieldInfo(alias="idSiteStart", default=None)
    """Unique identifier of the Site at the route's starting location.

    This ID can be used to obtain additional information on a Site using the 'get by
    ID' operation (e.g. /udl/site/{id}). For example, the Site object with idSite =
    abc would be queried as /udl/site/abc.
    """

    last_pt: Optional[datetime] = FieldInfo(alias="lastPt", default=None)
    """
    Date of the last data point used in this calculation, in ISO8601 UTC format with
    millisecond precision.
    """

    location_type: Optional[str] = FieldInfo(alias="locationType", default=None)
    """Type of location used for route start and end points (e.g., ICAO, PORT, etc.)."""

    max_duration: Optional[float] = FieldInfo(alias="maxDuration", default=None)
    """
    Maximum travel duration for the indicated distance and type of vehicle in hours.
    """

    max_speed: Optional[float] = FieldInfo(alias="maxSpeed", default=None)
    """Maximum speed during travel in the indicated unit of measurement, speedUnit."""

    min_duration: Optional[float] = FieldInfo(alias="minDuration", default=None)
    """
    Minimum travel duration for the indicated distance and type of vehicle in hours.
    """

    min_speed: Optional[float] = FieldInfo(alias="minSpeed", default=None)
    """Minimum speed during travel in the indicated unit of measurement, speedUnit."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    partial_desc: Optional[str] = FieldInfo(alias="partialDesc", default=None)
    """
    Description of the portion of travel used to estimate the value of the
    partialDuration field.
    """

    partial_duration: Optional[float] = FieldInfo(alias="partialDuration", default=None)
    """
    Estimated ideal travel duration in hours for a partial distance using the
    indicated vehicle type. The field "partialDesc" should be used to specify the
    intended portion of travel.
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    speed_unit: Optional[str] = FieldInfo(alias="speedUnit", default=None)
    """The unit of measurement used for speed in this calculation."""

    time_period: Optional[str] = FieldInfo(alias="timePeriod", default=None)
    """The time period this data was collected."""

    vehicle_category: Optional[str] = FieldInfo(alias="vehicleCategory", default=None)
    """
    The vehicle category that is the subject of this calculation (e.g., AIRCRAFT,
    CAR, BOAT, etc.).
    """

    vehicle_type: Optional[str] = FieldInfo(alias="vehicleType", default=None)
    """
    The vehicle type that is the subject of this calculation (e.g., C-17, F-15,
    etc.).
    """


RoutestatQueryResponse: TypeAlias = List[RoutestatQueryResponseItem]
