# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SarobservationCreateBulkParams", "Body"]


class SarobservationCreateBulkParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    collection_end: Required[Annotated[Union[str, datetime], PropertyInfo(alias="collectionEnd", format="iso8601")]]
    """Collection end time in ISO 8601 UTC format with microsecond precision."""

    collection_start: Required[Annotated[Union[str, datetime], PropertyInfo(alias="collectionStart", format="iso8601")]]
    """Collection start time in ISO 8601 UTC format with microsecond precision."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    sar_mode: Required[Annotated[str, PropertyInfo(alias="sarMode")]]
    """Collection mode setting for this collection (e.g.

    AREA, SPOTLIGHT, STRIP, etc.).
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    agjson: str
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. GeoJSON Reference: https://geojson.org/. Ignored if included with a POST
    or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    andims: int
    """Number of dimensions of the geometry depicted by region."""

    area: str
    """
    Optional geographical region or polygon (lat/lon pairs) of the area surrounding
    the image event as projected on the ground.
    """

    asrid: int
    """Geographical spatial_ref_sys for region."""

    atext: str
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a POST or PUT request that also specifies a valid 'area' field.
    """

    atype: str
    """Type of region as projected on the ground (POLYGON, POINT, LINE)."""

    azimuth_angle: Annotated[float, PropertyInfo(alias="azimuthAngle")]
    """
    The azimuth angle, in degrees, of the SAR satellite nadir subpoint measured
    clockwise from true north at the subpoint.
    """

    center_time: Annotated[Union[str, datetime], PropertyInfo(alias="centerTime", format="iso8601")]
    """
    The datetime at the center point of the collection in ISO 8601 UTC format with
    microsecond precision.
    """

    collection_id: Annotated[str, PropertyInfo(alias="collectionId")]
    """
    Optional identifier to indicate the specific collection tasking which produced
    this observation.
    """

    continuous_spot_angle: Annotated[float, PropertyInfo(alias="continuousSpotAngle")]
    """Required sweep angle for the continuous spot scene in degrees."""

    coord_sys: Annotated[str, PropertyInfo(alias="coordSys")]
    """
    The coordinate system used for the sensor velocity and target position vectors
    for the collection.
    """

    detection_end: Annotated[Union[str, datetime], PropertyInfo(alias="detectionEnd", format="iso8601")]
    """The detection end time in ISO 8601 UTC format, with microsecond precision."""

    detection_id: Annotated[str, PropertyInfo(alias="detectionId")]
    """
    Identifier of the specific detection within a collection which produced this
    observation.
    """

    detection_start: Annotated[Union[str, datetime], PropertyInfo(alias="detectionStart", format="iso8601")]
    """The detection start time in ISO 8601 UTC format, with microsecond precision."""

    dwell_time: Annotated[float, PropertyInfo(alias="dwellTime")]
    """The duration, in seconds, of this detection."""

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    far_range: Annotated[float, PropertyInfo(alias="farRange")]
    """
    Specifies the farthest range, in kilometers, from the flight path to target
    during the collection.
    """

    graze_angle: Annotated[float, PropertyInfo(alias="grazeAngle")]
    """The graze angle (also referred to as look angle) for the collection in degrees."""

    ground_resolution_projection: Annotated[float, PropertyInfo(alias="groundResolutionProjection")]
    """
    Distance between independent measurements, representing the physical dimension
    that represents a pixel of the image.
    """

    id_sensor: Annotated[str, PropertyInfo(alias="idSensor")]
    """Unique identifier of the reporting sensor."""

    incidence_angle: Annotated[float, PropertyInfo(alias="incidenceAngle")]
    """The center incidence angle in degrees."""

    looks_azimuth: Annotated[int, PropertyInfo(alias="looksAzimuth")]
    """The number of looks in the azimuth direction."""

    looks_range: Annotated[int, PropertyInfo(alias="looksRange")]
    """The number of looks in the range direction."""

    multilook_number: Annotated[float, PropertyInfo(alias="multilookNumber")]
    """
    Averages the input synthetic aperture radar (SAR) data by looks in range and
    azimuth to approximate square pixels, mitigates speckle, and reduces SAR tool
    processing time.
    """

    near_range: Annotated[float, PropertyInfo(alias="nearRange")]
    """
    Specifies the closest range, in kilometers, from the flight path to target
    during the collection.
    """

    ob_direction: Annotated[str, PropertyInfo(alias="obDirection")]
    """The antenna pointing direction (LEFT, RIGHT)."""

    operating_band: Annotated[str, PropertyInfo(alias="operatingBand")]
    """Name of the band containing operating frequency for the collection (e.g.

    C, E, EHF, HF, K, Ka, Ku, L, Q, S, SHF, UNK, UHF, V, VHF, VLF, W, X). See
    RFBandType for more details and descriptions of each band name.
    """

    operating_freq: Annotated[float, PropertyInfo(alias="operatingFreq")]
    """The operating frequency, in Mhz, for the collection."""

    orbit_state: Annotated[str, PropertyInfo(alias="orbitState")]
    """
    The orbital direction (ASCENDING, DESCENDING) of the platform during the
    collection.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Annotated[str, PropertyInfo(alias="origObjectId")]
    """
    Optional identifier provided by the source to indicate the onorbit object
    hosting the sensor associated with this collection. This may be an internal
    identifier and not necessarily a valid satellite number.
    """

    orig_sensor_id: Annotated[str, PropertyInfo(alias="origSensorId")]
    """
    Optional identifier provided by the source to indicate the sensor for this
    collection. This may be an internal identifier and not necessarily a valid
    sensor ID.
    """

    pulse_bandwidth: Annotated[float, PropertyInfo(alias="pulseBandwidth")]
    """The bandwidth frequency of the pulse in Mhz."""

    pulse_duration: Annotated[float, PropertyInfo(alias="pulseDuration")]
    """The duration of a pulse in seconds."""

    resolution_azimuth: Annotated[float, PropertyInfo(alias="resolutionAzimuth")]
    """The resolution in the azimuth direction measured in meters."""

    resolution_range: Annotated[float, PropertyInfo(alias="resolutionRange")]
    """The resolution in the range direction measured in meters."""

    rx_polarization: Annotated[str, PropertyInfo(alias="rxPolarization")]
    """Receive polarization e.g.

    H - (Horizontally Polarized) Perpendicular to Earth's surface, V - (Vertically
    Polarized) Parallel to Earth's surface, L - (Left Hand Circularly Polarized)
    Rotating left relative to the earth's surface, R - (Right Hand Circularly
    Polarized) Rotating right relative to the earth's surface.
    """

    sat_no: Annotated[int, PropertyInfo(alias="satNo")]
    """
    Satellite/Catalog number of the spacecraft hosting the sensor associated with
    this collection.
    """

    senalt: float
    """Sensor altitude during collection in kilometers."""

    senlat_end: Annotated[float, PropertyInfo(alias="senlatEnd")]
    """
    WGS-84 sensor latitude sub-point at collect end time (collectionEnd),
    represented as -90 to 90 degrees (negative values south of equator).
    """

    senlat_start: Annotated[float, PropertyInfo(alias="senlatStart")]
    """
    WGS-84 sensor latitude sub-point at collect start time (collectionStart),
    represented as -90 to 90 degrees (negative values south of equator).
    """

    senlon_end: Annotated[float, PropertyInfo(alias="senlonEnd")]
    """
    WGS-84 sensor longitude sub-point at collect end time (collectionEnd),
    represented as -180 to 180 degrees (negative values west of Prime Meridian).
    """

    senlon_start: Annotated[float, PropertyInfo(alias="senlonStart")]
    """
    WGS-84 sensor longitude sub-point at collect start time (collectionStart),
    represented as -180 to 180 degrees (negative values west of Prime Meridian).
    """

    senvelx: float
    """Sensor platform X-velocity during collection in kilometers/second."""

    senvely: float
    """Sensor platform Y-velocity during collection in kilometers/second."""

    senvelz: float
    """Sensor platform Z-velocity during collection in kilometers/second."""

    slant_range: Annotated[float, PropertyInfo(alias="slantRange")]
    """Slant distance from sensor to center point of imaging event in kilometers."""

    snr: float
    """Signal to noise ratio, in dB."""

    spacing_azimuth: Annotated[float, PropertyInfo(alias="spacingAzimuth")]
    """The pixel spacing in the azimuth direction measured in meters."""

    spacing_range: Annotated[float, PropertyInfo(alias="spacingRange")]
    """The pixel spacing in the range direction measured in meters."""

    squint_angle: Annotated[float, PropertyInfo(alias="squintAngle")]
    """The squint angle for the collection in degrees."""

    src_ids: Annotated[List[str], PropertyInfo(alias="srcIds")]
    """Array of UUIDs of the UDL data records that are related to the SAR Observation.

    See the associated 'srcTyps' array for the specific types of data, positionally
    corresponding to the UUIDs in this array. The 'srcTyps' and 'srcIds' arrays must
    match in size. See the corresponding srcTyps array element for the data type of
    the UUID and use the appropriate API operation to retrieve that object (e.g.
    /udl/sarobservation/{uuid}).
    """

    src_typs: Annotated[List[str], PropertyInfo(alias="srcTyps")]
    """Array of UDL record types (e.g.

    ANALYTICMAGERY, ESID, GROUNDIMAGE, NOTIFICATION, POI, SV, TRACK) that are
    related to the SAR Observation. See the associated 'srcIds' array for the record
    UUIDs, positionally corresponding to the record types in this array. The
    'srcTyps' and 'srcIds' arrays must match in size.
    """

    swath_length: Annotated[float, PropertyInfo(alias="swathLength")]
    """The length of the collection as projected on the ground in kilometers."""

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    targetposx: float
    """The collection target X position in kilometers."""

    targetposy: float
    """The collection target Y position in kilometers."""

    targetposz: float
    """The collection target Z position in kilometers."""

    transaction_id: Annotated[str, PropertyInfo(alias="transactionId")]
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    tx_polarization: Annotated[str, PropertyInfo(alias="txPolarization")]
    """Transmit polarization e.g.

    H - (Horizontally Polarized) Perpendicular to Earth's surface, V - (Vertically
    Polarized) Parallel to Earth's surface, L - (Left Hand Circularly Polarized)
    Rotating left relative to the earth's surface, R - (Right Hand Circularly
    Polarized) Rotating right relative to the earth's surface.
    """
