# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["HistoryQueryResponse", "HistoryQueryResponseItem"]


class HistoryQueryResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_sensor: str = FieldInfo(alias="idSensor")
    """Unique identifier of the sensor to which this calibration data applies.

    This ID can be used to obtain additional information on a sensor using the 'get
    by ID' operation (e.g. /udl/sensor/{id}). For example, the sensor with idSensor
    = abc would be queried as /udl/sensor/abc.
    """

    source: str
    """Source of the data."""

    start_time: datetime = FieldInfo(alias="startTime")
    """
    Calibration data span start time in ISO 8601 UTC format with millisecond
    precision.
    """

    id: Optional[str] = None
    """
    Unique identifier of the record, auto-generated by the system if not provided on
    create operations.
    """

    az_ra_accel_bias: Optional[float] = FieldInfo(alias="azRaAccelBias", default=None)
    """
    Sensor azimuth/right-ascension acceleration bias rate, in degrees per second
    squared, during sensor operation.
    """

    az_ra_accel_sigma: Optional[float] = FieldInfo(alias="azRaAccelSigma", default=None)
    """
    Standard deviation azimuth/right-ascension acceleration bias rate, in degrees
    per second squared.
    """

    az_ra_bias: Optional[float] = FieldInfo(alias="azRaBias", default=None)
    """Sensor azimuth/right-ascension bias, in degrees, during sensor operation."""

    az_ra_bias_rate: Optional[float] = FieldInfo(alias="azRaBiasRate", default=None)
    """
    Sensor azimuth/right-ascension bias rate, in degrees per second, during sensor
    operation.
    """

    az_ra_mean: Optional[float] = FieldInfo(alias="azRaMean", default=None)
    """The mean azimuth/right-ascension average, in degrees, for the duration span."""

    az_ra_rms: Optional[float] = FieldInfo(alias="azRaRms", default=None)
    """
    The root mean square of the azimuth/right-ascension, in degrees, for the
    duration span.
    """

    az_ra_sigma_rate: Optional[float] = FieldInfo(alias="azRaSigmaRate", default=None)
    """Standard deviation azimuth/right-ascension bias rate, in degrees per second."""

    cal_angle_ref: Optional[str] = FieldInfo(alias="calAngleRef", default=None)
    """Specifies the calibration reference angle set for this calibration data set.

    Azimuth and Elevation (AZEL) or Right Ascension and Declination (RADEC).
    """

    cal_track_mode: Optional[str] = FieldInfo(alias="calTrackMode", default=None)
    """
    Specifies that the calibration data are from INTRA_TRACK or INTER_TRACK
    residuals.
    """

    cal_type: Optional[str] = FieldInfo(alias="calType", default=None)
    """
    The basis of calibration values contained in this record (COMPUTED,
    OPERATIONAL).
    """

    confidence_noise_bias: Optional[float] = FieldInfo(alias="confidenceNoiseBias", default=None)
    """The confidence noise bias of the duration span."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    duration: Optional[float] = None
    """
    Duration of the sensor calibration data which produced these values, measured in
    days.
    """

    ecr: Optional[List[float]] = None
    """
    Three element array, expressing the sensor location in Earth Centered Rotating
    (ECR) coordinates, in kilometers. The array element order is [x, y, z].
    """

    el_dec_accel_bias: Optional[float] = FieldInfo(alias="elDecAccelBias", default=None)
    """
    Sensor elevation/declination acceleration bias rate, in degrees per second
    squared, during sensor operation.
    """

    el_dec_accel_sigma: Optional[float] = FieldInfo(alias="elDecAccelSigma", default=None)
    """
    Standard deviation elevation/declination acceleration bias rate, in degrees per
    second squared.
    """

    el_dec_bias: Optional[float] = FieldInfo(alias="elDecBias", default=None)
    """Sensor elevation/declination bias, in degrees, during sensor operation."""

    el_dec_bias_rate: Optional[float] = FieldInfo(alias="elDecBiasRate", default=None)
    """
    Sensor elevation/declination bias rate, in degrees per second, during sensor
    operation.
    """

    el_dec_mean: Optional[float] = FieldInfo(alias="elDecMean", default=None)
    """The mean elevation/declination residuals, in degrees, for the duration span."""

    el_dec_rms: Optional[float] = FieldInfo(alias="elDecRms", default=None)
    """
    The root mean square of the elevation/declination, in degrees, for the duration
    span.
    """

    el_dec_sigma_rate: Optional[float] = FieldInfo(alias="elDecSigmaRate", default=None)
    """Standard deviation elevation/declination bias rate, in degrees per second."""

    end_time: Optional[datetime] = FieldInfo(alias="endTime", default=None)
    """Calibration data span end time in ISO 8601 UTC format with millisecond
    precision.

    If provided, the endTime must be greater than or equal to the startTime in the
    SensorCalibration record.
    """

    num_az_ra_obs: Optional[int] = FieldInfo(alias="numAzRaObs", default=None)
    """
    The number of observables used in determining the azimuth or right-ascension
    calibration values.
    """

    num_el_dec_obs: Optional[int] = FieldInfo(alias="numElDecObs", default=None)
    """
    The number of observables used in determining the elevation or declination
    calibration values.
    """

    num_obs: Optional[int] = FieldInfo(alias="numObs", default=None)
    """The total number of observables available over the calibration span."""

    num_photo_obs: Optional[int] = FieldInfo(alias="numPhotoObs", default=None)
    """
    The number of observables used in determining the photometric calibration
    values.
    """

    num_range_obs: Optional[int] = FieldInfo(alias="numRangeObs", default=None)
    """The number of observables used in determining the range calibration values."""

    num_range_rate_obs: Optional[int] = FieldInfo(alias="numRangeRateObs", default=None)
    """
    The number of observables used in determining the range rate calibration values.
    """

    num_rcs_obs: Optional[int] = FieldInfo(alias="numRcsObs", default=None)
    """
    The number of observables used in determining the radar cross section (RCS)
    calibration values.
    """

    num_time_obs: Optional[int] = FieldInfo(alias="numTimeObs", default=None)
    """The number of observables used in determining the time calibration values."""

    num_tracks: Optional[int] = FieldInfo(alias="numTracks", default=None)
    """The total number of tracks available over the calibration span."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    photo_bias: Optional[float] = FieldInfo(alias="photoBias", default=None)
    """The photometric observation noise bias in visual magnitude."""

    photo_sigma: Optional[float] = FieldInfo(alias="photoSigma", default=None)
    """The photometric observation noise standard deviation in visual magnitude."""

    range_accel_bias: Optional[float] = FieldInfo(alias="rangeAccelBias", default=None)
    """
    Sensor range rate bias acceleration, in kilometers per second squared, during
    sensor operation.
    """

    range_accel_sigma: Optional[float] = FieldInfo(alias="rangeAccelSigma", default=None)
    """
    Standard deviation range rate bias acceleration, in kilometers per second
    squared.
    """

    range_bias: Optional[float] = FieldInfo(alias="rangeBias", default=None)
    """Sensor range bias, in kilometers, for the duration span."""

    range_rate_bias: Optional[float] = FieldInfo(alias="rangeRateBias", default=None)
    """Sensor range rate bias, in kilometers per second for the duration span."""

    range_rate_rms: Optional[float] = FieldInfo(alias="rangeRateRms", default=None)
    """
    The root mean square of the calibration sensor range rate, in kilometers per
    second, for the duration span.
    """

    range_rate_sigma: Optional[float] = FieldInfo(alias="rangeRateSigma", default=None)
    """Standard deviation range rate, in kilometers per second, for the duration span."""

    range_rms: Optional[float] = FieldInfo(alias="rangeRms", default=None)
    """
    The root mean square of the calibration sensor range, in kilometers, for the
    duration span.
    """

    range_sigma: Optional[float] = FieldInfo(alias="rangeSigma", default=None)
    """Calibration standard deviation range, in kilometers, for the duration span."""

    rcs_bias: Optional[float] = FieldInfo(alias="rcsBias", default=None)
    """The radar cross section (RCS) observation noise bias in square meters."""

    rcs_sigma: Optional[float] = FieldInfo(alias="rcsSigma", default=None)
    """
    The radar cross section (RCS) observation noise standard deviation in square
    meters.
    """

    ref_targets: Optional[List[str]] = FieldInfo(alias="refTargets", default=None)
    """Array of the catalog IDs of the reference targets used in the calibration."""

    ref_type: Optional[str] = FieldInfo(alias="refType", default=None)
    """The reference type used in the calibration."""

    sen_type: Optional[str] = FieldInfo(alias="senType", default=None)
    """The sensor type (MECHANICAL, OPTICAL, PHASED ARRAY, RF)."""

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    time_bias: Optional[float] = FieldInfo(alias="timeBias", default=None)
    """Sensor time bias, in seconds, for the duration span."""

    time_bias_sigma: Optional[float] = FieldInfo(alias="timeBiasSigma", default=None)
    """Standard deviation time, in seconds, for the duration span."""


HistoryQueryResponse: TypeAlias = List[HistoryQueryResponseItem]
