# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import date, datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .engine import Engine
from .._models import BaseModel
from .antenna_full import AntennaFull
from .battery_full import BatteryFull
from .location_full import LocationFull
from .organization_full import OrganizationFull
from .solar_array_details_full import SolarArrayDetailsFull

__all__ = [
    "SensorTupleResponse",
    "SensorTupleResponseItem",
    "SensorTupleResponseItemEntity",
    "SensorTupleResponseItemEntityOnOrbit",
    "SensorTupleResponseItemEntityOnOrbitAntenna",
    "SensorTupleResponseItemEntityOnOrbitBattery",
    "SensorTupleResponseItemEntityOnOrbitOnorbitDetail",
    "SensorTupleResponseItemEntityOnOrbitSolarArray",
    "SensorTupleResponseItemEntityOnOrbitSolarArraySolarArray",
    "SensorTupleResponseItemEntityOnOrbitThruster",
    "SensorTupleResponseItemEntityOperatingUnit",
    "SensorTupleResponseItemEntityOperatingUnitOperatingUnitRemark",
    "SensorTupleResponseItemEntityRfBand",
    "SensorTupleResponseItemEntityStatusCollection",
    "SensorTupleResponseItemEntityStatusCollectionSubStatusCollection",
    "SensorTupleResponseItemSensorcharacteristic",
    "SensorTupleResponseItemSensorlimitsCollection",
    "SensorTupleResponseItemSensorObservationType",
    "SensorTupleResponseItemSensorStat",
    "SensorTupleResponseItemSensorType",
]


class SensorTupleResponseItemEntityOnOrbitAntenna(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_antenna: str = FieldInfo(alias="idAntenna")
    """ID of the antenna."""

    id_on_orbit: str = FieldInfo(alias="idOnOrbit")
    """ID of the on-orbit object."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    antenna: Optional[AntennaFull] = None
    """
    Model representation of information on on-orbit/spacecraft communication
    antennas. A spacecraft may have multiple antennas and each antenna can have
    multiple 'details' records compiled by different sources.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityOnOrbitBattery(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_battery: str = FieldInfo(alias="idBattery")
    """ID of the battery."""

    id_on_orbit: str = FieldInfo(alias="idOnOrbit")
    """ID of the on-orbit object."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    battery: Optional[BatteryFull] = None
    """Model representation of specific spacecraft battery types."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    quantity: Optional[int] = None
    """The number of batteries on the spacecraft of the type identified by idBattery."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityOnOrbitOnorbitDetail(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_on_orbit: str = FieldInfo(alias="idOnOrbit")
    """UUID of the parent Onorbit record."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    additional_mass: Optional[float] = FieldInfo(alias="additionalMass", default=None)
    """Mass of fuel and disposables at launch time in kilograms."""

    adept_radius: Optional[float] = FieldInfo(alias="adeptRadius", default=None)
    """
    The radius used for long-term debris environment projection analyses that is not
    as conservative as COLA Radius, in meters.
    """

    bol_delta_v: Optional[float] = FieldInfo(alias="bolDeltaV", default=None)
    """The total beginning of life delta V of the spacecraft, in meters per second."""

    bol_fuel_mass: Optional[float] = FieldInfo(alias="bolFuelMass", default=None)
    """Spacecraft beginning of life fuel mass, in orbit, in kilograms."""

    bus_cross_section: Optional[float] = FieldInfo(alias="busCrossSection", default=None)
    """Average cross sectional area of the bus in meters squared."""

    bus_type: Optional[str] = FieldInfo(alias="busType", default=None)
    """Type of the bus on the spacecraft."""

    cola_radius: Optional[float] = FieldInfo(alias="colaRadius", default=None)
    """
    Maximum dimension of the box circumscribing the spacecraft (d = sqrt(a*a + b*b +
    c\\**c) where a is the tip-to-tip dimension, b and c are perpendicular to that.)
    in meters.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    cross_section: Optional[float] = FieldInfo(alias="crossSection", default=None)
    """Average cross sectional area in meters squared."""

    current_mass: Optional[float] = FieldInfo(alias="currentMass", default=None)
    """The estimated total current mass of the spacecraft, in kilograms."""

    delta_v_unc: Optional[float] = FieldInfo(alias="deltaVUnc", default=None)
    """The 1-sigma uncertainty of the total spacecraft delta V, in meters per second."""

    dep_est_masses: Optional[List[float]] = FieldInfo(alias="depEstMasses", default=None)
    """Array of the estimated mass of each deployable object, in kilograms.

    Must contain the same number of elements as the value of numDeployable.
    """

    dep_mass_uncs: Optional[List[float]] = FieldInfo(alias="depMassUncs", default=None)
    """
    Array of the 1-sigma uncertainty of the mass for each deployable object, in
    kilograms. Must contain the same number of elements as the value of
    numDeployable.
    """

    dep_names: Optional[List[str]] = FieldInfo(alias="depNames", default=None)
    """Array of satellite deployable objects.

    Must contain the same number of elements as the value of numDeployable.
    """

    drift_rate: Optional[float] = FieldInfo(alias="driftRate", default=None)
    """GEO drift rate, if applicable in degrees per day."""

    dry_mass: Optional[float] = FieldInfo(alias="dryMass", default=None)
    """Spacecraft dry mass (without fuel or disposables) in kilograms."""

    est_delta_v_duration: Optional[float] = FieldInfo(alias="estDeltaVDuration", default=None)
    """Estimated maximum burn duration for the object, in seconds."""

    fuel_remaining: Optional[float] = FieldInfo(alias="fuelRemaining", default=None)
    """Estimated remaining fuel for the object in kilograms."""

    geo_slot: Optional[float] = FieldInfo(alias="geoSlot", default=None)
    """GEO slot if applicable, in degrees.

    -180 (West of Prime Meridian) to 180 degrees (East of Prime Meridian). Prime
    Meridian is 0.
    """

    last_ob_source: Optional[str] = FieldInfo(alias="lastObSource", default=None)
    """The name of the source who last provided an observation for this idOnOrbit."""

    last_ob_time: Optional[datetime] = FieldInfo(alias="lastObTime", default=None)
    """
    Time of last reported observation for this object in ISO 8601 UTC with
    microsecond precision.
    """

    launch_mass: Optional[float] = FieldInfo(alias="launchMass", default=None)
    """Nominal mass of spacecraft and fuel at launch time, in kilograms."""

    launch_mass_max: Optional[float] = FieldInfo(alias="launchMassMax", default=None)
    """Maximum (estimated) mass of spacecraft and fuel at launch time, in kilograms."""

    launch_mass_min: Optional[float] = FieldInfo(alias="launchMassMin", default=None)
    """Minimum (estimated) mass of spacecraft and fuel at launch time, in kilograms."""

    maneuverable: Optional[bool] = None
    """Boolean indicating whether a spacecraft is maneuverable.

    Note that a spacecraft may have propulsion capability but may not be
    maneuverable due to lack of fuel, anomalous condition, or other operational
    constraints.
    """

    max_delta_v: Optional[float] = FieldInfo(alias="maxDeltaV", default=None)
    """Maximum delta V available for this on-orbit spacecraft, in meters per second."""

    max_radius: Optional[float] = FieldInfo(alias="maxRadius", default=None)
    """
    Maximum dimension across the spacecraft (e.g., tip-to-tip across the solar panel
    arrays) in meters.
    """

    mission_types: Optional[List[str]] = FieldInfo(alias="missionTypes", default=None)
    """Array of the type of missions the spacecraft performs.

    Must contain the same number of elements as the value of numMission.
    """

    num_deployable: Optional[int] = FieldInfo(alias="numDeployable", default=None)
    """The number of sub-satellites or deployable objects on the spacecraft."""

    num_mission: Optional[int] = FieldInfo(alias="numMission", default=None)
    """The number of distinct missions the spacecraft performs."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    rcs: Optional[float] = None
    """Current/latest radar cross section in meters squared."""

    rcs_max: Optional[float] = FieldInfo(alias="rcsMax", default=None)
    """Maximum radar cross section in meters squared."""

    rcs_mean: Optional[float] = FieldInfo(alias="rcsMean", default=None)
    """Mean radar cross section in meters squared."""

    rcs_min: Optional[float] = FieldInfo(alias="rcsMin", default=None)
    """Minimum radar cross section in meters squared."""

    ref_source: Optional[str] = FieldInfo(alias="refSource", default=None)
    """
    The reference source, sources, or URL from which the data in this record was
    obtained.
    """

    solar_array_area: Optional[float] = FieldInfo(alias="solarArrayArea", default=None)
    """Spacecraft deployed area of solar array in meters squared."""

    total_mass_unc: Optional[float] = FieldInfo(alias="totalMassUnc", default=None)
    """The 1-sigma uncertainty of the total spacecraft mass, in kilograms."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    vismag: Optional[float] = None
    """Current/latest visual magnitude in M."""

    vismag_max: Optional[float] = FieldInfo(alias="vismagMax", default=None)
    """Maximum visual magnitude in M."""

    vismag_mean: Optional[float] = FieldInfo(alias="vismagMean", default=None)
    """Mean visual magnitude in M."""

    vismag_min: Optional[float] = FieldInfo(alias="vismagMin", default=None)
    """Minimum visual magnitude in M."""


class SensorTupleResponseItemEntityOnOrbitSolarArraySolarArray(BaseModel):
    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Solar Array name."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    solar_array_details: Optional[List[SolarArrayDetailsFull]] = FieldInfo(alias="solarArrayDetails", default=None)
    """
    Read-only collection of additional SolarArrayDetails by various sources for this
    organization, ignored on create/update. These details must be created separately
    via the /udl/solararraydetails operations.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityOnOrbitSolarArray(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_on_orbit: str = FieldInfo(alias="idOnOrbit")
    """ID of the on-orbit object."""

    id_solar_array: str = FieldInfo(alias="idSolarArray")
    """ID of the SolarArray."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    quantity: Optional[int] = None
    """
    The number of solar arrays on the spacecraft of the type identified by
    idSolarArray.
    """

    solar_array: Optional[SensorTupleResponseItemEntityOnOrbitSolarArraySolarArray] = FieldInfo(
        alias="solarArray", default=None
    )
    """Model representation of information on on-orbit/spacecraft solar arrays.

    A spacecraft may have multiple solar arrays and each solar array can have
    multiple 'details' records compiled by different sources.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityOnOrbitThruster(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_engine: str = FieldInfo(alias="idEngine")
    """ID of the Engine."""

    id_on_orbit: str = FieldInfo(alias="idOnOrbit")
    """ID of the on-orbit object."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    engine: Optional[Engine] = None
    """Known launch vehicle engines and their performance characteristics and limits.

    A launch vehicle has 1 to many engines per stage.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    quantity: Optional[int] = None
    """
    The number of engines/thrusters on the spacecraft of the type identified by
    idEngine.
    """

    type: Optional[str] = None
    """The type of thruster associated with this record (e.g.

    LAE, Hydrazine REA, etc.).
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityOnOrbit(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    sat_no: int = FieldInfo(alias="satNo")
    """Satellite/Catalog number of the target on-orbit object."""

    source: str
    """Source of the data."""

    alt_name: Optional[str] = FieldInfo(alias="altName", default=None)
    """Alternate name of the on-orbit object."""

    antennas: Optional[List[SensorTupleResponseItemEntityOnOrbitAntenna]] = None
    """Read-only collection of antennas on this on-orbit object."""

    batteries: Optional[List[SensorTupleResponseItemEntityOnOrbitBattery]] = None
    """Read-only collection of batteries on this on-orbit object."""

    category: Optional[
        Literal[
            "Unknown",
            "On-Orbit",
            "Decayed",
            "Cataloged Without State",
            "Launch Nominal",
            "Analyst Satellite",
            "Cislunar",
            "Lunar",
            "Hyperbolic",
            "Heliocentric",
            "Interplanetary",
            "Lagrangian",
            "Docked",
        ]
    ] = None
    """Category of the on-orbit object.

    (Unknown, On-Orbit, Decayed, Cataloged Without State, Launch Nominal, Analyst
    Satellite, Cislunar, Lunar, Hyperbolic, Heliocentric, Interplanetary,
    Lagrangian, Docked).
    """

    common_name: Optional[str] = FieldInfo(alias="commonName", default=None)
    """Common name of the on-orbit object."""

    constellation: Optional[str] = None
    """Constellation to which this satellite belongs."""

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country code.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    decay_date: Optional[datetime] = FieldInfo(alias="decayDate", default=None)
    """Date of decay."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """
    For the public catalog, the idOnOrbit is typically the satellite number as a
    string, but may be a UUID for analyst or other unknown or untracked satellites,
    auto-generated by the system.
    """

    intl_des: Optional[str] = FieldInfo(alias="intlDes", default=None)
    """
    International Designator, typically of the format YYYYLLLAAA, where YYYY is the
    launch year, LLL is the sequential launch number of that year, and AAA is an
    optional launch piece designator for the launch.
    """

    launch_date: Optional[date] = FieldInfo(alias="launchDate", default=None)
    """Date of launch."""

    launch_site_id: Optional[str] = FieldInfo(alias="launchSiteId", default=None)
    """Id of the associated launchSite entity."""

    lifetime_years: Optional[int] = FieldInfo(alias="lifetimeYears", default=None)
    """Estimated lifetime of the on-orbit payload, if known."""

    mission_number: Optional[str] = FieldInfo(alias="missionNumber", default=None)
    """Mission number of the on-orbit object."""

    object_type: Optional[Literal["ROCKET BODY", "DEBRIS", "PAYLOAD", "PLATFORM", "MANNED", "UNKNOWN"]] = FieldInfo(
        alias="objectType", default=None
    )
    """
    Type of on-orbit object: ROCKET BODY, DEBRIS, PAYLOAD, PLATFORM, MANNED,
    UNKNOWN.
    """

    onorbit_details: Optional[List[SensorTupleResponseItemEntityOnOrbitOnorbitDetail]] = FieldInfo(
        alias="onorbitDetails", default=None
    )
    """Read-only collection of details for this on-orbit object."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    solar_arrays: Optional[List[SensorTupleResponseItemEntityOnOrbitSolarArray]] = FieldInfo(
        alias="solarArrays", default=None
    )
    """Read-only collection of solar arrays on this on-orbit object."""

    thrusters: Optional[List[SensorTupleResponseItemEntityOnOrbitThruster]] = None
    """Read-only collection of thrusters (engines) on this on-orbit object."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityOperatingUnitOperatingUnitRemark(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_operating_unit: str = FieldInfo(alias="idOperatingUnit")
    """The ID of the operating unit to which this remark applies."""

    source: str
    """Source of the data."""

    text: str
    """The text of the remark."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    alt_rmk_id: Optional[str] = FieldInfo(alias="altRmkId", default=None)
    """Unique identifier of the unit remark record from the originating system."""

    code: Optional[str] = None
    """The remark type identifier.

    For example, the Mobility Air Forces (MAF) remark code, defined in the Airfield
    Suitability and Restriction Report (ASRR).
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    name: Optional[str] = None
    """The name of the remark."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    type: Optional[str] = None
    """The remark type (e.g. Caution, Information, Misc, Restriction, etc.)."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityOperatingUnit(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Name of the operating unit."""

    source: str
    """Source of the data."""

    air_def_area: Optional[str] = FieldInfo(alias="airDefArea", default=None)
    """
    Air Defense District (ADD) or Air Defense Area (ADA) in which the geographic
    coordinates reside.
    """

    allegiance: Optional[str] = None
    """
    The DoD Standard country code designator for the country or political entity to
    which the operating unit owes its allegiance. This field will be set to "OTHR"
    if the source value does not match a UDL country code value (ISO-3166-ALPHA-2).
    """

    alt_allegiance: Optional[str] = FieldInfo(alias="altAllegiance", default=None)
    """
    Specifies an alternate allegiance code if the data provider code is not part of
    an official Country Code standard such as ISO-3166 or FIPS. This field will be
    set to the value provided by the source and should be used for all Queries
    specifying allegiance.
    """

    alt_country_code: Optional[str] = FieldInfo(alias="altCountryCode", default=None)
    """
    Specifies an alternate country code if the data provider code is not part of an
    official Country Code standard such as ISO-3166 or FIPS. This field will be set
    to the value provided by the source and should be used for all Queries
    specifying a Country Code.
    """

    alt_operating_unit_id: Optional[str] = FieldInfo(alias="altOperatingUnitId", default=None)
    """Unique identifier of the operating unit record from the originating system."""

    class_rating: Optional[str] = FieldInfo(alias="classRating", default=None)
    """Indicates the importance of the operating unit to the OES or MIR system.

    This data element is restricted to update by DIA (DB-4). Valid values are: 0 -
    Does not meet criteria above 1 - Primary importance to system 2 - Secondary
    importance to system 3 - Tertiary importance to system O - Other. Explain in
    Remarks.
    """

    condition: Optional[str] = None
    """The physical manner of being or state of existence of the operating unit.

    A physical condition that must be considered in the determining of a course of
    action. The specific usage and enumerations contained in this field may be found
    in the documentation provided in the referenceDoc field. If referenceDoc not
    provided, users may consult the data provider.
    """

    condition_avail: Optional[str] = FieldInfo(alias="conditionAvail", default=None)
    """Availability of the operating unit relative to its condition.

    Indicates the reason the operating unit is not fully operational. The specific
    usage and enumerations contained in this field may be found in the documentation
    provided in the referenceDoc field. If referenceDoc not provided, users may
    consult the data provider.
    """

    coord: Optional[str] = None
    """
    Indicates any of the magnitudes that serve to define the position of a point by
    reference to a fixed figure, system of lines, etc.

    Pos. 1-2. Latitude Degrees [00-90]

    Pos. 3-4. Latitude Minutes [00-59]

    Pos. 5-6. Latitude Seconds [00-59]

    Pos. 7-9. Latitude Thousandths Of Seconds [000-999]

    Pos. 10. Latitude Hemisphere [NS]

    Pos. 11-13. Longitude Degrees [00-180]

    Pos. 14-15. Longitude Minutes [00-59]

    Pos. 16-17. Longitude Seconds [00-59]

    Pos. 18-20. Longitude Thousandths Of Seconds [000-999]

    Pos. 21. Longitude Hemisphere [EW]

    Pos. 1-21. Unknown Latitude and Unknown Longitude [000000000U000000000U]
    """

    coord_datum: Optional[str] = FieldInfo(alias="coordDatum", default=None)
    """A mathematical model of the earth used to calculate coordinates on a map.

    US Forces use the World Geodetic System 1984 (WGS 84), but also use maps by
    allied countries with local datums. The datum must be specified to ensure
    accuracy of coordinates. The specific usage and enumerations contained in this
    field may be found in the documentation provided in the referenceDoc field. If
    referenceDoc not provided, users may consult the data provider.
    """

    coord_deriv_acc: Optional[float] = FieldInfo(alias="coordDerivAcc", default=None)
    """
    Indicates the plus or minus error assessed against the method used to derive the
    coordinate.
    """

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """
    The DoD Standard country code designator for the country or political entity to
    which the operating unit geographic coordinates reside . This field will be set
    to "OTHR" if the source value does not match a UDL country code value
    (ISO-3166-ALPHA-2).
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    deploy_status: Optional[str] = FieldInfo(alias="deployStatus", default=None)
    """A code describing the amount of operating unit participation in a deployment.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    description: Optional[str] = None
    """Description of the operating unit."""

    div_cat: Optional[str] = FieldInfo(alias="divCat", default=None)
    """Combat status of a divisional or equivalent operating unit.

    Currently, this data element applies only to operating units of the Former
    Soviet Union. The specific usage and enumerations contained in this field may be
    found in the documentation provided in the referenceDoc field. If referenceDoc
    not provided, users may consult the data provider.
    """

    echelon: Optional[str] = None
    """Organizational level of the operating unit.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    echelon_tier: Optional[str] = FieldInfo(alias="echelonTier", default=None)
    """Indicates the major group or level to which an echelon belongs.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    elev_msl: Optional[float] = FieldInfo(alias="elevMsl", default=None)
    """
    Ground elevation of the geographic coordinates referenced to (above or below)
    Mean Sea Level (MSL) vertical datum.
    """

    elev_msl_conf_lvl: Optional[int] = FieldInfo(alias="elevMslConfLvl", default=None)
    """
    Indicates the confidence level expressed as a percent that a specific geometric
    spatial element, ELEVATION_MSL linear accuracy, has been vertically positioned
    to within a specified vertical accuracy.
    """

    elev_msl_deriv_acc: Optional[float] = FieldInfo(alias="elevMslDerivAcc", default=None)
    """
    Indicates the plus or minus error assessed against the method used to derive the
    elevation.
    """

    eval: Optional[int] = None
    """
    The Intelligence Confidence Level or the Reliability/degree of confidence that
    the analyst has assigned to the data within this record. The numerical range is
    from 1 to 9 with 1 representing the highest confidence level.
    """

    flag_flown: Optional[str] = FieldInfo(alias="flagFlown", default=None)
    """The country code of the observed flag flown."""

    fleet_id: Optional[str] = FieldInfo(alias="fleetId", default=None)
    """Naval fleet to which an operating unit is assigned.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    force: Optional[str] = None
    """
    An aggregation of military units within a single service (i.e., ARMY, AIR FORCE,
    etc.) which operates under a single authority to accomplish a common mission.
    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    force_name: Optional[str] = FieldInfo(alias="forceName", default=None)
    """The specific name for a given force.

    For example, Force = ADF (Air Defense Force) and Force Name = Army Air Defense
    Force.
    """

    fpa: Optional[str] = None
    """Functional Production Area (FPA) under the Shared Production Program (SPP).

    Producers are defined per country per FPA. The specific usage and enumerations
    contained in this field may be found in the documentation provided in the
    referenceDoc field. If referenceDoc not provided, users may consult the data
    provider.
    """

    funct_role: Optional[str] = FieldInfo(alias="functRole", default=None)
    """
    Principal combat-related role that an operating unit is organized, structured
    and equipped to perform. Or, the specialized military or paramilitary branch in
    which an individual serves, their specialization. The specific usage and
    enumerations contained in this field may be found in the documentation provided
    in the referenceDoc field. If referenceDoc not provided, users may consult the
    data provider.
    """

    geoidal_msl_sep: Optional[float] = FieldInfo(alias="geoidalMslSep", default=None)
    """The distance between Mean Sea Level and a referenced ellipsoid."""

    id_contact: Optional[str] = FieldInfo(alias="idContact", default=None)
    """Unique identifier of the contact for this operating unit."""

    ident: Optional[str] = None
    """
    Estimated identity of the Site (ASSUMED FRIEND, FRIEND, HOSTILE, FAKER, JOKER,
    NEUTRAL, PENDING, SUSPECT, UNKNOWN):

    ASSUMED FRIEND: Track assumed to be a friend due to the object characteristics,
    behavior, and/or origin.

    FRIEND: Track object supporting friendly forces and belonging to a declared
    friendly nation or entity.

    HOSTILE: Track object belonging to an opposing nation, party, group, or entity
    deemed to contribute to a threat to friendly forces or their mission due to its
    behavior, characteristics, nationality, or origin.

    FAKER: Friendly track, object, or entity acting as an exercise hostile.

    JOKER: Friendly track, object, or entity acting as an exercise suspect.

    NEUTRAL: Track object whose characteristics, behavior, nationality, and/or
    origin indicate that it is neither supporting nor opposing friendly forces or
    their mission.

    PENDING: Track object which has not been evaluated.

    SUSPECT: Track object deemed potentially hostile due to the object
    characteristics, behavior, nationality, and/or origin.

    UNKNOWN: Track object which has been evaluated and does not meet criteria for
    any standard identity.
    """

    id_location: Optional[str] = FieldInfo(alias="idLocation", default=None)
    """Unique identifier of the location record for this operating unit."""

    id_operating_unit: Optional[str] = FieldInfo(alias="idOperatingUnit", default=None)
    """Unique identifier of the record, auto-generated by the system."""

    id_organization: Optional[str] = FieldInfo(alias="idOrganization", default=None)
    """Unique identifier of the organization record for this operating unit."""

    lat: Optional[float] = None
    """WGS84 latitude of the location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    location: Optional[LocationFull] = None
    """
    Model representation of a location, which is a specific fixed point on the earth
    and is used to denote the locations of fixed sensors, operating units, etc.
    """

    loc_name: Optional[str] = FieldInfo(alias="locName", default=None)
    """Location name for the coordinates."""

    loc_reason: Optional[str] = FieldInfo(alias="locReason", default=None)
    """Indicates the reason that the operating unit is at that location.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    lon: Optional[float] = None
    """WGS84 longitude of the location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    master_unit: Optional[bool] = FieldInfo(alias="masterUnit", default=None)
    """
    This field contains a value indicating whether the record is a master unit
    record (True) or a detail record (False). Master records contain basic
    information that does not change over time for each unit that has been selected
    to be projected.
    """

    mil_grid: Optional[str] = FieldInfo(alias="milGrid", default=None)
    """
    The Military Grid Reference System is the geocoordinate standard used by NATO
    militaries for locating points on Earth. The MGRS is derived from the Universal
    Transverse Mercator (UTM) grid system and the Universal Polar Stereographic
    (UPS) grid system, but uses a different labeling convention. The MGRS is used as
    geocode for the entire Earth. Example of an milgrid coordinate, or grid
    reference, would be 4QFJ12345678, which consists of three parts: 4Q (grid zone
    designator, GZD) FJ (the 100,000-meter square identifier) 12345678 (numerical
    location; easting is 1234 and northing is 5678, in this case specifying a
    location with 10 m resolution).
    """

    mil_grid_sys: Optional[str] = FieldInfo(alias="milGridSys", default=None)
    """Indicates the grid system used in the development of the milGrid coordinates.

    Values are:

    UPS - Universal Polar System

    UTM - Universal Transverse Mercator
    """

    msn_primary: Optional[str] = FieldInfo(alias="msnPrimary", default=None)
    """
    Indicates the principal type of mission that an operating unit is organized and
    equipped to perform. The specific usage and enumerations contained in this field
    may be found in the documentation provided in the referenceDoc field. If
    referenceDoc not provided, users may consult the data provider.
    """

    msn_primary_specialty: Optional[str] = FieldInfo(alias="msnPrimarySpecialty", default=None)
    """
    Indicates the principal specialty type of mission that an operating unit is
    organized and equipped to perform. The specific usage and enumerations contained
    in this field may be found in the documentation provided in the referenceDoc
    field. If referenceDoc not provided, users may consult the data provider.
    """

    operating_unit_remarks: Optional[List[SensorTupleResponseItemEntityOperatingUnitOperatingUnitRemark]] = FieldInfo(
        alias="operatingUnitRemarks", default=None
    )
    """Remarks contain amplifying information for a specific service.

    The information may contain context and interpretations for consumer use.
    """

    oper_status: Optional[str] = FieldInfo(alias="operStatus", default=None)
    """
    The Degree to which an operating unit is ready to perform the overall
    operational mission(s) for which it was organized and equipped. The specific
    usage and enumerations contained in this field may be found in the documentation
    provided in the referenceDoc field. If referenceDoc not provided, users may
    consult the data provider.
    """

    organization: Optional[OrganizationFull] = None
    """An organization such as a corporation, manufacturer, consortium, government,
    etc.

    An organization may have parent and child organizations as well as link to a
    former organization if this org previously existed as another organization.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    pol_subdiv: Optional[str] = FieldInfo(alias="polSubdiv", default=None)
    """Political subdivision in which the geographic coordinates reside.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    rec_status: Optional[str] = FieldInfo(alias="recStatus", default=None)
    """
    Validity and currency of the data in the record to be used in conjunction with
    the other elements in the record as defined by SOPs. Values are: A - Active I -
    Inactive K - Acknowledged L - Local Q - A nominated (NOM) or Data Change Request
    (DCR) record R - Production reduced by CMD decision W - Working Record.
    """

    reference_doc: Optional[str] = FieldInfo(alias="referenceDoc", default=None)
    """
    The reference documentiation that specifies the usage and enumerations contained
    in this record. If referenceDoc not provided, users may consult the data
    provider.
    """

    res_prod: Optional[str] = FieldInfo(alias="resProd", default=None)
    """
    Responsible Producer - Organization that is responsible for the maintenance of
    the record.
    """

    review_date: Optional[date] = FieldInfo(alias="reviewDate", default=None)
    """
    Date on which the data in the record was last reviewed by the responsible
    analyst for accuracy and currency. This date cannot be greater than the current
    date.
    """

    stylized_unit: Optional[bool] = FieldInfo(alias="stylizedUnit", default=None)
    """
    This field contains a value indicating whether the record is a stylized
    operating unit record (True) or a regular operating unit record (False). A
    stylized operating unit is a type of operating unit with one set of equipment
    that can be assigned to one or more superiors. A stylized operating unit is
    generally useful for lower echelon operating units where the number of operating
    units and types of equipment are equal for multiple organizations. In lieu of
    creating unique operating unit records for each operating unit, a template is
    created for the operating unit and its equipment. This template enables the user
    to assign the operating unit to multiple organizations.
    """

    sym_code: Optional[str] = FieldInfo(alias="symCode", default=None)
    """
    A standard scheme for symbol coding enabling the transfer, display and use of
    symbols and graphics among information systems, as per MIL-STD 2525B, and
    supported by the element AFFILIATION.
    """

    unit_identifier: Optional[str] = FieldInfo(alias="unitIdentifier", default=None)
    """
    An optional identifier for this operating unit that may be composed from items
    such as the originating organization, allegiance, one-up number, etc.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    utm: Optional[str] = None
    """Universal Transverse Mercator (UTM) grid coordinates. Pos.

    1-2, UTM Zone Column [01-60 Pos. 3, UTM Zone Row [C-HJ-NP-X] Pos. 4, UTM False
    Easting [0-9] Pos. 5-9, UTM Meter Easting [0-9][0-9][0-9][0-9][0-9] Pos. 10-11,
    UTM False Northing [0-9][0-9] Pos. 12-16, UTM Meter Northing
    [0-9][0-9][0-9][0-9][0-9].
    """

    wac: Optional[str] = None
    """
    World Aeronautical Chart identifier for the area in which a designated operating
    unit is located.
    """


class SensorTupleResponseItemEntityRfBand(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_entity: str = FieldInfo(alias="idEntity")
    """Unique identifier of the parent Entity which uses this band."""

    name: str
    """RF Band name."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    band: Optional[str] = None
    """Name of the band of this RF range (e.g.

    X,K,Ku,Ka,L,S,C,UHF,VHF,EHF,SHF,UNK,VLF,HF,E,Q,V,W). See RFBandType for more
    details and descriptions of each band name.
    """

    bandwidth: Optional[float] = None
    """RF Band frequency range bandwidth in Mhz."""

    beamwidth: Optional[float] = None
    """
    Angle between the half-power (-3 dB) points of the main lobe of the antenna, in
    degrees.
    """

    center_freq: Optional[float] = FieldInfo(alias="centerFreq", default=None)
    """Center frequency of RF frequency range, if applicable, in Mhz."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    edge_gain: Optional[float] = FieldInfo(alias="edgeGain", default=None)
    """RF Range edge gain, in dBi."""

    eirp: Optional[float] = None
    """
    EIRP is defined as the RMS power input in decibel watts required to a lossless
    half-wave dipole antenna to give the same maximum power density far from the
    antenna as the actual transmitter. It is equal to the power input to the
    transmitter's antenna multiplied by the antenna gain relative to a half-wave
    dipole. Effective radiated power and effective isotropic radiated power both
    measure the amount of power a radio transmitter and antenna (or other source of
    electromagnetic waves) radiates in a specific direction: in the direction of
    maximum signal strength (the "main lobe") of its radiation pattern.
    """

    erp: Optional[float] = None
    """
    Effective Radiated Power (ERP) is the total power in decibel watts radiated by
    an actual antenna relative to a half-wave dipole rather than a theoretical
    isotropic antenna. A half-wave dipole has a gain of 2.15 dB compared to an
    isotropic antenna. EIRP(dB) = ERP (dB)+2.15 dB or EIRP (W) = 1.64\\**ERP(W).
    Effective radiated power and effective isotropic radiated power both measure the
    amount of power a radio transmitter and antenna (or other source of
    electromagnetic waves) radiates in a specific direction: in the direction of
    maximum signal strength (the "main lobe") of its radiation pattern.
    """

    freq_max: Optional[float] = FieldInfo(alias="freqMax", default=None)
    """End/maximum of transmit RF frequency range, if applicable, in Mhz."""

    freq_min: Optional[float] = FieldInfo(alias="freqMin", default=None)
    """Start/minimum of transmit RF frequency range, if applicable, in Mhz."""

    mode: Optional[Literal["TX", "RX"]] = None
    """RF Band mode (e.g. TX, RX)."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    peak_gain: Optional[float] = FieldInfo(alias="peakGain", default=None)
    """RF Range maximum gain, in dBi."""

    polarization: Optional[Literal["H", "V", "R", "L"]] = None
    """Transponder polarization e.g.

    H - (Horizontally Polarized) Perpendicular to Earth's surface, V - (Vertically
    Polarized) Parallel to Earth's surface, L - (Left Hand Circularly Polarized)
    Rotating left relative to the Earth's surface, R - (Right Hand Circularly
    Polarized) Rotating right relative to the Earth's surface.
    """

    purpose: Optional[Literal["COMM", "TTC", "OPS", "OTHER"]] = None
    """
    Purpose or use of the RF Band -- COMM = communications, TTC =
    Telemetry/Tracking/Control, OPS = Operations, OTHER = Other).
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityStatusCollectionSubStatusCollection(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    notes: str
    """Descriptions and/or comments associated with the sub-status."""

    source: str
    """Source of the data."""

    status: Literal["FMC", "NMC", "PMC", "UNK"]
    """Status of the sub-system/capability, e.g. FMC, NMC, PMC, UNK."""

    status_id: str = FieldInfo(alias="statusId")
    """Id of the parent status."""

    type: Literal["mwCap", "ssCap", "mdCap"]
    """Parent entity's sub-system or capability status: mwCap, mdCap, ssCap, etc."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntityStatusCollection(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_entity: str = FieldInfo(alias="idEntity")
    """Unique identifier of the parent entity."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    declassification_date: Optional[datetime] = FieldInfo(alias="declassificationDate", default=None)
    """The declassification date of this data, in ISO 8601 UTC format."""

    declassification_string: Optional[str] = FieldInfo(alias="declassificationString", default=None)
    """Declassification string of this data."""

    derived_from: Optional[str] = FieldInfo(alias="derivedFrom", default=None)
    """
    The sources or SCG references from which the classification of this data is
    derived.
    """

    notes: Optional[str] = None
    """Comments describing the status creation and or updates to an entity."""

    ops_cap: Optional[Literal["FMC", "NMC", "PMC", "UNK"]] = FieldInfo(alias="opsCap", default=None)
    """Operation capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK)."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    state: Optional[Literal["UNKNOWN", "DEAD", "ACTIVE", "RF ACTIVE", "STANDBY"]] = None
    """Overall state of the entity, if applicable (e.g.

    UNKNOWN, DEAD, ACTIVE, RF ACTIVE, STANDBY).
    """

    sub_status_collection: Optional[List[SensorTupleResponseItemEntityStatusCollectionSubStatusCollection]] = FieldInfo(
        alias="subStatusCollection", default=None
    )

    sys_cap: Optional[Literal["FMC", "NMC", "PMC", "UNK"]] = FieldInfo(alias="sysCap", default=None)
    """System capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK)."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemEntity(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Unique entity name."""

    source: str
    """Source of the data."""

    type: Literal[
        "AIRCRAFT", "BUS", "COMM", "IR", "NAVIGATION", "ONORBIT", "RFEMITTER", "SCIENTIFIC", "SENSOR", "SITE", "VESSEL"
    ]
    """
    The type of entity represented by this record (AIRCRAFT, BUS, COMM, IR,
    NAVIGATION, ONORBIT, RFEMITTER, SCIENTIFIC, SENSOR, SITE, VESSEL).
    """

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country code.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_entity: Optional[str] = FieldInfo(alias="idEntity", default=None)
    """Unique identifier of the record."""

    id_location: Optional[str] = FieldInfo(alias="idLocation", default=None)
    """Unique identifier of the entity location, if terrestrial/fixed."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Onorbit identifier if this entity is part of an on-orbit object.

    For the public catalog, the idOnOrbit is typically the satellite number as a
    string, but may be a UUID for analyst or other unknown or untracked satellites.
    """

    id_operating_unit: Optional[str] = FieldInfo(alias="idOperatingUnit", default=None)
    """Unique identifier of the associated operating unit object."""

    location: Optional[LocationFull] = None
    """
    Model representation of a location, which is a specific fixed point on the earth
    and is used to denote the locations of fixed sensors, operating units, etc.
    """

    on_orbit: Optional[SensorTupleResponseItemEntityOnOrbit] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    operating_unit: Optional[SensorTupleResponseItemEntityOperatingUnit] = FieldInfo(
        alias="operatingUnit", default=None
    )
    """
    Model representation of a unit or organization which operates or controls a
    space-related Entity such as an on-orbit payload, a sensor, etc. A contact may
    belong to an organization.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    owner_type: Optional[Literal["Commercial", "Government", "Academic", "Consortium", "Other"]] = FieldInfo(
        alias="ownerType", default=None
    )
    """Type of organization which owns this entity (e.g.

    Commercial, Government, Academic, Consortium, etc).
    """

    rf_bands: Optional[List[SensorTupleResponseItemEntityRfBand]] = FieldInfo(alias="rfBands", default=None)
    """
    Read-only collection of RF bands utilized by this entity for communication
    and/or operation.
    """

    status_collection: Optional[List[SensorTupleResponseItemEntityStatusCollection]] = FieldInfo(
        alias="statusCollection", default=None
    )
    """Read-only collection of statuses which can be collected by multiple sources."""

    taskable: Optional[bool] = None
    """Boolean indicating if this entity is taskable."""

    terrestrial_id: Optional[str] = FieldInfo(alias="terrestrialId", default=None)
    """Terrestrial identifier of this entity, if applicable."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    urls: Optional[List[str]] = None
    """List of URLs to additional details/documents for this entity."""


class SensorTupleResponseItemSensorcharacteristic(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_sensor: str = FieldInfo(alias="idSensor")
    """Unique identifier of the parent sensor."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    accept_sample_ranges: Optional[List[float]] = FieldInfo(alias="acceptSampleRanges", default=None)
    """Array of measurement range(s) where radar samples must fall to be acceptable.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    aperture: Optional[float] = None
    """Optical sensor camera aperture."""

    asr_scan_rate: Optional[float] = FieldInfo(alias="asrScanRate", default=None)
    """
    For ASR (Air Surveillance Radar) sensors, the scan (360 deg sweep) rate of the
    radar, in scans/minute.
    """

    az_angs: Optional[List[float]] = FieldInfo(alias="azAngs", default=None)
    """Array of azimuth angles of a radar beam, in degrees.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    azimuth_rate: Optional[float] = FieldInfo(alias="azimuthRate", default=None)
    """Azimuth rate acquisition limit (radians/minute)."""

    band: Optional[str] = None
    """Sensor band."""

    beam_order: Optional[List[str]] = FieldInfo(alias="beamOrder", default=None)
    """Array designating the beam order of provided values (e.g.

    vb1 for vertical beam 1, ob1 for oblique beam 1, etc.). Required if any of the
    following array fields are populated: azAngs, elAngs, radarPulseWidths,
    pulseRepPeriods, delayGates, rangeGates, rangeSpacings, vertGateSpacings,
    vertGateWidths, specAvgSpectraNums, tempMedFiltCodes, runMeanCodes, totRecNums,
    reqRecords, acceptSampleRanges.
    """

    beam_qty: Optional[int] = FieldInfo(alias="beamQty", default=None)
    """Number of radar beams used by the sensor."""

    boresight: Optional[float] = None
    """The angle of the center of a phased array sensor."""

    boresight_off_angle: Optional[float] = FieldInfo(alias="boresightOffAngle", default=None)
    """The number of degrees off of the boresight for the sensor."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    crit_shear: Optional[float] = FieldInfo(alias="critShear", default=None)
    """
    Threshold shear value beyond which one of the radial velocity values will be
    rejected, measured in units of inverse second.
    """

    delay_gates: Optional[List[float]] = FieldInfo(alias="delayGates", default=None)
    """
    Array of time delay(s) for pulses from a radar beam to get to the first range
    gate, in nanoseconds. If this field is populated, the associated beam(s) must be
    provided in the beamOrder field.
    """

    description: Optional[str] = None
    """Description of the equipment and data source."""

    el_angs: Optional[List[float]] = FieldInfo(alias="elAngs", default=None)
    """Array of elevation angles of a radar beam, in degrees.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    elevation_rate_geolm: Optional[float] = FieldInfo(alias="elevationRateGeolm", default=None)
    """Elevation rate acquisition limit (radians/minute)."""

    equipment_type: Optional[str] = FieldInfo(alias="equipmentType", default=None)
    """Type of equipment used to take measurements."""

    fan_beam_width: Optional[float] = FieldInfo(alias="fanBeamWidth", default=None)
    """The beam width of a Sensor's Fan (range).

    The values for this range from (0.0 to PI).
    """

    fft: Optional[int] = None
    """
    Number of Fast Fourier Transform (FFT) points used to convert time varying
    signals into the frequency domain.
    """

    fgp_crit: Optional[int] = FieldInfo(alias="fgpCrit", default=None)
    """
    Maximum number of times the first guess was propagated in each gate before
    failing the first guess check.
    """

    focal_point: Optional[float] = FieldInfo(alias="focalPoint", default=None)
    """
    For radar based sensors, the focal point elevation of the radar at the site, in
    meters.
    """

    h_fov: Optional[float] = FieldInfo(alias="hFOV", default=None)
    """Horizontal field of view."""

    h_res_pixels: Optional[int] = FieldInfo(alias="hResPixels", default=None)
    """Horizontal pixel resolution."""

    k: Optional[float] = None
    """
    For radar based sensors, K-factor is a relative indicator of refractivity that
    infers the amount of radar beam bending due to atmosphere. (1<K<2).
    """

    left_clock_angle: Optional[float] = FieldInfo(alias="leftClockAngle", default=None)
    """For Orbiting Sensors, First Card Azimuth limit #1 (left, degrees)."""

    left_geo_belt_limit: Optional[float] = FieldInfo(alias="leftGeoBeltLimit", default=None)
    """Leftmost GEO belt longitude limit for this sensor (if applicable)."""

    location: Optional[str] = None
    """Site where measurement is taken."""

    mag_dec: Optional[float] = FieldInfo(alias="magDec", default=None)
    """Angle between magnetic north and true north at the sensor site, in degrees."""

    magnitude_limit: Optional[float] = FieldInfo(alias="magnitudeLimit", default=None)
    """Absolute magnitude acquisition limit for optical sensors."""

    max_deviation_angle: Optional[float] = FieldInfo(alias="maxDeviationAngle", default=None)
    """Max deviation angle of the sensor in degrees."""

    max_observable_range: Optional[float] = FieldInfo(alias="maxObservableRange", default=None)
    """Maximum observable sensor range, in kilometers."""

    max_range_limit: Optional[float] = FieldInfo(alias="maxRangeLimit", default=None)
    """
    Maximum observable range limit in kilometers -- sensor cannot acquire beyond
    this range.
    """

    min_range_limit: Optional[float] = FieldInfo(alias="minRangeLimit", default=None)
    """Minimum range measurement capability of the sensor, in kilometers."""

    min_signal_noise_ratio: Optional[float] = FieldInfo(alias="minSignalNoiseRatio", default=None)
    """Signal to Noise Ratio, in decibels.

    The values for this range from 0.0 - + 99.99 dB.
    """

    negative_range_rate_limit: Optional[float] = FieldInfo(alias="negativeRangeRateLimit", default=None)
    """Negative Range-rate/relative velocity limit (kilometers/second)."""

    num_integrated_pulses: Optional[int] = FieldInfo(alias="numIntegratedPulses", default=None)
    """For radar based sensors, number of integrated pulses in a transmit cycle."""

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    positive_range_rate_limit: Optional[float] = FieldInfo(alias="positiveRangeRateLimit", default=None)
    """Positive Range-rate/relative velocity limit (kilometers/second)."""

    prf: Optional[float] = None
    """For radar based sensors, pulse repetition frequency (PRF), in hertz.

    Number of new pulses transmitted per second.
    """

    prob_false_alarm: Optional[float] = FieldInfo(alias="probFalseAlarm", default=None)
    """
    For radar based sensors, probability of the indication of the presence of a
    radar target due to noise or interference.
    """

    pulse_rep_periods: Optional[List[float]] = FieldInfo(alias="pulseRepPeriods", default=None)
    """
    Array of interval(s) between the start of one radar pulse and the start of
    another for a radar beam, in microseconds. If this field is populated, the
    associated beam(s) must be provided in the beamOrder field.
    """

    radar_frequency: Optional[float] = FieldInfo(alias="radarFrequency", default=None)
    """Radar frequency of the sensor (if a radar sensor)."""

    radar_message_format: Optional[str] = FieldInfo(alias="radarMessageFormat", default=None)
    """Message data format transmitted by the sensor digitizer."""

    radar_mur: Optional[float] = FieldInfo(alias="radarMUR", default=None)
    """For radar based sensors, radar maximum unambiguous range, in kilometers."""

    radar_pulse_widths: Optional[List[float]] = FieldInfo(alias="radarPulseWidths", default=None)
    """Array of transmit time(s) for a radar beam pulse, in microseconds.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    radio_frequency: Optional[float] = FieldInfo(alias="radioFrequency", default=None)
    """Radio frequency (if sensor is RF)."""

    range_gates: Optional[List[int]] = FieldInfo(alias="rangeGates", default=None)
    """
    Array of the number(s) of discrete altitudes where return signals are sampled by
    a radar beam. If this field is populated, the associated beam(s) must be
    provided in the beamOrder field.
    """

    range_spacings: Optional[List[float]] = FieldInfo(alias="rangeSpacings", default=None)
    """Array of range gate spacing(s) for a radar beam, in nanoseconds.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    req_records: Optional[List[int]] = FieldInfo(alias="reqRecords", default=None)
    """
    Array of the total number(s) of records required to meet consensus for a radar
    beam. If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    right_clock_angle: Optional[float] = FieldInfo(alias="rightClockAngle", default=None)
    """For Orbiting Sensors, First Card Azimuth limit #3 (right, degrees)."""

    right_geo_belt_limit: Optional[float] = FieldInfo(alias="rightGeoBeltLimit", default=None)
    """Rightmost GEO belt longitude limit for this sensor (if applicable)."""

    run_mean_codes: Optional[List[int]] = FieldInfo(alias="runMeanCodes", default=None)
    """Array of running mean code(s) used by radar data processing.

    The running mean method involves taking a series of averages of different
    selections of the full data set to smooth out short-term fluctuations in the
    data. If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    site_code: Optional[str] = FieldInfo(alias="siteCode", default=None)
    """Site code of the sensor."""

    spec_avg_spectra_nums: Optional[List[int]] = FieldInfo(alias="specAvgSpectraNums", default=None)
    """
    Array of the number(s) of Doppler spectra used to process measurements from
    radar. Spectral averaging involves combining multiple Doppler spectra acquired
    to obtain a more accurate and representative spectrum. If this field is
    populated, the associated beam(s) must be provided in the beamOrder field.
    """

    system_noise_temperature: Optional[float] = FieldInfo(alias="systemNoiseTemperature", default=None)
    """
    For radar based sensors, expression of the radar system noise, aggregated as an
    equivalent thermal noise value, in degrees Kelvin.
    """

    taskable_range: Optional[float] = FieldInfo(alias="taskableRange", default=None)
    """Maximum taskable range of the sensor, in kilometers."""

    temp_med_filt_codes: Optional[List[int]] = FieldInfo(alias="tempMedFiltCodes", default=None)
    """Array of temporal median filter code(s) of a radar beam.

    Temporal median filtering is a noise-reducing algorithm which involves replacing
    each data point with the median value of a window of neighboring points over
    time. If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    test_number: Optional[str] = FieldInfo(alias="testNumber", default=None)
    """Test number for the observed measurement."""

    tot_rec_nums: Optional[List[int]] = FieldInfo(alias="totRecNums", default=None)
    """Array of the total number(s) of records for a radar beam.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    tower_height: Optional[float] = FieldInfo(alias="towerHeight", default=None)
    """For tower sensors, the physical height of the sensor tower, in meters."""

    track_angle: Optional[float] = FieldInfo(alias="trackAngle", default=None)
    """Beginning track angle limit, in radians.

    Track angle is the angle between the camera axis and the gimbal plane. Values
    range from 0 - PI/2.
    """

    transmit_power: Optional[float] = FieldInfo(alias="transmitPower", default=None)
    """Radar transmit power in Watts."""

    true_north_corrector: Optional[int] = FieldInfo(alias="trueNorthCorrector", default=None)
    """True North correction for the sensor, in ACP (Azimunth Change Pulse) count."""

    true_tilt: Optional[float] = FieldInfo(alias="trueTilt", default=None)
    """Antenna true tilt, in degrees."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    vert_beam_flag: Optional[bool] = FieldInfo(alias="vertBeamFlag", default=None)
    """Flag indicating if a vertical radar beam was used in the wind calculation."""

    vert_gate_spacings: Optional[List[float]] = FieldInfo(alias="vertGateSpacings", default=None)
    """
    Array of vertical distance(s) between points where radar measurements are taken,
    in meters. If this field is populated, the associated beam(s) must be provided
    in the beamOrder field.
    """

    vert_gate_widths: Optional[List[float]] = FieldInfo(alias="vertGateWidths", default=None)
    """Array of width(s) of each location where radar measurements are taken, in
    meters.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    v_fov: Optional[float] = FieldInfo(alias="vFOV", default=None)
    """Vertical field of view."""

    v_res_pixels: Optional[int] = FieldInfo(alias="vResPixels", default=None)
    """Vertical pixel resolution."""

    z1_max_range: Optional[float] = FieldInfo(alias="z1MaxRange", default=None)
    """Peformance zone-1 maximum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """

    z1_min_range: Optional[float] = FieldInfo(alias="z1MinRange", default=None)
    """Peformance zone-1 minimum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """

    z2_max_range: Optional[float] = FieldInfo(alias="z2MaxRange", default=None)
    """Peformance zone-2 maximum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """

    z2_min_range: Optional[float] = FieldInfo(alias="z2MinRange", default=None)
    """Peformance zone-2 minimum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """


class SensorTupleResponseItemSensorlimitsCollection(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the target sensor object."""

    id_sensor_limits: Optional[str] = FieldInfo(alias="idSensorLimits", default=None)
    """Unique identifier of the record, auto-generated by the system."""

    lower_left_azimuth_limit: Optional[float] = FieldInfo(alias="lowerLeftAzimuthLimit", default=None)
    """Leftmost or minimum lower azimuth within this limit.

    Interpreted according to site types as lower left azimuth limit elevation angle
    of axis of conical observation pattern. If the limit rectangle is parallel to
    the horizon, the upper and lower left azimuth limits would be equal. (degrees).
    """

    lower_left_elevation_limit: Optional[float] = FieldInfo(alias="lowerLeftElevationLimit", default=None)
    """Minimum or lower elevation within this limit.

    Interpreted according to site types as minimum elevation angle, constant
    elevation or fan beam centerline. (Degrees).
    """

    lower_right_azimuth_limit: Optional[float] = FieldInfo(alias="lowerRightAzimuthLimit", default=None)
    """Rightmost or maximum lower azimuth within this limit.

    Interpreted according to site types as 2nd lower azimuth limit elevation angle
    of axis of conical observation pattern. If the limit rectangle is parallel to
    the horizon, the upper and lower right azimuth limits would be equal. (degrees).
    """

    lower_right_elevation_limit: Optional[float] = FieldInfo(alias="lowerRightElevationLimit", default=None)
    """Minimum or lower right elevation within this limit.

    Interpreted according to site types as minimum right elevation angle, constant
    elevation or fan beam centerline. If the limit rectangle is parallel to the
    horizon, the left and right lower elevation limits would be equal. (Degrees).
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    upper_left_azimuth_limit: Optional[float] = FieldInfo(alias="upperLeftAzimuthLimit", default=None)
    """Leftmost or minimum upper azimuth within this sensor limit.

    Interpreted according to site types as beginning upper azimuth limit, left-hand
    upper boundary limit. If the limit rectangle is parallel to the horizon, the
    upper and lower left azimuth limits would be equal. (in degrees).
    """

    upper_left_elevation_limit: Optional[float] = FieldInfo(alias="upperLeftElevationLimit", default=None)
    """Maximum or upper elevation within this limit.

    Interpreted according to site types as maximum elevation angle, half the apex of
    conical observation pattern or star. (Degrees).
    """

    upper_right_azimuth_limit: Optional[float] = FieldInfo(alias="upperRightAzimuthLimit", default=None)
    """Rightmost or maximum upper azimuth within this limit.

    Interpreted according to site types as 2nd azimuth limit elevation angle of axis
    of conical observation pattern. If the limit rectangle is parallel to the
    horizon, the upper and lower right azimuth limits would be equal. (degrees).
    """

    upper_right_elevation_limit: Optional[float] = FieldInfo(alias="upperRightElevationLimit", default=None)
    """Maximum or upper right elevation within this limit.

    Interpreted according to site types as maximum rightmost elevation angle, half
    the apex of conical observation pattern or star. If the limit rectangle is
    parallel to the horizon, the left and right upper elevation limits would be
    equal. (Degrees).
    """


class SensorTupleResponseItemSensorObservationType(BaseModel):
    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    type: Optional[str] = None
    """The observation measurement type produced by a sensor."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItemSensorStat(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_sensor: str = FieldInfo(alias="idSensor")
    """Unique ID of the parent sensor."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    last_ob_time: Optional[datetime] = FieldInfo(alias="lastObTime", default=None)
    """Time of last reported observation in ISO 8601 UTC with microsecond precision."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """
    Read-only time the row was updated in the database, set automatically by the
    system on update.
    """

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who last updated the row in the database, set by the system
    automatically and ignored on create/edit operations.
    """


class SensorTupleResponseItemSensorType(BaseModel):
    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    id: Optional[int] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    type: Optional[str] = None
    """The specific sensor type and/or surveillance capability of this sensor."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


class SensorTupleResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    sensor_name: str = FieldInfo(alias="sensorName")
    """Unique name of this sensor."""

    source: str
    """Source of the data."""

    active: Optional[bool] = None
    """Optional flag indicating if the sensor is active."""

    af_id: Optional[str] = FieldInfo(alias="afId", default=None)
    """
    Optional US Air Force identifier for the sensor/ASR site, typically for air
    surveillance radar (ASR) sensors.
    """

    asr_type: Optional[str] = FieldInfo(alias="asrType", default=None)
    """The sensor type at the site. Optional field, intended primarily for ASRs."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    data_control: Optional[str] = FieldInfo(alias="dataControl", default=None)
    """
    Optional dissemination control required for accessing data (e.g observations)
    produced by this sensor. This is typically a proprietary data owner control for
    commercial sensors.
    """

    entity: Optional[SensorTupleResponseItemEntity] = None
    """
    An entity is a generic representation of any object within a space/SSA system
    such as sensors, on-orbit objects, RF Emitters, space craft buses, etc. An
    entity can have an operating unit, a location (if terrestrial), and statuses.
    """

    id_entity: Optional[str] = FieldInfo(alias="idEntity", default=None)
    """Unique identifier of the parent entity. idEntity is required for Put."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the record, auto-generated by the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    sensorcharacteristics: Optional[List[SensorTupleResponseItemSensorcharacteristic]] = None
    """
    Collection of Sensorcharacteristics which define characteristics and
    capabilities of a sensor.
    """

    sensorlimits_collection: Optional[List[SensorTupleResponseItemSensorlimitsCollection]] = FieldInfo(
        alias="sensorlimitsCollection", default=None
    )
    """
    Sensorlimits define 0 to many limits of a particular sensor in terms of
    observation coverage of on-orbit objects.
    """

    sensor_number: Optional[int] = FieldInfo(alias="sensorNumber", default=None)
    """Number assigned to this sensor.

    Since there is no authoritative numbering scheme, these numbers sometimes
    collide across sensors (especially commercial sensors). It is therefore not a
    unique identifier.
    """

    sensor_observation_type: Optional[SensorTupleResponseItemSensorObservationType] = FieldInfo(
        alias="sensorObservationType", default=None
    )

    sensor_stats: Optional[List[SensorTupleResponseItemSensorStat]] = FieldInfo(alias="sensorStats", default=None)
    """Collection of SensorStats which contain statistics of a sensor."""

    sensor_type: Optional[SensorTupleResponseItemSensorType] = FieldInfo(alias="sensorType", default=None)

    short_name: Optional[str] = FieldInfo(alias="shortName", default=None)
    """Optional short name for the sensor."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """


SensorTupleResponse: TypeAlias = List[SensorTupleResponseItem]
