# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SensormaintenanceUpdateParams"]


class SensormaintenanceUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    end_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="endTime", format="iso8601")]]
    """The planned outage end time in ISO8601 UTC format."""

    site_code: Required[Annotated[str, PropertyInfo(alias="siteCode")]]
    """The site to which this item applies.

    NOTE - this site code is COLT specific and may not identically correspond to
    other UDL site IDs.
    """

    source: Required[str]
    """Source of the data."""

    start_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="startTime", format="iso8601")]]
    """The planned outage start time in ISO8601 UTC format."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    activity: str
    """Description of the activity taking place during this outage."""

    approver: str
    """The name of the approver."""

    changer: str
    """The name of the changer, if applicable."""

    duration: str
    """The duration of the planned outage, expressed as ddd:hh:mm."""

    eow_id: Annotated[str, PropertyInfo(alias="eowId")]
    """COLT EOWID."""

    equip_status: Annotated[str, PropertyInfo(alias="equipStatus")]
    """The mission capability status of the equipment (e.g. FMC, NMC, PMC, UNK, etc.)."""

    id_sensor: Annotated[str, PropertyInfo(alias="idSensor")]
    """UUID of the sensor."""

    impacted_faces: Annotated[str, PropertyInfo(alias="impactedFaces")]
    """The sensor face(s) to which this COLT maintenance item applies, if applicable."""

    line_number: Annotated[str, PropertyInfo(alias="lineNumber")]
    """The internal COLT line number assigned to this item."""

    md_ops_cap: Annotated[str, PropertyInfo(alias="mdOpsCap")]
    """The Missile Defense operational capability of this maintenance item.

    Typical values are G, Y, R, and - for non-applicable sites.
    """

    mw_ops_cap: Annotated[str, PropertyInfo(alias="mwOpsCap")]
    """The Missile Warning operational capability of this maintenance item.

    Typical values are G, Y, R, and - for non-applicable sites.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    priority: str
    """The priority of this maintenance item."""

    recall: str
    """The minimum time required to recall this activity, expressed as ddd:hh:mm."""

    rel: str
    """Release."""

    remark: str
    """Remarks concerning this outage."""

    requestor: str
    """The name of the requestor."""

    resource: str
    """The name of the resource(s) affected by this maintenance item."""

    rev: str
    """The revision number for this maintenance item."""

    ss_ops_cap: Annotated[str, PropertyInfo(alias="ssOpsCap")]
    """The Space Surveillance operational capability of this maintenance item.

    Typical values are G, Y, R, and - for non-applicable sites.
    """
