# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SeradataearlywarningCreateParams"]


class SeradataearlywarningCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: Required[str]
    """Source of the data."""

    spacecraft_id: Required[Annotated[str, PropertyInfo(alias="spacecraftId")]]
    """Seradata ID of the spacecraft (SeradataSpacecraftDetails ID)."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    best_resolution: Annotated[float, PropertyInfo(alias="bestResolution")]
    """Best resolution for this IR in meters."""

    earth_pointing: Annotated[bool, PropertyInfo(alias="earthPointing")]
    """Is the sensor Earth Pointing."""

    frequency_limits: Annotated[str, PropertyInfo(alias="frequencyLimits")]
    """Frequency Limits for this IR."""

    ground_station_locations: Annotated[str, PropertyInfo(alias="groundStationLocations")]
    """Ground Station Locations for this IR."""

    ground_stations: Annotated[str, PropertyInfo(alias="groundStations")]
    """Ground Station info for this IR."""

    hosted_for_company_org_id: Annotated[str, PropertyInfo(alias="hostedForCompanyOrgId")]
    """Hosted for company/Organization Id."""

    id_ir: Annotated[str, PropertyInfo(alias="idIR")]
    """UUID of the parent IR record."""

    manufacturer_org_id: Annotated[str, PropertyInfo(alias="manufacturerOrgId")]
    """Manufacturer Organization Id."""

    missile_launch_phase_detection_ability: Annotated[str, PropertyInfo(alias="missileLaunchPhaseDetectionAbility")]
    """Missile Launch Phase Detection Ability."""

    name: str
    """Sensor name from Seradata, e.g. Infra red telescope, Schmidt Telescope, etc."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    partner_spacecraft_id: Annotated[str, PropertyInfo(alias="partnerSpacecraftId")]
    """Seradata ID of the spacecraft (SeradataSpacecraftDetails ID)."""

    payload_notes: Annotated[str, PropertyInfo(alias="payloadNotes")]
    """Payload notes."""

    spectral_bands: Annotated[str, PropertyInfo(alias="spectralBands")]
    """Spectral Bands, e.g. Infra-Red."""
