# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SeradatasigintpayloadGetResponse"]


class SeradatasigintpayloadGetResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    spacecraft_id: str = FieldInfo(alias="spacecraftId")
    """Seradata ID of the spacecraft (SeradataSpacecraftDetails ID)."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    frequency_coverage: Optional[str] = FieldInfo(alias="frequencyCoverage", default=None)
    """Frequency coverage for this payload."""

    ground_station_locations: Optional[str] = FieldInfo(alias="groundStationLocations", default=None)
    """Ground Station Locations for this payload."""

    ground_stations: Optional[str] = FieldInfo(alias="groundStations", default=None)
    """Ground Station info for this payload."""

    hosted_for_company_org_id: Optional[str] = FieldInfo(alias="hostedForCompanyOrgId", default=None)
    """Hosted for company/Organization Id."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """UUID of the Sensor record."""

    intercept_parameters: Optional[str] = FieldInfo(alias="interceptParameters", default=None)
    """Intercept parameters."""

    manufacturer_org_id: Optional[str] = FieldInfo(alias="manufacturerOrgId", default=None)
    """Manufacturer Organization Id."""

    name: Optional[str] = None
    """Sensor name from Seradata."""

    notes: Optional[str] = None
    """Payload notes."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    positional_accuracy: Optional[str] = FieldInfo(alias="positionalAccuracy", default=None)
    """Positional Accuracy for this payload."""

    swath_width: Optional[float] = FieldInfo(alias="swathWidth", default=None)
    """Swath Width in kilometers."""

    type: Optional[str] = None
    """SIGINT Payload type, e.g. Comint, Elint, etc."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """
