# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SeradataspacecraftdetailListResponse", "SeradataspacecraftdetailListResponseItem"]


class SeradataspacecraftdetailListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Spacecraft name."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    additional_missions_groups: Optional[str] = FieldInfo(alias="additionalMissionsGroups", default=None)
    """Spacecraft additional missions and groups."""

    altitude: Optional[float] = None
    """Spacecraft latest altitude in km."""

    annual_insured_depreciation_factor: Optional[float] = FieldInfo(
        alias="annualInsuredDepreciationFactor", default=None
    )
    """Annual insured depreciaion factor as a percent fraction."""

    annual_insured_depreciation_factor_estimated: Optional[bool] = FieldInfo(
        alias="annualInsuredDepreciationFactorEstimated", default=None
    )
    """
    Boolean indicating if the spacecraft annualInsuredDepreciationFactor is
    estimated.
    """

    apogee: Optional[float] = None
    """Apogee in km."""

    bus_id: Optional[str] = FieldInfo(alias="busId", default=None)
    """Spacecraft Bus ID."""

    capability_lost: Optional[float] = FieldInfo(alias="capabilityLost", default=None)
    """Total capability lost as a percent fraction."""

    capacity_lost: Optional[float] = FieldInfo(alias="capacityLost", default=None)
    """Total capacity lost as a percent fraction."""

    catalog_number: Optional[int] = FieldInfo(alias="catalogNumber", default=None)
    """NORAD satellite number if available."""

    collision_risk_cm: Optional[float] = FieldInfo(alias="collisionRiskCM", default=None)
    """Spacecraft collision risk 1cm sqm latest."""

    collision_risk_mm: Optional[float] = FieldInfo(alias="collisionRiskMM", default=None)
    """Spacecraft collision risk 1mm sqm latest."""

    combined_cost_estimated: Optional[bool] = FieldInfo(alias="combinedCostEstimated", default=None)
    """Boolean indicating if the spacecraft combined new cost is estimated."""

    combined_new_cost: Optional[float] = FieldInfo(alias="combinedNewCost", default=None)
    """Combined cost of spacecraft at new in M USD."""

    commercial_launch: Optional[bool] = FieldInfo(alias="commercialLaunch", default=None)
    """Boolean indicating if the launch was commercial."""

    constellation: Optional[str] = None
    """Spacecraft constellation."""

    cost_estimated: Optional[bool] = FieldInfo(alias="costEstimated", default=None)
    """Boolean indicating if the spacecraft cost is estimated."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    cubesat_dispenser_type: Optional[str] = FieldInfo(alias="cubesatDispenserType", default=None)
    """Cubesat dispenser type."""

    current_age: Optional[float] = FieldInfo(alias="currentAge", default=None)
    """Current age in years."""

    date_of_observation: Optional[datetime] = FieldInfo(alias="dateOfObservation", default=None)
    """Spacecraft date of observation."""

    description: Optional[str] = None
    """Description associated with the spacecraft."""

    design_life: Optional[int] = FieldInfo(alias="designLife", default=None)
    """Spacecraft design life in days."""

    dry_mass: Optional[float] = FieldInfo(alias="dryMass", default=None)
    """Mass dry in kg."""

    expected_life: Optional[int] = FieldInfo(alias="expectedLife", default=None)
    """Spacecraft expected life in days."""

    geo_position: Optional[float] = FieldInfo(alias="geoPosition", default=None)
    """WGS84 longitude of the spacecraft’s latest GEO position, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """UUID of the parent Onorbit record, if available."""

    inclination: Optional[float] = None
    """Seradata provided inclination in degrees."""

    insurance_losses_total: Optional[float] = FieldInfo(alias="insuranceLossesTotal", default=None)
    """Spacecraft total insurance losses as a fraction."""

    insurance_notes: Optional[str] = FieldInfo(alias="insuranceNotes", default=None)
    """Insurance notes for the spacecraft."""

    insurance_premium_at_launch: Optional[float] = FieldInfo(alias="insurancePremiumAtLaunch", default=None)
    """Insurance premium at launch in M USD."""

    insurance_premium_at_launch_estimated: Optional[bool] = FieldInfo(
        alias="insurancePremiumAtLaunchEstimated", default=None
    )
    """Boolean indicating if the spacecraft insurancePremiumAtLaunch is estimated."""

    insured_at_launch: Optional[bool] = FieldInfo(alias="insuredAtLaunch", default=None)
    """Boolean indicating if the spacecraft was insured at launch."""

    insured_value_at_launch: Optional[float] = FieldInfo(alias="insuredValueAtLaunch", default=None)
    """Insured value of spacecraft at launch in M USD."""

    insured_value_launch_estimated: Optional[bool] = FieldInfo(alias="insuredValueLaunchEstimated", default=None)
    """Boolean indicating if the spacecraft insured value at launch is estimated."""

    intl_number: Optional[str] = FieldInfo(alias="intlNumber", default=None)
    """Seradata international number."""

    lat: Optional[float] = None
    """Spacecraft latest latitude in degrees."""

    launch_arranger: Optional[str] = FieldInfo(alias="launchArranger", default=None)
    """Spacecraft launch arranger."""

    launch_arranger_country: Optional[str] = FieldInfo(alias="launchArrangerCountry", default=None)
    """Spacecraft launch arranger country."""

    launch_characteristic: Optional[str] = FieldInfo(alias="launchCharacteristic", default=None)
    """Seradata launch characteristic (e.g. Expendable, Reusable (New), etc)."""

    launch_cost: Optional[float] = FieldInfo(alias="launchCost", default=None)
    """Cost of launch in M USD."""

    launch_cost_estimated: Optional[bool] = FieldInfo(alias="launchCostEstimated", default=None)
    """Boolean indicating if the spacecraft launch cost is estimated."""

    launch_country: Optional[str] = FieldInfo(alias="launchCountry", default=None)
    """Seradata launch country."""

    launch_date: Optional[datetime] = FieldInfo(alias="launchDate", default=None)
    """Launch date."""

    launch_date_remarks: Optional[str] = FieldInfo(alias="launchDateRemarks", default=None)
    """Seradata remarks on launch date."""

    launch_id: Optional[str] = FieldInfo(alias="launchId", default=None)
    """Seradata launch ID."""

    launch_mass: Optional[float] = FieldInfo(alias="launchMass", default=None)
    """Mass at launch in kg."""

    launch_notes: Optional[str] = FieldInfo(alias="launchNotes", default=None)
    """Insurance notes for the spacecraft."""

    launch_number: Optional[str] = FieldInfo(alias="launchNumber", default=None)
    """Seradata launch number."""

    launch_provider: Optional[str] = FieldInfo(alias="launchProvider", default=None)
    """Seradata launch provider."""

    launch_provider_country: Optional[str] = FieldInfo(alias="launchProviderCountry", default=None)
    """Seradata launch provider country."""

    launch_provider_flight_number: Optional[str] = FieldInfo(alias="launchProviderFlightNumber", default=None)
    """Seradata launch vehicle family."""

    launch_site_id: Optional[str] = FieldInfo(alias="launchSiteId", default=None)
    """Seradata Launch Site ID."""

    launch_site_name: Optional[str] = FieldInfo(alias="launchSiteName", default=None)
    """Launch Site Name."""

    launch_type: Optional[str] = FieldInfo(alias="launchType", default=None)
    """Seradata launch type (e.g. Launched, Future, etc)."""

    launch_vehicle_id: Optional[str] = FieldInfo(alias="launchVehicleId", default=None)
    """Seradata launch ID."""

    leased: Optional[bool] = None
    """Boolean indicating if the spacecraft was leased."""

    life_lost: Optional[float] = FieldInfo(alias="lifeLost", default=None)
    """Spacecraft life lost as a percent fraction."""

    lon: Optional[float] = None
    """Spacecraft latest longitude in degrees."""

    mass_category: Optional[str] = FieldInfo(alias="massCategory", default=None)
    """Mass category (e.g.

    2500 - 3500kg - Large Satellite, 10 - 100 kg - Microsatellite, etc).
    """

    name_at_launch: Optional[str] = FieldInfo(alias="nameAtLaunch", default=None)
    """Spacecraft name at launch."""

    new_cost: Optional[float] = FieldInfo(alias="newCost", default=None)
    """Cost of spacecraft at new in M USD."""

    notes: Optional[str] = None
    """Notes on the spacecraft."""

    num_humans: Optional[int] = FieldInfo(alias="numHumans", default=None)
    """Number of humans carried on spacecraft."""

    operator: Optional[str] = None
    """Spacecraft operator name."""

    operator_country: Optional[str] = FieldInfo(alias="operatorCountry", default=None)
    """Spacecraft operator country."""

    orbit_category: Optional[str] = FieldInfo(alias="orbitCategory", default=None)
    """Spacecraft orbit category (e.g GEO, LEO, etc)."""

    orbit_sub_category: Optional[str] = FieldInfo(alias="orbitSubCategory", default=None)
    """Spacecraft sub orbit category (e.g LEO - Sun-synchronous, Geostationary, etc)."""

    order_date: Optional[datetime] = FieldInfo(alias="orderDate", default=None)
    """Spacecraft order date."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    owner: Optional[str] = None
    """Spacecraft owner name."""

    owner_country: Optional[str] = FieldInfo(alias="ownerCountry", default=None)
    """Spacecraft owner country."""

    perigee: Optional[float] = None
    """Perigee in km."""

    period: Optional[float] = None
    """Spacecraft period in minutes."""

    primary_mission_group: Optional[str] = FieldInfo(alias="primaryMissionGroup", default=None)
    """Spacecraft primary mission and group."""

    prime_manufacturer_org_id: Optional[str] = FieldInfo(alias="primeManufacturerOrgId", default=None)
    """UUID of the prime manufacturer organization, if available."""

    program_name: Optional[str] = FieldInfo(alias="programName", default=None)
    """Spacecraft program name."""

    quantity: Optional[int] = None
    """Spacecraft quantity."""

    reusable_flights: Optional[str] = FieldInfo(alias="reusableFlights", default=None)
    """Spacecraft reusable flights."""

    reused_hull_name: Optional[str] = FieldInfo(alias="reusedHullName", default=None)
    """Spacecraft reused hull name."""

    sector: Optional[str] = None
    """Seradata sector (e.g. Commercial, Military, Civil/Other)."""

    serial_number: Optional[str] = FieldInfo(alias="serialNumber", default=None)
    """Spacecraft serial number."""

    stabilizer: Optional[str] = None
    """Spacecraft stabilizer (e.g. 3-Axis, Gravity Gradiant, etc)."""

    status: Optional[str] = None
    """Spacecraft status (e.g.

    Inactive - Retired, Inactive - Re-entered, Active, etc).
    """

    total_claims: Optional[int] = FieldInfo(alias="totalClaims", default=None)
    """Number of insurance claims for this spacecraft."""

    total_fatalities: Optional[int] = FieldInfo(alias="totalFatalities", default=None)
    """Number of fatalities related to this spacecraft."""

    total_injuries: Optional[int] = FieldInfo(alias="totalInjuries", default=None)
    """Number of injuries related to this spacecraft."""

    total_payload_power: Optional[float] = FieldInfo(alias="totalPayloadPower", default=None)
    """Mass dry in kg."""

    youtube_launch_link: Optional[str] = FieldInfo(alias="youtubeLaunchLink", default=None)
    """Youtube link of launch."""


SeradataspacecraftdetailListResponse: TypeAlias = List[SeradataspacecraftdetailListResponseItem]
