# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SgiListResponse", "SgiListResponseItem"]


class SgiListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    effective_date: datetime = FieldInfo(alias="effectiveDate")
    """ISO8601 UTC Time the data was received and processed from the source.

    Typically a source provides data for a date window with each transmission
    including past, present, and future predicted values.
    """

    sgi_date: datetime = FieldInfo(alias="sgiDate")
    """ISO8601 UTC Time of the index value.

    This could be a past, current, or future predicted value. Note: sgiDate defines
    the start time of the time window for this data record.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    analyzer_attenuation: Optional[float] = FieldInfo(alias="analyzerAttenuation", default=None)
    """Signal analyzer's input attenuation level, in decibels.

    Attenuation is a setting on the hardware that measures the power of a signal.
    """

    ap: Optional[float] = None
    """
    Ap is the planetary geomagnetic 2 nT index (00-21 UT) for the timespan specified
    in apDuration. If apDuration is null, a 3 hour duration should be assumed.
    """

    ap_duration: Optional[int] = FieldInfo(alias="apDuration", default=None)
    """The time, in hours, for which the Ap index value is valid.

    If null, a span of 3 hours is assumed.
    """

    coeff_degree: Optional[List[int]] = FieldInfo(alias="coeffDegree", default=None)
    """Array containing the degree of the temperature coefficients.

    The coeffDegree and coeffOrder arrays must be the same length.
    """

    coeff_order: Optional[List[int]] = FieldInfo(alias="coeffOrder", default=None)
    """Array containing the order of the temperature coefficients.

    The coeffDegree and coeffOrder arrays must be the same length.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    ctce: Optional[List[float]] = None
    """
    Array containing the cosine spherical-harmonic coefficients for Exospheric
    temperature (DTC) difference. Each array element corresponds to the positional
    index of the coeffDegree and coeffOrder arrays.
    """

    ctci: Optional[List[float]] = None
    """
    Array containing the cosine spherical-harmonic coefficients for Inflection
    temperature (DTX) difference. Each array element corresponds to the positional
    index of the coeffDegree and coeffOrder arrays.
    """

    dst: Optional[float] = None
    """Disturbance Storm Time geomagnetic index in nT."""

    dtc: Optional[float] = None
    """delta exospheric temperature correction in units of K."""

    e10: Optional[float] = None
    """
    Extreme Ultraviolet (EUV) proxy, E10.7, in x10-22 Watts per meter squared per
    Hertz, is the integrated solar EUV energy flux at the top of atmosphere and
    normalized to solar flux units.
    """

    e54: Optional[float] = None
    """
    E54 (E10-Bar), in x10-22 Watts per meter squared per Hertz, uses the past
    54-days E10 values to determine the E10 average.
    """

    f10: Optional[float] = None
    """Daily solar 10.7 cm radio flux in x10-22 Watts per meter squared per Hertz."""

    f10_high: Optional[float] = FieldInfo(alias="f10High", default=None)
    """Daily F10.7 index - high range, in x10-22 Watts per meter squared per Hertz.

    This field usually applies to forecast values, based on the consensus of the
    Solar Cycle 24 Prediction Panel.
    """

    f10_low: Optional[float] = FieldInfo(alias="f10Low", default=None)
    """Daily F10.7 index - low range, in x10-22 Watts per meter squared per Hertz.

    This field usually applies to forecast values, based on the consensus of the
    Solar Cycle 24 Prediction Panel.
    """

    f54: Optional[float] = None
    """54 day solar 10.7 cm radio flux in x10-22 Watts per meter squared per Hertz."""

    f81: Optional[float] = None
    """81 day solar 10.7 cm radio flux in x10-22 Watts per meter squared per Hertz."""

    gamma: Optional[int] = None
    """The maximum measured gamma deflection during the kpDuration timespan.

    If kpDuration is null, a 3 hour duration should be assumed.
    """

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the reporting sensor."""

    k_index: Optional[int] = FieldInfo(alias="kIndex", default=None)
    """
    The maximum measured K-Index at the associated station during the kpDuration
    timespan. The K-Index is a unitless measure (0 - 9) of the deviation in the
    Earth's magnetic field from normal at the station geographic location, with 0
    indicating the absence of geomagnetic disturbance, and 9 indicating the most
    significant disturbance. If kpDuration is null, a 3 hour duration should be
    assumed.
    """

    kp: Optional[float] = None
    """The Planetary K-index (Kp) over the kpDuration timespan.

    The Kp-Index is the average K-Index for the entire Earth, utilizing a unitless
    scale (0-9, in incremenets of 1/3), with 0 indicating the absence of geomagnetic
    disturbance, and 9 indicating the most significant disturbance. If kpDuration is
    null, a 3 hour duration should be assumed.
    """

    kp_duration: Optional[int] = FieldInfo(alias="kpDuration", default=None)
    """The time, in hours, over which the K, Kp, and/or gamma index values are
    measured.

    If null, a span of 3 hours is assumed.
    """

    m10: Optional[float] = None
    """Daily M10.7 index for 100-110 km heating of O2 by solar photosphere.

    160 nm SRC emissions in x10-22 Watts per meter squared per Hertz.
    """

    m54: Optional[float] = None
    """54 day M10.7 index for 100-110 km heating of O2 by solar photosphere.

    160 nm SRC emissions in x10-22 Watts per meter squared per Hertz.
    """

    mode: Optional[int] = None
    """The transmitted DCA mode of the record (1-3)."""

    norm_factor: Optional[float] = FieldInfo(alias="normFactor", default=None)
    """
    The normalization factor that has already been applied to the index value prior
    to record ingest. Typically used to normalize the index value to a particular
    interval. Units of the normalization factor may vary depending on the provider
    of this data (REACH, POES, CEASE3, etc.).
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by the reporting source to indicate the sensor
    identifier which produced this data. This may be an internal identifier and not
    necessarily a valid sensor ID.
    """

    precedence: Optional[Literal["O", "P", "R", "Y", "Z"]] = None
    """
    The precedence of data in this record (O = Immediate, P = Priority, R = Routine,
    Y = Emergency, Z = Flash).
    """

    raw_file_uri: Optional[str] = FieldInfo(alias="rawFileURI", default=None)
    """
    Optional URI location in the document repository of the raw file parsed by the
    system to produce this record. To download the raw file, prepend
    https://udl-hostname/scs/download?id= to this value.
    """

    rb_duration: Optional[int] = FieldInfo(alias="rbDuration", default=None)
    """The timespan over which the associated radiation belt index is factored.

    If rbDuration is null, a 24 hour duration should be assumed. Note: rbDuration
    defines the length of the time window for this data record. The time window
    start time is defined by sgiDate, and the time window end time is defined by
    sgiDate plus rbDuration.
    """

    rb_index: Optional[float] = FieldInfo(alias="rbIndex", default=None)
    """The value of the radiation belt index.

    This is the ratio of current intensity of a radiation belt to long-term average
    value. It's long-term average should be close to 1. Depending on the type of
    belt sensor, this ratio may measure Flux (number of particles / (cm^2 sec energy
    solid-angle)), dose rate (rad per second), or relative counts of particles per
    time (counts per second). The index value may also be normalized, the
    normalization value typically represents an average of the sensor measurements
    taken within a region over a given time interval. See the normFactor field for
    the specific normalization factor, if provided.
    """

    rb_region_code: Optional[int] = FieldInfo(alias="rbRegionCode", default=None)
    """Region code for the associated radiation belt index.

    This is the code associated with the corresponding radiation belt location. See
    the provider card for reference to specific region code definitions.
    """

    s10: Optional[float] = None
    """Daily S10.7 index for >200 km heating of O by solar chromosphere.

    28.4-30.4 nm emissions in x10-22 Watts per meter squared per Hertz.
    """

    s54: Optional[float] = None
    """54 day S10.7 index for >200 km heating of O by solar chromosphere.

    28.4-30.4 nm emissions in x10-22 Watts per meter squared per Hertz.
    """

    state: Optional[Literal["I", "N", "P"]] = None
    """
    State indicating Issued (I), Nowcast (N), or Predicted (P) values for this
    record.
    """

    station_name: Optional[str] = FieldInfo(alias="stationName", default=None)
    """
    The name/location of the station that collected the geomagnetic data for this
    record.
    """

    stce: Optional[List[float]] = None
    """
    Array containing the sine spherical-harmonic coefficients for Exospheric
    temperature (DTC) difference. Each array element corresponds to the positional
    index of the coeffDegree and coeffOrder arrays.
    """

    stci: Optional[List[float]] = None
    """
    Array containing the sine spherical harmonic coefficients for Inflection
    temperature (DTX) difference. Each array element corresponds to the positional
    index of the coeffDegree and coeffOrder arrays.
    """

    sunspot_num: Optional[float] = FieldInfo(alias="sunspotNum", default=None)
    """Daily sunspot number."""

    sunspot_num_high: Optional[float] = FieldInfo(alias="sunspotNumHigh", default=None)
    """Daily sunspot number - high range.

    This field usually applies to forecast values, based on the consensus of the
    Solar Cycle 24 Prediction Panel.
    """

    sunspot_num_low: Optional[float] = FieldInfo(alias="sunspotNumLow", default=None)
    """Daily sunspot number - low range.

    This field usually applies to forecast values, based on the consensus of the
    Solar Cycle 24 Prediction Panel.
    """

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    type: Optional[str] = None
    """The type of data contained in this record (e.g.

    HASDM, JBH09, K-Index, PSD-dB, RBI, RFI-SFU, etc).
    """

    y10: Optional[float] = None
    """Daily Y10.7 index for 85-90 km heating of N2, O2, H2O, NO by solar coronal.

    0.1-0.8 nm and Lya 121 nm emissions in x10-22 Watts per meter squared per Hertz.
    """

    y54: Optional[float] = None
    """54 day Y10.7 index for 85-90 km heating of N2, O2, H2O, NO by solar coronal.

    0.1-0.8 nm and Lya 121 nm emissions in x10-22 Watts per meter squared per Hertz.
    """


SgiListResponse: TypeAlias = List[SgiListResponseItem]
