# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .onorbit_full import OnorbitFull
from ..attitudedata_full import AttitudedataFull

__all__ = ["AttitudesetFull"]


class AttitudesetFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    end_time: datetime = FieldInfo(alias="endTime")
    """
    The end time of the attitude ephemeris, in ISO 8601 UTC format, with microsecond
    precision. If this set is constituted by a single epoch attitude message then
    endTime should match the startTime.
    """

    frame1: str
    """
    Reference frame 1 of the quaternion or Euler angle transformation utilized in
    this attitude parameter or attitude ephemeris. The UDL convention is that
    transformations occur FROM frame1 TO frame2. A specific spacecraft frame or
    instrument name may be provided with the assumption the consumer understands the
    location of these frames (ex. SC BODY, J2000, LVLH, ICRF, INSTRUMENTx,
    THRUSTERx, etc.).
    """

    frame2: str
    """
    Reference frame 2 of the quaternion or Euler angle transformation utilized in
    this attitude parameter or attitude ephemeris. The UDL convention is that
    transformations occur FROM frame1 TO frame2. A specific spacecraft frame or
    instrument name may be provided with the assumption the consumer understands the
    location of these frames (ex. SC BODY, J2000, LVLH, ICRF, INSTRUMENTx,
    THRUSTERx, etc.).
    """

    num_points: int = FieldInfo(alias="numPoints")
    """Number of attitude records contained in this set."""

    source: str
    """Source of the data."""

    start_time: datetime = FieldInfo(alias="startTime")
    """
    The epoch or start time of the attitude parameter or attitude ephemeris, in ISO
    8601 UTC format, with microsecond precision. If this set is constituted by a
    single attitude parameter message then startTime is the epoch.
    """

    type: str
    """The type of attitude message or messages associated with this set.

    AEM = Attitude Ephemeris Message, specifying the attitude state of a single
    object at multiple epochs.

    APM = Attitude Parameters Message, specifying the attitude state of a single
    object at a single epoch.
    """

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    as_ref: Optional[List[str]] = FieldInfo(alias="asRef", default=None)
    """Array of UDL UUIDs of one or more AttitudeSet records associated with this set.

    For example, a spacecraft Attitude Ephemeris Set might include a reference to an
    Attitude Parameter Message defining the sensor to body frame transformation for
    a sensor onboard the spacecraft, which allows for calculation of the sensor
    orientation in frame2 of the attitude ephemeris.
    """

    attitude_list: Optional[List[AttitudedataFull]] = FieldInfo(alias="attitudeList", default=None)
    """Collection of attitude data associated with this Attitude Set."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    es_id: Optional[str] = FieldInfo(alias="esId", default=None)
    """
    Unique identifier of the parent (positional) Ephemeris Set, if this data is
    correlated with an Ephemeris.
    """

    euler_rot_seq: Optional[str] = FieldInfo(alias="eulerRotSeq", default=None)
    """
    The rotation sequence of the Euler angles in which attitude reference frame
    transformation occurs (from left to right). One, two, or three axis rotations
    are supported and are represented by one, two, or three characters respectively.
    Repeated axis rotations are also supported, however, these rotations should not
    be sequential. The numeric sequence values correspond to the body angles/rates
    as follows: 1 - xAngle/xRate, 2 - yAngle/yRate, and 3 - zAngle/zRate. Valid
    sequences are: 123, 132, 213, 231, 312, 321, 121, 131, 212, 232, 313, 323, 12,
    13, 21, 23, 31, 32, 1, 2, and 3.

    The following represent examples of possible rotation sequences: A single
    rotation about the Y-axis can be expressed as '2', a double rotation with X-Z
    sequence can be expressed as '13', and a triple rotation with Z-X-Y sequence can
    be expressed as '312'.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the on-orbit satellite to which this attitude set applies."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """
    Unique identifier of the sensor to which this attitude set applies IF this set
    is reporting a single sensor orientation.
    """

    interpolator: Optional[str] = None
    """Recommended interpolation method for estimating attitude ephemeris data."""

    interpolator_degree: Optional[int] = FieldInfo(alias="interpolatorDegree", default=None)
    """Recommended polynomial interpolation degree."""

    notes: Optional[str] = None
    """Optional notes/comments for this attitude set."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by the record source to indicate the target object
    of this attitude set. This may be an internal identifier and not necessarily map
    to a valid satellite number.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by the record source to indicate the sensor
    identifier to which this attitude set applies IF this set is reporting a single
    sensor orientation. This may be an internal identifier and not necessarily a
    valid sensor ID.
    """

    prec_angle_init: Optional[float] = FieldInfo(alias="precAngleInit", default=None)
    """Initial precession angle (ECI J2000 frame) in degrees."""

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """
    Satellite/catalog number of the on-orbit object to which this attitude set
    applies.
    """

    spin_angle_init: Optional[float] = FieldInfo(alias="spinAngleInit", default=None)
    """Initial spin angle (ECI J2000 frame) in degrees."""

    step_size: Optional[int] = FieldInfo(alias="stepSize", default=None)
    """Attitude ephemeris step size, in seconds.

    This applies to Attitude Ephemeris Messages (AEM) that employ a fixed step size.
    """
