# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "SigactListResponse",
    "SigactListResponseItem",
    "SigactListResponseItemRelatedDoc",
    "SigactListResponseItemRelatedDocDataSourceRef",
]


class SigactListResponseItemRelatedDocDataSourceRef(BaseModel):
    data_source_id: Optional[str] = FieldInfo(alias="dataSourceId", default=None)
    """Data source id."""

    end_position: Optional[str] = FieldInfo(alias="endPosition", default=None)
    """end position."""

    paragraph_number: Optional[str] = FieldInfo(alias="paragraphNumber", default=None)
    """paragraph number."""

    sentence_number: Optional[str] = FieldInfo(alias="sentenceNumber", default=None)
    """sentence number."""

    start_position: Optional[str] = FieldInfo(alias="startPosition", default=None)
    """start position."""


class SigactListResponseItemRelatedDoc(BaseModel):
    data_source_refs: Optional[List[SigactListResponseItemRelatedDocDataSourceRef]] = FieldInfo(
        alias="dataSourceRefs", default=None
    )
    """List of data sources related to this document."""

    document_id: Optional[str] = FieldInfo(alias="documentId", default=None)
    """The document id of the related document."""


class SigactListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    report_date: datetime = FieldInfo(alias="reportDate")
    """Date of the report or filing."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    accuracy: Optional[int] = None
    """Estimate of the accuracy that this event occurred as described/reported."""

    actors: Optional[List[str]] = None
    """A list of one or more actors involved in the event."""

    agjson: Optional[str] = None
    """
    Geographical region or polygon (lat/lon pairs), as depicted by the GeoJSON
    representation of the geometry/geography, of the image as projected on the
    ground. GeoJSON Reference: https://geojson.org/. Ignored if included with a POST
    or PUT request that also specifies a valid 'area' or 'atext' field.
    """

    andims: Optional[int] = None
    """Number of dimensions of the geometry depicted by region."""

    asrid: Optional[int] = None
    """Geographical spatial_ref_sys for region."""

    atext: Optional[str] = None
    """
    Geographical region or polygon (lon/lat pairs), as depicted by the Well-Known
    Text representation of the geometry/geography, of the image as projected on the
    ground. WKT reference: https://www.opengeospatial.org/standards/wkt-crs. Ignored
    if included with a POST or PUT request that also specifies a valid 'area' field.
    """

    atype: Optional[str] = None
    """Type of region as projected on the ground."""

    avg_tone: Optional[float] = FieldInfo(alias="avgTone", default=None)
    """
    This is the average tone of all documents containing one or more mentions of
    this event during the 15 minute update in which it was first seen. The score
    ranges from -100 (extremely negative) to +100 (extremely positive). Common
    values range between -10 and +10, with 0 indicating neutral.
    """

    cameo_base_code: Optional[str] = FieldInfo(alias="cameoBaseCode", default=None)
    """CAMEO event codes are defined in a three-level taxonomy.

    For events at level three in the taxonomy, this yields its level two leaf root
    node. For example, code 0251 (Appeal for easing of administrative sanctions)
    would yield an EventBaseCode of 025 (Appeal to yield). This makes it possible to
    aggregate events at various resolutions of specificity. For events at levels two
    or one, this field will be set to EventCode.
    """

    cameo_code: Optional[str] = FieldInfo(alias="cameoCode", default=None)
    """
    This is the raw CAMEO action code describing the action that Actor1 performed
    upon Actor2. Additional information about Cameo Codes can be obtained from the
    GDELT project documentation here:
    https://www.gdeltproject.org/data.html#documentation.
    """

    cameo_root_code: Optional[str] = FieldInfo(alias="cameoRootCode", default=None)
    """
    Similar to EventBaseCode, this defines the root-level category the event code
    falls under. For example, code 0251 (Appeal for easing of administrative
    sanctions) has a root code of 02 (Appeal). This makes it possible to aggregate
    events at various resolutions of specificity. For events at levels two or one,
    this field will be set to EventCode.
    """

    checksum_value: Optional[str] = FieldInfo(alias="checksumValue", default=None)
    """MD5 value of the file.

    The ingest/create operation will automatically generate the value.
    """

    city: Optional[str] = None
    """The city in or near which this event occurred."""

    civ_abd: Optional[int] = FieldInfo(alias="civAbd", default=None)
    """Number of civilians abducted in the activity."""

    civ_det: Optional[int] = FieldInfo(alias="civDet", default=None)
    """Number of civilians detained in the activity."""

    civ_kia: Optional[int] = FieldInfo(alias="civKIA", default=None)
    """Number of civilians killed in the activity."""

    civ_wound: Optional[int] = FieldInfo(alias="civWound", default=None)
    """Number of civilians wounded in the activity."""

    clarity: Optional[int] = None
    """
    1 (high) for events where the reporting allows the coder to identify the event
    in full. That is, events where the individual happening is described by the
    original source in a sufficiently detailed way as to identify individual
    incidents, i.e. separate activities of fighting in a single location:

    2 (lower) for events where an aggregation of information was already made by the
    source material that is impossible to undo in the coding process. Such events
    are described by the original source only as aggregates (totals) of multiple
    separate activities of fighting spanning over a longer period than a single,
    clearly defined day.
    """

    coal_abd: Optional[int] = FieldInfo(alias="coalAbd", default=None)
    """Number of coalition members abducted in the activity."""

    coal_det: Optional[int] = FieldInfo(alias="coalDet", default=None)
    """Number of coalition members detained in the activity."""

    coal_kia: Optional[int] = FieldInfo(alias="coalKIA", default=None)
    """Number of coalition members killed in the activity."""

    coal_wound: Optional[int] = FieldInfo(alias="coalWound", default=None)
    """Number of coalition members wounded in the activity."""

    complex_attack: Optional[bool] = FieldInfo(alias="complexAttack", default=None)
    """Flag indicating that this attack was of a complex or coordinated nature."""

    confidence: Optional[int] = None
    """Estimate of the confidence that this event occurred."""

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country code.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """
    Time the row was created in the database, auto-populated by the system, example
    = 2018-01-01T16:00:00.123Z.
    """

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    district: Optional[str] = None
    """The district in which this event occurred."""

    document_filename: Optional[str] = FieldInfo(alias="documentFilename", default=None)
    """The filename of the document or report."""

    document_source: Optional[str] = FieldInfo(alias="documentSource", default=None)
    """The source of the document or report."""

    enemy_abd: Optional[int] = FieldInfo(alias="enemyAbd", default=None)
    """Number of enemy combatants abducted in the activity."""

    enemy_det: Optional[int] = FieldInfo(alias="enemyDet", default=None)
    """Number of enemy combatants detained in the activity."""

    enemy_kia: Optional[int] = FieldInfo(alias="enemyKIA", default=None)
    """Number of enemy combatants killed in the activity."""

    event_description: Optional[str] = FieldInfo(alias="eventDescription", default=None)
    """A description of the event."""

    event_end: Optional[datetime] = FieldInfo(alias="eventEnd", default=None)
    """The approximate end time of the event, in ISO 8601 UTC format."""

    event_start: Optional[datetime] = FieldInfo(alias="eventStart", default=None)
    """The approximate start time of the event, in ISO 8601 UTC format."""

    event_type: Optional[str] = FieldInfo(alias="eventType", default=None)
    """The type of event (e.g. Military, Natural, Political, Social, etc.)."""

    filesize: Optional[int] = None
    """Size of the associated text file.

    Units in bytes. If filesize is provided without an associated file, it defaults
    to 0.
    """

    friendly_abd: Optional[int] = FieldInfo(alias="friendlyAbd", default=None)
    """Number of friendlies abducted in the activity."""

    friendly_det: Optional[int] = FieldInfo(alias="friendlyDet", default=None)
    """Number of friendlies in the activity."""

    friendly_kia: Optional[int] = FieldInfo(alias="friendlyKIA", default=None)
    """Number of friendlies killed in the activity."""

    friendly_wound: Optional[int] = FieldInfo(alias="friendlyWound", default=None)
    """Number of friendlies wounded in the activity."""

    goldstein: Optional[float] = None
    """
    Each CAMEO event code is assigned a numeric score from -10 to +10, capturing the
    theoretical potential impact that type of event will have on the stability of a
    country. This is known as the Goldstein Scale. NOTE: this score is based on the
    type of event, not the specifics of the actual event record being recorded thus
    two riots, one with 10 people and one with 10,000, will both receive the same
    Goldstein score. This can be aggregated to various levels of time resolution to
    yield an approximation of the stability of a location over time.
    """

    has_attachment: Optional[bool] = FieldInfo(alias="hasAttachment", default=None)
    """Flag indicating this SigAct record has an associated txt file stored in the UDL.

    Retrieve the txt file by using the GET/udl/sigact/getFile/{id} where id is the
    same as the SigAct record id. The maximum file size for this service is
    10,000,000 bytes (10MB). Files exceeding the maximum size will be rejected.
    """

    host_nat_abd: Optional[int] = FieldInfo(alias="hostNatAbd", default=None)
    """Number of Host Nation members abducted in the activity."""

    host_nat_det: Optional[int] = FieldInfo(alias="hostNatDet", default=None)
    """Number of Host Nation members detained in the activity."""

    host_nat_kia: Optional[int] = FieldInfo(alias="hostNatKIA", default=None)
    """Number of Host Nation members killed in the activity."""

    host_nat_wound: Optional[int] = FieldInfo(alias="hostNatWound", default=None)
    """Number of Host Nation members wounded in the activity."""

    id_number: Optional[str] = FieldInfo(alias="idNumber", default=None)
    """
    Unique identifier assigned to each event record that uniquely identifies it in
    the master dataset. This ID is provided for convenience of mapping to external
    systems.
    """

    lat: Optional[float] = None
    """WGS-84 centroid latitude of the event location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: Optional[float] = None
    """WGS-84 centroid longitude of the event location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    milgrid: Optional[str] = None
    """
    The Military Grid Reference System is the geocoordinate standard used by NATO
    militaries for locating points on Earth. The MGRS is derived from the Universal
    Transverse Mercator (UTM) grid system and the Universal Polar Stereographic
    (UPS) grid system, but uses a different labeling convention. The MGRS is used as
    geocode for the entire Earth. Example of an milgrid coordinate, or grid
    reference, would be 4QFJ12345678, which consists of three parts:

    &nbsp;&nbsp;4Q (grid zone designator, GZD)

    &nbsp;&nbsp;FJ (the 100,000-meter square identifier)

    &nbsp;&nbsp;12345678 (numerical location; easting is 1234 and northing is 5678,
    in this case specifying a location with 10 m resolution).
    """

    notes: Optional[str] = None
    """Notes related to the documents or event."""

    num_articles: Optional[int] = FieldInfo(alias="numArticles", default=None)
    """
    This is the total number of source documents containing one or more mentions of
    this event during the 15 minute update in which it was first seen. This can be
    used as a method of assessing the importance of an event: the more discussion of
    that event, the more likely it is to be significant.
    """

    num_mentions: Optional[int] = FieldInfo(alias="numMentions", default=None)
    """
    This is the total number of mentions of this event across all source documents
    during the 15 minute update in which it was first seen. Multiple references to
    an event within a single document also contribute to this count. This can be
    used as a method of assessing the importance of an event: the more discussion of
    that event, the more likely it is to be significant.
    """

    num_sources: Optional[int] = FieldInfo(alias="numSources", default=None)
    """
    This is the total number of information sources containing one or more mentions
    of this event during the 15 minute update in which it was first seen. This can
    be used as a method of assessing the importance of an event: the more discussion
    of that event, the more likely it is to be significant.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    province: Optional[str] = None
    """The province in which this event occurred."""

    related_docs: Optional[List[SigactListResponseItemRelatedDoc]] = FieldInfo(alias="relatedDocs", default=None)
    """Related document ids."""

    rep_unit: Optional[str] = FieldInfo(alias="repUnit", default=None)
    """The reporting unit."""

    rep_unit_activity: Optional[str] = FieldInfo(alias="repUnitActivity", default=None)
    """The activity the unit was engaged in."""

    rep_unit_type: Optional[str] = FieldInfo(alias="repUnitType", default=None)
    """The reporting unit type."""

    side_a_abd: Optional[int] = FieldInfo(alias="sideAAbd", default=None)
    """Number of side A members abducted in the activity."""

    side_a_det: Optional[int] = FieldInfo(alias="sideADet", default=None)
    """Number of side A members detained in the activity."""

    side_akia: Optional[int] = FieldInfo(alias="sideAKIA", default=None)
    """Number of side A members killed in the activity."""

    side_a_wound: Optional[int] = FieldInfo(alias="sideAWound", default=None)
    """Number of side A members wounded in the activity."""

    side_b_abd: Optional[int] = FieldInfo(alias="sideBAbd", default=None)
    """Number of side B members abducted in the activity."""

    side_b_det: Optional[int] = FieldInfo(alias="sideBDet", default=None)
    """Number of side B members detained in the activity."""

    side_bkia: Optional[int] = FieldInfo(alias="sideBKIA", default=None)
    """Number of side B members killed in the activity."""

    side_b_wound: Optional[int] = FieldInfo(alias="sideBWound", default=None)
    """Number of side B members wounded in the activity."""

    source_language: Optional[str] = FieldInfo(alias="sourceLanguage", default=None)
    """
    The source language of the significant event using the ISO 639-3, 3 character
    code definition.
    """

    source_url: Optional[str] = FieldInfo(alias="sourceUrl", default=None)
    """
    This field records the URL or citation of the first news report it found this
    event in. In most cases this is the first report it saw the article in, but due
    to the timing and flow of news reports through the processing pipeline, this may
    not always be the very first report, but is at least in the first few reports.
    """

    summary: Optional[str] = None
    """A summary of the event."""

    target: Optional[str] = None
    """The name of the target.

    The target may be an individual, an entity, or a country/region.
    """

    theater: Optional[str] = None
    """Area in which important military events occur or are progressing.

    A theater can include the entirety of the airspace, land and sea area that is or
    that may potentially become involved in war operations.
    """

    type_of_attack: Optional[str] = FieldInfo(alias="typeOfAttack", default=None)
    """The mode of this attack or event (e.g. Direct Fire, IED Explosion, etc.)."""


SigactListResponse: TypeAlias = List[SigactListResponseItem]
