# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import date
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .entity_ingest_param import EntityIngestParam

__all__ = ["SiteUpdateParams"]


class SiteUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: Required[str]
    """The name of this site."""

    source: Required[str]
    """Source of the data."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    activity: str
    """
    Indicates the function or mission of an entity, which that entity may or may not
    be engaged in at any particular time. Typically refers to a unit, organization,
    or installation/site performing a specific function or mission such as a
    redistribution center or naval shipyard. The specific usage and enumerations
    contained in this field may be found in the documentation provided in the
    referenceDoc field. If referenceDoc not provided, users may consult the data
    provider.
    """

    air_def_area: Annotated[str, PropertyInfo(alias="airDefArea")]
    """
    Air Defense District (ADD) or Air Defense Area (ADA) in which the geographic
    coordinates reside.
    """

    allegiance: str
    """
    The DoD Standard Country Code designator for the country or political entity to
    which the site owes its allegiance. This field will be set to "OTHR" if the
    source value does not match a UDL Country code value (ISO-3166-ALPHA-2).
    """

    alt_allegiance: Annotated[str, PropertyInfo(alias="altAllegiance")]
    """
    Specifies an alternate allegiance code if the data provider code is not part of
    an official Country Code standard such as ISO-3166 or FIPS. This field will be
    set to the value provided by the source and should be used for all Queries
    specifying allegiance.
    """

    be_number: Annotated[str, PropertyInfo(alias="beNumber")]
    """The Basic Encyclopedia Number associated with the Site.

    Uniquely identifies the installation of a site. The beNumber is generated based
    on the value input for the COORD to determine the appropriate World Aeronautical
    Chart (WAC) location identifier, the system assigned record originator and a
    one-up-number.
    """

    cat_code: Annotated[str, PropertyInfo(alias="catCode")]
    """
    The category code that represents the associated site purpose within the target
    system.
    """

    cat_text: Annotated[str, PropertyInfo(alias="catText")]
    """Textual Description of Site catCode."""

    class_rating: Annotated[str, PropertyInfo(alias="classRating")]
    """Indicates the importance of the entity to the OES or MIR system.

    This data element is restricted to update by DIA (DB-4). Valid values are:

    0 - Does not meet criteria above

    1 - Primary importance to system

    2 - Secondary importance to system

    3 - Tertiary importance to system

    O - Other. Explain in Remarks.
    """

    condition: str
    """The physical manner of being or state of existence of the entity.

    A physical condition that must be considered in the determining of a course of
    action. The specific usage and enumerations contained in this field may be found
    in the documentation provided in the referenceDoc field. If referenceDoc not
    provided, users may consult the data provider.
    """

    condition_avail: Annotated[str, PropertyInfo(alias="conditionAvail")]
    """Availability of the entity relative to its condition.

    Indicates the reason the entity is not fully operational. The specific usage and
    enumerations contained in this field may be found in the documentation provided
    in the referenceDoc field. If referenceDoc not provided, users may consult the
    data provider.
    """

    coord: str
    """
    Indicates any of the magnitudes that serve to define the position of a point by
    reference to a fixed figure, system of lines, etc.

    Pos. 1-2. Latitude Degrees [00-90]

    Pos. 3-4. Latitude Minutes [00-59]

    Pos. 5-6. Latitude Seconds [00-59]

    Pos. 7-9. Latitude Thousandths Of Seconds [000-999]

    Pos. 10. Latitude Hemisphere [NS]

    Pos. 11-13. Longitude Degrees [00-180]

    Pos. 14-15. Longitude Minutes [00-59]

    Pos. 16-17. Longitude Seconds [00-59]

    Pos. 18-20. Longitude Thousandths Of Seconds [000-999]

    Pos. 21. Longitude Hemisphere [EW]

    Pos. 1-21. Unknown Latitude and Unknown Longitude [000000000U000000000U].
    """

    coord_datum: Annotated[str, PropertyInfo(alias="coordDatum")]
    """A mathematical model of the earth used to calculate coordinates on a map.

    US Forces use the World Geodetic System 1984 (WGS 84), but also use maps by
    allied countries with local datums. The datum must be specified to ensure
    accuracy of coordinates. The specific usage and enumerations contained in this
    field may be found in the documentation provided in the referenceDoc field. If
    referenceDoc not provided, users may consult the data provider.
    """

    coord_deriv_acc: Annotated[float, PropertyInfo(alias="coordDerivAcc")]
    """
    Indicates the plus or minus error assessed against the method used to derive the
    coordinate.
    """

    elev_msl: Annotated[float, PropertyInfo(alias="elevMsl")]
    """
    Ground elevation of the geographic coordinates referenced to (above or below)
    Mean Sea Level (MSL) vertical datum, in meters.
    """

    elev_msl_conf_lvl: Annotated[int, PropertyInfo(alias="elevMslConfLvl")]
    """
    Indicates the confidence level expressed as a percent that a specific geometric
    spatial element, ELEVATION_MSL linear accuracy, has been vertically positioned
    to within a specified vertical accuracy.
    """

    elev_msl_deriv_acc: Annotated[float, PropertyInfo(alias="elevMslDerivAcc")]
    """
    Indicates the plus or minus error assessed against the method used to derive the
    elevation.
    """

    entity: EntityIngestParam
    """
    An entity is a generic representation of any object within a space/SSA system
    such as sensors, on-orbit objects, RF Emitters, space craft buses, etc. An
    entity can have an operating unit, a location (if terrestrial), and statuses.
    """

    eval: int
    """
    Eval represents the Intelligence Confidence Level or the Reliability/degree of
    confidence that the analyst has assigned to the data within this record. The
    numerical range is from 1 to 9 with 1 representing the highest confidence level.
    """

    faa: str
    """
    The Federal Aviation Administration (FAA) Location ID of this site, if
    applicable.
    """

    fpa: str
    """Functional Production Area (FPA) under the Shared Production Program (SPP).

    Producers are defined per country per FPA. The specific usage and enumerations
    contained in this field may be found in the documentation provided in the
    referenceDoc field. If referenceDoc not provided, users may consult the data
    provider.
    """

    funct_primary: Annotated[str, PropertyInfo(alias="functPrimary")]
    """Principal operational function being performed.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    geo_area: Annotated[str, PropertyInfo(alias="geoArea")]
    """
    Geographical region code used by the Requirements Management System (RMS) as
    specified by National Geospatial Agency (NGA) in Flight Information Publications
    (FIPS) 10-4, Appendix 3 - Country Code and Geographic Region Codes. The specific
    usage and enumerations contained in this field may be found in the documentation
    provided in the referenceDoc field. If referenceDoc not provided, users may
    consult the data provider.
    """

    geoidal_msl_sep: Annotated[float, PropertyInfo(alias="geoidalMslSep")]
    """The distance between Mean Sea Level and a referenced ellipsoid, in meters."""

    grade: int
    """
    Indicates the amount or degree of deviation from the horizontal represented as a
    percent. Grade is determined by the formula: vertical distance (VD) divided by
    horizontal distance (HD) times 100. VD is the difference between the highest and
    lowest elevation within the entity. HD is the linear distance between the
    highest and lowest elevation.
    """

    iata: str
    """
    The International Air Transport Association (IATA) code of this site, if
    applicable.
    """

    icao: str
    """
    The International Civil Aviation Organization (ICAO) code of this site, if
    applicable.
    """

    ident: str
    """
    Estimated identity of the Site (ASSUMED FRIEND, FRIEND, HOSTILE, FAKER, JOKER,
    NEUTRAL, PENDING, SUSPECT, UNKNOWN):

    ASSUMED FRIEND: Track assumed to be a friend due to the object characteristics,
    behavior, and/or origin.

    FRIEND: Track object supporting friendly forces and belonging to a declared
    friendly nation or entity.

    HOSTILE: Track object belonging to an opposing nation, party, group, or entity
    deemed to contribute to a threat to friendly forces or their mission due to its
    behavior, characteristics, nationality, or origin.

    FAKER: Friendly track, object, or entity acting as an exercise hostile.

    JOKER: Friendly track, object, or entity acting as an exercise suspect.

    NEUTRAL: Track object whose characteristics, behavior, nationality, and/or
    origin indicate that it is neither supporting nor opposing friendly forces or
    their mission.

    PENDING: Track object which has not been evaluated.

    SUSPECT: Track object deemed potentially hostile due to the object
    characteristics, behavior, nationality, and/or origin.

    UNKNOWN: Track object which has been evaluated and does not meet criteria for
    any standard identity.
    """

    id_entity: Annotated[str, PropertyInfo(alias="idEntity")]
    """Unique identifier of the parent entity. idEntity is required for Put."""

    id_parent_site: Annotated[str, PropertyInfo(alias="idParentSite")]
    """Unique identifier of the Parent Site record associated with this Site record."""

    lz_usage: Annotated[str, PropertyInfo(alias="lzUsage")]
    """Indicates the normal usage of the Landing Zone (LZ).

    Intended as, but not constrained to MIDB Helocopter Landing Area usage value
    definitions:

    AF - Airfield

    FD - Field

    HC - High Crop. 1 meter and over.

    HY - Highway

    LB - Lake Bed

    LC - Low Crop. 0-1 meters

    O - Other. Explain In Remarks.

    PD - Paddy

    PK - Park

    PS - Pasture

    RB - Riverbed

    SP - Sport Field

    U - Unknown

    Z - Inconclusive Analysis.
    """

    max_runway_length: Annotated[int, PropertyInfo(alias="maxRunwayLength")]
    """The length of the longest runway at this site, if applicable, in meters."""

    mil_grid: Annotated[str, PropertyInfo(alias="milGrid")]
    """
    The Military Grid Reference System is the geocoordinate standard used by NATO
    militaries for locating points on Earth. The MGRS is derived from the Universal
    Transverse Mercator (UTM) grid system and the Universal Polar Stereographic
    (UPS) grid system, but uses a different labeling convention. The MGRS is used as
    geocode for the entire Earth. Example of an milgrid coordinate, or grid
    reference, would be 4QFJ12345678, which consists of three parts:

    4Q (grid zone designator, GZD)

    FJ (the 100,000-meter square identifier)

    12345678 (numerical location; easting is 1234 and northing is 5678, in this case
    specifying a location with 10 m resolution).
    """

    mil_grid_sys: Annotated[str, PropertyInfo(alias="milGridSys")]
    """Indicates the grid system used in the development of the milGrid coordinates.

    Values are:

    UPS - Universal Polar System

    UTM - Universal Transverse Mercator.
    """

    msn_primary: Annotated[str, PropertyInfo(alias="msnPrimary")]
    """
    Indicates the principal type of mission that an entity is organized and equipped
    to perform. The specific usage and enumerations contained in this field may be
    found in the documentation provided in the referenceDoc field. If referenceDoc
    not provided, users may consult the data provider.
    """

    msn_primary_spec: Annotated[str, PropertyInfo(alias="msnPrimarySpec")]
    """
    Indicates the principal specialty type of mission that an entity is organized
    and equipped to perform. The specific usage and enumerations contained in this
    field may be found in the documentation provided in the referenceDoc field. If
    referenceDoc not provided, users may consult the data provider.
    """

    notes: str
    """Optional notes/comments for the site."""

    nuc_cap: Annotated[str, PropertyInfo(alias="nucCap")]
    """A sites ability to conduct nuclear warfare. Valid Values are:

    A - Nuclear Ammo Or Warheads Available

    N - No Nuclear Offense

    O - Other. Explain in Remarks

    U - Unknown

    W - Nuclear Weapons Available

    Y - Nuclear Warfare Offensive Capability

    Z - Inconclusive Analysis.
    """

    oper_status: Annotated[str, PropertyInfo(alias="operStatus")]
    """
    The Degree to which an entity is ready to perform the overall operational
    mission(s) for which it was organized and equipped. The specific usage and
    enumerations contained in this field may be found in the documentation provided
    in the referenceDoc field. If referenceDoc not provided, users may consult the
    data provider.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_lz_id: Annotated[str, PropertyInfo(alias="origLzId")]
    """Unique identifier of the LZ record from the originating system."""

    orig_site_id: Annotated[str, PropertyInfo(alias="origSiteID")]
    """Unique identifier of the Site record from the originating system."""

    osuffix: str
    """The O-suffix associated with this site.

    The O-suffix is a five-character alpha/numeric system used to identify a site,
    or demographic area, within an installation. The Installation Basic Encyclopedia
    (beNumber), in conjunction with the O-suffix, uniquely identifies the Site. The
    Installation beNumber and oSuffix are also used in conjunction with the catCode
    to classify the function or purpose of the facility.
    """

    pin: str
    """Site number of a specific electronic site or its associated equipment."""

    pol_subdiv: Annotated[str, PropertyInfo(alias="polSubdiv")]
    """Political subdivision in which the geographic coordinates reside.

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    pop_area: Annotated[bool, PropertyInfo(alias="popArea")]
    """Indicates whether the facility is in or outside of a populated area.

    True, the facility is in or within 5 NM of a populated area. False, the facility
    is outside a populated area.
    """

    pop_area_prox: Annotated[float, PropertyInfo(alias="popAreaProx")]
    """
    Indicates the distance to nearest populated area (over 1,000 people) in nautical
    miles.
    """

    rec_status: Annotated[str, PropertyInfo(alias="recStatus")]
    """
    Validity and currency of the data in the record to be used in conjunction with
    the other elements in the record as defined by SOPs.

    A - Active

    I - Inactive

    K - Acknowledged

    L - Local

    Q - A nominated (NOM) or Data Change Request (DCR) record

    R - Production reduced by CMD decision

    W - Working Record.
    """

    reference_doc: Annotated[str, PropertyInfo(alias="referenceDoc")]
    """
    The reference documentation that specifies the usage and enumerations contained
    in this record. If referenceDoc not provided, users may consult the data
    provider.
    """

    res_prod: Annotated[str, PropertyInfo(alias="resProd")]
    """
    Responsible Producer - Organization that is responsible for the maintenance of
    the record.
    """

    review_date: Annotated[Union[str, date], PropertyInfo(alias="reviewDate", format="iso8601")]
    """
    Date on which the data in the record was last reviewed by the responsible
    analyst for accuracy and currency, in ISO8601 UTC format. This date cannot be
    greater than the current date.
    """

    runways: int
    """The number of runways at the site, if applicable."""

    sym_code: Annotated[str, PropertyInfo(alias="symCode")]
    """
    A standard scheme for symbol coding enabling the transfer, display and use of
    symbols and graphics among information systems, as per MIL-STD 2525B, and
    supported by the element ident.
    """

    type: str
    """The type of this site (AIRBASE, AIRFIELD, AIRPORT, NAVAL STATION, etc.)."""

    usage: str
    """The use authorization type of this site (e.g MILITARY, CIVIL, JOINT-USE, etc.)."""

    utm: str
    """Universal Transverse Mercator (UTM) grid coordinates.

    Pos. 1-2, UTM Zone Column [01-60

    Pos. 3, UTM Zone Row [C-HJ-NP-X]

    Pos. 4, UTM False Easting [0-9]

    Pos. 5-9, UTM Meter Easting [0-9][0-9][0-9][0-9][0-9]

    Pos. 10-11, UTM False Northing [0-9][0-9]

    Pos. 12-16, UTM Meter Northing [0-9][0-9][0-9][0-9][0-9].
    """

    veg_ht: Annotated[float, PropertyInfo(alias="vegHt")]
    """Maximum expected height of the vegetation in the Landing Zone (LZ), in meters."""

    veg_type: Annotated[str, PropertyInfo(alias="vegType")]
    """The predominant vegetation found in the Landing Zone (LZ).

    The specific usage and enumerations contained in this field may be found in the
    documentation provided in the referenceDoc field. If referenceDoc not provided,
    users may consult the data provider.
    """

    wac: str
    """
    World Aeronautical Chart identifier for the area in which a designated place is
    located.
    """
