# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["SortiePprFull"]


class SortiePprFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_sortie: str = FieldInfo(alias="idSortie")
    """
    Unique identifier of the Aircraft Sortie associated with this prior permission
    required (PPR) record.
    """

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    end_time: Optional[datetime] = FieldInfo(alias="endTime", default=None)
    """
    Time the prior permission required (PPR) valid window ends, in ISO 8601 UTC
    format with millisecond precision.
    """

    external_id: Optional[str] = FieldInfo(alias="externalId", default=None)
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    grantor: Optional[str] = None
    """Identifier of the prior permission required (PPR) grantor."""

    number: Optional[str] = None
    """The prior permission required (PPR) number issued by the airfield for a sortie."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    remarks: Optional[str] = None
    """Remarks concerning the prior permission required (PPR) for a sortie."""

    requestor: Optional[str] = None
    """The username of the prior permission required (PPR) requestor."""

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    start_time: Optional[datetime] = FieldInfo(alias="startTime", default=None)
    """
    Time the prior permission required (PPR) valid window begins, in ISO 8601 UTC
    format with millisecond precision.
    """

    type: Optional[Literal["M", "C"]] = None
    """
    Type of prior permission required (PPR) for a sortie (M - Military or C -
    Civilian). Enum: [M, C].
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """
