# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SortiepprUnvalidatedPublishParams", "Body"]


class SortiepprUnvalidatedPublishParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_sortie: Required[Annotated[str, PropertyInfo(alias="idSortie")]]
    """
    Unique identifier of the Aircraft Sortie associated with this prior permission
    required (PPR) record.
    """

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    end_time: Annotated[Union[str, datetime], PropertyInfo(alias="endTime", format="iso8601")]
    """
    Time the prior permission required (PPR) valid window ends, in ISO 8601 UTC
    format with millisecond precision.
    """

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    grantor: str
    """Identifier of the prior permission required (PPR) grantor."""

    number: str
    """The prior permission required (PPR) number issued by the airfield for a sortie."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    remarks: str
    """Remarks concerning the prior permission required (PPR) for a sortie."""

    requestor: str
    """The username of the prior permission required (PPR) requestor."""

    start_time: Annotated[Union[str, datetime], PropertyInfo(alias="startTime", format="iso8601")]
    """
    Time the prior permission required (PPR) valid window begins, in ISO 8601 UTC
    format with millisecond precision.
    """

    type: Literal["M", "C"]
    """
    Type of prior permission required (PPR) for a sortie (M - Military or C -
    Civilian). Enum: [M, C].
    """
