# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SpaceenvobservationCreateBulkParams", "Body", "BodySeoList"]


class SpaceenvobservationCreateBulkParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class BodySeoList(TypedDict, total=False):
    ob_type: Required[Annotated[str, PropertyInfo(alias="obType")]]
    """The type of observation associated with this record."""

    ob_uo_m: Required[Annotated[str, PropertyInfo(alias="obUoM")]]
    """The Unit of Measure associated with this observation.

    If there are no physical units associated with the measurement, a value of NONE
    should be specified.
    """

    ob_array: Annotated[Iterable[float], PropertyInfo(alias="obArray")]
    """
    An array of observation values expressed in the specified unit of measure
    (obUoM). Because of the variability of the Space Environment data types, each
    record may employ a numeric observation value (obValue), a string observation
    value (obString), a Boolean observation value (obBool), an array of numeric
    observation values (obArray), or any combination of these.
    """

    ob_bool: Annotated[bool, PropertyInfo(alias="obBool")]
    """A Boolean observation.

    Because of the variability of the Space Environment data types, each record may
    employ a numeric observation value (obValue), a string observation value
    (obString), a Boolean observation value (obBool), an array of numeric
    observation values (obArray), or any combination of these.
    """

    ob_description: Annotated[str, PropertyInfo(alias="obDescription")]
    """
    Descriptive or additional information associated with this individual
    observation.
    """

    ob_quality: Annotated[str, PropertyInfo(alias="obQuality")]
    """The quality of this individual observation.

    The observation quality indicator value may vary among providers and may be a
    generalized statement (BAD, GOOD, UNCERTAIN, UNKNOWN) or a numeric value. Users
    should consult the data provider to verify the usage of the observation.
    """

    ob_string: Annotated[str, PropertyInfo(alias="obString")]
    """A single observation string expressed in the specified unit of measure (obUoM).

    Because of the variability of the Space Environment data types, each record may
    employ a numeric observation value (obValue), a string observation value
    (obString), a Boolean observation value (obBool), an array of numeric
    observation values (obArray), or any combination of these.
    """

    ob_value: Annotated[float, PropertyInfo(alias="obValue")]
    """A single observation value expressed in the specified unit of measure (obUoM).

    Because of the variability of the Space Environment data types, each record may
    employ a numeric observation value (obValue), a string observation value
    (obString), a Boolean observation value (obBool), an array of numeric
    observation values (obArray), or any combination of these.
    """


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    ob_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="obTime", format="iso8601")]]
    """Time of the observation, in ISO 8601 UTC format with millisecond precision."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    alt: float
    """
    Spacecraft/sensor altitude at observation time, expressed in kilometers above
    WGS-84 ellipsoid.
    """

    data_type: Annotated[str, PropertyInfo(alias="dataType")]
    """The data type (e.g.

    AP, AURORAL FLUX, ECP, KINDEX, PROPAGATED SOLAR WIND, XRAY FLUX, etc.) of
    observations in this record.
    """

    derived: bool
    """Flag indicating that this record contains derived data."""

    description: str
    """Descriptive or additional information associated with this observation record."""

    descriptor: str
    """Optional source-provided and searchable metadata or descriptor of the data."""

    external_id: Annotated[str, PropertyInfo(alias="externalId")]
    """Optional ID from external systems.

    This field has no meaning within UDL and is provided as a convenience for
    systems that require tracking of an internal system generated ID.
    """

    forecast: bool
    """Flag indicating that this record contains forecast data."""

    gen_system: Annotated[str, PropertyInfo(alias="genSystem")]
    """The external system which generated the message, if applicable."""

    gen_time: Annotated[Union[str, datetime], PropertyInfo(alias="genTime", format="iso8601")]
    """
    The time at which the associated data message was generated, in ISO 8601 UTC
    format with millisecond precision.
    """

    id_sensor: Annotated[str, PropertyInfo(alias="idSensor")]
    """Unique identifier of the reporting sensor."""

    instrument_type: Annotated[str, PropertyInfo(alias="instrumentType")]
    """The type of instrument from which this data was collected (e.g.

    ANTENNA, CHANNELTRON, INTERFEROMETER, MAGNETOMETER, RADIOMETER, etc.).
    """

    lat: float
    """
    WGS-84 spacecraft/sensor latitude sub-point at observation time, represented as
    -90 to 90 degrees (negative values south of equator).
    """

    lon: float
    """
    WGS-84 spacecraft/sensor longitude sub-point at observation time, represented as
    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    meas_type: Annotated[str, PropertyInfo(alias="measType")]
    """The sensor measurement type of the observation data contained in this record."""

    msg_type: Annotated[str, PropertyInfo(alias="msgType")]
    """The type of message associated with this record."""

    observatory_name: Annotated[str, PropertyInfo(alias="observatoryName")]
    """The name of the observatory from which this data was collected."""

    observatory_notes: Annotated[str, PropertyInfo(alias="observatoryNotes")]
    """Additional notes concerning the observatory."""

    observatory_type: Annotated[str, PropertyInfo(alias="observatoryType")]
    """The type of observatory from which this data was collected (e.g.

    FACILITY, ONORBIT, NETWORK, etc.).
    """

    ob_set_id: Annotated[str, PropertyInfo(alias="obSetId")]
    """A user-defined name or ID of a set of observations, if applicable.

    Used for identifying multiple observation records as part of one observation
    set.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_object_id: Annotated[str, PropertyInfo(alias="origObjectId")]
    """
    Optional identifier provided by the record source to indicate the satellite
    hosting the sensor which produced this data. This may be an internal identifier
    and not necessarily map to a valid satellite number.
    """

    orig_sensor_id: Annotated[str, PropertyInfo(alias="origSensorId")]
    """
    Optional identifier provided by the observation source to indicate the sensor
    which produced this observation. This may be an internal identifier and not
    necessarily a valid sensor ID.
    """

    particle_type: Annotated[str, PropertyInfo(alias="particleType")]
    """
    The particle type (AEROSOL, ALPHA PARTICLE, ATOM, DUST, ELECTRON, ION, MOLECULE,
    NEUTRON, POSITRON, PROTON) associated with this measurement.
    """

    quality: str
    """The quality of the overall data contained in this record.

    The quality indicator value may vary among providers and may be a generalized
    statement (BAD, GOOD, UNCERTAIN, UNKNOWN) or a numeric value. Users should
    consult the data provider to verify the usage of the quality indicator.
    """

    sat_no: Annotated[int, PropertyInfo(alias="satNo")]
    """
    Satellite/catalog number of the on-orbit satellite hosting the sensor which
    produced this data.
    """

    sen_energy_level: Annotated[str, PropertyInfo(alias="senEnergyLevel")]
    """The energy level bin of the sensor associated with this measurement."""

    sen_pos: Annotated[Iterable[float], PropertyInfo(alias="senPos")]
    """
    Three element array, expressing the observing spacecraft/sensor position vector
    components at observation time, in kilometers, in the specified
    senReferenceFrame. If senReferenceFrame is null then J2000 should be assumed.
    The array element order is [xpos, ypos, zpos].
    """

    sen_reference_frame: Annotated[
        Literal["J2000", "EFG/TDR", "ECR/ECEF", "TEME", "ITRF", "GCRF"], PropertyInfo(alias="senReferenceFrame")
    ]
    """The reference frame of the observing spacecraft/sensor state.

    If the senReferenceFrame is null it is assumed to be J2000.
    """

    sen_vel: Annotated[Iterable[float], PropertyInfo(alias="senVel")]
    """
    Three element array, expressing the observing spacecraft/sensor velocity vector
    components at observation time, in kilometers/second, in the specified
    senReferenceFrame. If senReferenceFrame is null then J2000 should be assumed.
    The array element order is [xvel, yvel, zvel].
    """

    seo_list: Annotated[Iterable[BodySeoList], PropertyInfo(alias="seoList")]
    """A collection of individual space environment observations."""

    src_ids: Annotated[List[str], PropertyInfo(alias="srcIds")]
    """
    Array of UUIDs of the UDL data records that are related to this observation
    record. See the associated 'srcTyps' array for specific types of data,
    positionally corresponding to the UUIDs in this array. The 'srcTyps' and
    'srcIds' arrays must match in size. See the corresponding srcTyps array element
    of the data type of the UUID and use the appropriate API operation to retrieve
    that object.
    """

    src_typs: Annotated[List[str], PropertyInfo(alias="srcTyps")]
    """
    Array of UDL record types (AIS, CONJUNCTION, DOA, ELSET, EO, ESID, GROUNDIMAGE,
    POI, MANEUVER, MTI, NOTIFICATION, RADAR, RF, SGI, SIGACT, SKYIMAGE, SPACEENVOB,
    SV, TRACK) that are related to this observation record. See the associated
    'srcIds' array for the record UUIDs, positionally corresponding to the record
    types in this array. The 'srcTyps' and 'srcIds' arrays must match in size.
    """
