# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .engine import Engine
from .._models import BaseModel

__all__ = ["StageTupleResponse", "StageTupleResponseItem"]


class StageTupleResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_engine: str = FieldInfo(alias="idEngine")
    """Identifier of the Engine record for this stage."""

    id_launch_vehicle: str = FieldInfo(alias="idLaunchVehicle")
    """Identifier of the launch vehicle record for this stage."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    avionics_notes: Optional[str] = FieldInfo(alias="avionicsNotes", default=None)
    """Description/notes of the stage avionics."""

    burn_time: Optional[float] = FieldInfo(alias="burnTime", default=None)
    """Total burn time of the stage engines in seconds."""

    control_thruster1: Optional[str] = FieldInfo(alias="controlThruster1", default=None)
    """Control thruster 1 type."""

    control_thruster2: Optional[str] = FieldInfo(alias="controlThruster2", default=None)
    """Control thruster 2 type."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    diameter: Optional[float] = None
    """Stage maximum external diameter in meters."""

    engine: Optional[Engine] = None
    """Known launch vehicle engines and their performance characteristics and limits.

    A launch vehicle has 1 to many engines per stage.
    """

    length: Optional[float] = None
    """Stage length in meters."""

    main_engine_thrust_sea_level: Optional[float] = FieldInfo(alias="mainEngineThrustSeaLevel", default=None)
    """Thrust of the stage main engine at sea level in kN."""

    main_engine_thrust_vacuum: Optional[float] = FieldInfo(alias="mainEngineThrustVacuum", default=None)
    """Thrust of the stage main engine in a vacuum in kN."""

    manufacturer_org_id: Optional[str] = FieldInfo(alias="manufacturerOrgId", default=None)
    """ID of the organization that manufactures this launch stage."""

    mass: Optional[float] = None
    """Stage gross mass in kg."""

    notes: Optional[str] = None
    """Description/notes of the stage."""

    num_burns: Optional[int] = FieldInfo(alias="numBurns", default=None)
    """Number of burns for the stage engines."""

    num_control_thruster1: Optional[int] = FieldInfo(alias="numControlThruster1", default=None)
    """Number of type control thruster 1."""

    num_control_thruster2: Optional[int] = FieldInfo(alias="numControlThruster2", default=None)
    """Number of type control thruster 2."""

    num_engines: Optional[int] = FieldInfo(alias="numEngines", default=None)
    """The number of the specified engines on this launch stage."""

    num_stage_elements: Optional[int] = FieldInfo(alias="numStageElements", default=None)
    """Number of launch stage elements used in this stage."""

    num_vernier: Optional[int] = FieldInfo(alias="numVernier", default=None)
    """Number of vernier or additional engines."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    photo_urls: Optional[List[str]] = FieldInfo(alias="photoURLs", default=None)
    """Array of URLs of photos of the stage."""

    restartable: Optional[bool] = None
    """Boolean indicating if this launch stage can be restarted."""

    reusable: Optional[bool] = None
    """Boolean indicating if this launch stage is reusable."""

    stage_number: Optional[int] = FieldInfo(alias="stageNumber", default=None)
    """The stage number of this launch stage."""

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    thrust_sea_level: Optional[float] = FieldInfo(alias="thrustSeaLevel", default=None)
    """Total thrust of the stage at sea level in kN."""

    thrust_vacuum: Optional[float] = FieldInfo(alias="thrustVacuum", default=None)
    """Total thrust of the stage in a vacuum in kN."""

    type: Optional[str] = None
    """Engine cycle type (e.g.

    Electrostatic Ion, Pressure Fed, Hall, Catalytic Decomposition, etc.).
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    vernier: Optional[str] = None
    """Engine vernier or additional engine type."""

    vernier_burn_time: Optional[float] = FieldInfo(alias="vernierBurnTime", default=None)
    """Total burn time of the vernier or additional stage engines in seconds."""

    vernier_num_burns: Optional[int] = FieldInfo(alias="vernierNumBurns", default=None)
    """Total number of burns of the vernier or additional stage engines."""

    vernier_thrust_sea_level: Optional[float] = FieldInfo(alias="vernierThrustSeaLevel", default=None)
    """Total thrust of one of the vernier or additional engines at sea level in kN."""

    vernier_thrust_vacuum: Optional[float] = FieldInfo(alias="vernierThrustVacuum", default=None)
    """Total thrust of one of the vernier or additional engines in a vacuum in kN."""


StageTupleResponse: TypeAlias = List[StageTupleResponseItem]
