# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["StarcatalogUpdateParams"]


class StarcatalogUpdateParams(TypedDict, total=False):
    astrometry_origin: Required[
        Annotated[Literal["GAIADR3", "HIPPARCOS", "USNOBSC"], PropertyInfo(alias="astrometryOrigin")]
    ]
    """Originating astrometric catalog for this object.

    Enum: [GAIADR3, HIPPARCOS, USNOBSC].
    """

    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    cs_id: Required[Annotated[int, PropertyInfo(alias="csId")]]
    """The ID of this object in the specific catalog associated with this record."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    dec: Required[float]
    """
    Barycentric declination of the source in International Celestial Reference
    System (ICRS) at the reference epoch, in degrees.
    """

    ra: Required[float]
    """
    Barycentric right ascension of the source in the International Celestial
    Reference System (ICRS) frame at the reference epoch, in degrees.
    """

    source: Required[str]
    """Source of the data."""

    star_epoch: Required[Annotated[float, PropertyInfo(alias="starEpoch")]]
    """
    Reference epoch to which the astrometric source parameters are referred,
    expressed as Julian Year in Barycentric Coordinate Time (TCB).
    """

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    bpmag: float
    """Gaia DR3 optical photometric Bp-band magnitude in the Vega scale."""

    bpmag_unc: Annotated[float, PropertyInfo(alias="bpmagUnc")]
    """Gaia DR3 optical Bp-band magnitude uncertainty in the Vega scale."""

    cat_version: Annotated[str, PropertyInfo(alias="catVersion")]
    """The version of the catalog associated with this object."""

    dec_unc: Annotated[float, PropertyInfo(alias="decUnc")]
    """
    Uncertainty of the declination of the source, in milliarcseconds, at the
    reference epoch.
    """

    gaiadr3_cat_id: Annotated[int, PropertyInfo(alias="gaiadr3CatId")]
    """The ID of this object in the Gaia DR3 Catalog."""

    gmag: float
    """Gaia DR3 optical photometric G-band magnitude in the Vega scale."""

    gmag_unc: Annotated[float, PropertyInfo(alias="gmagUnc")]
    """Gaia DR3 optical photometric G-band magnitude uncertainty in the Vega scale."""

    gnc_cat_id: Annotated[int, PropertyInfo(alias="gncCatId")]
    """The ID of this object in the Guidance and Navagation Control (GNC) Catalog."""

    hip_cat_id: Annotated[int, PropertyInfo(alias="hipCatId")]
    """The ID of this object in the Hipparcos Catalog."""

    hmag: float
    """
    Two Micron All Sky Survey (2MASS) Point Source Catalog (PSC) near-infrared
    photometric H-band magnitude in the Vega scale.
    """

    hmag_unc: Annotated[float, PropertyInfo(alias="hmagUnc")]
    """
    Two Micron All Sky Survey (2MASS) Point Source Catalog (PSC) near-infrared
    photometric H-band magnitude uncertainty in the Vega scale.
    """

    jmag: float
    """
    Two Micron All Sky Survey (2MASS) Point Source Catalog (PSC) near-infrared
    photometric J-band magnitude in the Vega scale.
    """

    jmag_unc: Annotated[float, PropertyInfo(alias="jmagUnc")]
    """
    Two Micron All Sky Survey (2MASS) Point Source Catalog (PSC) near-infrared
    photometric J-band magnitude uncertainty in the Vega scale.
    """

    kmag: float
    """
    Two Micron All Sky Survey (2MASS) Point Source Catalog (PSC) near-infrared
    photometric K-band magnitude in the Vega scale.
    """

    kmag_unc: Annotated[float, PropertyInfo(alias="kmagUnc")]
    """
    Two Micron All Sky Survey (2MASS) Point Source Catalog (PSC) near-infrared
    photometric K-band magnitude uncertainty in the Vega scale.
    """

    mult_flag: Annotated[bool, PropertyInfo(alias="multFlag")]
    """Flag indicating that this is a multiple object source."""

    neighbor_distance: Annotated[float, PropertyInfo(alias="neighborDistance")]
    """Distance between source and nearest neighbor, in arcseconds."""

    neighbor_flag: Annotated[bool, PropertyInfo(alias="neighborFlag")]
    """
    Flag indicating that the nearest catalog neighbor is closer than 4.6 arcseconds.
    """

    neighbor_id: Annotated[int, PropertyInfo(alias="neighborId")]
    """The catalog ID of the nearest neighbor to this source."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    parallax: float
    """Absolute stellar parallax of the source, in milliarcseconds."""

    parallax_unc: Annotated[float, PropertyInfo(alias="parallaxUnc")]
    """Uncertainty of the stellar parallax, in milliarcseconds."""

    pmdec: float
    """
    Proper motion in declination of the source, in milliarcseconds/year, at the
    reference epoch.
    """

    pmdec_unc: Annotated[float, PropertyInfo(alias="pmdecUnc")]
    """Uncertainty of proper motion in declination, in milliarcseconds/year."""

    pmra: float
    """
    Proper motion in right ascension of the source, in milliarcseconds/year, at the
    reference epoch.
    """

    pmra_unc: Annotated[float, PropertyInfo(alias="pmraUnc")]
    """Uncertainty of proper motion in right ascension, in milliarcseconds/year."""

    pm_unc_flag: Annotated[bool, PropertyInfo(alias="pmUncFlag")]
    """
    Flag indicating that the proper motion uncertainty in either ra or dec is
    greater than 10 milliarcseconds/year.
    """

    pos_unc_flag: Annotated[bool, PropertyInfo(alias="posUncFlag")]
    """
    Flag indicating that the position uncertainty in either ra or dec is greater
    than 100 milliarcseconds.
    """

    ra_unc: Annotated[float, PropertyInfo(alias="raUnc")]
    """
    Uncertainty of the right ascension of the source, in milliarcseconds, at the
    reference epoch.
    """

    rpmag: float
    """Gaia DR3 optical Rp-band magnitude in the Vega scale."""

    rpmag_unc: Annotated[float, PropertyInfo(alias="rpmagUnc")]
    """Gaia DR3 optical photometric Rp-band magnitude uncertainty in the Vega scale."""

    shift: float
    """Photocentric shift caused by neighbors, in arcseconds."""

    shift_flag: Annotated[bool, PropertyInfo(alias="shiftFlag")]
    """Flag indicating that the photocentric shift is greater than 50 milliarcseconds."""

    var_flag: Annotated[bool, PropertyInfo(alias="varFlag")]
    """Flag indicating that the source exhibits variable magnitude."""
