# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["StatusCreateParams", "SubStatusCollection"]


class StatusCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_entity: Required[Annotated[str, PropertyInfo(alias="idEntity")]]
    """Unique identifier of the parent entity."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    declassification_date: Annotated[Union[str, datetime], PropertyInfo(alias="declassificationDate", format="iso8601")]
    """The declassification date of this data, in ISO 8601 UTC format."""

    declassification_string: Annotated[str, PropertyInfo(alias="declassificationString")]
    """Declassification string of this data."""

    derived_from: Annotated[str, PropertyInfo(alias="derivedFrom")]
    """
    The sources or SCG references from which the classification of this data is
    derived.
    """

    notes: str
    """Comments describing the status creation and or updates to an entity."""

    ops_cap: Annotated[Literal["FMC", "NMC", "PMC", "UNK"], PropertyInfo(alias="opsCap")]
    """Operation capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK)."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    state: Literal["UNKNOWN", "DEAD", "ACTIVE", "RF ACTIVE", "STANDBY"]
    """Overall state of the entity, if applicable (e.g.

    UNKNOWN, DEAD, ACTIVE, RF ACTIVE, STANDBY).
    """

    sub_status_collection: Annotated[Iterable[SubStatusCollection], PropertyInfo(alias="subStatusCollection")]

    sys_cap: Annotated[Literal["FMC", "NMC", "PMC", "UNK"], PropertyInfo(alias="sysCap")]
    """System capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK)."""


class SubStatusCollection(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    notes: Required[str]
    """Descriptions and/or comments associated with the sub-status."""

    source: Required[str]
    """Source of the data."""

    status: Required[Literal["FMC", "NMC", "PMC", "UNK"]]
    """Status of the sub-system/capability, e.g. FMC, NMC, PMC, UNK."""

    status_id: Required[Annotated[str, PropertyInfo(alias="statusId")]]
    """Id of the parent status."""

    type: Required[Literal["mwCap", "ssCap", "mdCap"]]
    """Parent entity's sub-system or capability status: mwCap, mdCap, ssCap, etc."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """
