# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["StatusListResponse", "StatusListResponseItem", "StatusListResponseItemSubStatusCollection"]


class StatusListResponseItemSubStatusCollection(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    notes: str
    """Descriptions and/or comments associated with the sub-status."""

    source: str
    """Source of the data."""

    status: Literal["FMC", "NMC", "PMC", "UNK"]
    """Status of the sub-system/capability, e.g. FMC, NMC, PMC, UNK."""

    status_id: str = FieldInfo(alias="statusId")
    """Id of the parent status."""

    type: Literal["mwCap", "ssCap", "mdCap"]
    """Parent entity's sub-system or capability status: mwCap, mdCap, ssCap, etc."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """


class StatusListResponseItem(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_entity: str = FieldInfo(alias="idEntity")
    """Unique identifier of the parent entity."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    declassification_date: Optional[datetime] = FieldInfo(alias="declassificationDate", default=None)
    """The declassification date of this data, in ISO 8601 UTC format."""

    declassification_string: Optional[str] = FieldInfo(alias="declassificationString", default=None)
    """Declassification string of this data."""

    derived_from: Optional[str] = FieldInfo(alias="derivedFrom", default=None)
    """
    The sources or SCG references from which the classification of this data is
    derived.
    """

    notes: Optional[str] = None
    """Comments describing the status creation and or updates to an entity."""

    ops_cap: Optional[Literal["FMC", "NMC", "PMC", "UNK"]] = FieldInfo(alias="opsCap", default=None)
    """Operation capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK)."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    state: Optional[Literal["UNKNOWN", "DEAD", "ACTIVE", "RF ACTIVE", "STANDBY"]] = None
    """Overall state of the entity, if applicable (e.g.

    UNKNOWN, DEAD, ACTIVE, RF ACTIVE, STANDBY).
    """

    sub_status_collection: Optional[List[StatusListResponseItemSubStatusCollection]] = FieldInfo(
        alias="subStatusCollection", default=None
    )

    sys_cap: Optional[Literal["FMC", "NMC", "PMC", "UNK"]] = FieldInfo(alias="sysCap", default=None)
    """System capability of the entity, if applicable (e.g. FMC, NMC, PMC, UNK)."""


StatusListResponse: TypeAlias = List[StatusListResponseItem]
