# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SurfaceUpdateParams"]


class SurfaceUpdateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is REAL, TEST, SIMULATED, or EXERCISE data."""

    name: Required[str]
    """The surface name or identifier."""

    source: Required[str]
    """Source of the data."""

    type: Required[str]
    """The surface type of this record (e.g. RUNWAY, TAXIWAY, PARKING)."""

    body_id: Annotated[str, PropertyInfo(alias="id")]
    """Unique identifier of the record, auto-generated by the system."""

    alt_site_id: Annotated[str, PropertyInfo(alias="altSiteId")]
    """Alternate site identifier provided by the source."""

    condition: str
    """The surface condition (e.g.

    GOOD, FAIR, POOR, SERIOUS, FAILED, CLOSED, UNKNOWN).
    """

    ddt_wt_kip: Annotated[float, PropertyInfo(alias="ddtWtKip")]
    """
    The max weight allowable on this surface type for a DDT-type (double dual
    tandem) landing gear configuration, in kilopounds (kip).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    ddt_wt_kip_mod: Annotated[float, PropertyInfo(alias="ddtWtKipMod")]
    """
    The modified max weight allowable on this surface type for a DDT-type (double
    dual tandem) landing gear configuration, in kilopounds (kip).
    """

    ddt_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="ddtWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for a DDT-type (double dual
    tandem) landing gear configuration. For more information, contact the provider
    source.
    """

    ddt_wt_kn: Annotated[float, PropertyInfo(alias="ddtWtKN")]
    """
    The max weight allowable on this surface type for a DDT-type (double dual
    tandem) landing gear configuration, in kilonewtons (kN).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    dd_wt_kip: Annotated[float, PropertyInfo(alias="ddWtKip")]
    """
    The max weight allowable on this surface type for an FAA 2D-type (twin tandem)
    landing gear configuration, in kilopounds (kip).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    dd_wt_kip_mod: Annotated[float, PropertyInfo(alias="ddWtKipMod")]
    """
    The modified max weight allowable on this surface type for an FAA 2D-type (twin
    tandem) landing gear configuration, in kilopounds (kip).
    """

    dd_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="ddWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for an FAA 2D-type (twin
    tandem) landing gear configuration. For more information, contact the provider
    source.
    """

    dd_wt_kn: Annotated[float, PropertyInfo(alias="ddWtKN")]
    """
    The max weight allowable on this surface type for an FAA 2D-type (twin tandem)
    landing gear configuration, in kilonewtons (kN).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    end_lat: Annotated[float, PropertyInfo(alias="endLat")]
    """
    WGS-84 latitude of the coordinate representing the end-point of a surface, in
    degrees. -90 to 90 degrees (negative values south of equator).
    """

    end_lon: Annotated[float, PropertyInfo(alias="endLon")]
    """
    WGS-84 longitude of the coordinate representing the end-point of a surface, in
    degrees. -180 to 180 degrees (negative values west of Prime Meridian).
    """

    id_site: Annotated[str, PropertyInfo(alias="idSite")]
    """
    The unique identifier of the Site record that contains location information
    about this surface.
    """

    lcn: int
    """
    Load classification number or pavement rating which ranks aircraft on a scale of
    1 to 120.
    """

    lda_ft: Annotated[float, PropertyInfo(alias="ldaFt")]
    """The landing distance available for the runway, in feet.

    Applicable for runway surface types only.
    """

    lda_m: Annotated[float, PropertyInfo(alias="ldaM")]
    """The landing distance available for the runway, in meters.

    Applicable for runway surface types only.
    """

    length_ft: Annotated[float, PropertyInfo(alias="lengthFt")]
    """The length of the surface type, in feet.

    Applicable for runway and parking surface types.
    """

    length_m: Annotated[float, PropertyInfo(alias="lengthM")]
    """The length of the surface type, in meters.

    Applicable for runway and parking surface types.
    """

    lighting: bool
    """Flag indicating the surface has lighting."""

    lights_aprch: Annotated[bool, PropertyInfo(alias="lightsAPRCH")]
    """Flag indicating the runway has approach lights.

    Applicable for runway surface types only.
    """

    lights_cl: Annotated[bool, PropertyInfo(alias="lightsCL")]
    """Flag indicating the runway has centerline lights.

    Applicable for runway surface types only.
    """

    lights_ols: Annotated[bool, PropertyInfo(alias="lightsOLS")]
    """Flag indicating the runway has Optical Landing System (OLS) lights.

    Applicable for runway surface types only.
    """

    lights_papi: Annotated[bool, PropertyInfo(alias="lightsPAPI")]
    """Flag indicating the runway has Precision Approach Path Indicator (PAPI) lights.

    Applicable for runway surface types only.
    """

    lights_reil: Annotated[bool, PropertyInfo(alias="lightsREIL")]
    """Flag indicating the runway has Runway End Identifier Lights (REIL).

    Applicable for runway surface types only.
    """

    lights_rwy: Annotated[bool, PropertyInfo(alias="lightsRWY")]
    """Flag indicating the runway has edge lighting.

    Applicable for runway surface types only.
    """

    lights_seqfl: Annotated[bool, PropertyInfo(alias="lightsSEQFL")]
    """Flag indicating the runway has Sequential Flashing (SEQFL) lights.

    Applicable for runway surface types only.
    """

    lights_tdzl: Annotated[bool, PropertyInfo(alias="lightsTDZL")]
    """Flag indicating the runway has Touchdown Zone lights.

    Applicable for runway surface types only.
    """

    lights_unkn: Annotated[bool, PropertyInfo(alias="lightsUNKN")]
    """Flag indicating the runway lighting is unknown.

    Applicable for runway surface types only.
    """

    lights_vasi: Annotated[bool, PropertyInfo(alias="lightsVASI")]
    """Flag indicating the runway has Visual Approach Slope Indicator (VASI) lights.

    Applicable for runway surface types only.
    """

    material: str
    """The surface material (e.g. Asphalt, Concrete, Dirt)."""

    obstacle: bool
    """
    Flag indicating that one or more obstacles or obstructions exist in the
    proximity of this surface.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    pcn: str
    """Pavement classification number (PCN) and tire pressure code."""

    point_reference: Annotated[str, PropertyInfo(alias="pointReference")]
    """
    Description of the surface and its dimensions or how it is measured or oriented.
    """

    primary: bool
    """Flag indicating this is the primary runway.

    Applicable for runway surface types only.
    """

    raw_wbc: Annotated[str, PropertyInfo(alias="rawWBC")]
    """Raw weight bearing capacity value or pavement strength."""

    sbtt_wt_kip: Annotated[float, PropertyInfo(alias="sbttWtKip")]
    """
    The max weight allowable on this surface type for an SBTT-type (single belly
    twin tandem) landing gear configuration, in kilopounds (kip).Note: The
    corresponding equivalent field is not converted by the UDL and may or may not be
    supplied by the provider. The provider/consumer is responsible for all unit
    conversions.
    """

    sbtt_wt_kip_mod: Annotated[float, PropertyInfo(alias="sbttWtKipMod")]
    """
    The modified max weight allowable on this surface type for an SBTT-type (single
    belly twin tandem) landing gear configuration, in kilopounds (kip).
    """

    sbtt_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="sbttWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for an SBTT-type (single
    belly twin tandem) landing gear configuration. For more information, contact the
    provider source.
    """

    sbtt_wt_kn: Annotated[float, PropertyInfo(alias="sbttWtKN")]
    """
    The max weight allowable on this surface type for an SBTT-type (single belly
    twin tandem) landing gear configuration, in kilonewtons (kN).Note: The
    corresponding equivalent field is not converted by the UDL and may or may not be
    supplied by the provider. The provider/consumer is responsible for all unit
    conversions.
    """

    start_lat: Annotated[float, PropertyInfo(alias="startLat")]
    """
    WGS-84 latitude of the coordinate representing the start-point of a surface, in
    degrees. -90 to 90 degrees (negative values south of equator).
    """

    start_lon: Annotated[float, PropertyInfo(alias="startLon")]
    """
    WGS-84 longitude of the coordinate representing the start-point of a surface, in
    degrees. -180 to 180 degrees (negative values west of Prime Meridian).
    """

    st_wt_kip: Annotated[float, PropertyInfo(alias="stWtKip")]
    """
    The max weight allowable on this surface type for an ST-type (single tandem)
    landing gear configuration, in kilopounds (kip).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    st_wt_kip_mod: Annotated[float, PropertyInfo(alias="stWtKipMod")]
    """
    The modified max weight allowable on this surface type for an ST-type (single
    tandem) landing gear configuration, in kilopounds (kip).
    """

    st_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="stWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for an ST-type (single
    tandem) landing gear configuration. For more information, contact the provider
    source.
    """

    st_wt_kn: Annotated[float, PropertyInfo(alias="stWtKN")]
    """
    The max weight allowable on this surface type for an ST-type (single tandem)
    landing gear configuration, in kilonewtons (kN).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    s_wt_kip: Annotated[float, PropertyInfo(alias="sWtKip")]
    """
    The max weight allowable on this surface type for an S-type (single) landing
    gear configuration, in kilopounds (kip). Note: The corresponding equivalent
    field is not converted by the UDL and may or may not be supplied by the
    provider. The provider/consumer is responsible for all unit conversions.
    """

    s_wt_kip_mod: Annotated[float, PropertyInfo(alias="sWtKipMod")]
    """
    The modified max weight allowable on this surface type for an S-type (single)
    landing gear configuration, in kilopounds (kip).
    """

    s_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="sWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for an S-type (single)
    landing gear configuration. For more information, contact the provider source.
    """

    s_wt_kn: Annotated[float, PropertyInfo(alias="sWtKN")]
    """
    The max weight allowable on this surface type for an S-type (single) landing
    gear configuration, in kilonewtons (kN).Note: The corresponding equivalent field
    is not converted by the UDL and may or may not be supplied by the provider. The
    provider/consumer is responsible for all unit conversions.
    """

    tdt_wtkip: Annotated[float, PropertyInfo(alias="tdtWtkip")]
    """
    The max weight allowable on this surface type for a TDT-type (twin delta tandem)
    landing gear configuration, in kilopounds (kip).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    tdt_wt_kip_mod: Annotated[float, PropertyInfo(alias="tdtWtKipMod")]
    """
    The modified max weight allowable on this surface type for a TDT-type (twin
    delta tandem) landing gear configuration, in kilopounds (kip).
    """

    tdt_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="tdtWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for a TDT-type (twin delta
    tandem) landing gear configuration. For more information, contact the provider
    source.
    """

    tdt_wt_kn: Annotated[float, PropertyInfo(alias="tdtWtKN")]
    """
    The max weight allowable on this surface type for a TDT-type (twin delta tandem)
    landing gear configuration, in kilonewtons (kN).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    trt_wt_kip: Annotated[float, PropertyInfo(alias="trtWtKip")]
    """
    The max weight allowable on this surface type for a TRT-type (triple tandem)
    landing gear configuration, in kilopounds (kip).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    trt_wt_kip_mod: Annotated[float, PropertyInfo(alias="trtWtKipMod")]
    """
    The modified max weight allowable on this surface type for a TRT-type (triple
    tandem) landing gear configuration, in kilopounds (kip).
    """

    trt_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="trtWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for a TRT-type (triple
    tandem) landing gear configuration. For more information, contact the provider
    source.
    """

    trt_wt_kn: Annotated[float, PropertyInfo(alias="trtWtKN")]
    """
    The max weight allowable on this surface type for a TRT-type (triple tandem)
    landing gear configuration, in kilonewtons (kN).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    tt_wt_kip: Annotated[float, PropertyInfo(alias="ttWtKip")]
    """
    The max weight allowable on this surface type for a GDSS TT-type (twin tandem)
    landing gear configuration, in kilopounds (kip).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    tt_wt_kip_mod: Annotated[float, PropertyInfo(alias="ttWtKipMod")]
    """
    The modified max weight allowable on this surface type for a GDSS TT-type (twin
    tandem) landing gear configuration, in kilopounds (kip).
    """

    tt_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="ttWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for a GDSS TT-type (twin
    tandem) landing gear configuration. For more information, contact the provider
    source.
    """

    tt_wt_kn: Annotated[float, PropertyInfo(alias="ttWtKN")]
    """
    The max weight allowable on this surface type for a GDSS TT-type (twin tandem)
    landing gear configuration, in kilonewtons (kN).Note: The corresponding
    equivalent field is not converted by the UDL and may or may not be supplied by
    the provider. The provider/consumer is responsible for all unit conversions.
    """

    t_wt_kip: Annotated[float, PropertyInfo(alias="tWtKip")]
    """
    The max weight allowable on this surface type for a T-type (twin (dual)) landing
    gear configuration, in kilopounds (kip).Note: The corresponding equivalent field
    is not converted by the UDL and may or may not be supplied by the provider. The
    provider/consumer is responsible for all unit conversions.
    """

    t_wt_kip_mod: Annotated[float, PropertyInfo(alias="tWtKipMod")]
    """
    The modified max weight allowable on this surface type for a T-type (twin
    (dual)) landing gear configuration, in kilopounds (kip).
    """

    t_wt_kip_mod_note: Annotated[str, PropertyInfo(alias="tWtKipModNote")]
    """
    User input rationale for the manual modification of the prescribed value
    indicating the max weight allowable on this surface for a T-type (twin(dual))
    landing gear configuration. For more information, contact the provider source.
    """

    t_wt_kn: Annotated[float, PropertyInfo(alias="tWtKN")]
    """
    The max weight allowable on this surface type for a T-type (twin (dual)) landing
    gear configuration, in kilonewtons (kN).Note: The corresponding equivalent field
    is not converted by the UDL and may or may not be supplied by the provider. The
    provider/consumer is responsible for all unit conversions.
    """

    width_ft: Annotated[float, PropertyInfo(alias="widthFt")]
    """The width of the surface type, in feet."""

    width_m: Annotated[float, PropertyInfo(alias="widthM")]
    """The width of the surface type, in meters."""
