# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from ..shared.onorbit_full import OnorbitFull

__all__ = ["SwirFull"]


class SwirFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    ts: datetime
    """Data timestamp in ISO8601 UTC format."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    abs_fluxes: Optional[List[float]] = FieldInfo(alias="absFluxes", default=None)
    """
    Array of absolute flux measurement data, in Watts per square centimeter per
    micron. This array should correspond with the same-sized array of wavelengths.
    """

    bad_wave: Optional[str] = FieldInfo(alias="badWave", default=None)
    """User comments concerning sensor or data limitations."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    flux_ratios: Optional[List[float]] = FieldInfo(alias="fluxRatios", default=None)
    """Array of flux ratio data.

    This array should correspond with the same-sized array of ratioWavelengths.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the target on-orbit object."""

    lat: Optional[float] = None
    """Spacecraft WGS84 latitude, in degrees at obTime.

    -90 to 90 degrees (negative values south of equator).
    """

    location_name: Optional[str] = FieldInfo(alias="locationName", default=None)
    """Location/name of the observing sensor."""

    lon: Optional[float] = None
    """Spacecraft WGS84 longitude at ob time, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """Original object ID or Catalog Number provided by source."""

    ratio_wavelengths: Optional[List[float]] = FieldInfo(alias="ratioWavelengths", default=None)
    """Array of ratio wavelength data.

    This array should correspond with the same-sized array of fluxRatios.
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/catalog number of the target on-orbit object."""

    solar_phase_angle: Optional[float] = FieldInfo(alias="solarPhaseAngle", default=None)
    """
    The angle, in degrees, between the target-to-observer vector and the
    target-to-sun vector.
    """

    wavelengths: Optional[List[float]] = None
    """Array of wavelengths, in microns.

    This array should correspond with the same-sized array of absFluxes.
    """
