# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["DiffofarrivalAbridged"]


class DiffofarrivalAbridged(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    ob_time: datetime = FieldInfo(alias="obTime")
    """Ob detection time in ISO 8601 UTC with microsecond precision."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    bandwidth: Optional[float] = None
    """Bandwidth of the signal in Hz."""

    collection_mode: Optional[str] = FieldInfo(alias="collectionMode", default=None)
    """Collection mode (e.g.

    SURVEY, SPOT_SEARCH, NEIGHBORHOOD_WATCH, DIRECTED_SEARCH, MANUAL, etc).
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    delta_range: Optional[float] = FieldInfo(alias="deltaRange", default=None)
    """Delta range, in km. Delta range calculation convention is (sensor2 - sensor1)."""

    delta_range_rate: Optional[float] = FieldInfo(alias="deltaRangeRate", default=None)
    """Delta range rate, in km/sec.

    Delta range rate calculation convention is (sensor2 - sensor1).
    """

    delta_range_rate_unc: Optional[float] = FieldInfo(alias="deltaRangeRateUnc", default=None)
    """One sigma uncertainty in the delta range rate, in km/sec."""

    delta_range_unc: Optional[float] = FieldInfo(alias="deltaRangeUnc", default=None)
    """One sigma uncertainty in delta range, in km."""

    descriptor: Optional[str] = None
    """Optional source-provided and searchable metadata or descriptor of the data."""

    fdoa: Optional[float] = None
    """Frequency difference of arrival of the center frequency signal, in Hz.

    FDOA calculation convention is (sensor2 - sensor1).
    """

    fdoa_unc: Optional[float] = FieldInfo(alias="fdoaUnc", default=None)
    """
    One sigma uncertainty in frequency difference of arrival of the center frequency
    signal, in Hz.
    """

    frequency: Optional[float] = None
    """Center frequency of the collect in Hz."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the target on-orbit object, if correlated."""

    id_sensor1: Optional[str] = FieldInfo(alias="idSensor1", default=None)
    """Sensor ID of the primary/1st sensor used for this measurement."""

    id_sensor2: Optional[str] = FieldInfo(alias="idSensor2", default=None)
    """Sensor ID of the secondary/2nd sensor used for this measurement."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by observation source to indicate the target
    onorbit object of this observation. This may be an internal identifier and not
    necessarily a valid satellite number.
    """

    orig_sensor_id1: Optional[str] = FieldInfo(alias="origSensorId1", default=None)
    """
    Optional identifier provided by DOA source to indicate the primary/1st sensor
    identifier used for this measurement. This may be an internal identifier and not
    necessarily a valid sensor ID.
    """

    orig_sensor_id2: Optional[str] = FieldInfo(alias="origSensorId2", default=None)
    """
    Optional identifier provided by DOA source to indicate the secondary/2nd sensor
    identifier used for this this observation. This may be an internal identifier
    and not necessarily a valid sensor ID.
    """

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Catalog number of the target on-orbit object."""

    sen2alt: Optional[float] = None
    """Sensor 2 altitude at obTime (if mobile/onorbit) in km.

    If null, can be obtained from sensor info.
    """

    sen2lat: Optional[float] = None
    """Sensor 2 WGS84 latitude at obTime (if mobile/onorbit) in degrees.

    If null, can be obtained from sensor info.
    """

    sen2lon: Optional[float] = None
    """Sensor 2 WGS84 longitude at obTime (if mobile/onorbit) in degrees.

    If null, can be obtained from sensor info.
    """

    senalt: Optional[float] = None
    """Sensor altitude at obTime (if mobile/onorbit) in km.

    If null, can be obtained from sensor info.
    """

    senlat: Optional[float] = None
    """Sensor WGS84 latitude at obTime (if mobile/onorbit) in degrees.

    If null, can be obtained from sensor info. -90 to 90 degrees (negative values
    south of equator).
    """

    senlon: Optional[float] = None
    """Sensor WGS84 longitude at obTime (if mobile/onorbit) in degrees.

    If null, can be obtained from sensor info. -180 to 180 degrees (negative values
    west of Prime Meridian).
    """

    sensor1_delay: Optional[float] = FieldInfo(alias="sensor1Delay", default=None)
    """The signal arrival delay relative to sensor 1 in seconds."""

    sensor2_delay: Optional[float] = FieldInfo(alias="sensor2Delay", default=None)
    """The signal arrival delay relative to sensor 2 in seconds."""

    snr: Optional[float] = None
    """Signal to noise ratio, in dB."""

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    task_id: Optional[str] = FieldInfo(alias="taskId", default=None)
    """
    Optional identifier to indicate the specific tasking which produced this
    observation.
    """

    tdoa: Optional[float] = None
    """Time difference of arrival of the center frequency signal, in seconds.

    TDOA calculation convention is (sensor2 - sensor1).
    """

    tdoa_unc: Optional[float] = FieldInfo(alias="tdoaUnc", default=None)
    """
    One sigma uncertainty in time difference of arrival of the center frequency
    signal, in seconds.
    """

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    uct: Optional[bool] = None
    """
    Boolean indicating this observation is part of an uncorrelated track or was
    unable to be correlated to a known object. This flag should only be set to true
    by data providers after an attempt to correlate to an on-orbit object was made
    and failed. If unable to correlate, the 'origObjectId' field may be populated
    with an internal data provider specific identifier.
    """
