# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TrackUnvalidatedPublishParams", "Body"]


class TrackUnvalidatedPublishParams(TypedDict, total=False):
    body: Required[Iterable[Body]]


class Body(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: Required[str]
    """Source of the data."""

    ts: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """Track timestamp in ISO8601 UTC format."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    alt: float
    """Track point altitude relative to WGS-84 ellipsoid, in meters.

    Positive values indicate a track object height above ellipsoid, and negative
    values indicate a track object below ellipsoid, applicable to the depth estimate
    for a subsurface track.
    """

    asset: str
    """
    Id/name of the platform providing the track data (i.e., tail number for air
    platform, tower ID for tower based sensor, site id for fixed radar).
    """

    asset_nat: Annotated[str, PropertyInfo(alias="assetNat")]
    """Nationality or organization of the tracking/reporting system or platform (e.g.

    FR, NATO, US, etc.).
    """

    call_sign: Annotated[str, PropertyInfo(alias="callSign")]
    """The call sign currently assigned to this track object."""

    cntct: str
    """
    Contact information for assets reporting PPLI (Precise Participant Location and
    Identification). PPLI is a Link 16 message that is used by units to transmit
    complete location, identification, and limited status information.
    """

    course: float
    """
    The track object course-over-ground, in degrees clockwise from true North at the
    object location (0-360 degrees).
    """

    cov: Iterable[float]
    """
    Covariance matrix, in meter and second based units, for the defined cartesian
    system.

    The array values represent the lower triangular half of the position-velocity
    covariance matrix. The size of the covariance matrix is dynamic. The values are
    output as an array of values corresponding to the position-velocity covariance
    element positions, ordered as follows:

    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;x&nbsp;&nbsp;y&nbsp;&nbsp;z&nbsp;&nbsp;&nbsp;x'&nbsp;&nbsp;y'&nbsp;z'&nbsp;&nbsp;

    x&nbsp;&nbsp;&nbsp;&nbsp;1

    y&nbsp;&nbsp;&nbsp;&nbsp;2&nbsp;&nbsp;&nbsp;3

    z&nbsp;&nbsp;&nbsp;&nbsp;4&nbsp;&nbsp;&nbsp;5&nbsp;&nbsp;&nbsp;6

    x'&nbsp;&nbsp;&nbsp;7&nbsp;&nbsp;&nbsp;8&nbsp;&nbsp;&nbsp;9&nbsp;&nbsp;10

    y'&nbsp;&nbsp;11&nbsp;&nbsp;12&nbsp;&nbsp;13&nbsp;&nbsp;14&nbsp;&nbsp;15

    z'&nbsp;&nbsp;16&nbsp;&nbsp;17&nbsp;&nbsp;18&nbsp;&nbsp;19&nbsp;&nbsp;20&nbsp;&nbsp;
    21

    The covariance matrix will be as large as the last element needed, and with
    unused values zero-filled to maintain proper element positioning in the array.
    For example, for a 2D (x, y) position-only covariance, the covariance matrix
    will be 2x2 and the array would contain the 3 elements corresponding to the x,
    and y position. Another example, now for a 2D (x, y) position-velocity
    covariance, the covariance matrix will be 5x5 and the array would contain the 15
    elements corresponding to the relevant x, y, x', and y' values (with the z-row
    and z-column being all zeros). The cov array should contain only the lower left
    triangle values from top left down to bottom right, in order.
    """

    ecef_acc: Annotated[Iterable[float], PropertyInfo(alias="ecefAcc")]
    """Track object acceleration in ECEF [x'', y'', z''], meters/sec^2.

    When provided, array must always contain 3 values.
    """

    ecef_pos: Annotated[Iterable[float], PropertyInfo(alias="ecefPos")]
    """Track object location in ECEF [x, y, z], meters.

    When provided, array must always contain 3 values.
    """

    ecef_vel: Annotated[Iterable[float], PropertyInfo(alias="ecefVel")]
    """Track object velocity in ECEF [x', y', z'], meters/sec.

    When provided, array must always contain 3 values.
    """

    e_nu_pos: Annotated[Iterable[float], PropertyInfo(alias="eNUPos")]
    """East, North, Up position components, in meters.

    When provided, array must always contain 3 values.
    """

    e_nu_vel: Annotated[Iterable[float], PropertyInfo(alias="eNUVel")]
    """East, North, Up velocity components, in meters/sec.

    When provided, array must always contain 3 values.
    """

    env: str
    """The track environment type (AIR, LAND, SPACE, SUBSURFACE, SURFACE, UNKNOWN):

    AIR: Between sea level and the Kármán line, which has an altitude of 100
    kilometers (62 miles).

    LAND: On the surface of dry land.

    SPACE: Above the Kármán line, which has an altitude of 100 kilometers (62
    miles).

    SURFACE: On the surface of a body of water.

    SUBSURFACE: Below the surface of a body of water.

    UNKNOWN: Environment is not known.
    """

    env_conf: Annotated[float, PropertyInfo(alias="envConf")]
    """Track environment confidence estimate (not standardized)."""

    err_ellp: Annotated[Iterable[float], PropertyInfo(alias="errEllp")]
    """
    Uncertainty ellipsoid [semi-major axis (m), semi-minor axis (m), orientation
    (deg)].
    """

    hdng: float
    """
    The track object heading, in degrees clockwise from true North at the object
    location.
    """

    ident_amp: Annotated[str, PropertyInfo(alias="identAmp")]
    """
    Additional track object identity/status information, typically used for EXERCISE
    identity amplification (FAKER, JOKER, KILO, TRAVELLER, ZOMBIE):

    FAKER: Friendly track, object, or entity acting as an exercise hostile.

    JOKER: Friendly track, object, or entity acting as an exercise suspect.

    KILO: Friendly high-value object.

    TRAVELLER: Suspect land or surface track following a recognized traffic route.

    ZOMBIE: Suspect track, object, or entity of special interest.
    """

    ident_cred: Annotated[int, PropertyInfo(alias="identCred")]
    """Track object identity credibility."""

    ident_rel: Annotated[int, PropertyInfo(alias="identRel")]
    """Track object identity reliability."""

    j_series: Annotated[str, PropertyInfo(alias="jSeries")]
    """The J-series message type, if this track is derived from a J-series message."""

    lat: float
    """WGS-84 latitude of the track object, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lc_acc: Annotated[Iterable[float], PropertyInfo(alias="lcAcc")]
    """
    Estimate of the acceleration, [x'', y'', z''], of the track object in the
    defined cartesian system, in meters/sec^2. When provided, array must always
    contain 3 values.
    """

    lco: Iterable[float]
    """Origin of a local coordinate system [lat, lon, altitude].

    When provided, array must always contain 3 values.
    """

    lc_pos: Annotated[Iterable[float], PropertyInfo(alias="lcPos")]
    """
    Estimate of the position, [x, y, z], of the track object in the defined
    cartesian system, in meters. When provided, array must always contain 3 values.
    """

    lcs: Iterable[float]
    """x, y, and z-axis rotations about ECEF that define a local cartesian system.

    When provided, array must always contain 3 values.
    """

    lc_vel: Annotated[Iterable[float], PropertyInfo(alias="lcVel")]
    """
    Estimate of the velocity, [x', y', z'], of the track object in the defined
    cartesian system, in meters/sec. When provided, array must always contain 3
    values.
    """

    lon: float
    """WGS-84 longitude of the track object, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    m1: int
    """
    Mode-1 interrogation response (mission code), indicating mission or aircraft
    type.
    """

    m1v: int
    """Mode-1 validity status."""

    m2: int
    """Mode-2 interrogation response (military identification code)."""

    m2v: int
    """Mode-2 validity status."""

    m3a: int
    """
    Mode-3/A interrogation response (aircraft identification), provides a 4-digit
    octal identification code for the aircraft, assigned by the air traffic
    controller. Mode-3/A is shared military/civilian use.
    """

    m3av: int
    """Mode-3/A validity status."""

    mod_type: Annotated[str, PropertyInfo(alias="modType")]
    """The type of source information from which the track was derived.

    Intended as, but not constrained to, NATO STANAG 4676 modality types (AIS, BFT,
    BIOMETRIC, COMINT, DOPPLER, ELINT, HRR, HUMINT, IMAGE, MASINT, MIXED, OSINT,
    OTHER):

    AIS: Derived from an automated identification system source.

    BFT: Derived from a blue force tracking source.

    BIOMETRICS: Derived from a biometrics source.

    COMINT: Derived from a communications intelligence source.

    DOPPLER: Derived from a radar doppler source.

    ELINT: Derived from an electronics intelligence source.

    HRR: Derived from a radar high range resolution source.

    HUMINT: Derived from a human intelligence source.

    IMAGE: Derived from a still or motion imagery source.

    MASINT: Derived from a measurement and signals intelligence source.

    MIXED: Derived from a combination of two or more sources.

    OSINT: Derived from an open source intelligence source.

    OTHER: Derived from other types of unspecified sources.
    """

    msg_ts: Annotated[Union[str, datetime], PropertyInfo(alias="msgTs", format="iso8601")]
    """Message Timestamp."""

    msn_id: Annotated[str, PropertyInfo(alias="msnId")]
    """Mission ID related to the track."""

    multi_source: Annotated[bool, PropertyInfo(alias="multiSource")]
    """Flag indicating that this track is fused from multiple sensor sources."""

    obj_act: Annotated[str, PropertyInfo(alias="objAct")]
    """The activity in which the track object is engaged.

    Intended as, but not constrained to, MIL-STD-6016 environment dependent activity
    designations. The activity can be reported as either a combination of the code
    and environment (e.g. 65/AIR) or as the descriptive enumeration (e.g.
    DIVERTING), which are equivalent.
    """

    obj_id: Annotated[str, PropertyInfo(alias="objId")]
    """The UID or designation of the tracked object."""

    obj_ident: Annotated[str, PropertyInfo(alias="objIdent")]
    """
    The estimated identity of the track object (ASSUMED FRIEND, FRIEND, HOSTILE,
    NEUTRAL, PENDING, SUSPECT, UNKNOWN):

    ASSUMED FRIEND: Track assumed to be a friend due to the object characteristics,
    behavior, and/or origin.

    FRIEND: Track object supporting friendly forces and belonging to a declared
    friendly nation or entity.

    HOSTILE: Track object belonging to an opposing nation, party, group, or entity
    deemed to contribute to a threat to friendly forces or their mission due to its
    behavior, characteristics, nationality, or origin.

    NEUTRAL: Track object whose characteristics, behavior, nationality, and/or
    origin indicate that it is neither supporting nor opposing friendly forces or
    their mission.

    PENDING: Track object which has not been evaluated.

    SUSPECT: Track object deemed potentially hostile due to the object
    characteristics, behavior, nationality, and/or origin.

    UNKNOWN: Track object which has been evaluated and does not meet criteria for
    any standard identity.
    """

    obj_nat: Annotated[str, PropertyInfo(alias="objNat")]
    """Nationality or organization of the track object (e.g. FR, NATO, US, etc.)."""

    obj_plat: Annotated[str, PropertyInfo(alias="objPlat")]
    """The object platform type.

    Intended as, but not constrained to, MIL-STD-6016 environment dependent platform
    type designations. The platform type can be reported as either a combination of
    the code and environment (e.g. 14/LAND) or as the descriptive representations
    (e.g. COMBAT VEHICLE), which are equivalent.
    """

    obj_spec: Annotated[str, PropertyInfo(alias="objSpec")]
    """The object specific type.

    Intended as, but not constrained to, MIL-STD-6016 environment dependent specific
    type designations. The specific type can be reported as either a combination of
    the code and environment (e.g. 155/SURFACE) or as the descriptive representation
    (e.g. AUDACE DDG), which are equivalent.
    """

    obj_type: Annotated[str, PropertyInfo(alias="objType")]
    """
    The generic classification of the track object/group (e.g., HELICOPTER, TRACKED,
    WATERCRAFT, WHEELED, etc.). Referenced, but not constrained to, NATO STANAG 4676
    object type classifications.
    """

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    sen: str
    """Id/name of sensor providing the track data."""

    sen_qual: Annotated[str, PropertyInfo(alias="senQual")]
    """Sensor quality."""

    spd: float
    """Track object spd, in meters/sec."""

    src_ids: Annotated[List[str], PropertyInfo(alias="srcIds")]
    """
    Array of UUIDs of the UDL data records that contributed to the generation of
    this fused track. See the associated 'srcTyps' array for the specific types of
    data, positionally corresponding to the UUIDs in this array, used in the track
    fusion. The 'srcTyps' and 'srcIds' arrays must match in size. See the
    corresponding srcTyps array element for the data type of the UUID and use the
    appropriate API operation to retrieve that object (e.g. /udl/poi/{uuid}).
    """

    src_typs: Annotated[List[str], PropertyInfo(alias="srcTyps")]
    """
    Array of UDL record types (POI, MTI, TRACK, GROUNDIMAGE) that contributed to the
    generation of this fused track. See the associated 'srcIds' array for the record
    UUIDs, positionally corresponding to the record types in this array, used in the
    track fusion. The 'srcTyps' and 'srcIds' arrays must match in size.
    """

    strength: int
    """
    The number of objects or units moving as a group and represented as a single
    entity in this track message. If null, the track is assumed to represent a
    single object. Note that if this track derives from a J-series message then
    special definitions apply for the following values: 13 indicates an estimated
    2-7 units, 14 indicates an estimated more than 7 units, and 15 indicates an
    estimated more than 12 units.
    """

    tags: List[str]
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    trk_conf: Annotated[float, PropertyInfo(alias="trkConf")]
    """
    Overall track confidence estimate (not standardized, but typically a value
    between 0 and 1, with 0 indicating lowest confidence).
    """

    trk_id: Annotated[str, PropertyInfo(alias="trkId")]
    """
    UUID identifying the track, which should remain the same on subsequent tracks of
    the same object.
    """

    trk_itm_id: Annotated[str, PropertyInfo(alias="trkItmId")]
    """UUID of the track item object, applies to STANAG-4676 messages."""

    trk_num: Annotated[str, PropertyInfo(alias="trkNum")]
    """The track number (TN) of a surveillance entity.

    Intended as, but not constrained to, the J-series track number encoded as five
    character alpha-numeric characters. Users should refer to J-series documentation
    for specific TN definitions.
    """

    trk_pt_type: Annotated[str, PropertyInfo(alias="trkPtType")]
    """
    Means by which the track data was created (e.g., MEASURED, AUTOMATIC PREDICTED,
    etc.).
    """

    trk_qual: Annotated[int, PropertyInfo(alias="trkQual")]
    """Value indicating track quality (not standardized)."""

    trk_stat: Annotated[str, PropertyInfo(alias="trkStat")]
    """
    Status of the track (e.g., INITIATING, MAINTAINING, DROPPING, TERMINATED, etc.).
    """
