# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["TrackDetailsFull"]


class TrackDetailsFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    lat: float
    """WGS-84 latitude of the track object, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: float
    """WGS-84 longitude of the track object, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    source: str
    """Source of the data."""

    ts: datetime
    """Track timestamp in ISO8601 UTC format with microsecond precision."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    acft_sub_type: Optional[str] = FieldInfo(alias="acftSubType", default=None)
    """Subtype is a finer grain categorization of missile types.

    Examples include but are not limited to SRBM, MRBM, IRBM, LRBM, ICBM, SLBM:

    SRBM - Short-Range Ballistic Missile

    MRBM - Medium-Range Ballistic Missile

    IRBM - Intermediate-Range Ballistic Missile

    LRBM - Long-Range Ballistic Missile

    ICBM - Intercontinental Ballistic Missile

    SLBM - Submarine-Launched Ballistic Missile.
    """

    add_info: Optional[str] = FieldInfo(alias="addInfo", default=None)
    """
    A text amplifier for units, equipment and installations; content is
    implementation specific.
    """

    alert: Optional[str] = None
    """A track may be designated as an alert track with the following designations:

    HIT - High Interest Track

    TGT - Target

    SUS - Suspect Carrier

    NSP - Cleared Suspect

    If alert is null, the track is assumed to be of non-alert status.
    """

    alt: Optional[float] = None
    """Track point altitude relative to WGS-84 ellipsoid, in meters.

    Positive values indicate a track object height above ellipsoid, and negative
    values indicate a track object below ellipsoid, applicable to the depth estimate
    for a subsurface track.
    """

    ang_elev: Optional[float] = FieldInfo(alias="angElev", default=None)
    """
    The angle formed between the line of sight of the observer and the horizon, in
    degrees. The angular range is -90 to 90, with negative values representing angle
    of depression.
    """

    antenna_ref_dimensions: Optional[List[float]] = FieldInfo(alias="antennaRefDimensions", default=None)
    """The reference dimensions of the vessel, reported as [A, B, C, D], in meters.

    Where the array values represent the distance fore (A), aft (B), to port (C),
    and to starboard (D) of the navigation antenna. Array with values A = C = 0 and
    B, D > 0 indicate the length (B) and width (D) of the vessel without antenna
    position reference.
    """

    aou_rpt_data: Optional[List[float]] = FieldInfo(alias="aouRptData", default=None)
    """Three element array representing an Area of Uncertainty (AoU).

    The array element definitions and units are type specific depending on the
    aouRptType specified in this record:

    ELLIPSE:

    brg - orientation in degrees of the ellipse

    a1 - semi-major axis in meters

    a2 - semi-minor axis in meters

    BEARING (BEARING BOX or MTST BEARING BOX):

    brg - orientation in degrees of the bearing box

    a1 - length of bearing box in meters

    a2 - half-width of bearing box in meters

    OTHER (All other type values):

    brg - line of bearing in degrees true

    a1 - bearing error in degrees

    a2 - estimated range in meters.
    """

    aou_rpt_type: Optional[str] = FieldInfo(alias="aouRptType", default=None)
    """The track Area of Uncertainty (AoU) type (BEARING, ELLIPSE, OTHER) definition.

    This type defines the elements of the aouRptData array and is required if
    aouRptData is not null. See the aouRptData field definition for specific
    information.
    """

    app_grp: Optional[str] = FieldInfo(alias="appGrp", default=None)
    """Appearance group code.

    GP1 - Superstructure exceeds 1/3 of ship length.

    GP2 - Superstructure less than 1/3 of ship length.

    GP3 - Stack aft.
    """

    arr_cargo: Optional[str] = FieldInfo(alias="arrCargo", default=None)
    """The reported arrival cargo type.

    Intended as, but not constrained to, the USCG NAVCEN AIS cargo definitions.
    Users should refer to USCG Navigation Center documentation for specific
    definitions associated with ship and cargo types. USCG NAVCEN documentation may
    be found at https://www.navcen.uscg.gov.
    """

    arr_flag: Optional[str] = FieldInfo(alias="arrFlag", default=None)
    """The flag of the arrival port."""

    arr_port: Optional[str] = FieldInfo(alias="arrPort", default=None)
    """The Arrival Port of the vessel according to the AIS transmission."""

    arr_time: Optional[datetime] = FieldInfo(alias="arrTime", default=None)
    """
    The Arrival Time of the vessel at the destination, in ISO 8601 UTC format with
    microsecond precision.
    """

    aton: Optional[str] = None
    """Type of Aid to Navigation.

    Intended as, but not constrained to, the USCG NAVCEN aids to navigation. Users
    should refer to USCG Navigation Center documentation for specific device type
    information. USCG NAVCEN documentation may be found at
    https://www.navcen.uscg.gov.
    """

    avg_spd: Optional[float] = FieldInfo(alias="avgSpd", default=None)
    """
    The average speed, in kilometers/hour, calculated for the subject during the
    latest voyage/excursion.
    """

    az_corr_arc_width: Optional[float] = FieldInfo(alias="azCorrArcWidth", default=None)
    """
    Azimuth corridor arc distance measured in meters from reference point of azimuth
    corridor to far edge of bounded azimuth corridor wedge, measured along azimuth
    corridor center line.
    """

    az_corr_center_line: Optional[float] = FieldInfo(alias="azCorrCenterLine", default=None)
    """
    The azimuth corridor centerline angle measured in degrees clockwise from true
    north, of the center line of an azimuth corridor. The center line extends from
    the referenced corridor origin location.
    """

    be_number: Optional[str] = FieldInfo(alias="beNumber", default=None)
    """The Basic Encyclopedia (BE) number associated with this installation or area."""

    boosting: Optional[bool] = None
    """
    Flag indicating that the missile is currently in a state of boosting, if
    reporting a missile track.
    """

    burnout_alt: Optional[float] = FieldInfo(alias="burnoutAlt", default=None)
    """Track point burnout altitude relative to WGS-84 ellipsoid, in meters."""

    call_sign: Optional[str] = FieldInfo(alias="callSign", default=None)
    """The call sign currently assigned to this track object."""

    cargo_type: Optional[str] = FieldInfo(alias="cargoType", default=None)
    """The reported cargo type.

    Intended as, but not constrained to, the USCG NAVCEN AIS cargo definitions.
    Users should refer to USCG Navigation Center documentation for specific
    definitions associated with ship and cargo types. USCG NAVCEN documentation may
    be found at https://www.navcen.uscg.gov.
    """

    c_i: Optional[str] = FieldInfo(alias="cI", default=None)
    """
    Correlation Index; reference code for the site that originally reported the
    track.
    """

    containment: Optional[float] = None
    """The Area Of Uncertainty (AOU) percentage (0 - 100) containment value.

    The percentage of time (90%) that the estimated area of uncertainty will cover
    the true position of the track object.
    """

    coop_loc_ind: Optional[str] = FieldInfo(alias="coopLocInd", default=None)
    """
    The Cooperative Location Indicator specifies whether the reported entity
    location was derived using reported locations from sensors on more than one
    platform.

    0 - COOPERATIVE_LOCATOR_NONE

    1 - SINGLE_PLATFORM

    2 - FRAGMENT

    3 - COOPERATIVE.
    """

    course: Optional[float] = None
    """
    The track object course-over-ground, in degrees clockwise from true North at the
    object location (0-360 degrees).
    """

    cpa: Optional[float] = None
    """
    The distance, in meters, of the closest point of approach between this track to
    the master reference track.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """Application user who created the row in the database."""

    dep_cargo: Optional[str] = FieldInfo(alias="depCargo", default=None)
    """The reported departure cargo type.

    Intended as, but not constrained to, the USCG NAVCEN AIS cargo definitions.
    Users should refer to USCG Navigation Center documentation for specific
    definitions associated with ship and cargo types. USCG NAVCEN documentation may
    be found at https://www.navcen.uscg.gov.
    """

    dep_flag: Optional[str] = FieldInfo(alias="depFlag", default=None)
    """The flag of the departure port."""

    dep_port: Optional[str] = FieldInfo(alias="depPort", default=None)
    """The Departure Port of the vessel according to the AIS transmission."""

    des_cargo: Optional[str] = FieldInfo(alias="desCargo", default=None)
    """The reported destination cargo type.

    Intended as, but not constrained to, the USCG NAVCEN AIS cargo definitions.
    Users should refer to USCG Navigation Center documentation for specific
    definitions associated with ship and cargo types. USCG NAVCEN documentation may
    be found at https://www.navcen.uscg.gov.
    """

    des_flag: Optional[str] = FieldInfo(alias="desFlag", default=None)
    """The flag of the destination port."""

    destination: Optional[str] = None
    """The destination of the vessel according to the AIS transmission."""

    dis_id: Optional[str] = FieldInfo(alias="disId", default=None)
    """The Intel Discrete Identifier (IDI) code assigned to this track.

    The IDI is a four-digit code representing hostile or unknown tracks.
    """

    draught: Optional[float] = None
    """
    The maximum static draught, in meters, of the vessel according to the AIS
    transmission.
    """

    drop_pt_ind: Optional[bool] = FieldInfo(alias="dropPtInd", default=None)
    """The drop-point indicator setting."""

    dummy: Optional[bool] = None
    """Flag indicating that this track represents a dummy object or group.

    Identifies offensive or defensive units, equipment, and/or installations
    intended to draw the enemy's attention away from the area of the main attack.
    Based on MIL-STD-2525 symbology definitions.
    """

    ecef_pos: Optional[List[float]] = FieldInfo(alias="ecefPos", default=None)
    """Track object location in ECEF [x, y, z], meters.

    When provided, array must always contain 3 values.
    """

    ecef_vel: Optional[List[float]] = FieldInfo(alias="ecefVel", default=None)
    """Track object velocity in ECEF [x', y', z'], meters/sec.

    When provided, array must always contain 3 values.
    """

    elnot1: Optional[str] = None
    """
    Primary ELINT Notification (ELNOT), a five character identifier assigned to each
    non-communication emission for collection and reporting purposes. This
    five-digit field begins with an alpha character, followed by three numbers,
    ending with another alpha character.
    """

    elnot2: Optional[str] = None
    """
    Secondary ELINT Notification (ELNOT), a five character identifier assigned to
    each non-communication emission for collection and reporting purposes. This
    five-digit field begins with an alpha character, followed by three numbers,
    ending with another alpha character.
    """

    emg_ind: Optional[bool] = FieldInfo(alias="emgInd", default=None)
    """Flag indicating that the track object has an emergency."""

    emitter_name: Optional[str] = FieldInfo(alias="emitterName", default=None)
    """Radar name of the sensor tracking this object (e.g., RAY1500, SPN-43, HEADNET)."""

    env: Optional[Literal["AIR", "LAND", "SPACE", "SURFACE", "SUBSURFACE", "UNKNOWN"]] = None
    """The track environment type (AIR, LAND, SPACE, SUBSURFACE, SURFACE, UNKNOWN):

    AIR: Between sea level and the Kármán line, which has an altitude of 100
    kilometers (62 miles).

    LAND: On the surface of dry land.

    SPACE: Above the Kármán line, which has an altitude of 100 kilometers (62
    miles).

    SURFACE: On the surface of a body of water.

    SUBSURFACE: Below the surface of a body of water.

    UNKNOWN: Environment is not known.
    """

    err_area_orient: Optional[float] = FieldInfo(alias="errAreaOrient", default=None)
    """The error in the Area Orientation.

    Area Orientation is the angle or roll in degrees, between area semi-minor axis
    and plane defined by local vertical and area semi-major axis. When reported
    without major and minor axis, it is angle between an axis perpendicular to a 2D
    true north axis and plane defined by local vertical and a 2D true north axis.
    """

    err_geo_area_switch: Optional[str] = FieldInfo(alias="errGeoAreaSwitch", default=None)
    """
    Geometric area switch identifies the 3D shape of the error volume by providing
    the 2D shape for the 3D plane. The 3D plane is the plane orthogonal to the area
    semi-major axis and area semi-minor axis. Depending on whether the 2D plane is
    reported as an error ellipse 2D or as an error rectangle 2D, this switch reports
    a complete error volume that is cubical, 3D rectangular, cylindrical, 3D
    ellipsoidal, or spherical.

    0 - SWITCH_TYPE_UNKNOWN

    1 - SQUARE_RECTANGLE

    2 - CIRCLE_ELLIPSE.
    """

    err_semi_int_axis: Optional[float] = FieldInfo(alias="errSemiIntAxis", default=None)
    """The error in the semi-intermediate axis.

    The semi-intermediate axis is intermediate in length between semi-major and
    semi-minor axes. This field is doubled and centered on intersection of area
    semi-major axis and area semi-minor axis at 90 degrees to the plane defined by
    those axes. For these shapes, the volume is defined as having a 50-percent
    probability of containing the true location of the referenced entity.
    """

    err_semi_maj_elev: Optional[float] = FieldInfo(alias="errSemiMajElev", default=None)
    """The error in the Semi-major elevation axis.

    Semi-major elevation axis is the elevation of the cubical, 3D rectangular,
    cylindrical, 3D ellipsoidal, or spherical semi-major axis, in degrees, measured
    from local horizontal.
    """

    eta: Optional[datetime] = None
    """
    The Estimated Time of Arrival of the vessel at the destination port, in ISO 8601
    UTC format with microsecond precision.
    """

    etd: Optional[datetime] = None
    """
    The Estimated Time of Departure of the vessel from the departure port (depPort),
    according to Marine Traffic calculations, in ISO 8601 UTC format with
    microsecond precision.
    """

    eval_rating: Optional[str] = FieldInfo(alias="evalRating", default=None)
    """
    A text amplifier code for units, equipment, and installations that consists of a
    one-letter reliability rating and a one-number credibility rating based on the
    following definitions of each:

    Reliability Ratings:

    A-completely reliable

    B-usually reliable

    C-fairly reliable

    D-not usually reliable

    E-unreliable

    F-reliability cannot be judged

    Credibility Ratings:

    1-confirmed by other sources

    2-probably true

    3-possibly true

    4-doubtfully true

    5-improbable

    6-truth cannot be judged.
    """

    feint: Optional[bool] = None
    """Flag indicating that this track represents a feint object or group.

    Identifies offensive or defensive units, equipment, and/or installations
    intended to draw the enemy's attention away from the area of the main attack.
    Based on MIL-STD-2525 symbology definitions.
    """

    freq: Optional[float] = None
    """Frequency, in hertz, for the signature report."""

    ftn: Optional[str] = None
    """An ftn used to associate information and directives with the track."""

    ftn_cmd: Optional[str] = FieldInfo(alias="ftnCmd", default=None)
    """
    The name of the Command reporting the Force Over-The-Horizon Track Coordinator
    (FOTC) track number.
    """

    ftn_msg_ts: Optional[datetime] = FieldInfo(alias="ftnMsgTs", default=None)
    """
    The message timestamp that the ftn track position was recorded, in ISO 8601 UTC
    format with microsecond precision.
    """

    harmonics: Optional[str] = None
    """
    List of harmonics of the signature report in descending order of predominance
    using 1-2 digit combinations separated by commas, e.g., 8,12,4. (1-22NS).
    """

    hdng: Optional[float] = None
    """Track object heading, in degrees clockwise from true north."""

    hq: Optional[bool] = None
    """Flag indicating that this track represents a headquarters object.

    Based on MIL-STD-2525 symbology definitions.
    """

    hull_num: Optional[str] = FieldInfo(alias="hullNum", default=None)
    """The vessel hull number designation of this maritime vessel.

    The hull number is a 1-6 character alphanumeric entry assigned to a ship and
    painted on the hull.
    """

    hull_prof: Optional[str] = FieldInfo(alias="hullProf", default=None)
    """Hull profile code. Based on GCCS-J hull profiles.

    FLUSH No breaks in Hull Profile.

    RAISED 1 Hull Profile shows distinct raised area at bow. Remainder of deck is
    flush.

    RAISED 2 Hull Profile shows distinct raised area amidships. Bow and stern are
    flush.

    RAISED 3 Hull Profile shows distinct raised area at stern. Remainder of deck is
    flush.

    RAISED 1-2-3 Distinct raised areas at bow, midships, and stern with breaks
    between each raise.

    RAISED 1-2 Raised area at bow and midships with break between.

    RAISED 1-3 Raised area at bow and stern with break between.

    RAISED 12 Continuous raised area encompassing both bow and midships.

    RAISED 23 Continuous raised area encompassing midships and stern.

    RAISED 12-3 Raised areas at bow, midships and stern. Bow and midship raises are
    continuous. Break between midship and stern raises.

    RAISED 1-23 Raised areas at bow, midships, and stern. Midship and stern raises
    are continuous with break between bow and midship raises.

    RAISED 1-L2-3 Raised areas at bow, midships, and stern with break between each
    raise. Midships raise is longer than that associated with raised 1-2-3.
    """

    ident_amp: Optional[str] = FieldInfo(alias="identAmp", default=None)
    """
    Additional track object identity/status information, typically used for EXERCISE
    identity amplification (FAKER, JOKER, KILO, TRAVELLER, ZOMBIE):

    FAKER: Friendly track, object, or entity acting as an exercise hostile.

    JOKER: Friendly track, object, or entity acting as an exercise suspect.

    KILO: Friendly high-value object.

    TRAVELLER: Suspect land or surface track following a recognized traffic route.

    ZOMBIE: Suspect track, object, or entity of special interest.
    """

    iff: Optional[str] = None
    """A text amplifier displaying IFF/SIF/AIS Identification modes and codes."""

    imon: Optional[int] = None
    """The International Maritime Organization Number of the vessel.

    IMON is a seven-digit number that uniquely identifies the vessel.
    """

    impact_aou_data: Optional[List[float]] = FieldInfo(alias="impactAouData", default=None)
    """Three element array representing the impact point Area of Uncertainty (AoU).

    The array element definitions and units are type specific depending on the
    impactAouType specified in this record:

    ELLIPSE:

    brg - orientation in degrees of the ellipse

    a1 - semi-major axis in meters

    a2 - semi-minor axis in meters

    BEARING (BEARING BOX or MTST BEARING BOX):

    brg - orientation in degrees of the bearing box

    a1 - length of bearing box in meters

    a2 - half-width of bearing box in meters

    OTHER (All other type values):

    brg - line of bearing in degrees true

    a1 - bearing error in degrees

    a2 - estimated range in meters.
    """

    impact_aou_type: Optional[str] = FieldInfo(alias="impactAouType", default=None)
    """
    The impact point Area of Uncertainty (AoU) type (BEARING, ELLIPSE, OTHER)
    definition. This type defines the elements of the impactAouData array and is
    required if impactAouData is not null. See the impactAouData field definition
    for specific information.
    """

    impact_lat: Optional[float] = FieldInfo(alias="impactLat", default=None)
    """WGS-84 latitude of the missile impact point, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    impact_lon: Optional[float] = FieldInfo(alias="impactLon", default=None)
    """WGS-84 longitude of the missile impact point, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    impact_time: Optional[datetime] = FieldInfo(alias="impactTime", default=None)
    """Missile impact timestamp in ISO8601 UTC format with microsecond precision."""

    info_source: Optional[str] = FieldInfo(alias="infoSource", default=None)
    """Source code for source of information used to detect track."""

    installation: Optional[bool] = None
    """Flag indicating that this track represents an installation.

    Based on MIL-STD-2525 symbology definitions.
    """

    launch_aou_data: Optional[List[float]] = FieldInfo(alias="launchAouData", default=None)
    """Three element array representing the launch location Area of Uncertainty (AoU).

    The array element definitions and units are type specific depending on the
    launchAouType specified in this record:

    ELLIPSE:

    brg - orientation in degrees of the ellipse

    a1 - semi-major axis in meters

    a2 - semi-minor axis in meters

    BEARING (BEARING BOX or MTST BEARING BOX):

    brg - orientation in degrees of the bearing box

    a1 - length of bearing box in meters

    a2 - half-width of bearing box in meters

    OTHER (All other type values):

    brg - line of bearing in degrees true

    a1 - bearing error in degrees

    a2 - estimated range in meters.
    """

    launch_aou_type: Optional[str] = FieldInfo(alias="launchAouType", default=None)
    """
    The launch location Area of Uncertainty (AoU) type (BEARING, ELLIPSE, OTHER)
    definition. This type defines the elements of the launchAouData array and is
    required if launchAouData is not null. See the launchAouData field definition
    for specific information.
    """

    launch_lat: Optional[float] = FieldInfo(alias="launchLat", default=None)
    """WGS-84 latitude of the missile launch point, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    launch_lon: Optional[float] = FieldInfo(alias="launchLon", default=None)
    """WGS-84 longitude of the missile launch point, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    launch_time: Optional[datetime] = FieldInfo(alias="launchTime", default=None)
    """Missile launch timestamp in ISO8601 UTC format with microsecond precision."""

    length: Optional[float] = None
    """The overall length of the vessel, in meters.

    A value of 511 indicates a vessel length of 511 meters or greater.
    """

    lost_trk_ind: Optional[bool] = FieldInfo(alias="lostTrkInd", default=None)
    """
    Flag indicating whether the missile is considered lost, if reporting a missile
    track.
    """

    maneuver_ind: Optional[str] = FieldInfo(alias="maneuverInd", default=None)
    """The manuevering indicator specifying the missile boost phase.

    0 - POST_BOOST_NONE

    1 - POST_BOOST_MANUEVER

    2 - POST_BOOST_COMPLETE_MANUEVER.
    """

    max_freq: Optional[float] = FieldInfo(alias="maxFreq", default=None)
    """Maximum frequency, in hertz, reported for this acoustic track."""

    midb_cat: Optional[str] = FieldInfo(alias="midbCat", default=None)
    """
    The category code that represents the associated facility purpose within the
    target system. This value is the category code in the MIDB (Modernized
    Intelligence Database).
    """

    mil2525_bstr: Optional[str] = FieldInfo(alias="mil2525Bstr", default=None)
    """The MIL-STD-2525B symbology code that applies to the subject of this track."""

    mmsi: Optional[int] = None
    """The Maritime Mobile Service Identity of the vessel.

    MMSI is a nine-digit number that identifies the transmitter station of the
    vessel.
    """

    msg_type: Optional[str] = FieldInfo(alias="msgType", default=None)
    """Optional message type designation."""

    msl_status: Optional[str] = FieldInfo(alias="mslStatus", default=None)
    """
    The status of the missile track in this record, if reporting a missile track
    (e.g. AT LAUNCH, AT OBSERVATION, FLYING, IMPACTED, LOST, STALE, DEBRIS).
    """

    muid_src: Optional[str] = FieldInfo(alias="muidSrc", default=None)
    """Source of the Missile-Unique Identifier (MUID), if reporting a missile track."""

    muid_src_trk: Optional[str] = FieldInfo(alias="muidSrcTrk", default=None)
    """
    Track ID for the source of the Missile-Unique Identifier (MUID), if reporting a
    missile track.
    """

    name: Optional[str] = None
    """Track name."""

    nav_status: Optional[str] = FieldInfo(alias="navStatus", default=None)
    """The AIS Navigational Status of the vessel (e.g.

    Underway Using Engine, Moored, Aground, etc.). Intended as, but not constrained
    to, the USCG NAVCEN navigation status definitions. Users should refer to USCG
    Navigation Center documentation for specific definitions associated with
    navigation status. USCG NAVCEN documentation may be found at
    https://www.navcen.uscg.gov.
    """

    ntds: Optional[str] = None
    """The Naval Tactical Data System (NTDS) track number assigned to this track."""

    num_blades: Optional[int] = FieldInfo(alias="numBlades", default=None)
    """The number of blades per shaft of the track object.

    Applicable for maritime vessels.
    """

    num_shafts: Optional[int] = FieldInfo(alias="numShafts", default=None)
    """The number of shafts on the track object. Applicable for maritime vessels."""

    obj_act: Optional[str] = FieldInfo(alias="objAct", default=None)
    """The activity in which the track object is engaged.

    Intended as, but not constrained to, MIL-STD-6016 environment dependent activity
    designations. The activity can be reported as either a combination of the code
    and environment (e.g. 65/AIR) or as the descriptive enumeration (e.g.
    DIVERTING), which are equivalent. For cases in which no MIl-STD-6016 designation
    exists, a general description can be used (e.g. ANTISPACE WARFARE).
    """

    obj_ident: Optional[Literal["ASSUMED FRIEND", "FRIEND", "HOSTILE", "NEUTRAL", "PENDING", "SUSPECT", "UNKNOWN"]] = (
        FieldInfo(alias="objIdent", default=None)
    )
    """
    The estimated identity of the track object (ASSUMED FRIEND, FRIEND, HOSTILE,
    NEUTRAL, PENDING, SUSPECT, UNKNOWN):

    ASSUMED FRIEND: Track assumed to be a friend due to the object characteristics,
    behavior, and/or origin.

    FRIEND: Track object supporting friendly forces and belonging to a declared
    friendly nation or entity.

    HOSTILE: Track object belonging to an opposing nation, party, group, or entity
    deemed to contribute to a threat to friendly forces or their mission due to its
    behavior, characteristics, nationality, or origin.

    NEUTRAL: Track object whose characteristics, behavior, nationality, and/or
    origin indicate that it is neither supporting nor opposing friendly forces or
    their mission.

    PENDING: Track object which has not been evaluated.

    SUSPECT: Track object deemed potentially hostile due to the object
    characteristics, behavior, nationality, and/or origin.

    UNKNOWN: Track object which has been evaluated and does not meet criteria for
    any standard identity.
    """

    obj_nat: Optional[str] = FieldInfo(alias="objNat", default=None)
    """Nationality of the tracked object."""

    obj_plat: Optional[str] = FieldInfo(alias="objPlat", default=None)
    """
    The object platform type is intended as, but not constrained to, MIL-STD-6016
    environment dependent platform type designations. The platform type can be
    reported as either a combination of the code and environment (e.g. 14/LAND) or
    as the descriptive representations (e.g. COMBAT VEHICLE), which are equivalent.
    For cases in which no MIl-STD-6016 designation exists, a general description can
    be used (e.g. SATELLITE).
    """

    obj_type: Optional[str] = FieldInfo(alias="objType", default=None)
    """
    The generic classification of the track object/group (e.g., BALLISTIC,
    HELICOPTER, TRACKED, WATERCRAFT, WHEELED, etc.). Referenced, but not constrained
    to, NATO STANAG 4676 object type classifications.
    """

    off_pos_ind: Optional[str] = FieldInfo(alias="offPosInd", default=None)
    """Indicator position (OFF, ON, UNK) for optional floating navigational aids only."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_xref: Optional[str] = FieldInfo(alias="origXref", default=None)
    """
    Original source cross-reference code for the Command that originated the report.
    """

    o_suffix: Optional[str] = FieldInfo(alias="oSuffix", default=None)
    """The O-suffix associated with this facility.

    The O-suffix is a five-character alpha/numeric system used to identify a
    facility, or demographic area, within an installation. The Installation Basic
    Encyclopedia (beNumber), in conjunction with the O-suffix, uniquely identifies
    the facility within the Modernized Integrated Database (MIDB). The Installation
    beNumber and oSuffix are also used in conjunction with the midbCat code to
    classify the function or purpose of the facility.
    """

    pif: Optional[str] = None
    """
    The Pseudo Identification Feature (PIF) number is a four digit code that
    provides an exact ID for the ship or aircraft. Friendly military only.
    """

    pin: Optional[str] = None
    """
    This value represents the site number of a specific electronic site or its
    associated equipment.
    """

    polar_sing_loc_lat: Optional[float] = FieldInfo(alias="polarSingLocLat", default=None)
    """WGS-84 azimuth corridor reference point latitude, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    polar_sing_loc_lon: Optional[float] = FieldInfo(alias="polarSingLocLon", default=None)
    """WGS-84 azimuth corridor reference point longitude, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    pos_device_type: Optional[str] = FieldInfo(alias="posDeviceType", default=None)
    """The type of electronic position fixing device (e.g.

    GPS, GLONASS, etc.). Intended as, but not constrained to, the USCG NAVCEN
    electronic position fixing device definitions. Users should refer to USCG
    Navigation Center documentation for specific device type information. USCG
    NAVCEN documentation may be found at https://www.navcen.uscg.gov.
    """

    prf: Optional[float] = None
    """Pulse repetition frequency of the emitter, measured in pulses per second.

    PRF is the number of pulses transmitted per second. This is the reciprocal of
    the pri value.
    """

    pri: Optional[float] = None
    """Pulse repetition interval of the emitter, measured in microseconds.

    The interval between the start of one pulse and the start of another.
    """

    prop_rpm: Optional[float] = FieldInfo(alias="propRPM", default=None)
    """The number of propeller revolutions per minute for a submarine or ship."""

    prop_type: Optional[str] = FieldInfo(alias="propType", default=None)
    """The type of propulsion employed by the track object (Diesel, Nuclear)."""

    pw: Optional[float] = None
    """Pulse width of the emitter, measured in microseconds.

    This is the duration of the pulse.
    """

    reduced: Optional[bool] = None
    """Flag indicating for the track represents a reduced force object or group.

    Based on MIL-STD-2525 symbology definitions.
    """

    reinforced: Optional[bool] = None
    """Flag indicating that this track represents a reinforced object or group.

    Based on MIL-STD-2525 symbology definitions.
    """

    rpt_archived: Optional[bool] = FieldInfo(alias="rptArchived", default=None)
    """Flag indicating whether this track is archived."""

    rpt_chxref: Optional[str] = FieldInfo(alias="rptChxref", default=None)
    """Source cross-reference code for the Command that originated the track report."""

    rtn: Optional[List[str]] = None
    """
    A Reference Track Number used to associate information and directives with the
    track. Referenced, but not constrained to, MIL-STD-6016F Reference Track Number.
    The 'rtnMsgTs' and 'rtn' arrays must match in size.
    """

    rtn_cmd: Optional[str] = FieldInfo(alias="rtnCmd", default=None)
    """The name of the Command reporting the Received Track Number (RTN)."""

    rtn_msg_ts: Optional[List[datetime]] = FieldInfo(alias="rtnMsgTs", default=None)
    """
    The message timestamp that the reference track position was recorded, in ISO
    8601 UTC format with microsecond precision. The 'rtnMsgTs' and 'rtn' arrays must
    match in size.
    """

    rtn_trk_state: Optional[str] = FieldInfo(alias="rtnTrkState", default=None)
    """Value representing the state of the Received Track."""

    scan_rate: Optional[float] = FieldInfo(alias="scanRate", default=None)
    """Scan rate of the emitter, measured in seconds per rotation (SPR)."""

    scan_type: Optional[str] = FieldInfo(alias="scanType", default=None)
    """Type of radar scan."""

    scn: Optional[int] = None
    """The Sequential Contact Number (SCN) for this track."""

    sconum: Optional[str] = None
    """
    The Ship Control Number (SCONUM) is a naval vessel identification number
    (alphanumeric code) assigned by the Office of Naval Intelligence. SCONUM is
    sometimes referred to as NOIC ID. SCONUMs are typically of the form A#####,
    where A is an alpha character and # is numerical.
    """

    self_report: Optional[bool] = FieldInfo(alias="selfReport", default=None)
    """Flag indicating that this track is self reported."""

    sen: Optional[str] = None
    """Id/name of sensor providing the track data."""

    ship_class: Optional[str] = FieldInfo(alias="shipClass", default=None)
    """
    The common name for a group of ships with similar design, usually named for the
    first vessel of the class.
    """

    short_name: Optional[str] = FieldInfo(alias="shortName", default=None)
    """Abbreviated track name."""

    source_uid: Optional[str] = FieldInfo(alias="sourceUid", default=None)
    """The unique identifier of the source node."""

    space_amp: Optional[str] = FieldInfo(alias="spaceAmp", default=None)
    """
    Space amplification indicates additional information on the space environment
    object being reported (e.g. DEBRIS, FUEL-AIR EXPLOSIVE, NUCLEAR WARHEAD).
    """

    space_amp_conf: Optional[int] = FieldInfo(alias="spaceAmpConf", default=None)
    """Confidence level of the amplifying characteristics.

    Values range from 0 to 6, with 0 indicating the lowest confidence and 6
    indicating the highest.
    """

    space_spec_type: Optional[str] = FieldInfo(alias="spaceSpecType", default=None)
    """Specific type of point or track with an environment of space."""

    spd: Optional[float] = None
    """Track object speed, in meters/sec."""

    staff_cmts: Optional[str] = FieldInfo(alias="staffCmts", default=None)
    """
    A text amplifier for units, equipment and installations; content is
    implementation specific.
    """

    stern_type: Optional[str] = FieldInfo(alias="sternType", default=None)
    """The stern type code (Counter, Cruiser) associated with the track object."""

    task_force: Optional[bool] = FieldInfo(alias="taskForce", default=None)
    """Flag indicating that this track represents a task force.

    Based on MIL-STD-2525 symbology definitions.
    """

    tcpa: Optional[datetime] = None
    """
    The time, in ISO 8601 UTC format with millisecond precision, of the closest
    point of approach between this track and the master reference track.
    """

    tes_event_id: Optional[str] = FieldInfo(alias="tesEventId", default=None)
    """Threat Event System Track ID."""

    tol: Optional[float] = None
    """Motion model Time On Leg in hours."""

    tpk: Optional[float] = None
    """The number of turns of the vessel propellers per knot of forward motion."""

    trk_conf: Optional[float] = FieldInfo(alias="trkConf", default=None)
    """
    Overall track confidence estimate (not standardized, but typically a value
    between 0 and 1, with 0 indicating lowest confidence).
    """

    trk_id: Optional[str] = FieldInfo(alias="trkId", default=None)
    """
    UUID identifying the track, which should remain the same on subsequent tracks of
    the same object.
    """

    trk_num: Optional[str] = FieldInfo(alias="trkNum", default=None)
    """The track number (TN) of a surveillance entity.

    Intended as, but not constrained to, the J-series track number encoded as five
    character alpha-numeric characters. Users should refer to J-series documentation
    for specific TN definitions.
    """

    trk_qual: Optional[int] = FieldInfo(alias="trkQual", default=None)
    """Track Quality is reported as an integer from 0-15.

    Track Quality specifies the reliability of the positional information of a
    reported track; Higher values indicate higher track quality, i.e., lower errors
    in reported position.
    """

    trk_scope: Optional[str] = FieldInfo(alias="trkScope", default=None)
    """
    Value Indicating the scope of this track: 1 - TERMINAL (Terminal) - available
    only on the workstation where they were created. 2 - LOCAL (Local) - available
    only on workstations in the local area network 3 - OTH (Over the Horizon) -
    available to everyone.
    """

    trnspdr_id: Optional[str] = FieldInfo(alias="trnspdrId", default=None)
    """Transponder ID for the track.

    This does not correspond to the UDL transponder schema.
    """

    trnspdr_type: Optional[str] = FieldInfo(alias="trnspdrType", default=None)
    """Transponder type for the track."""

    vsl_wt: Optional[float] = FieldInfo(alias="vslWt", default=None)
    """The weight, in tons, of the vessel associated with this track."""

    width: Optional[float] = None
    """The breadth of the vessel, in meters.

    A value of 63 indicates a vessel breadth of 63 meters or greater.
    """
