# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TransponderCreateParams"]


class TransponderCreateParams(TypedDict, total=False):
    classification_marking: Required[Annotated[str, PropertyInfo(alias="classificationMarking")]]
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Required[Annotated[Literal["REAL", "TEST", "SIMULATED", "EXERCISE"], PropertyInfo(alias="dataMode")]]
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_comm: Required[Annotated[str, PropertyInfo(alias="idComm")]]
    """ID of the parent Comm object for this transponder."""

    source: Required[str]
    """Source of the data."""

    id: str
    """Unique identifier of the record, auto-generated by the system."""

    fec: int
    """Forward error correction, e.g.

    0=Auto, 1 = 1/2, 2 = 2/3, 3 = 3/4, 4 = 5/6, 5 = 7/8, 6 = 8/9, 7 = 3/5, 8 = 4/5,
    9 = 9/10, 15 = None.
    """

    format: str
    """Format."""

    modulation: str
    """Transponder modulation, e.g. Auto, QPSK, 8PSK."""

    name: str
    """Optional name of the transponder."""

    nid: str
    """Optional external network id as provided data source."""

    origin: str
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    symbol_rate: Annotated[float, PropertyInfo(alias="symbolRate")]
    """
    Symbol rate is the number of symbol changes, waveform changes, or signaling
    events, across the transmission medium per time unit using a digitally modulated
    signal or a line code. Also measured in Hz.
    """

    system: str
    """Transponder system, e.g. DVB-S, DVB-S2."""

    tid: str
    """Optional external transponder id as provided data source."""

    ttf: float
    """Transponder Translation Factor.

    This is the frequency difference between the uplink received by a satellite, and
    the downlink transmitted back. It varies satellite to satellite dependent on the
    mission.
    """
