# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ItemTrackingFull"]


class ItemTrackingFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    scan_code: str = FieldInfo(alias="scanCode")
    """The tracking identifier of an item or person.

    May be similar in representation of a barcode or UPC.
    """

    scanner_id: str = FieldInfo(alias="scannerId")
    """The ID of the scanner or input device."""

    source: str
    """Source of the data."""

    ts: datetime
    """The timestamp of the scan, in ISO 8601 UTC format with millisecond precision."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    dv_code: Optional[str] = FieldInfo(alias="dvCode", default=None)
    """
    The United States distinguished visitor code of the person scanned, only
    applicable to people.
    """

    id_item: Optional[str] = FieldInfo(alias="idItem", default=None)
    """The UDL ID of the item this record is associated with."""

    keys: Optional[List[str]] = None
    """Array of keys that may be associated with this tracked item."""

    lat: Optional[float] = None
    """WGS84 latitude where the item was scanned, in degrees."""

    lon: Optional[float] = None
    """WGS84 longitude where the item was scanned, in degrees."""

    notes: Optional[str] = None
    """Optional notes or comments about the tracking data."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    scan_type: Optional[str] = FieldInfo(alias="scanType", default=None)
    """The type of scan for tracking the item within it's journey (e.g.

    IN, OUT, RECEIVED, DELIVERED, TRANSIT, ABANDONDED, REFUSED, UNABLE, RETURNED,
    HELD, OTHER). For example, received and delivered are for when an item is
    received from or delivered to the end customer. In and out are for stops in
    between such as being loaded on an airplane or received at a warehouse.
    """

    sc_gen_tool: Optional[str] = FieldInfo(alias="scGenTool", default=None)
    """The algorithm name or standard that generated the scanCode (e.g.

    UPC-A, EAN-13, GTIN, SSCC, bID, JAN, etc.).
    """

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    type: Optional[str] = None
    """The type of item that is being scanned (e.g.

    CARGO, PERSON, MAIL, MICAP, OTHER).
    """

    values: Optional[List[str]] = None
    """Array of values for the keys that may be associated to this tracked item.

    The entries in this array must correspond to the position index in the keys
    array. This array must be the same length as keys.
    """
