# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel
from ...shared.onorbit_full import OnorbitFull

__all__ = ["RfobservationdetailsFull"]


class RfobservationdetailsFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    ob_time: datetime = FieldInfo(alias="obTime")
    """Ob detection time in ISO 8601 UTC with microsecond precision."""

    source: str
    """Source of the data."""

    type: str
    """Type of RF ob (e.g. RF, RF-SOSI, PSD, RFI, SPOOF, etc)."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    antenna_name: Optional[str] = FieldInfo(alias="antennaName", default=None)
    """Antenna name of the RFObservation record."""

    azimuth: Optional[float] = None
    """azimuth angle in degrees and J2000 coordinate frame."""

    azimuth_measured: Optional[bool] = FieldInfo(alias="azimuthMeasured", default=None)
    """
    Optional flag indicating whether the azimuth value is measured (true) or
    computed (false). If null, consumers may consult the data provider for
    information regarding whether the corresponding value is computed or measured.
    """

    azimuth_rate: Optional[float] = FieldInfo(alias="azimuthRate", default=None)
    """Rate of change of the azimuth in degrees per second."""

    azimuth_unc: Optional[float] = FieldInfo(alias="azimuthUnc", default=None)
    """One sigma uncertainty in the azimuth angle measurement, in degrees."""

    bandwidth: Optional[float] = None
    """Measured bandwidth in Hz."""

    baud_rate: Optional[float] = FieldInfo(alias="baudRate", default=None)
    """
    Baud rate is the number of symbol changes, waveform changes, or signaling
    events, across the transmission medium per second.
    """

    baud_rates: Optional[List[float]] = FieldInfo(alias="baudRates", default=None)
    """Array of measured signal baud rates."""

    bit_error_rate: Optional[float] = FieldInfo(alias="bitErrorRate", default=None)
    """The ratio of bit errors per number of received bits."""

    carrier_standard: Optional[str] = FieldInfo(alias="carrierStandard", default=None)
    """Carrier standard (e.g. DVB-S2, 802.11g, etc.)."""

    channel: Optional[int] = None
    """Channel of the RFObservation record."""

    chip_rates: Optional[List[float]] = FieldInfo(alias="chipRates", default=None)
    """Array of chipRates."""

    code_fills: Optional[List[str]] = FieldInfo(alias="codeFills", default=None)
    """Array of code fills."""

    code_lengths: Optional[List[float]] = FieldInfo(alias="codeLengths", default=None)
    """Array of code lengths."""

    code_taps: Optional[List[str]] = FieldInfo(alias="codeTaps", default=None)
    """Array of code taps."""

    collection_mode: Optional[str] = FieldInfo(alias="collectionMode", default=None)
    """Collection mode (e.g.

    SURVEY, SPOT_SEARCH, NEIGHBORHOOD_WATCH, DIRECTED_SEARCH, MANUAL, etc).
    """

    confidence: Optional[float] = None
    """Confidence in the signal and its measurements and characterization."""

    confidences: Optional[List[float]] = None
    """Array of measurement confidences."""

    constellation_x_points: Optional[List[float]] = FieldInfo(alias="constellationXPoints", default=None)
    """Array of individual x-coordinates for demodulated signal constellation.

    This array should correspond with the same-sized array of constellationYPoints.
    """

    constellation_y_points: Optional[List[float]] = FieldInfo(alias="constellationYPoints", default=None)
    """Array of individual y-coordinates for demodulated signal constellation.

    This array should correspond with the same-sized array of constellationXPoints.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    descriptor: Optional[str] = None
    """Optional source-provided and searchable metadata or descriptor of the data."""

    detection_status: Optional[str] = FieldInfo(alias="detectionStatus", default=None)
    """Detection status (e.g.

    DETECTED, CARRIER_ACQUIRING, CARRIER_DETECTED, NOT_DETECTED, etc).
    """

    detection_statuses: Optional[List[str]] = FieldInfo(alias="detectionStatuses", default=None)
    """Array of detection statuses (e.g.

    DETECTED, CARRIER_DETECTED, NOT_DETECTED) for each measured signal.
    """

    eirp: Optional[float] = None
    """Measured Equivalent Isotopically Radiated Power in dBW."""

    elevation: Optional[float] = None
    """elevation in degrees and J2000 coordinate frame."""

    elevation_measured: Optional[bool] = FieldInfo(alias="elevationMeasured", default=None)
    """
    Optional flag indicating whether the elevation value is measured (true) or
    computed (false). If null, consumers may consult the data provider for
    information regarding whether the corresponding value is computed or measured.
    """

    elevation_rate: Optional[float] = FieldInfo(alias="elevationRate", default=None)
    """Rate of change of the elevation in degrees per second."""

    elevation_unc: Optional[float] = FieldInfo(alias="elevationUnc", default=None)
    """One sigma uncertainty in the elevation angle measurement, in degrees."""

    elnot: Optional[str] = None
    """ELINT notation."""

    end_frequency: Optional[float] = FieldInfo(alias="endFrequency", default=None)
    """End carrier frequency in Hz."""

    frequencies: Optional[List[float]] = None
    """Array of individual PSD frequencies of the signal in Hz.

    This array should correspond with the same-sized array of powers.
    """

    frequency: Optional[float] = None
    """Center carrier frequency in Hz."""

    frequency_shift: Optional[float] = FieldInfo(alias="frequencyShift", default=None)
    """Frequency Shift of the RFObservation record."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Unique identifier of the target on-orbit object, if correlated."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the reporting sensor."""

    incoming: Optional[bool] = None
    """True if the signal is incoming, false if outgoing."""

    inner_coding_rate: Optional[int] = FieldInfo(alias="innerCodingRate", default=None)
    """
    Inner forward error correction rate: 0 = Auto, 1 = 1/2, 2 = 2/3, 3 = 3/4, 4 =
    5/6, 5 = 7/8, 6 = 8/9, 7 = 3/5, 8 = 4/5, 9 = 9/10, 15 = None.
    """

    max_psd: Optional[float] = FieldInfo(alias="maxPSD", default=None)
    """Maximum measured PSD value of the trace in dBW."""

    min_psd: Optional[float] = FieldInfo(alias="minPSD", default=None)
    """Minimum measured PSD value of the trace in dBW."""

    modulation: Optional[str] = None
    """Transponder modulation (e.g. Auto, QPSK, 8PSK, etc)."""

    noise_pwr_density: Optional[float] = FieldInfo(alias="noisePwrDensity", default=None)
    """Noise power density, in dBW-Hz."""

    nominal_bandwidth: Optional[float] = FieldInfo(alias="nominalBandwidth", default=None)
    """Expected bandwidth in Hz."""

    nominal_eirp: Optional[float] = FieldInfo(alias="nominalEirp", default=None)
    """Expected Equivalent Isotopically Radiated Power in dBW."""

    nominal_frequency: Optional[float] = FieldInfo(alias="nominalFrequency", default=None)
    """Nominal or expected center carrier frequency in Hz."""

    nominal_power_over_noise: Optional[float] = FieldInfo(alias="nominalPowerOverNoise", default=None)
    """Expected carrier power over noise (dBW/Hz)."""

    nominal_snr: Optional[float] = FieldInfo(alias="nominalSnr", default=None)
    """Nominal or expected signal to noise ratio, in dB."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by observation source to indicate the target
    onorbit object of this observation. This may be an internal identifier and not
    necessarily a valid satellite number.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by observation source to indicate the sensor
    identifier which produced this observation. This may be an internal identifier
    and not necessarily a valid sensor ID.
    """

    outer_coding_rate: Optional[int] = FieldInfo(alias="outerCodingRate", default=None)
    """
    Outer forward error correction rate: 0 = Auto, 1 = 1/2, 2 = 2/3, 3 = 3/4, 4 =
    5/6, 5 = 7/8, 6 = 8/9, 7 = 3/5, 8 = 4/5, 9 = 9/10, 15 = None.
    """

    peak: Optional[bool] = None
    """Peak of the RFObservation record."""

    pgri: Optional[float] = None
    """
    A pulse group repetition interval (PGRI) is a pulse train in which there are
    groups of closely spaced pulses separated by much longer times between these
    pulse groups.
    """

    pn_orders: Optional[List[int]] = FieldInfo(alias="pnOrders", default=None)
    """Array of pnOrder."""

    polarity: Optional[float] = None
    """The antenna pointing dependent polarizer angle, in degrees."""

    polarity_type: Optional[Literal["H", "V", "R", "L"]] = FieldInfo(alias="polarityType", default=None)
    """Transponder polarization e.g.

    H - (Horizontally Polarized) Perpendicular to Earth's surface, V - (Vertically
    Polarized) Parallel to Earth's surface, L - (Left Hand Circularly Polarized)
    Rotating left relative to the earth's surface, R - (Right Hand Circularly
    Polarized) Rotating right relative to the earth's surface.
    """

    power_over_noise: Optional[float] = FieldInfo(alias="powerOverNoise", default=None)
    """Measured carrier power over noise (dBW/Hz)."""

    powers: Optional[List[float]] = None
    """Array of individual measured PSD powers of the signal in dBW.

    This array should correspond with the same-sized array of frequencies.
    """

    range: Optional[float] = None
    """Target range in km."""

    range_measured: Optional[bool] = FieldInfo(alias="rangeMeasured", default=None)
    """
    Optional flag indicating whether the range value is measured (true) or computed
    (false). If null, consumers may consult the data provider for information
    regarding whether the corresponding value is computed or measured.
    """

    range_rate: Optional[float] = FieldInfo(alias="rangeRate", default=None)
    """Rate of change of the range in km/sec."""

    range_rate_measured: Optional[bool] = FieldInfo(alias="rangeRateMeasured", default=None)
    """
    Optional flag indicating whether the rangeRate value is measured (true) or
    computed (false). If null, consumers may consult the data provider for
    information regarding whether the corresponding value is computed or measured.
    """

    range_rate_unc: Optional[float] = FieldInfo(alias="rangeRateUnc", default=None)
    """One sigma uncertainty in the range rate measurement, in kilometers/second."""

    range_unc: Optional[float] = FieldInfo(alias="rangeUnc", default=None)
    """One sigma uncertainty in the range measurement, in kilometers."""

    raw_file_uri: Optional[str] = FieldInfo(alias="rawFileURI", default=None)
    """
    Optional URI location in the document repository of the raw file parsed by the
    system to produce this record. To download the raw file, prepend
    https://udl-hostname/scs/download?id= to this value.
    """

    reference_level: Optional[float] = FieldInfo(alias="referenceLevel", default=None)
    """Reference signal level, in dBW."""

    relative_carrier_power: Optional[float] = FieldInfo(alias="relativeCarrierPower", default=None)
    """Measured power of the center carrier frequency in dBW."""

    relative_noise_floor: Optional[float] = FieldInfo(alias="relativeNoiseFloor", default=None)
    """
    The measure of the signal created from the sum of all the noise sources and
    unwanted signals within the measurement system, in dBW.
    """

    resolution_bandwidth: Optional[float] = FieldInfo(alias="resolutionBandwidth", default=None)
    """Resolution bandwidth in Hz."""

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Satellite/Catalog number of the target on-orbit object."""

    senalt: Optional[float] = None
    """Sensor altitude at obTime (if mobile/onorbit) in km.

    If null, can be obtained from sensor info.
    """

    senlat: Optional[float] = None
    """Sensor WGS84 latitude at obTime (if mobile/onorbit) in degrees.

    If null, can be obtained from sensor info. -90 to 90 degrees (negative values
    south of equator).
    """

    senlon: Optional[float] = None
    """Sensor WGS84 longitude at obTime (if mobile/onorbit) in degrees.

    If null, can be obtained from sensor info. -180 to 180 degrees (negative values
    west of Prime Meridian).
    """

    signal_ids: Optional[List[str]] = FieldInfo(alias="signalIds", default=None)
    """Array of optional source provided identifiers of the measurements/signals."""

    snr: Optional[float] = None
    """Signal to noise ratio, in dB."""

    snrs: Optional[List[float]] = None
    """Array of signal to noise ratios of the signals, in dB."""

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    spectrum_analyzer_power: Optional[float] = FieldInfo(alias="spectrumAnalyzerPower", default=None)
    """Measured spectrum analyzer power of the center carrier frequency in dBW."""

    start_frequency: Optional[float] = FieldInfo(alias="startFrequency", default=None)
    """Start carrier frequency in Hz."""

    switch_point: Optional[int] = FieldInfo(alias="switchPoint", default=None)
    """Switch Point of the RFObservation record."""

    symbol_to_noise_ratio: Optional[float] = FieldInfo(alias="symbolToNoiseRatio", default=None)
    """Symbol to noise ratio, in dB."""

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    task_id: Optional[str] = FieldInfo(alias="taskId", default=None)
    """
    Optional identifier to indicate the specific tasking which produced this
    observation.
    """

    telemetry_ids: Optional[List[str]] = FieldInfo(alias="telemetryIds", default=None)
    """
    Array of optional source provided telemetry identifiers of the
    measurements/signals.
    """

    track_id: Optional[str] = FieldInfo(alias="trackId", default=None)
    """Optional identifier of the track to which this observation belongs."""

    track_range: Optional[float] = FieldInfo(alias="trackRange", default=None)
    """Target track or apparent range in km."""

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """

    transmit_filter_roll_off: Optional[float] = FieldInfo(alias="transmitFilterRollOff", default=None)
    """Transmit pulse shaping filter roll-off value."""

    transmit_filter_type: Optional[str] = FieldInfo(alias="transmitFilterType", default=None)
    """Transmit pulse shaping filter typ (e.g. RRC)."""

    transponder: Optional[str] = None
    """
    Optional identifier provided by observation source to indicate the transponder
    used for this measurement.
    """

    uct: Optional[bool] = None
    """
    Boolean indicating this observation is part of an uncorrelated track or was
    unable to be correlated to a known object. This flag should only be set to true
    by data providers after an attempt to correlate to an on-orbit object was made
    and failed. If unable to correlate, the 'origObjectId' field may be populated
    with an internal data provider specific identifier.
    """

    url: Optional[str] = None
    """Optional URL containing additional information on this observation."""

    video_bandwidth: Optional[float] = FieldInfo(alias="videoBandwidth", default=None)
    """Video bandwidth in Hz."""
