# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SensormaintenanceFull"]


class SensormaintenanceFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    end_time: datetime = FieldInfo(alias="endTime")
    """The planned outage end time in ISO8601 UTC format."""

    site_code: str = FieldInfo(alias="siteCode")
    """The site to which this item applies.

    NOTE - this site code is COLT specific and may not identically correspond to
    other UDL site IDs.
    """

    source: str
    """Source of the data."""

    start_time: datetime = FieldInfo(alias="startTime")
    """The planned outage start time in ISO8601 UTC format."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    activity: Optional[str] = None
    """Description of the activity taking place during this outage."""

    approver: Optional[str] = None
    """The name of the approver."""

    changer: Optional[str] = None
    """The name of the changer, if applicable."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    duration: Optional[str] = None
    """The duration of the planned outage, expressed as ddd:hh:mm."""

    eow_id: Optional[str] = FieldInfo(alias="eowId", default=None)
    """COLT EOWID."""

    equip_status: Optional[str] = FieldInfo(alias="equipStatus", default=None)
    """The mission capability status of the equipment (e.g. FMC, NMC, PMC, UNK, etc.)."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """UUID of the sensor."""

    impacted_faces: Optional[str] = FieldInfo(alias="impactedFaces", default=None)
    """The sensor face(s) to which this COLT maintenance item applies, if applicable."""

    inactive_date: Optional[datetime] = FieldInfo(alias="inactiveDate", default=None)
    """The date that this item became inactive in ISO8601 UTC format."""

    line_number: Optional[str] = FieldInfo(alias="lineNumber", default=None)
    """The internal COLT line number assigned to this item."""

    md_ops_cap: Optional[str] = FieldInfo(alias="mdOpsCap", default=None)
    """The Missile Defense operational capability of this maintenance item.

    Typical values are G, Y, R, and - for non-applicable sites.
    """

    mw_ops_cap: Optional[str] = FieldInfo(alias="mwOpsCap", default=None)
    """The Missile Warning operational capability of this maintenance item.

    Typical values are G, Y, R, and - for non-applicable sites.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    priority: Optional[str] = None
    """The priority of this maintenance item."""

    recall: Optional[str] = None
    """The minimum time required to recall this activity, expressed as ddd:hh:mm."""

    rel: Optional[str] = None
    """Release."""

    remark: Optional[str] = None
    """Remarks concerning this outage."""

    requestor: Optional[str] = None
    """The name of the requestor."""

    resource: Optional[str] = None
    """The name of the resource(s) affected by this maintenance item."""

    rev: Optional[str] = None
    """The revision number for this maintenance item."""

    ss_ops_cap: Optional[str] = FieldInfo(alias="ssOpsCap", default=None)
    """The Space Surveillance operational capability of this maintenance item.

    Typical values are G, Y, R, and - for non-applicable sites.
    """

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was last updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """
