# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SitestatusFull"]


class SitestatusFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_site: str = FieldInfo(alias="idSite")
    """The ID of the site, if this status is associated with a fixed site or platform."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    cat: Optional[Literal["COLD", "WARM", "HOT"]] = None
    """Crisis Action Team (CAT).

    COLD - Not in use.

    WARM - Facility prepped/possible skeleton crew.

    HOT - Fully active.
    """

    cold_inventory: Optional[int] = FieldInfo(alias="coldInventory", default=None)
    """
    Estimated number of cold missiles of all types remaining in weapons system
    inventory.
    """

    comm_impairment: Optional[str] = FieldInfo(alias="commImpairment", default=None)
    """
    The communications component causing the platform or system to be less than
    fully operational.
    """

    cpcon: Optional[Literal["1", "2", "3", "4", "5"]] = None
    """Cyberspace Protection Condition (CPCON).

    1 - VERY HIGH - Critical functions.

    2 - HIGH - Critical and essential functions.

    3 - MEDIUM - Critical, essential, and support functions.

    4 - LOW - All functions.

    5 - VERY LOW - All functions.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    eoc: Optional[Literal["COLD", "WARM", "HOT"]] = None
    """Emergency Operations Center (EOC) status.

    COLD - Not in use.

    WARM - Facility prepped/possible skeleton crew.

    HOT - Fully active.
    """

    fpcon: Optional[Literal["NORMAL", "ALPHA", "BRAVO", "CHARLIE", "DELTA"]] = None
    """Force Protection Condition (FPCON).

    NORMAL - Applies when a general global threat of possible terrorist activity
    exists and warrants a routine security posture.

    ALPHA - Applies when an increased general threat of possible terrorist activity
    against personnel or facilities. Nature and extent of threat are unpredictable.

    BRAVO - Applies when an increased or predictable threat of terrorist activity
    exists.

    CHARLIE - Applies when an incident occurs or intelligence is received indicating
    some form of terrorist action against personnel and facilities is imminent.

    DELTA - Applies in the immediate area where an attack has occurred or when
    intelligence is received indicating terrorist action against a location is
    imminent.
    """

    hot_inventory: Optional[int] = FieldInfo(alias="hotInventory", default=None)
    """
    Estimated number of hot missiles of all types remaining in weapons system
    inventory.
    """

    hpcon: Optional[Literal["0", "ALPHA", "BRAVO", "CHARLIE", "DELTA"]] = None
    """Health Protection Condition (HPCON).

    0 - Routine, no community transmission.

    ALPHA - Limited, community transmission beginning.

    BRAVO - Moderate, increased community transmission.

    CHARLIE - Substantial, sustained community transmission.

    DELTA - Severe, widespread community transmission.
    """

    inst_status: Optional[Literal["FMC", "PMC", "NMC", "UNK"]] = FieldInfo(alias="instStatus", default=None)
    """The status of the installation.

    FMC - Fully Mission Capable

    PMC - Partially Mission Capable

    NMC - Non Mission Capable

    UNK - Unknown.
    """

    link: Optional[List[str]] = None
    """
    Array of Link item(s) for which status is available and reported (ATDL, IJMS,
    LINK-1, LINK-11, LINK-11B, LINK-16). This array must be the same length as the
    linkStatus array.
    """

    link_status: Optional[List[str]] = FieldInfo(alias="linkStatus", default=None)
    """
    Array of the status (AVAILABLE, DEGRADED, NOT AVAILABLE, etc.) for each links in
    the link array. This array must be the same length as the link array, and the
    status must correspond to the appropriate position index in the link array.
    """

    missile: Optional[List[str]] = None
    """
    Array of specific missile types for which an estimated inventory count is
    available (e.g. GMD TYPE A, HARPOON, TOMAHAWK, etc.). This array must be the
    same length as the missileInventory array.
    """

    missile_inventory: Optional[List[int]] = FieldInfo(alias="missileInventory", default=None)
    """Array of the quantity of each of the missile items.

    This array must be the same length as the missile array, and the values must
    correspond to appropriate position index in the missile array.
    """

    mobile_alt_id: Optional[str] = FieldInfo(alias="mobileAltId", default=None)
    """Alternate Identifier for a mobile or transportable platform provided by source."""

    ops_capability: Optional[str] = FieldInfo(alias="opsCapability", default=None)
    """The operational status of the platform (e.g.

    Fully Operational, Partially Operational, Not Operational, etc.).
    """

    ops_impairment: Optional[str] = FieldInfo(alias="opsImpairment", default=None)
    """
    The primary component degrading the operational capability of the platform or
    system.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    pes: Optional[bool] = None
    """
    Position Engagement Status flag, Indicating whether this platform is initiating
    multiple simultaneous engagements. A value of 1/True indicates the platform is
    initiating multiple simultaneous engagements.
    """

    poiid: Optional[str] = None
    """The POI (point of interest) ID related to this platform, if available."""

    radar_status: Optional[List[str]] = FieldInfo(alias="radarStatus", default=None)
    """
    Array of the status (NON-OPERATIONAL, OPERATIONAL, OFF) for each radar system in
    the radarSystem array. This array must be the same length as the radarSystem
    array, and the status must correspond to the appropriate position index in the
    radarSystem array.
    """

    radar_system: Optional[List[str]] = FieldInfo(alias="radarSystem", default=None)
    """
    Array of radar system(s) for which status is available and reported
    (ACQUISITION, IFFSIF, ILLUMINATING, MODE-4, PRIMARY SURVEILLANCE, SECONDARY
    SURVEILLANCE, TERTIARY SURVEILLANCE). This array must be the same length as the
    radarStatus array.
    """

    radiate_mode: Optional[str] = FieldInfo(alias="radiateMode", default=None)
    """SAM sensor radar surveillance mode (Active, Passive, Off)."""

    report_time: Optional[datetime] = FieldInfo(alias="reportTime", default=None)
    """Time of report, in ISO8601 UTC format."""

    sam_mode: Optional[str] = FieldInfo(alias="samMode", default=None)
    """The state of a SAM unit (e.g. Initialization, Standby, Reorientation, etc.)."""

    site_type: Optional[str] = FieldInfo(alias="siteType", default=None)
    """Optional site type or further detail of type.

    Intended for, but not limited to, Link-16 site type specifications (e.g. ADOC,
    GACC, SOC, TACC, etc.).
    """

    time_function: Optional[str] = FieldInfo(alias="timeFunction", default=None)
    """Description of the time function associated with the reportTime (e.g.

    Activation, Deactivation, Arrival, Departure, etc.), if applicable.
    """

    track_id: Optional[str] = FieldInfo(alias="trackId", default=None)
    """
    The track ID related to this platform (if mobile or transportable), if
    available.
    """

    track_ref_l16: Optional[str] = FieldInfo(alias="trackRefL16", default=None)
    """Link-16 specific reference track number."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Time the row was updated in the database, auto-populated by the system."""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who updated the row in the database, auto-populated by the
    system.
    """

    weather_message: Optional[str] = FieldInfo(alias="weatherMessage", default=None)
    """Description of the current weather conditions over a site."""
