# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel
from ...shared.onorbit_full import OnorbitFull
from ...eo_observations.eo_observation_full import EoObservationFull

__all__ = ["SkyimageryFull"]


class SkyimageryFull(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    exp_start_time: datetime = FieldInfo(alias="expStartTime")
    """Start time of the exposure, in ISO 8601 UTC format with microsecond precision."""

    image_type: str = FieldInfo(alias="imageType")
    """The type of image associated with this record (e.g. FITS, EOSSA, EOCHIP, MP4)."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    annotation_key: Optional[str] = FieldInfo(alias="annotationKey", default=None)
    """Reference to an annotation document associated with this image."""

    calibration_key: Optional[str] = FieldInfo(alias="calibrationKey", default=None)
    """Reference to a calibration document associated with this image."""

    checksum_value: Optional[str] = FieldInfo(alias="checksumValue", default=None)
    """MD5 value of the file.

    The ingest/create operation will automatically generate the value.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    description: Optional[str] = None
    """Optional name/description associated with this image."""

    eo_observations: Optional[List[EoObservationFull]] = FieldInfo(alias="eoObservations", default=None)
    """Collection of linked EOObservations."""

    exp_end_time: Optional[datetime] = FieldInfo(alias="expEndTime", default=None)
    """End time of the exposure, in ISO 8601 UTC format with microsecond precision."""

    filename: Optional[str] = None
    """Name of the uploaded image file."""

    filesize: Optional[int] = None
    """Size of the image file, in bytes."""

    frame_fov_height: Optional[float] = FieldInfo(alias="frameFOVHeight", default=None)
    """Field Of View frame height, in degrees."""

    frame_fov_width: Optional[float] = FieldInfo(alias="frameFOVWidth", default=None)
    """Field Of View frame width, in degrees."""

    frame_height_pixels: Optional[int] = FieldInfo(alias="frameHeightPixels", default=None)
    """Frame height of the image, in number of pixels."""

    frame_width_pixels: Optional[int] = FieldInfo(alias="frameWidthPixels", default=None)
    """Frame width of the image, in number of pixels."""

    id_attitude_set: Optional[str] = FieldInfo(alias="idAttitudeSet", default=None)
    """
    Optional identifier of the AttitudeSet data record describing the orientation of
    an object body.
    """

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Optional identifier of the target on-orbit object, if correlated."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the reporting sensor."""

    id_soi_set: Optional[str] = FieldInfo(alias="idSOISet", default=None)
    """
    Optional unique identifier of the SOI Observation Set associated with this
    image.
    """

    image_set_id: Optional[str] = FieldInfo(alias="imageSetId", default=None)
    """The user-defined set ID of a sequence of images."""

    image_set_length: Optional[int] = FieldInfo(alias="imageSetLength", default=None)
    """The number of images in an image set."""

    image_source_info: Optional[str] = FieldInfo(alias="imageSourceInfo", default=None)
    """String that uniquely identifies the data source."""

    on_orbit: Optional[OnorbitFull] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    orig_object_id: Optional[str] = FieldInfo(alias="origObjectId", default=None)
    """
    Optional identifier provided by the imaging source to indicate the target
    onorbit object of this image. This may be an internal identifier and not
    necessarily a valid satellite number.
    """

    orig_sensor_id: Optional[str] = FieldInfo(alias="origSensorId", default=None)
    """
    Optional identifier provided by the imaging source to indicate the sensor
    identifier which produced this image. This may be an internal identifier and not
    necessarily a valid sensor ID.
    """

    pixel_bit_depth: Optional[int] = FieldInfo(alias="pixelBitDepth", default=None)
    """Bit depth of the image, in number of pixels."""

    pixel_fov_height: Optional[float] = FieldInfo(alias="pixelFOVHeight", default=None)
    """Field Of View pixel height, in degrees."""

    pixel_fov_width: Optional[float] = FieldInfo(alias="pixelFOVWidth", default=None)
    """Field Of View pixel width, in degrees."""

    sat_no: Optional[int] = FieldInfo(alias="satNo", default=None)
    """Catalog number of the target on-orbit object."""

    senalt: Optional[float] = None
    """Sensor altitude at exposure start epoch, in km.

    If null, can be obtained from sensor info.
    """

    senlat: Optional[float] = None
    """Sensor latitude at exposure start epoch, in degrees.

    If null, can be obtained from sensor info. -90 to 90 degrees (negative values
    south of equator).
    """

    senlon: Optional[float] = None
    """Sensor longitude at exposure start epoch, in degrees.

    If null, can be obtained from sensor info. -180 to 180 degrees (negative values
    west of Prime Meridian).
    """

    sen_quat: Optional[List[float]] = FieldInfo(alias="senQuat", default=None)
    """
    The quaternion describing the rotation of the body-fixed frame used for this
    system into the local geodetic frame, at exposure start epoch (expStartTime).
    The array element order convention is scalar component first, followed by the
    three vector components. For a vector u in the body-fixed frame, the
    corresponding vector u' in the geodetic frame should satisfy u' = quq\\**, where q
    is this quaternion.
    """

    sen_quat_dot: Optional[List[float]] = FieldInfo(alias="senQuatDot", default=None)
    """
    The derivative of the quaternion describing the rotation of the body-fixed frame
    used for this system into the local geodetic frame, exposure start epoch
    (expStartTime). The array element order convention is scalar component first,
    followed by the three vector components. For a vector u in the body-fixed frame,
    the corresponding vector u' in the geodetic frame should satisfy u' = quq\\**,
    where q is this quaternion.
    """

    senx: Optional[float] = None
    """
    Sensor x position at exposure start epoch, in km (if mobile/onorbit) in J2000
    coordinate frame.
    """

    seny: Optional[float] = None
    """
    Sensor y position at exposure start epoch, in km (if mobile/onorbit) in J2000
    coordinate frame.
    """

    senz: Optional[float] = None
    """
    Sensor z position at exposure start epoch, in km (if mobile/onorbit) in J2000
    coordinate frame.
    """

    sequence_id: Optional[int] = FieldInfo(alias="sequenceId", default=None)
    """The sequence ID of an image within an image set."""

    source_dl: Optional[str] = FieldInfo(alias="sourceDL", default=None)
    """The source data library from which this record was received.

    This could be a remote or tactical UDL or another data library. If null, the
    record should be assumed to have originated from the primary Enterprise UDL.
    """

    tags: Optional[List[str]] = None
    """
    Optional array of provider/source specific tags for this data, where each
    element is no longer than 32 characters, used for implementing data owner
    conditional access controls to restrict access to the data. Should be left null
    by data providers unless conditional access controls are coordinated with the
    UDL team.
    """

    top_left_start_az: Optional[float] = FieldInfo(alias="topLeftStartAz", default=None)
    """The telescope pointing azimuth, in degrees, at the exposure start epoch."""

    top_left_start_el: Optional[float] = FieldInfo(alias="topLeftStartEl", default=None)
    """The telescope pointing elevation, in degrees, at the exposure start epoch."""

    top_left_stop_az: Optional[float] = FieldInfo(alias="topLeftStopAz", default=None)
    """The telescope pointing azimuth, in degrees, at the exposure stop epoch."""

    top_left_stop_el: Optional[float] = FieldInfo(alias="topLeftStopEl", default=None)
    """The telescope pointing elevation, in degrees, at the exposure stop epoch."""

    transaction_id: Optional[str] = FieldInfo(alias="transactionId", default=None)
    """
    Optional identifier to track a commercial or marketplace transaction executed to
    produce this data.
    """
