# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["VideoGetStreamFileResponse"]


class VideoGetStreamFileResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    description: str
    """Description/notes associated with the video stream."""

    name: str
    """Name of the video stream."""

    source: str
    """Source of the data."""

    token_value: str = FieldInfo(alias="tokenValue")
    """Video Publisher Token."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    origin: Optional[str] = None

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    start_time: Optional[datetime] = FieldInfo(alias="startTime", default=None)
    """The timestamp when the stream is available from. The unit is ISO 8601 format."""

    stop_time: Optional[datetime] = FieldInfo(alias="stopTime", default=None)
    """The timestamp when the stream is available until. The unit is ISO 8601 format."""

    video_urls: Optional[List[str]] = FieldInfo(alias="videoUrls", default=None)
    """Video Streaming Support URLs."""
